\qt@newcmd\qurantrans@en@i{%
In the Name of Allah, the Merciful, the Most Merciful\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ii{%
Praise be to Allah, Lord of the Worlds,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@iii{%
the Merciful, the Most Merciful,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@iv{%
Owner of the Day of Recompense.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@v{%
You (alone) we worship; and You (alone) we rely for help.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@vi{%
Guide us to the Straight Path,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@vii{%
the Path of those upon whom You have favored, not those upon whom is the anger, nor the astray. (Amen please answer)\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen AlifLaamMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ix{%
That is the (Holy) Book, where there is no doubt. It is a guidance for the cautious (of evil and Hell).\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@x{%
Who believe in the unseen and establish the (daily) prayer; who spend out of what We have provided them.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@xi{%
Who believe in that which has been sent down to you (Prophet Muhammad) and what has been sent down before you (to Prophets Jesus and Moses) and firmly believe in the Everlasting Life.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@xii{%
These are guided by their Lord; these surely are the prosperous.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@xiii{%
Those who disbelieve, whether you forewarn them or not, they will not believe.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah has set a seal upon their hearts and ears; their sight is dimmed and for them is a great punishment.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@xv{%
There are some people who say: 'We believe in Allah and the Last Day,'yet they are not believers.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@xvi{%
They seek to deceive Allah and those who believe, but they deceive none except themselves, though they do not sense it.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@xvii{%
There is a sickness in their hearts which Allah has increased. For them there is a painful punishment because they lie.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@xviii{%
When it is said to them, 'Do not corrupt in the land,' they reply, 'We are only reformers.'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@xix{%
But it is they who are the evildoers, though they do not sense it.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@xx{%
When it is said to them: 'Believe as (other) people believe,' they reply, 'Are we to believe as fools believe?' It is they who are the fools, if only they knew!\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@xxi{%
When they meet those who believe, they say, 'We, too believe.' But when they are alone with their devils, they say to them: 'We follow none but you, we were only mocking\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@xxii{%
Allah will mock at them and prolong them in sin, blundering blindly.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@xxiii{%
Such are those who barter away guidance for error, their trade did not profit (them), nor are they guided.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their example is like one who kindled a fire, and when it lit all around him, Allah took away their light and left them in darkness. They could not see.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@xxv{%
Deaf, dumb, and blind, they shall never return.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or, like (those who, under) a cloudburst from the sky with darkness, thunder and lightning, they thrust their fingers in their ears at the sound of every thunderclap for fear of death, and Allah encompasses the unbelievers.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning almost snatches away their sight, whenever it flashes upon them they walk on, but as soon as it darkens they stand still. Indeed, if Allah willed, He could take away their sight and hearing. Allah has power over all things.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@xxviii{%
O people, worship your Lord who has created you and those who have gone before you, so that you will be cautious.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@xxix{%
Who has made the earth a bed for you and the sky a dome, and has sent down water from the sky to bring forth fruits for your provision. Do not knowingly set up rivals to Allah.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@xxx{%
If you are in doubt of what We have sent down to Our worshiper (Prophet Muhammad), produce a chapter comparable to it. Call upon your helpers, other than Allah, to assist you, if you are true.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@xxxi{%
But if you fail, as you are sure to fail, then guard yourselves against the Fire whose fuel is people and stones, prepared for the unbelievers.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@xxxii{%
Bear glad tidings to those who believe and do good works. They shall live in Gardens underneath which rivers flow. Whenever they are given fruit as provision they will say: 'This is what we were given before,' for they shall be given in resemblance. Therein they shall have pure spouses, and shall live there for ever.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Allah is not shy to strike a parable whatsoever a gnat or larger. Those who believe know that it is the truth from their Lord. As for those who disbelieve they ask: 'What could Allah mean by this parable? By it, Allah misleads many and guides many.' But He misleads none except the evildoers,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@xxxiv{%
who break the covenant of Allah after accepting it and sever what Allah has bidden to be joined and corrupt in the land. These are the losers.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@xxxv{%
How can you disbelieve Allah? Did He not give you life when you were dead, and He will cause you to die and then restore you to life. Then you will return to Him.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@xxxvi{%
He created for you all that is in the earth, then, He willed to the heaven, and leveled them seven heavens. He has knowledge of all things.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@xxxvii{%
When your Lord said to the angels: 'I am placing on the earth a caliph,' they replied: 'Will You put there who corrupts and sheds blood, when we exalt Your praises and sanctify You?' He said: 'I know what you do not know'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@xxxviii{%
He taught Adam (father of humans) the names all of them and then presented them to the angels, saying: 'Tell Me the names of these, if you are truthful'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@xxxix{%
'Exaltations to You,' they replied, 'we have no knowledge except that which You have taught us. You are indeed the Knowing, the Wise'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@xl{%
Then He said to Adam: 'Tell them their names.' And when Adam had named them, He said: 'Did I not tell you that I know the unseen of the heavens and earth, and all that you reveal and all that you hide'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@xli{%
And when We said to the angels: 'Prostrate (to Me) yourselves towards Adam,' they all prostrated themselves except iblis (satan, father of the jinn), who, in his pride refused and became an unbeliever.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@xlii{%
To Adam We said: 'Dwell with your wife in Paradise and both eat of it as much as you wish and wherever you will. But neither of you should come close to this tree or else you shall both become transgressors'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@xliii{%
But satan made them slip therefrom and caused them to depart from that in which they had been. 'Go down,' We said, 'be enemies to each other. The earth will provide your dwelling place an enjoyment for a while'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@xliv{%
Then Adam received Words from his Lord, and his Lord relented towards him. He is the Receiver of Repentance, the Merciful.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@xlv{%
'Go down, all together,' We said, 'so if a guidance shall come to you from Me, whosoever follows My guidance no fear shall be on them, neither shall they be saddened.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@xlvi{%
But those who disbelieve and belie Our verses shall be the companions of the Fire, and there they shall live for ever'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@xlvii{%
'Children of Israel, remember My favor I have bestowed upon you. Fulfill My covenant, and I will fulfill your covenant with you. Me, you must fear.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in what I have sent down confirming what is with you, and do not be the first to disbelieve it. Do not sell My verses for a little price and fear Me.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@xlix{%
Do not confound truth with falsehood, nor knowingly hide the truth while you know.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@l{%
Establish your prayers, pay the obligatory charity, and bow with those who bow.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@li{%
Would you order righteousness on others and forget it yourselves? Yet you recite the Book, have you no sense?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@lii{%
And seek help in patience and prayer. For it is heavy, except to the humble,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@liii{%
who reckon that they will meet their Lord and that to Him they will return.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@liv{%
Children of Israel, remember the favors I have bestowed on you, and that I have preferred you (the prophets among you) above the worlds.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@lv{%
Guard yourselves against the Day when no soul can avail a thing to another, when neither intercession nor ransom shall be accepted from it, nor will they be helped.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@lvi{%
(Remember) how We saved you from Pharaoh's people who had oppressed you cruelly, slaying your sons and sparing your women. Surely, that was a great trial from your Lord.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@lvii{%
We parted the sea for you, and, taking you to safety, drowned the family of Pharaoh before your eyes.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@lviii{%
We appointed for Moses forty nights, but in his absence you took the calf, thereby committing harm.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@lix{%
Yet after that We pardoned you, so that you might give thanks.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@lx{%
And when We gave Moses the Book and the Criterion, so that you might be guided;\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@lxi{%
and when Moses said to his nation: 'My nation, you have harmed yourselves by taking the calf (to worship). So turn in repentance to your Creator and slay yourselves. That will be best for you with your Creator.' And He shall accept you. He is the Receiver of Repentance, the Merciful.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@lxii{%
And when you said to Moses: 'We will not believe in you until we see Allah openly' a thunderbolt struck you whilst you were looking.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We raised you from your death, so that you might give thanks.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@lxiv{%
We caused the clouds to cast their shadow over you and sent down for you manna and quails, (saying:) 'Eat of the good things We have provided you. 'Indeed, they did not harm Us, but they harmed themselves.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@lxv{%
'Enter this village' We said, 'and eat wherever you will and as much as you wish. Make your way prostrating through the gates, saying: ``Unburdening." We shall forgive you your sins and We will increase the gooddoers'\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@lxvi{%
But the harmdoers tampered with Our Words, different from that said to them, and We let loose on the harmdoers a scourge from heaven as a punishment for their debauchery.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@lxvii{%
(Remember) when Moses prayed for water for his nation, We said to him: 'Strike the Rock with your staff' Thereupon twelve springs gushed from it, and each tribe knew their drinking place. 'Eat and drink of that which Allah has provided and do not act evilly in the land, corrupting'\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@lxviii{%
'Moses' you said, 'we will no longer be patient with one type of food. Call on your Lord to bring forth for us some of the produce of the earth, green herbs and cucumbers, corn, lentils and onions' 'What' he answered, 'Would you exchange that which is lesser for what is better? Go down into Egypt, there you shall find all that you have asked' Humiliation and abasement were pitched upon them, and they incurred the Anger of Allah; because they disbelieved His signs and slew His Prophets unjustly; because they disobeyed and were transgressors.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@lxix{%
Those who believe, Jews, Nazarenes and Sabaeans whoever believes in Allah and the Last Day and does good deeds shall be rewarded by their Lord; they have nothing to fear nor are they saddened.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@lxx{%
And when We made a covenant with you and raised the Mount above you, (saying) 'Take what We have given you forcefully and remember what is in it, so that you will be cautious'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@lxxi{%
yet after that you turned away, but for the Grace of Allah and His Mercy you would have surely been among the losers.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@lxxii{%
You have surely known of those amongst you who transgressed the Sabbath. We said to them: 'Be apes, despised'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@lxxiii{%
We made it a punishment for the former times and for the latter, an exhortation to the cautious.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@lxxiv{%
When Moses said to his nation: 'Allah commands you to slaughter a cow' they replied: 'Are you taking us in mockery' 'I seek protection with Allah lest I should be one of the ignorant' he said.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@lxxv{%
'Call on your Lord' they said, 'to make known to us what she shall be' He said: ``He says she is a cow neither old, nor virgin, middling between both." Therefore, do as you have been ordered'\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@lxxvi{%
'Call on your Lord' they said, 'to make known to us what her color shall be' 'Your Lord says: ``The cow is yellow, a rich yellow pleasing to the onlookers.'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@lxxvii{%
'Call on your Lord' they said, 'to make known to us which cow she shall be; to us cows look alike. If Allah wills, we shall be guided'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@lxxviii{%
He replied: 'He says: ``She is a cow, neither worn out plowing the earth nor watering the field, one kept secure free from any blemish.' 'Now you have brought us the truth' they answered. And they slaughtered her, after they had been reluctant to do so.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@lxxix{%
And when you slew a soul and then fell out with one another concerning it, Allah made known what you concealed.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@lxxx{%
We said: 'Strike him with a piece of it' Like this, Allah restores the dead to life and shows you His signs in order that you will understand.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Yet after that your hearts became as hard as rock or even harder. Indeed among the stones are those from which rivers burst. And others split so that water issues from them; and others crash down through fear of Allah. Allah is not inattentive of what you do.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Do you then hope that they will believe in you, when some of them have already heard the Word of Allah and knowingly tampered with it, after they understood it!\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
When they meet those who believe, they say: 'We are believers' But when alone, they say to their other (chiefs). 'Do you tell to them what Allah has revealed to you so that they will dispute with you concerning it with your Lord? Have you no sense'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Do they not know that Allah has knowledge of all they hide and all that they reveal!\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And some of them are common (people) and do not know the Book, but only wishful thoughts, and they are only doubters.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
Woe to those who write the Book with their own hands and then say: 'This is from Allah' in order to gain a small price for it. So woe to them for what their hands have written, and woe to them for their earnings.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
They say: 'The Fire will never touch us except for a number of days' Say: 'Did Allah make you such a promise for Allah never breaks His promise or do you say about Allah what you do not know'\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Indeed, he who earns evil and becomes engrossed in his sin, they are the people of the Fire; in it they shall remain for ever.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@lxxxix{%
But those who believe and do good works are the people of Paradise; for ever they shall live in it.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@xc{%
(Remember) when We made a covenant with the Children of Israel, you shall worship none except Allah. Show kindness to your parents, to kinsmen, to the orphans, and to the needy, and speak of goodness to people. Establish your prayers and pay the obligatory charity. But, except for a few, you all turned your backs and gave no heed.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@xci{%
And when We made a covenant with you, that you shall not shed your blood or turn yourselves out of your dwellings, to this you consented and bore witness.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@xcii{%
Yet there you are, slaying your ownselves, and turning a number of them out of their dwellings, and helping each other against them with sin and aggression. Although, should they come to you as captives, you would ransom them. Surely, their expulsion was unlawful. Do you then believe in a part of the Book and disbelieve another! What shall be the recompense of those of you who do that, but degradation in the worldly life, and on the Day of Resurrection to be returned to the most terrible punishment. Allah is not inattentive of what you do.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@xciii{%
Such are they who buy the worldly life at the price of the Everlasting Life. Their punishment shall not be lightened, nor shall they be helped.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@xciv{%
To Moses We gave the Book and after him We sent other Messengers. We gave (Prophet) Jesus, the son of Mary, veritable signs, and supported him with the Spirit of Purity (Gabriel). Will you then become proud whenever any Messenger comes to you with that which does not suit your fancies, and you belied some (Prophet Jesus) and killed others!\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@xcv{%
They say: 'Our hearts are covered' But Allah has cursed them for their disbelief. Little is that they believe.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when a Book came to them from Allah confirming what was with them, while before that they used to pray for victory over the unbelievers when there came to them what they knew, they disbelieved him. Therefore, the curse of Allah be upon the unbelievers!\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@xcvii{%
Evil is that for which they have bartered away their souls, that they disbelieve what Allah has sent down, grudging that Allah should send down from His bounty to whom He chooses from His worshipers! They have incurred wrath over wrath. For the unbelievers there is a humiliating punishment.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@xcviii{%
When it is said to them: 'Believe in what Allah has sent down' they reply: 'We believe in what was sent down to us' But they disbelieve in what is sent after it, although it is the truth, confirming their own Book. Say: 'Why, before did you kill the Prophets of Allah, if you are believers'\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@xcix{%
Moses came to you with clear signs, then you took to yourselves the calf after him and you were harmdoers'\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@c{%
When We made a covenant with you and raised the Mount above you (saying): 'Take what We have given you forcefully and hear' they replied: 'We hear, but disobey' For their disbelief, they were made to drink the calf into their very hearts. Say: 'Evil is your belief that orders you to (worship the calf), if you are indeed believers'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@ci{%
Say: 'If the abode of the Everlasting Life is with Allah for you especially, to the exclusion of all other people, then long for death if you are truthful'\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@cii{%
But they will never long for it (death), because of what their hands forwarded; and Allah knows the harmdoers.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ciii{%
Indeed, you will find them more eager than other people for this life. And (more than) those who disbelieve. Each one of them wishes to live a thousand years. But his prolonged life will surely not remove him from the punishment. Allah is the Seer of what they do.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@civ{%
Say: 'Whoever is an enemy of Gabriel, indeed, he has brought it down by the permission of Allah to your heart, confirming what was before it and a guidance and glad tidings to the believers.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@cv{%
Whoever is an enemy of Allah, His Angels, His Messengers, Gabriel, and Michael indeed Allah is the enemy of the unbelievers'\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@cvi{%
We have sent down to you clear verses, none will disbelieve them except the evildoers.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@cvii{%
Why, whenever they make a promise do some of them cast it aside! Most of them do not believe.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@cviii{%
And now that a Messenger has come to them from Allah confirming what was with them, some of those to whom the Book was given reject the Book of Allah behind their backs, as though they knew nothing\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@cix{%
and follow what the devils recited over the Kingdom of Solomon. Solomon did not disbelieve, it is the devils who disbelieved, teaching people magic and that which was sent down upon the angels Harut and Marut in Babylon. They did not teach anyone, until both had said: 'We have been sent as a trial; do not disbelieve' From them they learned how they might separate a husband and his wife. However, they did not harm anyone with it, except by the permission of Allah. Indeed, they learned what harms them and does not profit them, yet they knew that anyone who buys it would have no share in the Everlasting Life. Evil is that for which they have sold their souls, if they but knew!\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@cx{%
Had they believed and were cautious, far better for them would be the reward from Allah, if they but knew.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@cxi{%
'Believers, do not say 'Observe us (Ra'ina, in Hebrew means evil) ', but instead say: ``Look after us (Undhurna), and listen' for the unbelievers is a painful punishment.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@cxii{%
The unbelievers among the People of the Book (Jews and Nazarenes) and the idolaters resent that any good should have been sent down to you from your Lord. But Allah chooses whom He will for His Mercy. And Allah is of great bounty.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@cxiii{%
If We supersede any verse or cause it to be forgotten, We bring a better one or one similar. Do you not know that Allah has power over all things!\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@cxiv{%
Do you not know that it is to Allah that the Kingdom of the heavens and the earth belong, and that there is none, other than Him, to protect or help you!\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@cxv{%
Would you rather demand of your Messenger that which was once demanded of Moses! He who exchanges belief for disbelief has surely strayed from the Right Path.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many of the People of the Book wish they might turn you back as unbelievers after you have believed, in envy of their souls, after the truth has been clarified to them. So pardon and forgive until Allah brings His command. Allah is Powerful over everything.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@cxvii{%
Establish your prayers and pay the obligatory charity. Whatever good you shall forward for your soul you shall find it with Allah. He is the Seer of what you do.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cxviii{%
They say: 'None but Jews and Nazarenes shall be admitted to Paradise' Such are their wishful fancies. Say: 'Bring us your proof, if what you say is true'\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cxix{%
Indeed, whoever submits his face to Allah and does good works shall be rewarded by his Lord; there they shall have nothing to fear nor shall they be saddened.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cxx{%
The Jews say the Nazarenes are not on anything, and the Nazarenes say it is the Jews who are not on anything. Yet they both read the Book. And those who do not know say like their saying. Allah will judge between them their disputes on the Day of Resurrection.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cxxi{%
Who does greater harm than he who prevents His Name to be remembered in the Mosques of Allah and strives to destroy them? Those, they will not enter them except in fear. And for them shame in this world and a great punishment in the next.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cxxii{%
To Allah belong the east and the west. Whichever way you turn, there is the Face of Allah. He is the Embracer, the Knower.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cxxiii{%
They say: 'Allah has taken (to Himself) a son' Exaltations to Him (Allah). For Him is what is in the heavens and the earth, all are obedient to Him.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cxxiv{%
Creator of the heavens and the earth! When He decrees a thing, He only says: 'Be' and it is.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cxxv{%
And those who do not know say: 'Why does not Allah speak to us or a sign come to us' Likewise, those who were before them said similar to their saying. Their hearts are alike. Indeed, We have clarified the signs to a nation who are certain.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cxxvi{%
We have sent you (Prophet Muhammad) forth with the truth, a giver of glad tidings and a giver of warning. You shall not be questioned about the companions of Hell.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cxxvii{%
You will please neither the Jews nor the Nazarenes unless you follow their creed. Say: 'The guidance of Allah is the guidance' And if after all the knowledge you have been given you yield to their desires, you shall not have, other than Allah, either a guide or a helper.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those to whom We have given the Book, and who recite it as it ought to be read, truly believe in it; those who disbelieve it shall be the losers.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cxxix{%
Children of Israel, remember My favor which I bestowed upon you and that I preferred your (prophets among you) above the worlds.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cxxx{%
And fear a Day when no soul for another will compensate a thing, and no equivalent will be accepted from it, neither intercession will benefit it, nor shall they be helped.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And when Abraham was tested by His Lord with certain words and he fulfilled them, He said: 'I have appointed you as a leader for the nation' (Abraham) asked: 'And of my descendants' 'My covenant' said He, 'the harmdoers shall not receive it'\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And when We made the House (Ka'bah) a visitation and a sanctuary for the people (saying:) 'Make the place where Abraham stood a place of prayer. 'And We made a covenant with Abraham and Ishmael: 'Purify My House for those who circumambulate around it, and those who cleave to it, to those who bow and prostrate'\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And when Abraham said: 'My Lord, make this country safe and provide its inhabitants whosoever of them believes in Allah and the Last Day with fruits' He said: 'And whosoever disbelieves, to him I shall give enjoyment for a while. Then I shall compel him to the punishment of the Fire, how evil an arrival'\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And when Abraham and Ishmael raised the foundations of the House (supplicating): 'O our Lord, accept this from us, You are the Hearer, the Knower.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cxxxv{%
Our Lord, make us both submissive to You, and of our descendants a submissive nation to You. Show us our rites and accept us; You are the Receiver of Repentance, the Merciful.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
Our Lord, send among them a Messenger from them who shall recite to them Your verses and teach them the Book and wisdom, and purify them; You are the Mighty, the Wise'\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
And who has no desire for the religion of Abraham, except he who fooled himself? We chose him in this world, and in the Everlasting world, he shall be among the righteous.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said to him: 'Submit' he answered: 'I have submitted to the Lord of the Worlds'\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cxxxix{%
Abraham charged his children with this, and so did Jacob, saying: 'My sons, Allah has chosen for you the religion. Do not die except being submissive (Muslims)'\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cxl{%
Or, were you witnesses when death came to Jacob! He said to his children: 'What will you worship after me' They replied: 'We will worship your God and the God of your forefathers, Abraham, Ishmael, and Isaac, the One God. To Him, we are submissive'\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cxli{%
That was a nation that has passed away. Theirs is what they earned, and yours what you have earned. You shall not be questioned about what they did.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cxlii{%
They say: 'Be Jews or Nazarenes and you shall be guided' Say: 'No, rather the Creed of Abraham, the upright one. He was not among the idolaters'\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say: 'We believe in Allah and that which is sent down to us, and in what was sent down to Abraham, Ishmael, Isaac, Jacob, and the tribes; to Moses and Jesus and the Prophets from their Lord. We do not differentiate between any of them, and to Him we are submissive (Muslims)'\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cxliv{%
If they believe as you have believed they shall be guided; if they reject it, they shall surely be in clear dissension. Allah will suffice you. He is the Hearer, the Knower.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cxlv{%
The (indelible) marking of Allah. And who marks better than Allah! And for Him we are worshipers.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say: 'Would you dispute with us about Allah, who is our Lord and your Lord? Our deeds belong to us and your deeds belong to you. We are sincere to Him'\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or do you say that Abraham, Ishmael, Isaac, Jacob, and the tribes, were Jews or Nazarenes! Say: 'Who knows better, you or Allah? Who is more unjust than he who hides a testimony received from Allah? And Allah is not inattentive of what you do'\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cxlviii{%
That nation has passed away. Theirs is what they earned and yours what you have earned. You shall not be questioned about what they did.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cxlix{%
The fools among the people will say: 'What has made them turn away from the direction they were facing' Say: 'The east and the west belong to Allah. He guides whom He will to the Straight Path'\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cl{%
And so We have made you a median nation, in order that you will be a witness above the people, and that the Messenger be a witness above you. We did not change the direction that you were facing except that We might know who followed the Messenger from him who turned on both his heels. Though it was a hardship except for those whom Allah has guided. But Allah would never waste your faith. Indeed, Allah is Gentle with people, the Most Merciful.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cli{%
We have seen you turning your face towards the heaven, We shall surely turn you to a direction that shall satisfy you. So turn your face towards the Sacred Mosque (built by Abraham); wherever you are, turn your faces to it' Those to whom the Book was given know this to be the truth from their Lord. Allah is not inattentive of what they do.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@clii{%
But even if you brought those to whom the Book had been given every proof, they would not accept your direction, nor would you accept theirs; nor would any of them accept the direction of the other. If after all the knowledge you have been given you yield to their desires, then you will surely be among the harmdoers.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cliii{%
Those to whom We gave the Book know him (Prophet Muhammad) as they know their own sons. But a party of them conceal the truth while they know.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cliv{%
The truth comes from your Lord so do not be among the doubters.\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@clv{%
And for everyone is a direction for which he turns. So race in goodness. And wherever you are, Allah will bring you all together. He has power over all things.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@clvi{%
From wherever you emerge, turn your face towards the Sacred Mosque. This is surely the truth from your Lord. Allah is never inattentive of what you do.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@clvii{%
From wherever you emerge, turn your face towards the Sacred Mosque, and wherever you are, face towards it, so that the people will have no argument against you, except the harmdoers among them. Do not fear them, fear Me, so that I will perfect My Favor to you and that you will be guided.\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@clviii{%
As We have sent among you a Messenger (Prophet Muhammad) from yourselves, to recite to you Our verses and to purify you, who will teach you the Book and Wisdom, and teach you that of which you have no knowledge.\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@clix{%
So remember Me, I will remember you. Give thanks to Me and do not be ungrateful towards Me.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@clx{%
Believers, seek assistance in patience and prayer, Allah is with those who are patient.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@clxi{%
Do not say that those killed in the Way of Allah are dead, they are alive, although you are unaware.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@clxii{%
We shall test you with something of fear and hunger, and decrease of goods, life and fruits. Give glad tidings to the patient,\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@clxiii{%
who, in adversity say: 'We belong to Allah and to Him we shall return'\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@clxiv{%
On those will be prayers and mercy from their Lord, those are guided.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@clxv{%
Safah and Marwah are the waymarks of Allah. Whoever performs the pilgrimage to the House or the visit, there shall be no guilt on him to circumambulate between both of them. And whoever volunteers good, Allah is Thankful, the Knower.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@clxvi{%
Those who hide the clear verses and the guidance We have sent down after We have clarified them in the Book for the people shall be cursed by Allah and cursed by the cursers,\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@clxvii{%
except those who repent, and mend (their deeds) and clarify. Those I shall accept them. I am the Receiver of repentance, the Most Merciful.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@clxviii{%
But those who disbelieve, and die disbelieving shall incur the curse of Allah, the angels, and all people.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@clxix{%
They are there (in the Fire) for eternity neither shall the punishment be lightened for them; nor shall they be given respite.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@clxx{%
Your God is One God. There is no god except He. He is the Merciful, the Most Merciful.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@clxxi{%
In the creation of the heavens and the earth; in the alternation of night and day; in the ships that sail upon the sea with what is beneficial to the people; in the water which Allah sends down from the sky and with which He revives the earth after its death, and He spread in it from each moving (creation); in the movement of the winds, and in the clouds that are compelled between heaven and earth surely, these are signs for people who understand.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@clxxii{%
And among the people are those who take to themselves rivals, other than Allah, loving them as Allah is loved. But those who believe are more loving to Allah. When the harmdoers see when they see the punishment because the power altogether belongs to Allah, and that Allah is firm in punishment,\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@clxxiii{%
when those who were followed disown those who followed, and they see the punishment and relationships are broken off,\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@clxxiv{%
those who followed them will say: 'If only that we might return once, and disown them as they have disowned us' As such Allah will show them their own works to be regrets for them, and they shall never emerge from the Fire.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@clxxv{%
People, eat of what is lawful and good on the earth and do not walk in satan's footsteps, because he is for you a clear enemy,\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@clxxvi{%
he orders you to commit evil and indecency and to assert about Allah what you do not know.\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@clxxvii{%
When it is said to them: 'Follow what Allah has sent down' they reply: 'We will follow that which we found our fathers upon' even though their fathers did not understand anything and they were not guided.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@clxxviii{%
The likeness of those who disbelieve is as the likeness of he who calls to that which does not hear, except a shout and a voice. Deaf, dumb, and blind, they do not understand.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@clxxix{%
Believers, eat of the good with which We have provided you and give thanks to Allah, if you really worship Him.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@clxxx{%
He has forbidden you the dead, blood, and the flesh of swine, also that which is invoked to other than Allah. But whoever is constrained (to eat) any of these, not intending to sin or transgress, incurs no guilt. Allah is Forgiving and the Most Merciful.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Those who conceal what Allah has sent down of the Book and sell it for a small price shall swallow nothing but fire into their bellies. On the Day of Resurrection, Allah will neither speak to them nor purify them. Theirs shall be a painful punishment.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@clxxxii{%
Such are those who buy error for guidance, and punishment for pardon. How patiently they will be in the Fire.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
That is because Allah has sent down the Book with the truth; those who disagree about it are in extreme dissension.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
Righteousness is not whether you face towards the east or the west. But righteousness is to believe in Allah and the Last Day, in the angels and the Book, and the Prophets, and to give wealth however cherished, to kinsmen, to the orphans, to the needy, to the destitute traveler, and to the beggars, and to ransom the slave; who establish their prayers and pay the obligatory charity; who are true to their promise when they have promised. Who are patient in misfortune and hardship and during the time of courage. Such are the truthful; such are the cautious.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@clxxxv{%
Believers, retaliation is decreed for you concerning the killed. A free (man) for a free (man), a slave for a slave, and a female for a female. He who is pardoned by his brother, let the ensuing be with kindness, and let the payment be with generosity. This is an alleviation from your Lord and mercy. He who transgresses thereafter shall have a painful punishment.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
O owners of minds, for you in retaliation is life, in order that you be cautious.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
Written for any of you when death arrives, if he leaves behind goods, is the will for his parents and relatives with kindness. This is a duty incumbent on the cautious.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
Then, if anyone changes it after hearing it, the sin shall rest upon those who change it. Allah is Hearing and Knowing.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@clxxxix{%
He who fears injustice or sin on the part of a testator and brings about a settlement among the parties incurs no guilt. Allah is the Forgiver and the Most Merciful.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@cxc{%
Believers, fasting is decreed for you as it was decreed for those before you; perchance you will be cautious.\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@cxci{%
(Fast) a certain number of days, but if any one of you is ill or on a journey let him (fast) a similar number of days later on; and for those who are unable (tofast), there is a ransom the feeding of a needy person. Whosoever volunteers good, it is good for him; but to fast is better for you, if you but knew.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@cxcii{%
The month of Ramadan is the month in which the Koran was sent down, a guidance for people, and clear verses of guidance and the criterion. Therefore, whoever of you witnesses the month, let him fast. But he who is ill, or on a journey shall (fast) a similar number (of days) later on. Allah wants ease for you and does not want hardship for you. And that you fulfill the number of days and exalt Allah who has guided you in order that you be thankful.\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@cxciii{%
When My worshipers ask you about Me, I am near. I answer the supplication of the suppliant when he calls to Me; therefore, let them respond to Me and let them believe in Me, in order that they will be righteous.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@cxciv{%
Permitted to you, on the night of the Fast, is the approach to your wives; they are raiments for you, as you are raiments for them. Allah knows that you have been deceiving yourselves. He has accepted and pardoned you. Therefore, you may now touch them and seek what Allah has ordained for you. Eat and drink until the white thread becomes clear to you from a black thread at the dawn. Then resume the fast till nightfall and do not touch them while you cleave to the mosques. These are the Bounds of Allah, do not come near them. As such He makes known His verses to people so that they will be cautious.\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@cxcv{%
Do not consume your wealth between you in falsehood; neither propose it to judges, in order that you sinfully consume a portion of the people's wealth, while you know.\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They question you about the crescents. Say: 'They are times fixed for people and for the pilgrimage' Righteousness does not consist in entering dwellings from the back. But righteousness is he who wardsoff (sin). Enter dwellings by their doors and fear Allah, so that you will prosper.\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@cxcvii{%
Fight in the way of Allah those who fight against you, but do not aggress. Allah does not love the aggressors.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@cxcviii{%
Kill them wherever you find them. Drive them out of the places from which they drove you. Dissension is greater than killing. But do not fight them by the Holy Mosque unless they attack you there; if they fight you, kill them. Like this is the recompense of the unbelievers,\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@cxcix{%
but if they desist, know that Allah is the Forgiver and the Most Merciful.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@cc{%
Fight against them until there is no dissension, and the religion is for Allah. But if they desist, there shall be no aggression except against the harmdoers.\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@cci{%
The sacred month for the sacred month, prohibitions are (subject to) retaliation. If any one aggresses against you, so aggress against him with the likeness of that which he has aggressed against you. Fear Allah, and know that Allah is with the cautious.\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@ccii{%
Spend in the way of Allah and do not cast into destruction with your own hands. Be gooddoers; Allah loves the gooddoers.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@cciii{%
Fulfill the pilgrimage and make the visitation for Allah. If you are prevented, then whatever offering that may be easy. And do not shave your heads until the offerings have reached their destination. But if any of you is ill or suffers from an ailment of the head (scalp), he must pay a ransom either by fasting or by the giving of charity, or by offering a sacrifice. When you are safe, then whosoever enjoys the visitation until the pilgrimage, let his offering be that which may be easy, but if he lacks the means, let him fast three days during the pilgrimage and seven when he has returned, that is, ten days in all. That is for him whose family is not present at the Holy Mosque. And fear Allah and know that He is firm in inflicting punishment.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@cciv{%
The pilgrimage is in the appointed months. (For) whosoever undertakes the pilgrimage there is no approaching (women), neither transgression nor disputing in the pilgrimage. Allah is Aware of whatever good you do. Provide well for yourselves, the best provision is piety. Fear Me, O owners of minds.\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@ccv{%
It shall be no offense for you to seek the bounty of your Lord. When you surge on from Arafat, remember Allah as you approach the Holy Mountain of Mash'ar. Remember Him as it is He who guided you though before that you were amongst the astray.\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then surge on from where the people surge and ask Allah for forgiveness. He is Forgiving and the Most Merciful.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@ccvii{%
And when you have fulfilled your sacred duties remember Allah as you remember your forefathers or with deeper reverence. There are some who say: 'Lord, give us good in this world' He shall have no share in the Everlasting Life.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@ccviii{%
But there are others who say: 'Lord, give us a merit in the world and good in the Everlasting Life, and save us from the punishment of the Fire'\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@ccix{%
These shall have a share of what they have earned. Swift is the reckoning of Allah.\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@ccx{%
Remember Allah during counted days. Whosoever hastens on in two days, no sin shall be on him. And if any delay, no sin shall be on him, for he who wardsoff (evil). And fear Allah, and know that you shall be assembled unto Him.\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@ccxi{%
There is he whose sayings pleases you in this worldly life and uses Allah as a witness for what is in his heart, but he is most stubborn in adversary.\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@ccxii{%
No sooner does he leave than he hastens about the earth to corrupt there and destroy crops and cattle. Allah does not love corruption.\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@ccxiii{%
When it is said to him: 'Fear Allah' egotism takes him in his sin. Gehenna (Hell) shall be enough for him. How evil a cradling!\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@ccxiv{%
But there are among people he who would give away his life desiring the Pleasure of Allah. Allah is Gentle to His worshipers.\qt@no{(207)}}%
\qt@newcmd\qurantrans@en@ccxv{%
Believers, all of you, enter the peace and do not follow in satan's footsteps; he is a clear enemy to you.\qt@no{(208)}}%
\qt@newcmd\qurantrans@en@ccxvi{%
If you lapse back after the clear verses that have come to you, know that Allah is the Almighty, the Wise.\qt@no{(209)}}%
\qt@newcmd\qurantrans@en@ccxvii{%
Are they waiting for Allah to come to them in the shadows of the clouds with the angels! Their matter will have been settled then. To Allah shall all things return.\qt@no{(210)}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the Children of Israel how many clear signs We have given them. Whoever changes the Favor of Allah after it has come to him, Allah is Firm in inflicting the punishment.\qt@no{(211)}}%
\qt@newcmd\qurantrans@en@ccxix{%
For those who disbelieve, the worldly life is decked with all manner of decorations. They scoff at those who believe, but the cautious shall be above them on the Day of Resurrection. Allah gives without count to whom He will.\qt@no{(212)}}%
\qt@newcmd\qurantrans@en@ccxx{%
The people were one nation. Then Allah sent forth Prophets to give them glad tidings and to warn them; and with them He sent down the Book with the truth, that He might rule between the people in that which they differ. Only those to whom it had been given differed about it after the clear verses had come to them, transgressing between themselves. Then Allah guided those who believed concerning that which they were at variance in the truth, by His permission. Allah guides whom He will to the Straight Path.\qt@no{(213)}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Or did you suppose that you would go to Paradise untouched by that endured by those before you! Affliction and adversity befell them; and they were shaken until the Messenger, and those who believed with him, said: 'When will the victory of Allah come' Is it not so that the victory of Allah is near.\qt@no{(214)}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They will question you about what they should spend (in charity). Say: 'Whatever good you spend is for (your) parents, kinsmen, orphans, the needy, and the destitute traveler. Allah is Aware of whatever good you do'\qt@no{(215)}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
(Offensive) fighting is obligatory for you, though it is hateful to you. But you may hate a thing although it is good for you, and may love a thing although it is evil for you. Allah knows, and you do not.\qt@no{(216)}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask you about the Sacred Month and fighting in it. Say: 'To fight in this month is a grave (offense); but to bar others from the Path of Allah, and disbelief in Him, and the Holy Mosque, and to expel its inhabitants from it is greater with Allah. Dissension is greater than killing' They will not cease to fight against you until they force you to renounce your religion, if they are able. But whosoever of you recants from his religion and dies an unbeliever, their works shall be annulled in this world and in the Everlasting Life, and those shall be the companions of Hell, and there they shall live for ever.\qt@no{(217)}}%
\qt@newcmd\qurantrans@en@ccxxv{%
But those who believe and those who migrate and struggle in the way of Allah, those, have hope of the Mercy of Allah. Allah is Forgiving and Merciful.\qt@no{(218)}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask you about intoxicating drink and gambling. Say: 'There is great sin in both, although they have some benefit for people; but their sin is far greater than their benefit' They ask you what they should spend. Say: 'That which remains' So, Allah makes plain to you His verses, in order that you will reflect\qt@no{(219)}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
upon this world and the Everlasting Life. They will question you concerning orphans. Say: 'Doing good for them is best. If you mix their affairs with yours, remember they are your brothers. Allah knows the corrupter from the reformer. If Allah willed He could have brought hardship upon you. He is Almighty and Wise'\qt@no{(220)}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
Do not wed idolatresses, until they believe. A believing slavegirl is better than a (free) idolatress, even if she pleases you. And do not wed idolaters, until they believe. A believing slave is better than a (free) idolater, even though he pleases you. Those call to the Fire; but Allah calls to Paradise and pardon by His permission. He makes plain His verses to the people, in order that they will remember.\qt@no{(221)}}%
\qt@newcmd\qurantrans@en@ccxxix{%
They ask you about menstruation. Say: 'It is an injury. Stay away from women during their menstrual periods and do not approach them until they are cleansed. When they have cleansed themselves, then come to them from where Allah has commanded you. Allah loves those who turn to Him in repentance and He loves those who cleanse themselves'\qt@no{(222)}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Women are your planting place (for children); come then to your planting place as you please and forward (good deeds) for your souls, and fear Allah. And know that you shall meet Him. Give glad tidings to the believers.\qt@no{(223)}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
Do not make Allah a deterrent through your oaths, that you be righteous, cautious, and reform between people. Surely, Allah is Hearing and Knowing.\qt@no{(224)}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah will not call you to account for a slip in your oaths. But He will take you to task for that which is intended in your hearts. Allah is Forgiving and Merciful.\qt@no{(225)}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
For those who swear a wait of four months from their women, if they revert, Allah is Forgiving, the Most Merciful.\qt@no{(226)}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
But if they resolve on divorce, surely, Allah is the Hearer, the Knower.\qt@no{(227)}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
Divorced women shall wait by themselves for three periods. It is unlawful for them, if they believe in Allah and the Last Day, to hide what He has created in their wombs, in which case their husbands would have a better right to restore them should they desire reconciliation. And for them similar to what is due from them with kindness. But men have a degree above them. Allah is Mighty and Wise.\qt@no{(228)}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
Divorce is twice, then an honorable keeping or allowed to go with kindness. It is unlawful for you to take from them anything you have given them, unless both fear that they will not be able to keep within the Bounds of Allah; in which case it shall be no offense for either of them if she ransom herself. These are the Bounds of Allah; do not transgress them. Those who transgress the Bounds of Allah are harmdoers.\qt@no{(229)}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
If he divorces her (for the third time), she shall not be lawful to him after that until she has wed (not for the purpose of remarrying her former husband) another spouse and then if he divorces her it shall be no offense for either of them to return to each other, if they think that they can keep within the Bounds of Allah. Those are the Bounds of Allah. He makes them plain to people who know.\qt@no{(230)}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
When you have divorced women and they have reached the end of their waiting period, either keep them in kindness or let them go with kindness. But you shall not keep them, being harmful, in order to transgress. Whoever does this wrongs himself. Do not take the verses of Allah in mockery. Remember the favor of Allah upon you, and what He sent down to you from the Book and Wisdom to exhort you. Fear Allah and know that He has knowledge of everything.\qt@no{(231)}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
When you divorce women, and they have reached their term, do not restrain them from marrying their (future) husbands, when they have agreed together with kindness. That is an exhortation for whosoever of you believes in Allah and the Last Day. That is cleaner and purer for you. Allah knows, and you do not know.\qt@no{(232)}}%
\qt@newcmd\qurantrans@en@ccxl{%
Mothers shall suckle their children for two years completely, for whoever desires to fulfill the suckling. It is for the father to provide for them and clothe them with kindness. No soul is charged except to its capacity. A mother shall not be harmed for her child, neither a father for his child. And upon the heir is like that. If both desire to wean by mutual consent and consultation, then no guilt shall be on them. And if you desire a wet nurse for your children, then no guilt shall be on you if you hand over what you have given with kindness. And fear Allah, and know that Allah is the Seer of what you do.\qt@no{(233)}}%
\qt@newcmd\qurantrans@en@ccxli{%
And those of you who die and leave wives behind such wives shall wait by themselves for four months and ten (nights). When they have reached the end of their waiting period, there shall be no offense for you in whatever they choose for themselves kindly. Allah is Aware of what you do.\qt@no{(234)}}%
\qt@newcmd\qurantrans@en@ccxlii{%
No guilt shall be on you in the indication of an engagement to women or what you suppress in yourself. Allah knows that you will remember them; but do not promise them secretly unless you speak kind words (only of indication). And do not resolve on the knot of marriage until the writing has reached its term. And know that Allah knows what is in your hearts, so be cautious of Him. And know that Allah is the Forgiver, the Clement.\qt@no{(235)}}%
\qt@newcmd\qurantrans@en@ccxliii{%
It shall be no offense for you to divorce your wives as long as you have not touched them or obligated a right for them. Provide for them with fairness; the rich according to his means, and the restricted according to his. A right on the gooddoers.\qt@no{(236)}}%
\qt@newcmd\qurantrans@en@ccxliv{%
If you divorce them before you have touched them but after their dowry has been determined, give them half of what you determined, unless they pardon, or he pardons in whose hand is the marriage knot. And if you pardon it is nearer to wardingoff (evil). Do not forget the generosity between each other. Allah is the Seer of what you do.\qt@no{(237)}}%
\qt@newcmd\qurantrans@en@ccxlv{%
And preserve the prayers and the middle prayer, and stand obedient to Allah.\qt@no{(238)}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
And if you fear, then (pray) on foot or riding. But when you are safe, then remember Allah, as He has taught you what you did not know.\qt@no{(239)}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
Those who die and leave wives behind should bequeath to them a year's maintenance without causing them to leave their homes; but if they leave, no blame shall be attached to you in what they do with themselves kindly. Allah is Mighty and Wise.\qt@no{(240)}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
Provision should be made for divorced women with kindness. That is a right on the cautious.\qt@no{(241)}}%
\qt@newcmd\qurantrans@en@ccxlix{%
Like this Allah clarifies to you His verses in order that you understand.\qt@no{(242)}}%
\qt@newcmd\qurantrans@en@ccl{%
Haven't you seen those who went out from their homes in their thousands cautious of death? Allah said to them: 'Die' and then He revived them. Surely, Allah is Bountiful to the people, but most people do not thank.\qt@no{(243)}}%
\qt@newcmd\qurantrans@en@ccli{%
Fight in the way of Allah. And know that Allah is the Hearer and the Knower.\qt@no{(244)}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is he that will lend Allah a good loan! He will multiply it many multiples! Allah grasps and outspreads and to Him you shall be returned.\qt@no{(245)}}%
\qt@newcmd\qurantrans@en@ccliii{%
Have you not seen the congregation of the Children of Israel who demanded of one of their Prophets after (the death of) Moses? 'Raise up for us a king' they said, 'and we will fight in the way of Allah' He replied: 'Might it be that if fighting is written for you, you will not fight' 'Why shouldn't we fight in the way of Allah' they replied, 'when we and all our children have been driven from our dwellings' Yet, when fighting was written for them all except for a few, turned away. And Allah has knowledge of the harmdoers.\qt@no{(246)}}%
\qt@newcmd\qurantrans@en@ccliv{%
Their Prophet said to them: 'Allah has raised Saul to be your king' But they replied: 'Should he be given the kingship over us, when we are more deserving of it than he and he has not been given abundant wealth' He said: 'Allah has chosen him over you and increased him with amplitude in knowledge and body. Allah gives His kingship to whom He will. Allah is the Embracer, the Knower'\qt@no{(247)}}%
\qt@newcmd\qurantrans@en@cclv{%
Their Prophet said to them: 'The sign of his kingship is the coming of the Ark to you, therein shall be tranquility from your Lord, and a remnant which the House of Moses and the House of Aaron left behind. It will be borne by the angels. That will be a sign for you if you are believers'\qt@no{(248)}}%
\qt@newcmd\qurantrans@en@cclvi{%
And when Saul marched out with his army, he said: 'Allah will test you with a river. He who drinks from it shall cease to be one of mine but he who does not drink from it, except he who scoops up once with his hand, shall be of mine' But for a few of them, they all drank from it. And when he had crossed it with those who believed, they said: 'We have no power this day against Goliath and his soldiers' But those of them who reckoned they would meet Allah replied: 'Many a small band has, by the permission of Allah, vanquished a mighty army. Allah is with the patient'\qt@no{(249)}}%
\qt@newcmd\qurantrans@en@cclvii{%
When they appeared to Goliath and his soldiers, they said: 'Lord, pour upon us patience. Make us firm of foot and give us victory against the nation of unbelievers'\qt@no{(250)}}%
\qt@newcmd\qurantrans@en@cclviii{%
By the permission of Allah, they routed them. David slew Goliath, and Allah bestowed on him the kingship and wisdom, and taught him from that He willed. Had Allah not pushed the people, some by the other, the earth would have been corrupted. But Allah is Bountiful to the worlds.\qt@no{(251)}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the verses of Allah. We recite (them) to you in truth, for you (Prophet Muhammad) are one of the Messengers.\qt@no{(252)}}%
\qt@newcmd\qurantrans@en@cclx{%
Of these Messengers, We have preferred some above others. To some Allah spoke; and some He raised in rank. We gave (Prophet) Jesus, the son of Mary, clear signs and strengthened him with the Spirit of Purity (Gabriel). Had Allah willed, those who succeeded them would not have fought against one another after the clear verses came to them. But they differed among themselves; some believed, and others disbelieved. Yet had Allah willed, they would not have fought against one another. Allah does whatever He will.\qt@no{(253)}}%
\qt@newcmd\qurantrans@en@cclxi{%
Believers, spend of what We have given you before that Day arrives when there shall be neither trade, nor friendship, nor intercession. It is the unbelievers who are the harmdoers.\qt@no{(254)}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah, there is no god except He, the Living, the Everlasting. Neither dozing, nor sleep overtakes Him. To Him belongs all that is in the heavens and the earth. Who is he that shall intercede with Him except by His permission! He knows what will be before their hands and what was behind them, and they do not comprehend anything of His Knowledge except what He willed. His Seat embraces the heavens and the earth, and the preserving of them does not weary Him. He is the High, the Great.\qt@no{(255)}}%
\qt@newcmd\qurantrans@en@cclxiii{%
There is no compulsion in religion. Righteousness is now distinct from error. He who disbelieves in the idol and believes in Allah has grasped the firmest tie that will never break. Allah is Hearing, Knowing.\qt@no{(256)}}%
\qt@newcmd\qurantrans@en@cclxiv{%
Allah is the Guardian of those who believe. He brings them out from darkness into the light. As for those who disbelieve, their guides are idols, they bring them out from the light into darkness. They are the companions of the Fire and shall live in it for ever.\qt@no{(257)}}%
\qt@newcmd\qurantrans@en@cclxv{%
Have you not seen he who argued with Abraham about his Lord that Allah had given him the kingship! When Abraham said: 'My Lord is He who revives, and causes to die' He said: 'I revive, and cause to die' Abraham said: 'Allah brings up the sun from the east; so you bring it from the west' Then he who disbelieved became pale. Allah does not guide the nation, the harmdoers.\qt@no{(258)}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or of him, who, when passing by the ruined village that was fallen on its roofs, remarked: 'How can Allah give life to this after its death' Thereupon Allahcaused him to die, and after a hundred years He revived him. He asked: 'How long have you remained' 'A day' he replied, 'or part of a day' Allah said: 'Rather, you have remained a hundred years. Look at your food and drink; they have not rotted. And look at your donkey (that had died). We will make you a sign to the people. And look at the bones (of your donkey) how We shall revive them and clothe them with flesh' And when it had all become clear to him, he said: 'I know that Allah has power over all things'\qt@no{(259)}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And (remember) when Abraham said: 'Show me, Lord, how You raise the dead' He replied: 'Have you not believed' 'Rather' said Abraham, 'in order that my heart be satisfied' 'Take four birds' said He, 'draw them to you, then set a part of them on every hill, then call them, they will come swiftly to you. Know that Allah is Mighty and Wise'\qt@no{(260)}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The example of those who give their wealth in the way of Allah is like a grain of corn that sprouts seven ears, in every ear a hundred grains. Allah multiplies to whom He will, Allah is the Embracer, the Knower.\qt@no{(261)}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who spend their wealth in the way of Allah and do not follow their spending with reproach and insults shall be rewarded by their Lord; they shall have nothing to fear or to regret.\qt@no{(262)}}%
\qt@newcmd\qurantrans@en@cclxx{%
A kind word and forgiveness is better than charity followed by injury. Allah is the Clement.\qt@no{(263)}}%
\qt@newcmd\qurantrans@en@cclxxi{%
Believers, do not annul your charitable giving with reproach and hurt, like he who spends his wealth to show off to the people and believes neither in Allah nor in the Last Day. His likeness is as a smooth rock covered with dust, if a heavy rain strikes it, it leaves it bare. They have no power over what they have earned. Allah does not guide the nation, the unbelievers.\qt@no{(264)}}%
\qt@newcmd\qurantrans@en@cclxxii{%
But those who give away their wealth with a desire to please Allah and to reassure themselves are like a garden on a hillside, if heavy rain strikes it, it yields up twice its normal crop, and if heavy rain does not strike it, then light rain. Allah is the Seer of what you do.\qt@no{(265)}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would any one of you, being welladvanced in age with helpless children, wish to have a garden of palmtrees, vines and all manner of fruits watered by running streams struck and burned by a fiery whirlwind? Even so, Allah makes plain to you His signs, in order that you give thought.\qt@no{(266)}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
Believers, spend of the good you have earned and of that which We have brought out of the earth for you. And do not intend the bad of it for your spending; while you would never take it yourselves, except you closed an eye on it. Know that Allah is Rich, the Praised.\qt@no{(267)}}%
\qt@newcmd\qurantrans@en@cclxxv{%
satan promises you with poverty and orders you to commit what is indecent. But Allah promises you His Forgiveness and bounty from Him. Allah is the Embracer, the Knower.\qt@no{(268)}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He gives wisdom to whom He will, and he who is given wisdom has been given a lot of good. Yet none will remember except the owners of minds.\qt@no{(269)}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
Whatever you spend and whatever vows you make are known to Allah. The harmdoers shall have none to help them.\qt@no{(270)}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If you reveal your charity it is good, but to give charity to the poor in private is better and will acquit you from some of your evil deeds. Allah is Knowledgeable of what you do.\qt@no{(271)}}%
\qt@newcmd\qurantrans@en@cclxxix{%
It is not for you (Prophet Muhammad to cause) their guidance. Allah guides whom He will. Whatever good you spend is for yourselves, provided that you give it desiring the Face of Allah. And whatever good you spend shall be repaid to you in full, you shall not be harmed.\qt@no{(272)}}%
\qt@newcmd\qurantrans@en@cclxxx{%
(Charity is) for the poor who are restrained in the way of Allah, and are unable to journey in the land. The ignorant take them to be rich because of their abstinence. But you can recognize them by their signs. They do not persistently beg people. Whatever good you give is known to Allah.\qt@no{(273)}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who spend their wealth by day and by night, in private and in public, their wage is with their Lord, and no fear shall be on them, neither shall they sorrow.\qt@no{(274)}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who consume usury shall not rise up (from their tomb) except as he who rises in madness that satan has touched. That is because they say: 'Selling is like usury' Allah has permitted trading and forbidden usury. To whomsoever an exhortation comes from his Lord then he desists, he shall have his past gains, and his matter is with Allah. But whoever reverts shall be among the people of the Fire and shall remain in it for ever.\qt@no{(275)}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah effaces usury and nurtures charity. Allah does not love any ungrateful sinner.\qt@no{(276)}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Those who believe and do good works, establish the prayers and pay the obligatory charity, will be rewarded by their Lord and will have nothing to fear or to regret.\qt@no{(277)}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
Believers, fear Allah and give up what is still due to you from usury, if you are believers;\qt@no{(278)}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
but if you do not, then take notice of war from Allah and His Messenger. Yet, if you repent, you shall have the principal of your wealth. Neither will you harm nor will you be harmed.\qt@no{(279)}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
If he should be in hardship, then a postponement until ease; while if you give charity it is better for you if you know.\qt@no{(280)}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
Fear the Day when you shall be returned to Allah. And every soul shall be paid in full what it has earned; and they shall not be harmed.\qt@no{(281)}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
Believers, when you contract a debt for a fixed period, put it in writing. Let a scribe write it down between you with fairness; no scribe shall refuse to write as Allah has taught him. Therefore, let him write; and let the debtor dictate, fearing Allah his Lord, and do not decrease anything of it. If the debtor is a fool, or weak, or unable to dictate himself, let his guardian dictate for him in fairness. Call to witness two witnesses of your men, if the two are not men, then a man and two women from the witnesses whom you approve; so that if one of the two errs, one of them will remind the other. Whenever witnesses are called upon they must not refuse, and do not be weary to write it down, be it small or large, together with its term. This is more just with Allah; it ensures accuracy in testifying and is the least of doubt. Unless it is present merchandise that you circulate between you; then no guilt shall be on you if you do not write it down and take witnesses when you are selling, and let no harm be done to either scribe or witness. If you do, that is a transgression in you. Fear Allah. Allah teaches you, and Allah has knowledge of everything.\qt@no{(282)}}%
\qt@newcmd\qurantrans@en@ccxc{%
If you are upon a journey and a scribe cannot be found, then let pledges be taken. If any of you trusts another let the trusted deliver his trust; and let him fear Allah his Lord. And you shall not conceal the testimony. He who conceals it, his heart is sinful. Allah has knowledge of what you do.\qt@no{(283)}}%
\qt@newcmd\qurantrans@en@ccxci{%
To Allah belongs all that is in the heavens and the earth. Whether you reveal what is in your hearts or hide it Allah will bring you to account for it. He will forgive whom He will and punish whom He will; He has power over all things.\qt@no{(284)}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Messenger believes in what has been sent down to him from His Lord, and so do the believers. Each believes in Allah and His Angels, His Books, and His Messengers, we do not differentiate between any one of His Messengers. They say: 'We hear and obey. (We ask) Your forgiveness Lord, and to You is the arrival.\qt@no{(285)}}%
\qt@newcmd\qurantrans@en@ccxciii{%
Allah charges no soul except to its capacity. For it is what it has earned, and against it what it has gained. 'Our Lord, do not take us to account if we have forgotten, or made a mistake. Our Lord, do not burden us with a load as You have burdened those before us. Our Lord, do not over burden us with more than we can bear. And pardon us, and forgive us, and have mercy on us. You are our Guide, so give us victory over the nation, the unbelievers.'\qt@no{(286)}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen AlifLaamMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah! There is no god except He, the Living, the Everlasting.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
He has sent down to you the Book with the truth, confirming what preceded it; and He has sent down the Torah and the Gospel (of Prophet Jesus which has been lost)\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
before, as a guidance for people, and He sent down the Criterion. As for those who disbelieve in the verses of Allah, for them is an intense punishment. Allah is Mighty, Owner of Vengeance.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Nothing on earth or in heaven is hidden from Allah.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@ccxcix{%
It is He who shapes you in your mothers' wombs as He wills. There is no god except Him, the Almighty, the Wise.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@ccc{%
It is He who has sent down to you the Book. Some of its verses are precise in meaning they are the foundation of the Book and others obscure. Those whose hearts are swerving with disbelief, follow the obscure desiring sedition and desiring its interpretation, but no one knows its interpretation except Allah. Those who are wellgrounded in knowledge say: 'We believe in it, it is all from our Lord. And none remember except those who are possessed of minds.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@ccci{%
Lord, do not cause our hearts to swerve after You have guided us. Grant us Your Mercy. You are the Embracing Giver.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@cccii{%
Lord, You will surely gather all the people for a Day that will come in which there is no doubt' Allah will not break His promise.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@ccciii{%
Those who disbelieve, neither their riches nor their children shall save them from Allah. They shall become the fuel of the Fire.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@ccciv{%
Like Pharaoh's people and those before them who belied Our revelations; Allah seized them in their sinfulness. Allah is firm in inflicting punishment.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@cccv{%
Say to those who disbelieve: 'You shall be overcome and gathered into Gehenna (Hell), an evil cradling'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@cccvi{%
Indeed, there was a sign for you in the two armies which met on the battlefield. One was fighting in the way of Allah, and another unbelieving. They (the believers) saw with their eyes that they were twice their own number. Allah strengthens with His victory whom He will. Surely, in that there was a lesson for those possessed of eyes.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@cccvii{%
Decorated for people are the desires of women, offspring, and of heaped up piles of gold and silver, of pedigree horses, cattle, and sown fields. These are the enjoyments of the worldly life, but with Allah is the best return.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say: 'Shall I tell you of a better thing than that? For the cautious with their Lord, theirs shall be Gardens underneath which rivers flow, where they shall live for ever, and purified spouses, and pleasure from Allah' Allah is watching over His worshipers.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@cccix{%
Those are they who say: 'Lord, we believe in You, forgive us our sins and save us from the punishment of the Fire',\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@cccx{%
who are patient, truthful, obedient, and charitable, and who ask forgiveness at dawn.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@cccxi{%
Allah bears witness that there is no god except He, and so do the angels and the knowledgeable. He upholds justice there is no god except He, the Mighty, the Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@cccxii{%
The only religion with Allah is Islam (submission). Those to whom the Book was given disagreed among themselves only after knowledge had been given to them being insolent among themselves. He who disbelieves the verses of Allah indeed Allah is Swift in reckoning.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@cccxiii{%
If they argue with you, say: 'I have submitted my face to Allah and so have those who follow me' To those who have received the Book (Jews and Nazarenes) and to the ignorant, ask: 'Have you submitted yourselves to Allah' If they became Muslims they were guided, if they turn away, then your only duty is to warn them. Allah is watching over all His worshipers.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Those who disbelieve the verses of Allah and slay the Prophets unjustly, and slay those who bid to justice give them the glad tidings of a painful punishment!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@cccxv{%
Their works shall be annulled in this world and in the Everlasting Life, and there shall be none to help them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Have you not seen those who have received a portion of the Book being called to the Book of Allah, that it might judge between them, and some turned away, swerving aside.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@cccxvii{%
For they say: 'The Fire will not touch us except for a certain number of days' And the lies they forged have deluded them in their religion.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@cccxviii{%
How will it be when We gather them for a Day in which there is no doubt, when every soul will be given what it has earned and they will not be wronged?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say: 'O Allah, Owner of the Kingdom. You give the kingdom to whom You will, and take it away from whom You will, You exalt whom You will and abase whom You will. In Your Hand is good, You have power over all things.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@cccxx{%
You cause the night to enter into the day, and the day to enter into the night. You bring forth the living from the dead and the dead from the living. You provide without reckoning to whom You will'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@cccxxi{%
The believers should not take the unbelievers as guides in preference to the believers he who does this does not belong to Allah in anything, unless you have a fear of them. Allah warns you to be cautious of Him, the arrival is to Allah.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say: 'Whether you hide what is in your hearts or reveal it, Allah knows it. He knows all that is in the heavens and earth and has power over all things'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
The Day that every soul shall find what it has done of good brought forward, and what it has done of evil, it will wish if there were only a far space between it and that (Day). Allah warns you to be wary of Him; and Allah is Gentle with His worshipers.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say (Prophet Muhammad): 'If you love Allah, follow me and Allah will love you, and forgive your sins. Allah is Forgiving and Merciful'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say: 'Obey Allah and the Messenger' But if they turn away, then truly, Allah does not love the unbelievers.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Allah chose Adam and Noah, the House of Abraham and the House of Imran above all worlds.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
They were the offspring of one another. Allah is Hearing, and Knowing.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
(Remember) when the wife of 'Imran said: 'Lord, I have vowed to You in dedication that which is hidden inside me. Accept this from me. You are the Hearer, the Knower'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@cccxxix{%
And when she was delivered of her, she said: 'Lord, I have given birth to her, a female' Allah knew of what she had given birth the male is not like the female 'and I have called her Mary. Protect her and all her descendants from satan, the stoned one'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@cccxxx{%
Her Lord graciously accepted her. He made her grow with a fine upbringing and entrusted her to the care of Zachariah. Whenever Zachariah went to her in the sanctuary, he found that she had provision with her. 'Mary' he said, 'how does this come to you' 'It is from Allah' she answered. Truly, Allah provides whomsoever He will without reckoning.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
Thereupon Zachariah supplicated to his Lord, saying: 'Lord, give me from You a good offspring. You hear all prayers'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
And the angels called out to him when he was standing in the sanctuary worshipping, saying: 'Allah gives you glad tidings of John, who shall confirm a Word from Allah. He shall be a master and chaste, a Prophet and from the righteous'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said: 'Lord, how shall I have a son when I am overtaken by old age and my wife is barren' He said: 'Even so, Allah does what He will'\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said: 'Lord, appoint for me a sign' He said: 'Your sign is that you shall not speak to people except by signs for three days' And remember your Lord abundantly, exalt Him in the evening and at the dawn'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
And when the angels said to Mary: 'Allah has chosen you and purified you. He has chosen you above all women of the worlds.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
Mary, be obedient to your Lord, prostrate and bow with those who bow'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
This is from the news of the unseen. We reveal it to you (Prophet Muhammad). You were not present when they cast their quills to see which of them should look after Mary, nor were you present when they were disputing.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
When the angels said: 'O Mary, Allah gives you glad tidings of a Word (Be) from Him, whose name is Messiah, Jesus, the son of Mary. He shall be honored in this world and in the Everlasting Life and he shall be among those who are close.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
He shall speak to people in his cradle and when he is aged, and shall be among the righteous'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@cccxl{%
'Lord' she said, 'how can I bear a child when no human being has touched me' He replied: 'Such is the Will of Allah. He creates whom He will. When He decrees a thing, He only says: ``Be," and it is.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@cccxli{%
He will teach him the Book, the Wisdom, the Torah and the Gospel,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@cccxlii{%
to be a Messenger to the Children of Israel, (saying): ``I have come to you with a sign from your Lord. From clay, I will create for you the likeness of a bird. I shall breathe into it and by the permission of Allah, it shall be a bird. I shall heal the blind, and the leper, and raise the dead to life by the permission of Allah. I shall tell you what you ate and what you store in your houses. Surely, that will be a sign for you, if you are believers.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@cccxliii{%
Likewise confirming the Torah that has been before me and to make lawful to you some of the things you have been forbidden. I bring you a sign from your Lord, therefore, fear Allah and obey me.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@cccxliv{%
Allah is my Lord and your Lord, therefore, worship Him. This is the Straight Path"'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@cccxlv{%
When (Prophet) Jesus felt their disbelief, he said: 'Who will be my helpers in the way of Allah' The disciples replied: 'We are the helpers of Allah. We believe in Allah. Bear witness that we are submitters (Muslims).\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
Lord, we have believed in what You sent down and followed the Messenger. Write us among Your witnesses'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
They devised, and Allah devised. And Allah is the Best Devisor.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
Allah said' (Prophet) Jesus, I will take you to Me and will raise you to Me, and I will purify you from those who disbelieve. I will make your followers (who died before Prophet Muhammad) above those who disbelieve till the Day of Resurrection. Then, to Me you shall all return, and I shall judge between you as to that you were at variance.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@cccxlix{%
As for those who disbelieve, I will sternly punish them in this world and in the Everlasting Life, there shall be none to help them.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@cccl{%
As for those who believe and do good works, He will pay them their wages in full. Allah does not love the harmdoers.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@cccli{%
This, We recite to you of the verses and the Wise Remembrance.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@ccclii{%
Truly, the likeness of (Prophet) Jesus with Allah, is as the likeness of Adam, He created him from dust then He said to him ``Be" and he was.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@cccliii{%
The truth is from your Lord, therefore, do not be among the doubters.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@cccliv{%
Those who dispute with you concerning him after the knowledge has come to you, say: 'Come, let us gather our sons and your sons, our womenfolk and your womenfolk, ourselves and yourselves. Then let us humbly pray, so lay the curse of Allah upon the ones who lie'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@ccclv{%
This is indeed the truthful narration. There is no god except Allah. It is Allah who is the Almighty, the Wise.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@ccclvi{%
If they turn away, Allah knows the evildoers.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say: 'People of the Book, let us come to a common word between us and you that we will worship none except Allah, that we will associate none with Him, and that none of us take others for lords besides Allah' If they turn away, say: 'Bear witness that we are Muslims'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@ccclviii{%
People of the Book, why do you dispute about Abraham when both the Torah and the Gospel were not sent down till after him? Have you no sense?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@ccclix{%
Indeed, you have disputed about that which you have knowledge. Why then dispute about that of which you have no knowledge? Allah knows and you do not know.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@ccclx{%
No, Abraham was neither a Jew nor a Nazarene. He was of pure faith, a submitter (Muslim). He was never of the idolaters.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Surely, the people who are nearest to Abraham are those who followed him, and this Prophet (Muhammad), and those who believe. Allah is the Guardian of the believers.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@ccclxii{%
Some of the People of the Book wish to make you go astray, but they lead none astray except themselves, though they do not sense it.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
People of the Book! Why do you disbelieve the verses of Allah while you are witness?\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
People of the Book! Why do you confound truth with falsehood, and knowingly hide the truth?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@ccclxv{%
Some of the People of the Book say: 'Believe in that which is sent down to those who believe at the beginning of the day and disbelieve at the end of it, so that they will return.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
Believe none except those who follow your own religion' Say: 'The true guidance is the Guidance of Allah that anyone should be given the like of what you have been given, or dispute with you before your Lord' Say: 'Bounty is in the Hand of Allah' He gives it to whomsoever He will. Allah is the Embracer, the Knower.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He singles out for His Mercy whom He will. And Allah is of abundant bounty.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
Among the People of the Book there are some, who, if you trust him with a Qintar (98, 841. 6 lbs.), will return it to you, and there are others, who, if you trust him with a dinar will not hand it back unless you stand over him, for they say: 'As for the common people, they have no recourse to us' They say lies against Allah while they know.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Rather, those who keep their promise and fear Allah Allah loves the cautious.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Those who sell the promise of Allah and their own oaths for a little price shall have no share in the Everlasting Life. Allah will neither speak to them, nor look at them, nor purify them on the Day of Resurrection. Theirs shall be a painful punishment.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And there is a sect among them who twist their tongues with the Book, so you will think it is from the Book, whereas it is not from the Book. They say: 'This is from Allah' whereas it is not from Allah. And they knowingly tell lies against Allah.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
No human to whom Allah has given the (Holy) Book, Judgement and Prophethood would say to the people: 'Be worshipers of me, other than Allah' But rather, 'Be of the Lord, for that you teach the Book, and in that you have studied'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
Nor would he order you to take the angels and the Prophets for lords, what, would he order you with disbelief after you were submitters (Muslims)!\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
And when Allah took the covenant of the Prophets: 'That I have given you of the Book and Wisdom. Then there shall come to you a Messenger (Muhammad) confirming what is with you, you shall believe in him and you shall support him to be victorious, do you agree and take My load on this' They answered: 'We do agree' Allah said: 'Then bear witness, and I will be with you among the witnesses'\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
Whosoever turns back after that, they are the transgressors.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
Are they seeking a religion other than that of Allah, and to Him whosoever is in the heavens and the earth has submitted willingly and unwillingly. To Him they shall be returned.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say: 'We believe in Allah and in what is sent down to us and in that which was sent down to Abraham, Ishmael, Isaac, Jacob and the tribes, and in that which was given to (Prophets) Moses and Jesus, and the Prophets from their Lord. We do not differentiate between any of them. To Him we are submitters (Muslims)'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
He who chooses a religion other than Islam, it will not be accepted from him, and in the Everlasting Life he will be among the losers.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How shall Allah guide a people who lapse into disbelief after they believed and bore witness that the Messenger is true, and after receiving clear proofs! Allah does not guide the harmdoers.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
Those, their recompense shall be the curse of Allah, the angels, and all the people\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
there they shall live for ever. Their punishment shall not be lightened, nor shall they be given respite.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Except those who afterwards repent and mend their ways, Allah is Forgiving and the Most Merciful.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Indeed those who disbelieve after they have believed and increase in disbelief, their repentance shall not be accepted. These are those who are astray.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
As for those who disbelieve and die unbelievers, there shall be not accepted from anyone of them, the whole earth full of gold, if he would ransom himself thereby. Those, for them there is a painful punishment, and none shall help them.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
You shall not attain righteousness until you spend of what you love. Whatever you spend is known to Allah.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was lawful to the Children of Israel except what Israel forbade himself before the Torah had been sent down. Say: 'Bring the Torah and recite it, if you are truthful'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
Those who after this invent lies about Allah are harmdoers.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say: 'Allah has said the truth. Follow the Creed of Abraham, he was of pure faith, and not an idolater'\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
The first House ever to be built for people was that at Bakkah (Mecca) blessed and a guidance for the worlds.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@cccxc{%
In it, there are clear signs; the station where Abraham stood. Whoever enters it let him be safe. Pilgrimage to the House is a duty to Allah for all who can make the journey. And whosoever disbelieves, Allah is Rich, independent of all the worlds.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say: 'People of the Book, why do you disbelieve the verses of Allah? Surely, Allah is witness to all that you do'\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say: 'People of the Book, why do you bar he who believes from the Path of Allah and seek to make it crooked, when you yourselves are witnesses? Allah is not inattentive of what you do'\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@cccxciii{%
Believers, if you obey a sect of those who were given the Book, they will turn you into unbelievers after you have believed.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@cccxciv{%
How can you disbelieve when the verses of Allah are recited to you and His Messenger is among you! He who holds fast to Allah shall be guided to the Straight Path.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@cccxcv{%
Believers, fear Allah as He should be feared, and do not die except as Muslims.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold fast to the Bond of Allah, together, and do not scatter. Remember the Favor of Allah bestowed upon you when you were enemies, and how He united your hearts, so that by His Favor you became brothers. And how He saved you from the Pit of Fire when you were on the brink of it. And so Allah makes plain to you His verses, in order that you will be guided.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
Let there be one nation of you that shall call to righteousness, ordering honor, and forbidding dishonor. Those are the prosperous.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
Do not follow the example of those who became divided and differed with one another after clear proofs had come to them. For those, there is a great punishment.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@cccxcix{%
The Day when faces will be whitened and faces blackened. To those whose faces have become blackened it will be said: 'Did you disbelieve after you had believed? Then taste the punishment for that you disbelieved'\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@cd{%
As for those whose faces will be whitened, they shall be in the Mercy of Allah for ever.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@cdi{%
Such are the verses of Allah, We recite them to you with truth. Allah does not want injustice for the worlds.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@cdii{%
To Allah belongs all that is in the heavens and the earth. To Him all matters shall return.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@cdiii{%
You are the best nation ever to be brought forth for people. You order honor and forbid dishonor, and you believe in Allah. Had the People of the Book believed, it would have surely been better for them. Some of them are believers, but most of them are evildoers.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will not harm you except a little hurt. And if they fight against you, they will turn their backs. Then they will not be victorious.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cdv{%
Abasement shall be pitched upon them wherever they are found, except they are in a bond from Allah, and a bond of the people. They have incurred theAnger of Allah and have been humiliated, because they disbelieved the verses of Allah and unjustly slew His Prophets and because they disobeyed and were transgressors.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cdvi{%
Yet they are not all alike. There are among the People of the Book an upstanding nation that recite the verses of Allah (the Koran) throughout the night and prostrate themselves,\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cdvii{%
who believe in Allah and the Last Day, who order honor and forbid dishonor and race in good works. These are the righteous.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cdviii{%
Whatever good they do, for them it shall not be denied. Allah knows the cautious.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cdix{%
As for those who disbelieve, neither their riches nor their children shall help them a thing from Allah. They are the people of the Fire, and there they shall remain for ever.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cdx{%
The wealth they spend in this worldly life is like a freezing wind that smites the harvest of a people who have wronged themselves and destroys it. Allah has not wronged them, but they wronged themselves.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cdxi{%
Believers, do not take intimates with other than your own. They spare nothing to ruin you, they yearn for you to suffer. Hatred has already shown itself from their mouths, and what their chests conceal is yet greater. Indeed, We have made clear to you the signs, if you understand.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cdxii{%
There you are loving them, and they do not love you. You believe in the entire Book. When they meet you they say: 'We, believe' But when alone, they bite their fingertips at you out of rage. Say: 'Die in your rage! Allah has knowledge of what is in your chests'\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cdxiii{%
When you are touched with good fortune, they grieve, but when evil befalls you, they rejoice. If you are patient and cautious, their guile will never harm you. Allah encompasses what they do.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cdxiv{%
And when you went out at dawn from your family to lodge the believers in their positions for the battle. Allah is Hearing, Knowing.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cdxv{%
Two parties of you were about to fail, though Allah was their Guardian, and in Allah believers put all their trust.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cdxvi{%
And Allah most assuredly helped you at Badr when you were humiliated. Therefore, fear Allah, in order that you will give thanks to Him.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cdxvii{%
When you said to the believers: 'Is it not enough for you that your Lord should reinforce you with three thousand angels sent down upon you?\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cdxviii{%
Rather, if you have patience and are cautious, and they suddenly come against you, your Lord will reinforce you with five thousand marked angels'\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cdxix{%
Allah did not make this to be except as glad tidings for you, so that your hearts might be comforted. Victory comes only from Allah, the Mighty, the Wise.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cdxx{%
And that He might cut off a part of those who disbelieve or suppress them, so that they will turn back, disappointed.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cdxxi{%
No part of the matter is yours whether He turns towards them or punishes them. They are harmdoers.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cdxxii{%
To Allah belongs all that is in the heavens and the earth. He forgives whom He will and punishes whom He will. Allah is Forgiving, the Most Merciful.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
Believers, do not consume usury, doubled and redoubled, and fear Allah, in order that you shall prosper.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
Guard yourselves against the Fire prepared for unbelievers.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cdxxv{%
Obey Allah and the Messenger in order to be subjected to mercy.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And hasten to a forgiveness from your Lord and a Paradise as wide as heaven and earth, prepared for the cautious\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
who spend in prosperity and in adversity, for those who curb their anger and those who forgive people. And Allah loves the charitable\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
and those who, if they commit indecency or wrong themselves remember Allah and ask forgiveness of their sins for who but Allah forgives sins and those who do not persist in what they do while they know.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cdxxix{%
Those, their recompense is forgiveness from their Lord and Gardens underneath which rivers flow, where they shall live for ever. How excellent is the wage of those who labor.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cdxxx{%
There have been examples before you. Journey in the land and see what was the fate of the liars.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This is a declaration to the people, a guidance and an admonition to the cautious.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
Do not be weak, neither sorrow while you are the upper ones, if you are believers.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If a wound touches you, a similar wound already has touched the nation. Such days We alternate between the people so that Allah knows those who believe, and that He will take witnesses from among you, for Allah does not love the harmdoers,\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
and so that Allah will examine those who believe and efface the unbelievers.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Did you suppose that you would enter Paradise without Allah knowing those of you who struggled and who were patient?\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
You used to wish for death before you met it, so you have seen it while you were looking.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad is not except a Messenger; Messengers have passed away before him. If he dies or is killed, will you turn about on your heels? And he who turns on his heels will not harm Allah a thing. Allah will recompense the thankful.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
It is not for any soul to die except by the permission of Allah a postponed book and he who desires the reward of this world, We shall give him of it, and he who desires the reward of the Everlasting Life, We shall give him of it. And We will recompense the thankful.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
There has been many a Prophet with whom many of the Lord have fought and they did not faint when they were smitten in the way of Allah, neither did they weaken, nor did they humble themselves, and Allah loves the patient.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cdxl{%
Their only words were: 'Lord, forgive us our sins and that we exceeded in our affair, make us firm of foot and give us victory over the unbelievers'\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@cdxli{%
And Allah gave them the reward of this life, and the best reward of the Everlasting Life. Allah loves the gooddoers.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@cdxlii{%
Believers, if you obey those who disbelieve they will turn you upon your heels and you will turn to be losers.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@cdxliii{%
But Allah is your Sponsor. He is the Best of victors.\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@cdxliv{%
We will throw terror into the hearts of those who disbelieve. For that they have associated with Allah that which He did not send down for a proof. Fire shall be their home, evil indeed is the dwellingplace of the harmdoers.\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@cdxlv{%
Allah has been true in His promise towards you when you routed them by His leave, until you lost heart, and quarreled about the matter, and disobeyed, afterHe had shown you that which you loved. Some among you wanted the world, and some among you wanted the Everlasting Life. Then He made you turn away from them in order to test you. But He has forgiven you, for Allah is Bounteous to the believers.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
And when you were going up, and paid no heed for anyone, and the Messenger was calling you from behind; so He rewarded you with grief upon grief that you might not sorrow for what escaped you neither for what smote you. And Allah is Aware of what you do.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then, after sorrow, He sent down upon you safety. Slumber overtook a party, while another party cared only for themselves, thinking of Allah thoughts that were not true, the guess of ignorance, saying: 'Have we any say in the affair' Say: 'The entire affair belongs to Allah' They conceal in themselves what they do not disclose to you. They say: 'If we had any say in the affair we should not have been killed here' Say: 'Had you stayed in your homes, those of you for whom slaying was written would have come out to their (death) beds so that Allah might try what was in your chests and that He will examine what is in your hearts' And Allah knows the innermost of the chests.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Those of you who turned away on the day when the two armies met must have been seduced by satan on account of some of what they had earned. But Allah has pardoned them. He is Forgiving and Clement.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@cdxlix{%
Believers, do not be as those who disbelieve and say of their brothers when they journey in the land or go of to battle: 'Had they stayed with us, they would not have died, nor would they have been killed' In order that Allah will make that a regret in their hearts. Allah revives and causes to die. He has knowledge of what you do.\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@cdl{%
If you should be killed in the way of Allah or die, the Forgiveness and Mercy from Allah would surely be better than all you amass.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@cdli{%
And if you die or are killed, before Allah you shall all be gathered.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@cdlii{%
It was by that Mercy of Allah that you (Prophet Muhammad) dealt so leniently with them. Had you been harsh and hardhearted, they would have surely deserted you. Therefore, pardon them and ask forgiveness for them. Take counsel with them in the matter and when you are resolved, put your trust in Allah. Allah loves those who trust.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah helps you, none can overcome you. If He forsakes you, who then can help you after Him? Therefore, in Allah let the believers put all their trust.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not for a Prophet to defraud, whosoever defrauds shall bring that fraud on the Day of Resurrection. Then, every soul shall be paid in full what it has earned, and they shall not be wronged.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@cdlv{%
Is he who follows the pleasure of Allah like he who is laden with the Anger of Allah, Gehenna (Hell) shall be his shelter. Evil shall be his return!\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They are in ranks with Allah. Allah sees what they do.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Allah has surely been gracious to the believers when He sent among them a Messenger from themselves to recite to them His verses, to purify them, and to teach them the Book and the Wisdom (prophetic sayings), though before that they were in clear error.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@cdlviii{%
Why, when an affliction hits you and that you had yourselves inflicted twice the like of it, you said: 'How is this' Say: 'This is from your own selves' Surely, Allah has power over all things.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@cdlix{%
What hit you the day the two armies met was by the permission of Allah, so that He might know the believers\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@cdlx{%
and that He might know the hypocrites' When it was said to them: 'Come, fight or repel in the way of Allah' They replied: 'If only we knew how to fight, we would follow you' On that day, they were nearer to disbelief than belief. They said with their mouths what was not in their hearts. And Allah knows what they hide.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@cdlxi{%
Who said to their brothers and they themselves had stayed behind 'Had they obeyed us, they would not have been killed' Say to them: 'Avert death from yourselves then, if what you say is true'\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@cdlxii{%
You must not think that those who were killed in the way of Allah are dead. But rather, they are alive with their Lord and have been provided for,\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
rejoicing in the Bounty that Allah has given to them and having glad tidings in those who remain behind and have not joined them, for no fear shall be on them neither shall they sorrow,\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
having glad tidings of a Favor and Bounty from Allah. Allah will not waste the wage of the believers.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@cdlxv{%
Those who answered Allah and the Messenger after the wound had afflicted them, for those of them who did good and were cautious there is a great wage.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Those to whom the people said: 'The people have gathered against you, therefore fear them' but it increased them in belief and they said: 'Allah is Sufficient for us. He is the Best Guardian'\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So, they returned with the Favor and Bounty of Allah so evil did not touch them. They followed the pleasure of Allah, and Allah is of Great Bounty.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
That is satan frightening those whom he sponsored. So do not fear them, and fear Me, if you are believers.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@cdlxix{%
Do not let those who race in disbelief sadden you. They will not harm Allah a thing. Allah does not want to give them a share in the Everlasting Life. For them is a great punishment.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Those who buy disbelief with belief will not harm Allah a thing, for them there is a painful punishment!\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
Do not let those who disbelieve think that what We delay is better for them. Indeed, We delay for them only that they will increase in sin, and for them a humiliating punishment.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
Allah will not leave the believers in that which you are till He shall distinguish the evil from the good. Allah will not let you see the unseen. But Allah chooses from His Messengers whom He will. Therefore, believe in Allah and His Messengers, for if you believe and are cautious there shall be for you a great wage.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
And do not let those who are greedy with what Allah has given them of His Bounty think it is better for them, but rather, it is worse for them. They will be coiled in that which they were greedy on the Day of Resurrection. And to Allah belongs the inheritance of the heavens and the earth. And Allah is Aware of what you do.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Allah has heard the saying of those who said: 'Allah is poor, but we are rich' We will write down what they have said, and their slaying of the Prophets without right. And We shall say: 'Taste the punishment of the burning'\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
That, is for what your hands have forwarded. And Allah is never unjust to His worshipers.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
Those (the Jews) who say: 'Allah has promised us that we do not believe in a Messenger unless he brings to us an offering that fire consumes' Say: 'Indeed Messengers have come to you before me with clear proofs and with that of which you spoke. Why did you kill them, if what you say is true'\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
If they belie you (Prophet Muhammad), indeed other Messengers before you were belied who came with clear proofs, and the Psalms, and the Illuminating Book.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Every soul shall taste death. You shall be paid your wages in full on the Day of Resurrection. Whoever is removed from Hell and is admitted to Paradise shall prosper, for the worldly life is nothing but the enjoyment of delusion.\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
You shall be tried in your wealth and yourselves, and you shall hear much hurt from those who were given the Book before you, and from those who are idolaters. But if you are patient and cautious, surely, that is of the firm affairs.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
When Allah took a covenant with those to whom the Book was given, (saying): 'You shall make it clear to the people, and not conceal it. 'But they threw it behind their backs and they bought with it a little price. Evil was what they bought.\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Do not think that those who rejoice in what they have brought and love to be praised for what they have not done do not think they will be secure from the punishment. And for them there is a painful punishment.\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
To Allah belongs the Kingdom of the heavens and the earth. Allah has Power over all things.\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Surely, in the creation of the heavens and the earth, and in the alternation of night and day, there are signs for those with minds.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Those who remember Allah when standing, sitting, and on their sides, and contemplate upon the creation of the heavens and the earth (saying:) 'Lord, You have not created these in falsehood. Exaltations to You! Guard us against the punishment of the Fire.\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
Our Lord, whomsoever You admit into the Fire, You will have abased, and the harmdoers shall have no helpers.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
Our Lord, we have heard the caller calling to belief, ``Believe in your Lord!" So we believe. Our Lord, forgive us our sins and acquit us of our evil deeds, and take us to You in death with the righteous.\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
Our Lord, give us what You promised us by Your Messengers, and do not abase us on the Day of Resurrection. You do not break Your promise'\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
And indeed their Lord answers them: 'I do not waste the labor of any that labors among you, male or female you are from each other. And those who emigrated, and were expelled from their houses, those who suffered hurt in My way, and fought, and were killed those I shall surely acquit of their evil deeds, and I shall admit them to Gardens underneath which rivers flow' A reward from Allah, and Allah with Him is the best reward.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Do not let the coming and going in the land of those who disbelieve delude you;\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@cdxc{%
a little enjoyment, then, their shelter is in Gehenna (Hell), an evil cradling.\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@cdxci{%
But for those who fear their Lord, for them shall be Gardens underneath which rivers flow, there they shall live for ever, a (goodly) hosting from Allah, and that which is with Allah is better for the righteous.\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@cdxcii{%
There are some among the People of the Book who believe in Allah, and in what has been sent down to you, and what has been sent down to them, humble to Allah and do not buy with the verses of Allah a little price. Those, their wage shall be with their Lord. Allah is Swift at reckoning.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@cdxciii{%
Believers, be patient, and race in patience, be steadfast, fear Allah, in order that you will be victorious.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O people, fear your Lord, who created you from a single soul. From it He created its spouse, and from both of them scattered many men and women. Fear Allah, by whom you ask one another, and (fear) the wombs (lest you sever its relationship). Allah is ever watching over you.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@cdxcv{%
Give the orphans their wealth. Do not exchange the evil for the good, nor consume their wealth with your wealth. Surely, that is a great sin.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
If you fear that you cannot act justly towards the orphans, then marry such women as seem good to you; two, three, four of them. But if you fear that you cannot do justice, then one only, or, those you possess. It is likelier then that you will not be partial.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
Give women their dowries freely, but if they are pleased to offer you any of it, consume it good and smooth.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
Do not give the (orphaned) fools your wealth with which Allah has entrusted you for (their) support, and provide for them and clothe them from it, and speak to them with kind words.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@cdxcix{%
And test the orphans until they reach (the age of) marriage. If you perceive in them right judgment, hand over to them their wealth, and do not consume it wastefully, nor hastily before they are grown. And whosoever is rich let him abstain, if poor, let him consume with kindness. When you hand over to them their wealth, take witness over them; it is sufficient that Allah is the Reckoner.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@d{%
Men shall have a share in what their parents and kinsmen leave, and women shall have a share in what their parents and kinsmen leave, whether it is little or abundant, it is an obligated share.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@di{%
If relatives, orphans, or the needy are present at the division (of the inheritance), provide for them out of it, and speak to them in kind words.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dii{%
And let them fear, who, if they themselves left behind weak offspring, would be afraid for them, and let them fear Allah and speak exactly.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@diii{%
Those who consume the wealth of orphans wrongfully, only consume fire in their bellies, and they shall roast in the Blaze.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@div{%
Allah charges you concerning your children, for a male like the share of two females. If they are women, above two, they shall have two thirds of what he left, but if she is one, then to her a half. While for his parents, to each one of the two a sixth of what he left, if he has a child. But if he has no child and his heirs are his parents, his mother shall have a third. If he has siblings, to his mother a sixth after any bequest he had bequeathed, or any debt. Your fathers and your children, you do not know which of them is nearer in benefit to you. This is an obligation from Allah. Surely, Allah is the Knower, the Wise.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dv{%
For you half of what your wives leave if they have no child. If they have a child, a quarter of what they leave shall be yours after any bequest she had bequeathed, or any debt. And for them (the females) they shall inherit one quarter of what you leave if you have no child. If you have a child, they shall inherit one eighth, after any bequest you had bequeathed, or any debt. If a man or a woman have no direct heirs, but have a brother or a sister, to each of the two a sixth. If they are more than that, they shall equally share the third, after any bequest that he had bequeathed or any debt without harm. This is an obligation from Allah. He is the Knower, the Clement.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dvi{%
Such are the Bounds of Allah. He who obeys Allah and His Messenger, He will admit him to Gardens underneath which rivers flow. That is a great wining.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dvii{%
And he who disobeys Allah and His Messenger and transgresses His Bounds, He will admit him to a Fire and shall live in it for ever. For him, there is a humiliating punishment.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dviii{%
If any of your women commit indecency, call in four witnesses from among yourselves against them, if they testify, confine them to their houses till death overtakes them or till Allah makes for them a way.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dix{%
If two among you commit it punish them both. If they repent and make amends, leave them alone. Allah is the Relenter, the Merciful.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dx{%
(Allah accepts) the repentance from only those who commit evil in ignorance and then quickly turn to Him in repentance. Allah will relent towards them. Allah is Knowing, Wise.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dxi{%
(Allah will accept) no repentance from those who do evil deeds until death comes to one of them, he says: 'Now I repent' Nor those who die unbelieving. For those We have prepared a painful punishment.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dxii{%
Believers, it is unlawful for you to inherit women forcefully, neither bar them, in order that you go off with part of what you have given them, except when they commit a clear indecency. Live with them honorably. If you hate them, it may be that you hate something which Allah has set in it much good.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dxiii{%
If you wish to take a wife in the place of another wife, and you have given to one a Qintar (98, 841. 6 lbs.) so do not take from it anything. What, will you take it by way of calumny and a clear sin!\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dxiv{%
How can you take it back when you have reached one another (sexually) and they have taken from you a strong covenant!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dxv{%
And do not marry women your fathers married unless it is a thing of the past surely that was an indecency, hated, and a way of evil.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden to you are your mothers, your daughters, your sisters, your paternal aunts and maternal aunts, your brother's daughters, your sister's daughters, your mothers who have given suck to you, your suckling sisters, your wives mothers, and your stepdaughters who are in your care from your wives with whom you have lain, but if you have never lain with them it is no fault in you. (Also forbidden to you) are the wives of your sons who are of your loins, and to take to you two sisters together unless it is a thing of the past. Allah is the Forgiver and the Most Merciful.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dxvii{%
And (forbidden to you) are married women, except those whom your right hand owns. Such Allah has written for you. Lawful to you beyond all that, is that you can seek using your wealth in marriage and not fornication. So whatever you have enjoyed from them give them their obligated wage. And there is no fault in you in what ever you mutually agree after the obligation. Allah is the Knower, the Wise.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dxviii{%
If any one of you do not have the affluence to be able marry free believing women, (let him marry) from among the believing women that your right hand owns. Allah knows best your belief, you are from each other. Marry them with the permission of their people and give them their wages (dowry) honorably being women in marriage and chaste, not taking lovers. If, after marriage they commit adultery, they shall be liable to half the punishment of a married (free) woman. That is for those of you who fear fornication, but it is better for you to be patient. Allah is the Forgiver, the Most Merciful.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah wishes to make this clear to you and to guide you along the ways of those who have gone before you, and turns towards you. And Allah is the Knower, the Wise.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dxx{%
Allah wishes to turn towards you, but those who follow their lower desires wish you to greatly swerve away.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dxxi{%
Allah wishes to lighten for you (the jurisprudence), and humans are created weak.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dxxii{%
Believers, do not consume your wealth among yourselves in falsehood, except there be trading by your mutual agreement. And do not kill yourselves. Allah is the Most Merciful to you.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dxxiii{%
But whosoever does that in transgression and wrongfully We shall roast him in the Fire. That is an easy matter for Allah.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If you avoid the major sins that are forbidden to you, We shall pardon your evil deeds and admit you by an entrance of honor.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dxxv{%
Do not wish for the bounty which Allah has preferred one of you above another. For men is a share of what they earn, and for women is a share of what they earn. Ask Allah of His Bounty. Allah has knowledge of all things.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dxxvi{%
To everyone we have made heirs of that which parents and kinsmen leave, and those with whom you have sworn an agreement, so give to them their share. Allah is Witness over everything.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are the maintainers of women for that Allah has preferred in bounty one of them over another, and for that they have spent of their wealth. Righteous women are obedient, guarding in secret that which Allah has guarded. Those from whom you fear rebelliousness, admonish them and desert them in the bed and smack them (without harshness). Then, if they obey you, do not look for any way against them. Allah is High, Great.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dxxviii{%
If you fear a breach between them send for an arbiter from his people and an arbiter from her people. If both wish reconciliation, Allah will bring success between them. Allah is the Knower, the Aware.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dxxix{%
Worship Allah and do not associate anything with Him. Be kind to parents and near kinsmen, to the orphans and to the needy, to your neighbor who is your kindred, and to the neighbor at your far side, and the companion at your side, and to the destitute traveler, and to that which your right hands owns. Allah does not love he who is proud and struts,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dxxx{%
(or) those who are greedy and order other people to be greedy, who themselves conceal the bounty that Allah has given them. And We have prepared a humiliating punishment for the unbelievers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dxxxi{%
And those who spend their wealth to showoff to people and neither believe in Allah nor in the Last Day. Whosoever has satan for a companion, he is an evil companion.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dxxxii{%
What (harm) could befall them if they believed in Allah and the Last Day and spent of what Allah provided them with? Allah is Knowledgeable of them all.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Surely, Allah shall not harm so much as the weight of an atom, and if it is a good deed He will double it, and give from His Own a great wage.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
How then shall it be when We bring forward from every nation a witness, and bring you (Prophet Muhammad) to witness against those!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dxxxv{%
On that Day those who disbelieved, and have disobeyed the Messenger (Muhammad) will wish that the earth might be leveled with them, and they will not conceal a statement from Allah.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
Believers, do not come close to prayer when you are drunk, until you know what you are saying, nor when you are in a state of impurity, unless you are crossing through the way (prayer area) until you have bathed yourselves. If you are ill or on a journey, or if any of you comes from the toilet or you have touchedwomen, and you cannot find water, so touch pure dust and wipe your faces and your hands. Allah is the Pardoner, the Forgiver.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Have you not seen those to whom a portion of the Book was given purchasing error and wishing that you should err from the Path?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
But Allah knows best your enemies. It is sufficient that Allah is the Guardian, and it is sufficient that Allah is the Helper.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Some Jews tampered with the words (altering) their places saying: 'We have heard and we disobey' and 'Hear, without hearing' and 'Observe us (Ra'ina, in Hebrew means evil) ', twisting with their tongues traducing religion. But if they had said: 'We have heard and obey' and 'Hear' and 'Regard us' it would have been better for them, and more upright; but Allah has cursed them for their disbelief, so they do not believe, except a few.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dxl{%
You, to whom the Book was given, believe in that which We have sent down confirming that which you have, before We obliterate faces and turn them on their backs, or curse them as We cursed the people of the Sabbath. And the command of Allah is done.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dxli{%
Allah does not forgive (the sin of inventing an) association with Him, but He forgives other (sins) to whomsoever He will. He who associates with Allah has invented a great sin.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dxlii{%
Have you not seen those who exalt themselves? Rather, Allah purifies whom He will and they shall not be wronged a single tissue that covers a date stone.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dxliii{%
Look how they forge lies against Allah, and it is sufficient for a clear sin.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dxliv{%
Have you not seen those to whom a portion of the Book was given believing in (the two statutes of Mecca) jibt and taghout and say to those who disbelieve: 'Those are more guided on the way than those who believe.'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dxlv{%
Those are they whom Allah has cursed and whosoever Allah has cursed, you will not find any helper for him.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Or, will they have a share in the Kingdom? If so, they will not give the people the pit mark of a date stone.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or do they envy people for the Bounty Allah has given them? We gave the family of Abraham the Book and Wisdom, and a great kingdom.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dxlviii{%
There are some of them who believed in him (Prophet Muhammad), and some of them that bar from it, and Gehenna (Hell) is sufficient for a Blaze.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dxlix{%
Those who disbelieve Our verses We will roast them in a Fire! As often as their skins are cooked, We exchange their skin with another, in order that they taste the punishment. Surely, Allah is Mighty, the Wise.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dl{%
As for those who believe and do good works, We shall admit them to Gardens underneath which rivers flow, they are there for eternity, and for them purified spouses. And We shall admit them into plenteous shade.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dli{%
Allah orders you all to hand back trusts to their owners, and when you judge between people you judge with justice. Indeed, the best is the exhortation with which Allah exhorts you. Allah is the Hearer, the Seer.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dlii{%
Believers, obey Allah and obey the Messenger and those in authority among you. Should you dispute about anything refer it to Allah and the Messenger, if you believe in Allah and the Last Day. That is better and the best interpretation.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dliii{%
Have you not seen those who claim that they believe in what has been sent down to you and what was sent down before you? They desire to be judged by the idol, although they have been commanded to disbelieve it. But satan desires to lead them astray into far error.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dliv{%
When it is said to them: 'Come to what Allah has sent down and to the Messenger' you see the hypocrites completely barring the way to you.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dlv{%
How would it be if some affliction hit them for what their hands have forwarded? Then, they would come to you swearing by Allah, 'We sought only kindness and conciliation'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dlvi{%
Those, Allah knows what is in their hearts, so turn away from them, and exhort them, and say to them penetrating words about themselves.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dlvii{%
We did not send a Messenger except that he should be obeyed, by the permission of Allah. If, when they wronged themselves, they had come to you and asked Allah for forgiveness, and the Messenger had asked for forgiveness for them, they would have found Allah the Turner, the Most Merciful.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dlviii{%
But no, by your Lord, they will not believe you until they make you the judge regarding the disagreement between them, then, they will not find in themselves any discomfort concerning your verdict, and will surrender to you in full submission.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dlix{%
Had We written for them, saying, 'Slay yourselves' or 'Emerge from your houses' they would not have done so, except a few of them. Yet, if they had done as they were exhorted, it would have been better for them, and stronger in firmness,\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dlx{%
and then We would surely have given them from Our Own, a great wage,\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dlxi{%
and guided them to a Straight Path.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dlxii{%
Whosoever obeys Allah, and the Messenger, they are with those whom Allah has favored, the Prophets, the sincere, the martyrs and the righteous, and these are the best company.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dlxiii{%
This is the Bounty of Allah. It is sufficient that Allah is the Knowledgeable.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dlxiv{%
Believers, take your precautions. March in detachments or march all together.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dlxv{%
Surely, there are among you, he who lingers, then, if an affliction hits you, he would say: 'Allah has favored me, that I was not a martyr with them'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dlxvi{%
But, if the Bounty of Allah reaches you, he would surely say as if there had never been any affection between you and him: 'Would that I had been with them! I should have indeed won a great triumph'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dlxvii{%
So let those who sell the worldly life for the Everlasting Life fight in the way of Allah, whoever fights in the way of Allah, and is killed or conquers, We shall give him a great wage.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dlxviii{%
So why is it, that you do not fight in the way of Allah, and for the abased among men, women, and children who say: 'Our Lord, bring us out from this village whose people are harmdoers, and give to us a guardian from You, and give to us a helper from You.'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dlxix{%
And those who believe fight in the way of Allah, but those who disbelieve fight in the way of the idol. Therefore, fight against those guided by satan. Indeed, satan's guile is always weak.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dlxx{%
Have you not seen those to whom it has been said: 'Restrain your hands, establish your prayers and pay the obligatory charity' Then, as soon as fighting is written for them, there is a party of them fearing people as they would fear Allah, or with stronger fear. And they say: 'Our Lord, why have You written fighting for us, why not postpone us to a near term' Say: 'The pleasure of this life is little. The Everlasting Life is better for the cautious. You shall not be wronged a single tissue (of the fine skin that covers a date stone).\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dlxxi{%
Wherever you are, death will overtake you, even if you shall be in the fortified, high towers' If bounty reaches them, they say: 'This is from Allah' but when evil hits them, they say: 'This is from you' Say to them: 'All is from Allah' What is the matter with this people that they scarcely understand any statement.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever good reaches you, it is from Allah, and whatever evil reaches you, it is from yourself. We have sent you (Prophet Muhammad) as a Messenger to humanity. Allah is sufficient for a Witness.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
Whosoever obeys the Messenger, indeed he has obeyed Allah. As for those who turn away, We have not sent you to be their protector.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
They say, 'Obedience' but as soon as they leave you, a party of them hide other than what they said. Allah writes down what they hide. So turn away from them, and rely on Allah. Allah is sufficient for a Guardian.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Will they not contemplate upon the Koran? If it had been from other than Allah, they would surely have found in it many contradictions.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
When a matter comes to them, be it of security or fear, they broadcast it, whereas if they returned it to the Messenger and to those in authority among them, those of them whose task is to research it would have known it. If it was not for the Bounty of Allah and His Mercy, all but a few of you would have followed satan.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
Therefore, fight in the way of Allah. You are only responsible for yourself. Urge the believers on, in order that Allah may restrain the might of those who disbelieve. Allah is stronger in might, and stronger in punishment.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whosoever intercedes with a good intercession shall receive a share of it, and whosoever intercedes with a bad intercession shall receive a portion of it. Allah has power over all things.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dlxxix{%
And when you are greeted with a greeting, greet with better than it, or return it. Allah is the Reckoner of all things.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dlxxx{%
Allah, there is no god except He. He will gather you to the Resurrection Day, there is no doubt in it. And who is truer in statement than Allah?\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
What is the matter with you that you are two parties concerning the hypocrites when Allah has overthrown them for what they earned? Would you desire to guide those whom Allah has caused to be led astray? Whosoever Allah leads astray, you will not find for him a way.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They wish that you would disbelieve as they disbelieve, and then you would be equal. Therefore, do not take a guide from them until they emigrate in the way of Allah. Then, if they turn back take them and kill them wherever you find them. Do not take them for guides or helpers,\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
except those who join to a nation in which there is between you and them a treaty, or they come to you with their chests constricted from fighting you or fighting their nation. Had Allah willed, He would have given them power over you, and then they would have certainly fought you. Therefore, if they keep away from you and do not fight you, offering you peace, then Allah does not make any way for you against them.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
You will find others desiring to be secure from you, and secure from their own nation. Whenever they are called back to sedition, they plunge into it. If they do not keep away from you and offer you peace, and restrain their hands, take them and kill them wherever you find them. Those, over them, We give you clear authority.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
It is not for a believer to kill another believer, except that it is by error. Whosoever kills a believer in error, let him free a believing slave, and ransom is to be handed to his family, unless they forgo being charitable. If he belonged to a people who are your enemies and is a believer then, the setting free of a believing slave. If he belonged to a people in which there is between you and them a treaty, then a ransom is to be handed to his family and the setting free of a believing slave. But, if he does not find (the means) let him fast two consecutive months in repentance to Allah. And Allah is the Knower, the Wise.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
The recompense for he who kills a believer deliberately is Gehenna (Hell), he is eternal there. Allah will be angry with him and will curse him and prepare for him a great punishment.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
Believers, if you are journeying in the way of Allah, do not say to those who offer you peace, until it has been clarified: 'You are not believers' seeking the enjoyment of the worldly life, with Allah there are many spoils. You were like that before, and Allah has been gracious to you. Therefore let it be clarified. Surely, Allah is Aware of what you do.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Believers who stay behind, having no injury, are not equal to those who fight in the way of Allah with their wealth and their souls. Allah has preferred those who fight with their wealth and their souls a degree above those who stay behind (because of sickness). Yet to each, Allah has promised the most excellent (Paradise). And Allah has preferred those who fought over those who stayed behind with a great wage.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Ranks from Him, forgiveness and mercy. Allah is the Forgiver, the Most Merciful.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dxc{%
And the angels who take those who wronged themselves will say: 'In what condition were you' They will reply 'We were oppressed in the land' They (the angels) will say: 'Was not the earth of Allah wide enough for you in order that you migrate in it' Those, their shelter will be Gehenna (Hell), an evil arrival.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dxci{%
Except the men, women, and children, who, being abased have no means and they are unable to guide themselves to a way.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dxcii{%
Those, Allah may pardon them, He is the Pardoner, the Forgiver.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dxciii{%
Whosoever emigrates in the way of Allah shall find in the land numerous refuges and abundance. Whosoever leaves his house an immigrant to Allah and His Messenger and then death overtakes him, his wage shall have fallen upon Allah. Allah is the Forgiver, the Most Merciful.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dxciv{%
And when you are journeying in the land, there is no fault in you that you shorten the prayer if you fear that those who disbelieve will afflict you. Indeed, the unbelievers are a clear enemy for you.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dxcv{%
When you are with them, and establish the prayer, let a party of them stand with you, and let them take their weapons. After making their prostrations, let them be behind you, and let another party who have not prayed come and pray with you, taking their precautions and their weapons. Those who disbelieve wish that you should be inattentive of your weapons and your baggage, so that they might swoop upon you with one assault. But there is no fault in you if you are harmed by rain, or you are sick to lay aside your weapons, but take your precautions. Allah has prepared a humiliating punishment for the unbelievers.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dxcvi{%
When you have established the prayer, remember Allah standing, sitting, and on your sides. Then, when you are secure, establish the prayer, surely, prayer is timely written upon the believer.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dxcvii{%
And do not be weak in seeking out the people. If you are suffering, they are also suffering as you are suffering, but you are hoping from Allah that which they do not hope. Allah is the Knower, the Wise.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dxcviii{%
Surely, We have sent down to you the Book with the truth, so that you will rule between the people by that Allah has shown you. So do not be an advocate for the traitors.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dxcix{%
And ask the forgiveness of Allah, surely Allah is the Forgiver, the Most Merciful.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dc{%
And do not argue on behalf of those who betray themselves, surely, Allah does not love the sinful traitor.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dci{%
They seek to hide themselves from the people, but they do not hide themselves from Allah for He is with them when they hide the saying that does not please Him. Allah encompasses what they do.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcii{%
There you are, you have argued on their behalf in the worldly life, but who will argue with Allah on their behalf on the Day of Resurrection! Or who will be a guardian for them?\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dciii{%
He who does evil or wrongs himself and then asks forgiveness of Allah will find that Allah is the Forgiver, the Most Merciful.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@dciv{%
Whosoever earns a sin, he only earns it against himself. Allah is the Knower, the Wise.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@dcv{%
Whosoever earns a fault or a sin and casts it upon the innocent, indeed, he bears the slander and a clear sin.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@dcvi{%
But for the Favor of Allah to you (Prophet Muhammad) and His Mercy, a party of them intended to lead you astray, but they only lead themselves astray, and they did not harm you a thing. Allah has sent down to you the Book and the Wisdom and He has taught you what you did not know. The Bounty of Allah to you is ever great.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@dcvii{%
There is no good in much of their confiding, except for he who bids to charity, honor, or reforms between people. Whosoever does that for the sake of the pleasure of Allah, We shall give him a great wage.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@dcviii{%
But whosoever opposes the Messenger after guidance has been made clear to him and follows a path other than that of the believers, We shall let him follow what he has turned to and We shall roast him in Gehenna (Hell) an evil arrival.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@dcix{%
Allah does not forgive (the sin of inventing an) association with Him, but He forgives other sins to whomsoever He will. Whosoever associates with Allah has gone astray in far error.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@dcx{%
Instead of Him they supplicate to none but females, and indeed they supplicate to none except the rebellious satan,\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@dcxi{%
whom Allah has cursed and he (satan) said: 'Indeed, I will take to myself an appointed portion of Your worshipers,\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@dcxii{%
and lead them astray. I shall fill them with fancies and order them to cut off the ears of cattle. I shall order them to alter the creation of Allah' Indeed, whosoever chooses satan for a guide, instead of Allah, has surely suffered a clear loss.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@dcxiii{%
he promises them and fills them with fancies, but what satan promises them is only a delusion.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@dcxiv{%
Those, their shelter will be Gehenna (Hell), and from it they shall find no refuge.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@dcxv{%
But those who believe and do good works We shall admit them to Gardens underneath which rivers flow, and there they shall live for ever, the promise of Allah is true. And who is truer in speech than Allah!\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@dcxvi{%
It is not by your fancies, nor by the fancies of the People of the Book. Whosoever does evil shall be recompensed for it, and he will not find for himself, other than Allah, a guardian or helper.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@dcxvii{%
But whosoever does good works of righteousness, whether they be a believing male or female, shall enter Paradise, and not be wronged a pit mark of a date stone.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And who is better in religion than he who submits his face to Allah, being a gooddoer, and follows the Creed of Abraham, pure in faith? Allah took Abraham for a close friend.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@dcxix{%
To Allah belongs all that is in the heavens and the earth. Allah encompasses everything.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@dcxx{%
They will ask you for a verdict concerning women. Say: ``Allah decides for you concerning them, and what has been recited in the Book concerning orphaned women to whom you do not give what is written, and yet desire to marry them, and the abased children, and that you secure justice for orphans. Whatever good you do, Allah has knowledge it.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@dcxxi{%
If a woman fears hatred or aversion from her husband there is no fault in them if the couple set things right between them, for reconciliation is better. Avarice attends the souls, but if you do what is good and are cautious, surely, Allah is Aware of what you do.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@dcxxii{%
You will not be able to be just between your women, even though you are eager. Do not be altogether partial so that you leave her as if she were suspended. If you reform and are cautious, Allah is the Forgiver, the Merciful.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
But if they separate, Allah will enrich each of them out from His Vastness. He is the Embracer, the Wise.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
To Allah belongs all that is in the heavens and earth. We have charged those who were given the Book before you and you to fear Allah. If you disbelieve, to Allah belongs all that is in the heavens and the earth. Allah is Rich, the Praised.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@dcxxv{%
To Allah belongs all that is in heaven and earth. It is sufficient that Allah is a Guardian.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
O people, if He will, He could make you extinct, and bring others. Surely, Allah is Powerful over that.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whosoever desires the reward of the world, with Allah is the reward of the world and of the Everlasting Life. Allah is the Hearer, the Seer.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
Believers, be maintainers of justice and witnesses for Allah, even though it is against yourselves, your parents, or your kinsmen, whether he is rich or poor, Allah has more rights over both of them. So do not follow desires, so that you are (not) just. If you twist or turn, Allah is Aware of what you do.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@dcxxix{%
Believers, believe in Allah and His Messenger (Muhammad), in the Book He has sent down to His Messenger, and in the Book He sent down before. Whosoever disbelieves in Allah, His angels, His Books, His Messengers, and the Last Day, has surely gone astray into far error.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Those who believe, and then disbelieve, and then believe, and then disbelieve, and increase in disbelief Allah is not to forgive them nor guide them on a way.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Give glad tidings to the hypocrites that for them there is a painful punishment.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who take unbelievers for guides instead of believers, are they seeking might with them? Surely, the Might altogether belongs to Allah.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
He has sent down upon you in the Book: ``When you hear His verses being disbelieved or mocked, do not sit with them until they engage in other talk, or elseyou will surely be like them. Allah will surely gather the hypocrites and unbelievers altogether in Gehenna (Hell).\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
(As for) those who lay in wait for you. If a victory comes to you from Allah they say: 'Were we not with you' But if the unbelievers get a portion, they say, 'Were we not mightier than you, and did we not defend you from the believers' Allah will judge between you on the Day of Resurrection. Allah will not grant the unbelievers any way over the believers.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
The hypocrites seek to deceive Allah, but Allah is deceiving them. When they stand up to pray, they stand up lazily, showing off to the people and do not remember Allah, except a little,\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
wavering between (belief and disbelief), neither to these nor to those, and whom Allah leads astray, you will not find a way for him.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
Believers, do not take the unbelievers for guides instead of the believers, or do you desire to give Allah a clear authority over you?\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
The hypocrites will be in the lowest place of the Fire, you will not find a helper for them.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
But those who repent and mend (their ways), who hold fast to Allah, and make their religion sincerely for Allah they are with the believers, and Allah will certainly give the believers a great wage.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@dcxl{%
What, would Allah do with punishing you if you thank and believe! Allah is the Thanker, the Knower.\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah does not love the shouting of evil words, except by he who has been wronged. He is the Hearer, the Knower.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@dcxlii{%
If you display good or hide it, or pardon an evil, surely, Allah is the Pardoner, the Powerful.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Those who disbelieve in Allah and His Messengers, and desire to divide between Allah and His Messengers (by believing in Him without them), and say, 'We believe in some (Prophets Moses and Jesus), and disbelieve in some of them (such as Prophet Muhammad)' desiring to take between this (and that) a way (between belief and disbelief)\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@dcxliv{%
those in truth are the unbelievers, and We have prepared for the unbelievers a humiliating punishment.\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@dcxlv{%
And those who believe in Allah, and His Messengers and do not divide between any of them; to those, We shall surely give them their wages. Allah is the Forgiver, the Most Merciful.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The People of the Book ask you to bring down upon them a Book from heaven. Of Moses they asked greater than that, they said to him: 'Show us Allah openly' And a thunderbolt took them for their evil doing. Then they took to themselves the calf, after the clear proofs had come to them, yet We forgave that and We gave Moses clear authority.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And We raised the Mount above them, and took covenant with them, and We said: 'Enter in at the gate, prostrating', and We said to them, 'Do not transgress the Sabbath', and We took from them a solemn covenant.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
So, for their breaking of the covenant, and disbelieving the verses of Allah, and killing their Prophets without right and for saying, 'Our hearts are covered' no, but Allah has sealed them for their disbelief, so, except for a few, they do not believe.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@dcxlix{%
Also for their disbelief and their saying about Mary a great calumny,\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@dcl{%
and for their saying, 'We killed the Messiah, Jesus the son of Mary, the Messenger (and Prophet) of Allah' They did not kill him, nor did they crucify him, but to them, he (the crucified) had been given the look (of Prophet Jesus). Those who differ concerning him (Prophet Jesus) are surely in doubt regarding him, they have no knowledge of him, except the following of supposition, and (it is) a certainty they did not kill him.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@dcli{%
Rather, Allah raised him up to Him. Allah is Almighty, the Wise.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@dclii{%
There is not one of the People of the Book but will surely believe in him (Prophet Jesus) before his death, and on the Day of Resurrection he will be a witness against them.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@dcliii{%
And for the harmdoing of those of Jewry, We have forbidden them the good things that were permitted to them, and also for their barring many from the way of Allah.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@dcliv{%
And for their taking of usury, that they were prohibited, and consuming the wealth of people in falsehood, for the unbelievers among them We have prepared a painful punishment.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@dclv{%
But those of them that are firmly rooted in knowledge, and the believers believing in what has been sent down to you (Prophet Muhammad), and what was sent down before you, and those who establish the prayer and pay the obligatory charity, and those who believe in Allah and the Last Day to those, We surely give a great wage.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@dclvi{%
We have revealed to you as We revealed to Noah and to the Prophets after him, and We revealed to (Prophets) Abraham, Ishmael, Isaac, Jacob and the tribes, Jesus, Job, Jonah, Aaron, and Solomon, and We gave to David the Psalms.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@dclvii{%
And Messengers of whom We have narrated to you before, and Messengers of whom We did not narrate to you. Certainly, Allah talked to Moses.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@dclviii{%
Messengers bearing glad tidings and warning, so that the people will have no argument against Allah, after the Messengers. Allah is the Almighty, the Wise.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@dclix{%
But Allah bears witness for that which He has sent down to you. He has sent it down with His Knowledge, and the angels bear witness, it is sufficient that Allah is the Witness.\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@dclx{%
Those who disbelieve and bar from the way of Allah have strayed into far error.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@dclxi{%
Surely, those who disbelieve and have done harm. Allah would not forgive them, neither guide them to a Path,\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@dclxii{%
except the road to Gehenna, there they are eternal, and for Allah that is an easy matter.\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O people, the Messenger (Prophet Muhammad) has come to you with the truth from your Lord, so believe, it is better for you. If you disbelieve, to Allah belongs all that is in the heavens and the earth. And Allah is the Knower, the Wise.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@dclxiv{%
People of the Book, do not exaggerate your religion. Do not say about Allah except the truth. Indeed, the Messiah, Jesus son of Mary, is only a Messenger (and Prophet) of Allah, and His Word (Be) which He gave to Mary, and a (created) spirit by Him. So believe in Allah and His Messengers and do not say: 'Trinity. 'Refrain, it is better for you. Allah is only One God. Exaltations to Him that He should have son! To Him belongs all that is in the heavens and in the earth, it is sufficient that Allah is the Guardian.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@dclxv{%
The Messiah would not despise being a worshiper of Allah, nor would the angels who are near. Whosoever despises worshipping Him, and becomes proud, He will surely assemble them all to Him.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@dclxvi{%
As for those who believe and did good deeds, He will pay them in full their wages, and He will increase them from His Bounty. As for those who despise and became proud, He will punish them with a painful punishment, and they will find neither a guide nor a helper for themselves, other than Allah.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O people, a proof has come to you from your Lord, and We have sent down to you a clear light.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@dclxviii{%
Those who believe in Allah and hold fast to Him, He will surely admit them to a Mercy and Bounty from Him, and He will guide them to Him on a Straight Path.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@dclxix{%
They will ask you for a verdict. Say: 'Allah rules for you concerning the indirect heir (alkalalah which is), if a person dies, having no children, but he has a sister, she shall receive half of what he leaves, and he is her heir if she has no children. If there are two sisters, they shall receive twothirds of what he leaves, if there are siblings, men and women, for a male like the share of two females. Allah clarifies to you, lest you go astray, Allah is Knowledgeable of everything.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen Believers, fulfill your obligations. It is lawful for you (to eat the flesh of) the beast among cattle other than that which is recited to you, hunting is forbidden while you are on pilgrimage. Allah decrees what He will.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@dclxxi{%
Believers, do not violate the rites of Allah, or the sacred month, or the offerings, or (those hung with) necklaces, nor those whose aim is to the Sacred House seeking from their Lord bounty and pleasure. Once your pilgrimage has ended, you are free to hunt. Do not allow your hatred for a nation who would bar you from the Holy Mosque to lead you to transgress. And cooperate in righteousness and warding off (evil), and do not cooperate in sinfulness and transgression. Have fear of Allah, for Allah is Stern in retribution.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@dclxxii{%
You are forbidden (to consume) the dead, blood and the flesh of swine; also flesh dedicated to any other than Allah, the flesh of strangled (animals) and of those beaten, that which is killed by falling, gored to death, mangled by beasts of prey, unless you find it (still alive) and slaughter it; also of animals sacrificed on stones (to idols). (You are forbidden) to seek division by the arrows, that is debauchery. Those who disbelieve have this day despaired of your religion. Do not fear them, but fear Me. This day I have perfected your religion for you and completed My favor to you. I have approved Islam to be your religion. (As for) he who does not intend to commit a sin but is constrained by hunger to eat of what is forbidden, then surely Allah is Forgiving, Merciful.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask you what is lawful to them. Say: 'The good things are lawful to you, as well as that which you have taught the birds and beasts of prey to catch, teaching them of what Allah has taught you. Eat of what they catch for you, pronouncing upon it the Name of Allah. And fear Allah, Allah is Swift at reckoning'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
The good things have this day been made lawful to you. The food of those to whom the Book was given is lawful to you, and your food is lawful to them. Lawful to you (in marriage) are the free believing women and the free women from among those who were given the Book before you, provided that you give them their dowries in marriage, neither committing fornication nor taking them as mistresses. Whosoever denies the belief, his labors will be annulled. In the Everlasting Life he is of the losers.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@dclxxv{%
Believers, when you rise to pray wash your faces and your hands as far as the elbow, and wipe your heads and (wash) your feet to the ankle. If you are in a state of impurity, cleanse yourselves. But if you are sick or traveling, or, if when you have just relieved yourselves or had intercourse with women and you cannot find water, touch the clean surface of the earth and rub your hands and faces with it. Allah does not wish to burden you, He seeks only to purify you and to complete His Favor to you in order that you may thank.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
Remember the favor of Allah upon you, and the covenant with which He bound you when you said: 'We hear and obey' Have fear of Allah. Allah is the Knower of the innermost of the chests'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
Believers, be dutiful to Allah and bearers of just witness. Do not allow your hatred for other people to turn you away from justice. Deal justly; it is nearer to piety. Have fear of Allah; Allah is Aware of what you do.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
Allah has promised those who believe and do good works forgiveness and a great reward.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@dclxxix{%
As for those who disbelieve and belie Our verses, they shall become the companions of Hell.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@dclxxx{%
Believers, remember the favor which Allah bestowed upon you when certain people were about to stretch their hands towards you, but He restrained them. Have fear of Allah. In Allah let the believers put their trust.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
Allah made a covenant with the Children of Israel and raised among them twelve chieftains. He said: 'I shall be with you and if you establish the prayers and pay the obligatory charity; if you believe in My Messengers and assist them and give Allah a generous loan, I shall forgive you your sins and admit you to Gardens underneath which rivers flow. Whosoever amongst you disbelieves after that, he indeed has strayed from the Straight Path'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
But because they broke their covenant, We cursed them and hardened their hearts. They changed the Words from their places and have forgotten a portion of what they were reminded. Except for a few, you will always find treachery from them, yet pardon them, and forgive; indeed Allah loves the gooddoers.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
With those who said they were Nazarenes, We made a Covenant, but they have forgotten much of what they were reminded. Therefore, We stirred among them enmity and hatred till the Day of Resurrection when Allah will inform them of all that they have done.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
People of the Book! Our Messenger (Muhammad) has come to clarify to you much of what you have hidden of the Book, and to forgive you much. A light has come to you from Allah and a Clear Book,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
with which Allah guides those who seek His pleasure to the Paths of Peace. By His permission He takes them out from darkness to the light, and guides them to a Straight Path.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
Those who say that Allah is the Messiah, son of Mary are indeed those who disbelieved. Say: 'Who then could prevent any thing from Allah, if He willed to destroy the Messiah, son of Mary, together with his mother and all the people of the earth? For Allah is the kingdom of the heavens and the earth and all that lies between them. He creates what He will and has power over all things'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
The Jews and the Nazarenes say: 'We are the children of Allah and His loved ones' Say: 'Why then does He punish you for your sins? Surely, you are mortals amongst what He created. He forgives whom He will, and punishes whom He will. For Allah is the Kingdom of the heavens and the earth, and all that is between them. All shall return to Him'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
People of the Book! After an interval during which there were no Messengers, Our Messenger (Muhammad) has come to clarify (your religion) to you, lest you should say: 'No bearer of glad tidings or a warner has come to us' Indeed, there has come to you a bearer of glad tidings and a warner. Allah has power over all things.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
(Remember) when Moses said to his people. 'Remember, my people, the favors which Allah has bestowed upon you. He has raised up Prophets among you, made you kings, and given you that which He has not given to any one of the worlds.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dcxc{%
Enter, my people, the Holy Land which Allah has written for you. Do not turn back in your footsteps, lest you shall turn to be losers'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dcxci{%
'Moses' they replied, 'therein is a nation of giants. We will not enter until they depart from it; if they depart from it only then shall we enter'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Thereupon, two pious men whom Allah had favored said: 'Go in to them through the gate, and if you enter you shall surely be victorious. In Allah put your trust, if you are believers'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said: 'Moses, we will never go in so long as they are in it. Go, you and your Lord, to fight. We will stay here'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dcxciv{%
He said: 'Lord, I have none but myself and my brother. Set a barrier between us and the wicked people'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dcxcv{%
He said: 'They shall be forbidden this land for forty years, during which time they shall wander (homeless) on the earth. Do not grieve for these wicked people.'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
Recite to them in all truth the news of Adam's two sons; how they each made an offering, and how the offering of the one was accepted while that of the other was not. He said: 'I will surely kill you' (The other) said: 'Allah accepts only from the righteous.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
If you stretch your hand to kill me, I shall not stretch mine to kill you; for I fear Allah, the Lord of the Worlds.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
I would rather you bear my sin and your sin and become among the inhabitants of Hell. Such is the recompense of the harmdoers'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dcxcix{%
His soul made it seem fair to him to slay his brother; he killed him and became one of the lost.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dcc{%
Then Allah sent down a crow, which dug the earth to show him how to bury the naked corpse of his brother. 'Alas' he said, 'am I unable to be like this crow and so I bury my brother's naked corpse' And he became among those who regret.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dcci{%
That was why We wrote for the Children of Israel that who ever killed a soul, except for a soul slain, or for sedition in the earth, it should be considered as though he had killed all mankind; and that who ever saved it should be regarded as though he had saved all mankind. Our Messengers brought them proofs; then many of them thereafter commit excesses in the earth.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dccii{%
The recompense of those who make war against Allah and His Messenger and spread corruption in the land is that they are to be killed or crucified, or have their hand and a foot cut off on opposite sides, or be expelled from the land. For them is shame in this world and a great punishment in the Everlasting Life;\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dcciii{%
except those who repent before you have power over them. For you must know that Allah is Forgiving, the Most Merciful.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dcciv{%
Believers, have fear of Allah and seek the means by which you come to Him. Struggle in His Way in order that you are prosperous.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dccv{%
As for those who disbelieve, if they possessed all that the earth contains and as much besides to ransom themselves from the punishment of the Day of Resurrection, it shall not be accepted from them. Theirs shall be a painful punishment.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will wish to get out of the Fire, but they shall not, theirs shall be a lasting punishment.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dccvii{%
As for the man or woman who is guilty of theft, recompense them by cutting off their hands for their crimes. That is the punishment from Allah. Allah is Mighty, Wise.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dccviii{%
But whoever repents and mends his ways after committing evil shall be pardoned by Allah. Allah is Forgiving, Most Merciful.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dccix{%
Do you not know that to Allah belongs the Kingdom of the heavens and the earth? He punishes whom He will and forgives whom He will. Allah has power over all things.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger, do not grieve for those who race into disbelief; those who say with their mouth: 'We believe' yet their hearts did not believe, and the Jews who listen to lies and listen to other nations who have not come to you. They pervert the words in their places and say: 'If you are given this, accept it; if not, then beware' Whomsoever Allah wishes to try, you will not own anything with Allah concerning him. For those whose hearts Allah does not will to purify shall be disgrace in this world and a grievous punishment in the Everlasting Life.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dccxi{%
They are listeners to lies and devourers of the unlawful. If they come to you, judge between them or turn away from them. If you avoid them they cannot harm you in anything; but if you judge, judge between them with fairness. Allah loves the just.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dccxii{%
But how will they come to you for judgment when they already have the Torah in which is the judgement of Allah? Then they turn away after that; those are not believers.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dccxiii{%
We have sent down the Torah in which there is guidance and light by which the submissive prophets judged the Jews, as did the rabbis and those of their Lord, guarding what they were required to of the Book of Allah, and for which they were witness. Do not fear people, but fear Me. And, do not take a small price for My verses. Those who do not judge with what Allah has sent down are the unbelievers.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dccxiv{%
We have written for them a life for a life, an eye for an eye, a nose for a nose, an ear for an ear, a tooth for a tooth, and for wounds equal retaliation, but whosoever forgoes it as a freewill offering, it will be an expiation for him. Whoever does not judge according to what Allah has sent down are the harmdoers.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dccxv{%
And We sent, following in their footsteps (Prophet) Jesus, the son of Mary, confirming that which was before him in the Torah, and gave him the Gospel, in which there is guidance and light, confirming that which was before him in the Torah, a guide and an admonition to the cautious.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dccxvi{%
Therefore, let the people of Gospel judge in accordance with that which Allah has sent in it. Those who do not judge according to that which Allah has sent down are the evildoers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And to you We have revealed the Book with the truth confirming the Book that was revealed before it, and a guardian over it. Therefore, give judgment among them in accordance to what Allah has sent down and do not yield to their fancies from the truth that has come to you. We have ordained a law and a Path for each of you. Had Allah willed, He could have made you one nation but that He might try you by that which He has bestowed upon you. Race with one another in good works, to Allah you shall all return and He will declare to you what you were at variance.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And judge among them in accordance to that which Allah has sent down and do not be led by their desires. Take heed lest they should turn you away from a part of that which Allah has sent to you. If they reject your judgment, know that Allah wants to scourge them for some of their sins. Many of the people are wrongdoers.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dccxix{%
Is it pagan laws that they wish to be judged by? Who is a better judge than Allah for a nation whose belief is firm?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dccxx{%
Believers, take neither Jews nor Nazarenes for your guides. They are guides of one another. Whosoever of you takes them for a guide shall become one of their number. Allah does not guide the wrongdoers.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dccxxi{%
You see those in whose hearts is sickness racing with one another to come to them. They say: 'We fear lest a change of fortune should befall us' May Allah bring victory or make known His ordinance, then, they shall regret what they had hidden in themselves.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dccxxii{%
Then the believers will say: 'Are those (the ones) who solemnly swore by Allah that they would stand by you' Their works will be annulled and they shall be the losers.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
Believers, whosoever of you turns from his religion, Allah will bring a nation whom He loves and they love Him, humble towards the believers and stern towards the unbelievers, striving for the Path of Allah and fearless of anyone's blame. Such is the Bounty of Allah; He bestows it on whom He will. He is the Embracer, the Knower.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Your guide is only Allah, His Messenger, and the believers; those who establish the prayer, pay their obligatory charity, and bow down (in worship).\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dccxxv{%
Whosoever takes Allah for a guide, His Messenger, and the believers the party of Allah is the victor.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
Believers, do not take as guides those who were given the Book before you who have made of your religion a jest and a pastime, nor the unbelievers. Have fear of Allah, if you are believers.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
When you call to prayer, they treat it as a jest and a pastime. That is because they are a people who have no understanding.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say: 'People of the Book, do you blame us for any reason other than that we believe in Allah and in what has been sent down to us, and what was sent down before us, and that most of you are evildoers'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say: 'Shall I tell you who will receive a worse recompense from Allah than that? Those whom Allah has cursed and with whom He is angry, and made some of them apes and swine, and those who worship the devil. The place of these is worse, and they have strayed further from the Right Path'\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dccxxx{%
When they came to you they said: 'We are believers' Indeed, they have entered with disbelief, and so they have departed with it; Allah knows best what they conceal.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
You see many of them race with one another in sin and transgression and devour the unlawful. Evil is what they do.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Do those of the Lord and the rabbis not forbid them to speak sinfully and to devour what is unlawful? Evil indeed is what they were doing.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
The Jews say: 'The Hand of Allah is chained' Their own hands are chained! And they are cursed for what they said! Rather, His Hands are both outstretched, He spends as He will. That which Allah has sent down to you will surely increase the tyranny and disbelief of many of them. We have stirred among them enmity and hatred up until the Day of Resurrection. Whenever they kindle the fire of war, Allah extinguishes it. They spread corruption in the land, and Allah does not love those who corrupt.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
If the People of the Book had believed and kept from evil, We would pardon them their sins and admit them to the Gardens of Delight.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
If they had established the Torah and the Gospel and what was sent down to them from their Lord they would be eating from above them and from beneath their feet. Some of them are a righteous nation; but many of them evil is what they do.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger, deliver what is sent down to you from your Lord; if you do not, you will not have conveyed His Message. Allah protects you from the people. Allah does not guide the nation, the unbelievers.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say: 'People of the Book, you are not upon anything until you establish the Torah and the Gospel and that which is sent down to you from your Lord' And that which is sent down to you (Prophet Muhammad) from your Lord will surely increase the tyranny and disbelief of many of them. But do not grieve for the unbelieving nation.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Those who believe, Jews, Sabaeans, and Nazarenes whoever believes in Allah and the Last Day and does good shall neither fear, nor shall they sorrow (as long as they do not reject any of the prophets).\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
We took a covenant with the Children of Israel and sent forth Messengers to them. But whenever a Messenger came to them with that which did not suit their fancies they belied some and killed others.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dccxl{%
They thought there would be no trial; so they were blind and deaf. Then Allah turned towards them; then again many of them were blind and deaf. And Allah is the Seer of what they do.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dccxli{%
The unbelievers are those who say: 'Allah is the Messiah, the son of Mary' But the Messiah said: 'Children of Israel, worship Allah, my Lord and your Lord. 'He who associates anything with Allah, Allah has indeed forbidden Paradise to him, and his abode shall be in the Fire. The harmdoers shall have no helpers.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dccxlii{%
Indeed those who say: 'Allah is the third of the Trinity' became unbelievers. There is but One God. If they do not desist in what they say, a painful punishment will afflict those of them that disbelieve.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Will they not turn to Allah in repentance and ask His forgiveness? He is Forgiving, Merciful.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah, the son of Mary, was not except a Messenger, other Messengers had gone before him. His mother was in the state of sincerity, they both ate food. See how We make plain to them Our signs. Then, see how perverted they are.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say: 'Will you worship instead of Allah that which owns neither harm, nor benefit for you? Allah is the Hearer, Knower'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say: 'People of the Book! Do not exaggerate your religion, other than the truth, and do not follow the desires of a people who went astray before, and led many astray, and, (once again) have gone astray from the Straight Path'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Those who disbelieved of the Children of Israel were cursed by the tongue of (Prophets) David and Jesus, the son of Mary, because they disobeyed and transgressed.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They did not forbid one another from the wrongdoing they were committing. Evil is what they were doing.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dccxlix{%
You see many of them taking the unbelievers as guides. Evil is that to which their souls forwarded them, that Allah is angered against them, and in the punishment they shall live for ever.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dccl{%
Had they believed in Allah and the Prophet (Muhammad) and that which is sent down to him, they would not have taken them as guides. But many of them are evildoers.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dccli{%
You will find that the most people in enmity to the believers are the Jews and idolaters, and that the nearest in affection to the believers are those who say: 'We are Nazarenes' That is because amongst them there are priests and monks; and because they are not proud.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dcclii{%
When they listen to that which was sent down to the Messenger, you will see their eyes fill with tears as they recognize its truth. They say: 'Lord, we believe. Write us among the witnesses.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dccliii{%
Why should we not believe in Allah and in the truth that has come down to us? Why should we not hope for admission among the righteous'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dccliv{%
For their words Allah has rewarded them with Gardens underneath which rivers flow, where they shall live for ever. Such is the recompense of the righteous.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dcclv{%
But those who disbelieve and belie Our verses shall be the companions of Hell.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dcclvi{%
Believers, do not forbid the good things that Allah has made lawful to you. Do not transgress; Allah does not love the transgressors.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dcclvii{%
Eat of the lawful and good things with which Allah has provided you. Have fear of Allah in whom you believe.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah will not take you to account for a slip in your oaths. But He will take you to account for the oaths which you solemnly swear. Its expiation is the feeding of ten needy (people) with such food as you normally offer to your own people; or the clothing of them; or the freeing of a slave. He who does not have must fast three days. That is the expiation of your oaths when you have sworn; but keep your oaths. Allah makes plain to you His verses, in order that you are thankful.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dcclix{%
Believers, wine and gambling, idols and divining arrows are abominations from the work of satan. Avoid them, in order that you prosper.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dcclx{%
satan seeks to stir up enmity and hatred among you by means of wine and gambling, and to bar you from the remembrance of Allah and from praying. Will you not abstain from them?\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dcclxi{%
Obey Allah, and obey the Messenger. Beware; if you give no heed, know that Our Messenger's duty is only to give the clear delivery.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dcclxii{%
No blame shall be attached to those who believe and did good works in regard to any food they have eaten, so long as they ward off (the forbidden) and believe, and do good deeds, then they fear and believe, and again, so long as they fear and do fine deeds. Allah loves the generous.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
Believers, Allah will test you by means of some hunting which you can catch with your hands and with your spears, in order that Allah knows those who fear Him in private. For he who transgresses thereafter shall be a painful punishment.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O believers, do not kill the hunted while you are in pilgrim sanctity. Whosoever of you kills it willfully there shall be a recompense, the like of what he has slain from cattle as shall be judged by two just men among you, an offering to reach the Ka'bah; or expiation food for needy persons or the equivalent of that in fasting, so that he may taste the weight of the recompense of his action. Allah has pardoned what is past; but whoever offends again, Allah will take vengeance on him. Allah is the Almighty, Owner of Vengeance.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dcclxv{%
Made lawful to you is the fished of the sea and its food, an enjoyment for you and for travelers. But you are forbidden the hunted of the land whilst you are on pilgrimage. Have fear of Allah, before whom you shall all be assembled.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah has made the Ka'bah the Sacred House, as an establishment for people; and the Sacred Month, and the offering, and the necklaces, in order that you know that Allah has knowledge of all that is in the heavens and the earth; and that Allah has knowledge of all things.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know that Allah is Stern in retribution, and that Allah is the Forgiver and the Most Merciful.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
The duty of the Messenger is only the delivery (of the Message). Allah knows what you reveal and what you hide.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say: 'The evil and the good are not alike, even if the abundance of evil pleases you. Have fear of Allah, you who are possessed of minds, in order that you prosper'\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dcclxx{%
Believers, do not ask about things that if they appeared to you, would only upset you; but if you ask about them when the Koran is being sent down, they shall be made plain to you. Allah will pardon it; Allah is Forgiving, Clement.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
A nation asked about them before you, and with it they became unbelievers.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
Allah has not made cattle, a slit eared shecamel, nor a freely grazing shecamel, nor a shecamel that bore twins, nor an uncastrated camel (dedicated to idols), but those who disbelieve invent lies against Allah. Most of them do not understand.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
When it is said to them: 'Come to that which Allah has sent down, and to the Messenger' they reply: 'Sufficient for us is what we have found our fathers upon' even though their fathers knew nothing and were not guided.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
Believers, look after your own souls, he who goes astray cannot harm you if you are guided. You shall all return to Allah, and He will inform you of what you have done.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
Believers, if you are traveling in the land and the affliction of death befalls you, at the bequeathing testimony shall be two just men from among you, or two others from other than you. You shall detain both after the prayer, and they shall swear by Allah if you are doubtful: 'We will not sell it for a price, even though it were a near kinsmen, nor will we hide the testimony of Allah, because then we would surely be among the sinful'\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
But if it is discovered that both of them have been subject to sinning, then two others shall stand in their place, these being the nearest of those most concerned, and they shall swear by Allah: 'Our testimony is truer than their testimony, and we have not transgressed, because then we would surely be among the harmdoers'\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
So it is likelier that they will bear testimony in proper form, or else they will be afraid that oaths may be rejected after their oaths. Fear Allah, and listen; Allah does not guide the people of the evildoers.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
On a Day, Allah will gather all the Messengers and ask them: 'How were you answered' They will reply: 'We have no knowledge, You are the Knower of the unseen'\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
When Allah said: '(Prophet) Jesus, son of Mary, remember the favor upon you and on your mother; how I strengthened you with the Holy Spirit (Gabriel), to speak to people in your cradle and of age (when he descends and dies); how I taught you the Book and Wisdom, the Torah and the Gospel; and how, by My permission, you fashioned from clay the likeness of a bird, and breathed into it so that, by My permission, it became a living bird. How, by My permission, you healed the blind man and the leper, and by My permission you brought the dead forth; and how I protected you from the Children of Israel when you brought them clear signs; whereupon the unbelievers among them said: ``This is nothing but plain magic".\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
When I revealed to the disciples to believe in Me and in My Messenger they replied: ``We believe, bear witness that we submit."\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
When the disciples said: 'O (Prophet) Jesus, son of Mary, can your Lord send down to us a table from heaven' He replied: 'Have fear of Allah, if you are believers'\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
'We wish to eat of it' they said, 'so that we can satisfy our hearts and know that what you said to us is true, and that we become witnesses to it'\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
'Allah, our Lord' said (Prophet) Jesus, the son of Mary, 'send down upon us a table out of heaven, that shall be a festival for us the first and the last of us and a sign from You. And provide for us; You are the Best of providers'\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Allah replied: 'I am sending it to you. But whoever of you disbelieves thereafter I shall punish him with a punishment that I do not punish anyone from the worlds'\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And when Allah said: '(Prophet) Jesus, son of Mary, did you ever say to the people: ``Take me and my mother for two gods, other than Allah?" 'Exaltations to You' he said, 'how could I say that to which I have no right? If I had said that, You would have surely known. You know what is in my self, but I do not know what is in Yours. Indeed, You are the Knowledgeable of the unseen.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
I spoke to them of nothing except that which You ordered me, that you worship Allah, my Lord and our Lord. I witnessed them whilst living in their midst and ever since You took me to You, You have been the Watcher over them. You are the Witness of everything.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
If You punish them (for their disbelief), they surely are Your subjects; and if You forgive them, surely You are the Almighty, the Wise'\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Allah will say: 'This is the Day the truthful shall benefit by their truthfulness. They shall live for ever in Gardens underneath which rivers flow. Allah is pleased with them, and they are pleased with Him. That is the great winning'\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To Allah belongs the Kingdom of the heavens and the earth and what is in them. He has power over all things.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen Praise is due to Allah, who has created the heavens and the earth and made darkness and light. Yet the unbelievers make (others) equal with their Lord.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@dccxci{%
It is He who has created you from clay. He has decreed a term for you and another one set with Him. Yet you are still in doubt.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@dccxcii{%
He is Allah in the heavens and earth. He has knowledge of all that you hide and all that you reveal. He knows what you earn.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@dccxciii{%
Yet every time a sign comes to them from the signs of their Lord, they turn away from it.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@dccxciv{%
They belied the truth when it came to them, but there shall come to them news of that they were mocking.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Have they not seen how many generations We have destroyed before them whom We had established in the land in a way We never established you, sending down for them abundant water from the sky and made the rivers to flow underneath them? Yet because they sinned, We destroyed them and raised up other generations after them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
Had We sent down to you a Book on parchment and they touched it with their own hands, those who disbelieved would say: 'This is nothing but plain magic'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
They ask: 'Why has no angel been sent down to him' If We had sent down an angel, their fate would have been determined and they would never have been respited.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
If We had made him an angel, We would have given him the resemblance of a man, and would have as such confused them with that in which they are already confused.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@dccxcix{%
Other Messengers have been mocked before you. But those who scoffed at them were encompassed by that they had mocked'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@dccc{%
Say: 'Travel the land and see what was the fate of those who belied'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dccci{%
Say: 'To whom belongs that which is in the heavens and the earth' Say: 'To Allah. He has written for Himself mercy, and will gather you on the Day ofResurrection in which there is no doubt. Those who have lost their souls, they do not believe'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dcccii{%
His is whatever is at rest in the night and in the day. He is the Hearing, the Knowing.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say: 'Should I take any but Allah for a guardian? He is the Originator of the heavens and the earth. He feeds and is not fed' Say: 'I was commanded to be the first to submit to Him' Do not be one of the idolaters.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say: 'Indeed I fear, if I should disobey my Lord, the punishment of a great Day'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dcccv{%
From whomsoever it is averted on that Day, He will have mercy on him; that is a clear triumph.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dcccvi{%
If Allah visits you with affliction, none can remove it except He; and if He touches you with good, indeed, He has power over all things.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dcccvii{%
He is the Conqueror over His worshipers. He is the Wise, the Aware.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say: 'What thing is greatest in testimony' Say: 'Allah is a witness between me and you. This Koran has been revealed to me in order that I can warn you and all whom it reaches. Do you indeed testify that there are gods other than Allah' Say: 'I do not testify' Say: 'He is only One God, and I am quit of that which you associate'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those to whom We have given the Book know him (Prophet Muhammad) as they know their own children. But those who have lost their own souls do not believe.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dcccx{%
Who is more wicked than he who invents a lie about Allah or belies His verses? The harmdoers shall never prosper.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dcccxi{%
On the Day when We gather them all together We shall say to the idolaters: 'Where are your partners now, those whom you claimed'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dcccxii{%
Then it was not their trial, but they will say: 'By Allah, our Lord we have never been idolaters'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Look how they lie against themselves, and how that which they were forging has gone astray from them!\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
Some of them listen to you. But We have cast veils over their hearts lest they understand it and in their ears heaviness; and if they see every sign they do not believe in it. When they come to you they argue, the unbelievers say: 'This is nothing but the tales of the ancient ones'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dcccxv{%
They forbid from it (the Koran) and keep away from it. They destroy none except themselves, though they do not sense it.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If you could see them when they are set before the Fire! They will say: 'Would that we could return! Then we would not belie the verses of our Lord and would be believers'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
Indeed, that which they concealed will appear to them. But if they were sent back, they would return to that which they have been forbidden. They are indeed liars.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
They say: 'There is only but our present life; we shall not be resurrected'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If you could see them when they are made to stand before their Lord! He will say: 'Is this not the truth' 'Yes, by our Lord' they will reply, and He will say: 'Taste then the punishment, for that which you disbelieved'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dcccxx{%
They are lost indeed, those who belied the meeting with Allah. When the Hour overtakes them suddenly, they will say: 'Alas, for us, that we neglected it' On their backs they shall be bearing their sinful loads; how evil is what they sin!\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
The life of this world is but playing and an amusement. Surely, the Everlasting home is better for the cautious. Will you not understand?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know what they say saddens you. It is not you that they belie; but the harmdoers deny the verses of Allah.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
Messengers indeed were belied before you, yet they became patient with that which they were belied, and were hurt until Our help came to them. There is none to alter the Words of Allah; and there has already come to you some news of the Messengers.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
If their turning away is hard upon you, seek if you can, a tunnel in the ground or a ladder to the sky by which you can bring them a sign. Had Allah willed, He would gather them to guidance. Do not then be among the ignorant.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
Those who listen will surely answer. As for the dead, Allah will revive them. To Him they shall return.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
They ask: 'Why has no sign been sent down to him from his Lord' Say: 'Allah is Able to send down a sign' But most of them do not know.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
There is no crawling creature on the earth, nor a bird that flies with its two wings, but they are nations like you. We have neglected nothing in the Book. They shall all be gathered before their Lord.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
Those who belie Our verses are deaf and dumb, in darkness. Allah leaves in error whom He will, and guides to the Straight Path whom He pleases.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say: 'Do you see yourselves when the punishment of Allah smites you or the Hour overtakes you, will you call on any except Allah, if you are truthful?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
No, on Him alone you will call, and He will remove that for which you call upon Him, if He will. Then you will forget what you associate (with Him).\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
Before you We sent forth to other nations, and then seized them with misery and hardship so that they might humble themselves.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
If only they humbled themselves when Our scourge overtook them! But their hearts were hardened, and satan decorated to them what they were doing.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
And when they had forgotten that with which they have been admonished, We opened the gates of everything to them, until just as they were rejoicing in what they were given, We suddenly seized them and they were in utter despair.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
As such the harmdoers were annihilated. Praise be to Allah, Lord of the Worlds!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say: 'What would you see if Allah took away your hearing and your sight, and set a seal upon your hearts, who is a god, other than Allah, to bring it back to you' Look how We make plain to them Our verses, and yet they turn away.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say: 'What do you see yourselves then, if the punishment of Allah overtook you suddenly or openly, would any perish but the harmdoing nation'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
We send forth Our Messengers only to give glad tidings to mankind and to warn them. Those who believe and mend their ways shall have nothing to fear or to be saddened.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
But those who belie Our verses, punishment shall touch them for their misdeeds.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say: 'I do not tell you that I have the treasuries of Allah or know the unseen, nor do I claim to be an angel. I follow only that which is revealed to me' Say: 'Are the blind and the seeing alike? Will you not think'\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And warn with it those who fear to be brought before their Lord that they have no guardian or intercessor, other than Allah, in order that they are cautious.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dcccxli{%
Do not drive away those who call on their Lord morning and evening, seeking only His Face. Nothing of their account falls upon you, and nothing of your account falls upon them, that you should drive them away and so become one of the harmdoers.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
As such We have made some of them a means for testing others, so that they should say: 'Are those whom Allah favors amongst us' But does not Allah best know the thankful?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
When those who believe in Our verses come to you, say: 'Peace be upon you. Your Lord has decreed Mercy on Himself, if any one of you commits evil through ignorance, and then repents, and mends his ways, then He is Forgiving, the Most Merciful'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
As such We make plain Our verses, so that the path of the wicked will be clear.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say: 'I am forbidden to worship whom you call upon instead of Allah' Say: 'I will not yield to your wishes, for then I should have strayed and should not be of those guided'\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say: 'I am upon a clear proof from my Lord, yet you belie Him. I do not have that which you seek to hasten; judgement is for Allah alone. He narrates the truth and He is the Best of deciders'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say: 'If what you seek to hasten were with me, the matter between you and me would be decided, and Allah knows very well the harmdoers'\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
With Him are the keys of the unseen, none knows them but He. He knows that which is in the land and sea. No leaf falls except He knows it, and there is no grain in the darkness of the earth, fresh or withered, but is recorded in a clear Book.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
It is He who makes you to die by night, knowing what you have gained by day, and then resurrects you so that an ordained term is realized. To Him you shall return, and He will tell you of what you have been doing.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dcccl{%
He is the Conqueror over His worshipers. He sends forth guardians who watch over you until death comes to one of you, when Our messengers take him, and they are not neglectful.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then, they are returned to Allah their Guardian, the True. Surely, the judgement is for Him, He is the Swiftest of reckoners'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say: 'Who saves you from the darkness of the land and sea, when you call out to Him humbly and in secret, (saying:) ``If You save us from this, we will be among the thankful."\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say: 'Allah saves you from them, and from all afflictions. Then, you associate (with Him)'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say: 'He is Able to send forth upon you punishment from above you or beneath your feet, or to divide you into discordant factions, and to make some of you taste the affliction of the other' Look how We make plain Our verses, in order that they understand.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dccclv{%
Your nation has belied it (the Koran), although it is the truth. Say: 'I am not a guardian over you.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dccclvi{%
Every news has its appointed time; you will surely know'\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dccclvii{%
When you see those who plunge (scoffing) into Our verses, withdraw from them till they plunge into some other talk. If satan causes you to forget, leave the wrongdoing people as soon as you remember.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dccclviii{%
Those who are cautious are not accountable for them in anything, but it is a reminder in order that they be cautious.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dccclix{%
Avoid those who take their religion as playing and an amusement and are seduced by the life of this world. Admonish them hereby lest a soul be taken by what it has gained, for it has no guardian or intercessor before Allah, and though it offers every ransom, it shall not be taken from it. Those are they who are taken for that which they earned. For them a drink of boiling water, a stern punishment for their disbelief.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say: 'Are we to call, other than Allah, what can neither help nor harm us? Are we to turn on our heels after Allah has guided us like him, who, being bewitched by devils, blunders aimlessly in the earth, although his friends call him to the guidance, (saying) 'Come to us' Say: 'The guidance of Allah is the Guidance. We are commanded to submit to the Lord of the Worlds,\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dccclxi{%
and to establish prayer, and fear Him. Before Him you shall all be assembled'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dccclxii{%
It was He who created the heavens and the earth in truth. On the Day when He says: 'Be' it shall be. His Word is the truth. His shall be the Kingdom on the Day when the Horn is blown. The Knower of the unseen and the visible, and He is the Wise, the Aware.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
(And remember) when Abraham said to his father Azar: 'Will you take idols for gods, surely I see you and your people are in clear error'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
And so We showed Abraham the kingdom of the heavens and the earth, so that he might be of those who are certain.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dccclxv{%
When night drew over him, he saw a planet. 'This' he said: 'is surely my Lord' But when it set he said: 'I do not like the setting ones'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
When he saw the rising moon, he said: 'This is my Lord' But when it set, he said: 'If my Lord does not guide me, I shall surely be amongst the astray nation'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
Then, when he saw the sun rise, shining, he said: 'This must be my Lord, it is larger' But when it set, he said: 'O nation I am quit of what you associate (with Allah, the Creator),\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
I have turned my face to Him who has created the heavens and the earth, uprightly, and I am not among the idolaters'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dccclxix{%
His nation argued with him. He said: 'Will you argue with me about Allah, indeed He guided me! Except by His will, I do not fear those you associate with Him. My Lord embraces all things in knowledge, will you not remember?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dccclxx{%
And how should I fear what you have associated when you yourselves are not afraid that you have associated with Allah that which He did not send down for it upon you an authority. Which of the two parties is more deserving of safety, if you know?\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
Those who believe and have not confounded their belief with harm security belongs to them; and they are guided'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
Such is the argument that We gave Abraham against his nation. We raise whom We will to an exalted rank. Your Lord is Wise, Knowing.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
We gave him Isaac and Jacob and guided both; and We guided Noah before them, among his descendants were David and Solomon, Job, Joseph, Moses and Aaron as such, We recompense the gooddoers,\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
and (Prophets) Zachariah, John, Jesus and Elias, each was of the righteous,\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
and Ishmael, Elisha, Jonah and Lot. Each We preferred above the worlds,\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
as We did their fathers, their descendants, and their brothers. We chose them and guided them to a Straight Path.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
Such is the guidance of Allah by it He guides whom He will of His worshipers. Had they associated (others with Him), their labors would have indeed been annulled.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
Those, We have given them the Book, judgment, and prophethood. If these disbelieve it, We have entrusted it to others who do not disbelieve in it.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
Those were whom Allah guided. Follow then their guidance and say: 'I do not ask you a wage for it. Surely, it is a reminder to the worlds'\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
They have not valued Allah with His true value, when they said 'Allah has never sent down anything to a mortal' Say: 'Who, then sent down the Book which Moses brought, a light and guidance for people? You put it on to parchments, revealing them and hiding much, you have now been taught what neither you nor your fathers knew before' Say: 'Allah' Then leave them, playing in their plunging.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
And this is a Blessed Book which We have sent down, confirming what came before it, in order that you warn the Mother of the Villages (Mecca) and those who (live) around it. Those who believe in the Everlasting Life believe in it and preserve their prayers.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
Who is more harmful than he who invents a lie about Allah, or says: ``It has been revealed to me," when nothing has been revealed to him? Or he who says: 'I will send down the like of what Allah has sent down' Would that you could see the harmdoers when death overwhelms them! With hands outstretched, the angels (will say): 'Yield up your souls. You shall be recompensed with a humiliating punishment this Day, for you have said of Allah what is untrue and you grew proud against His verses.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
Now you have returned to Us, alone, as We created you at first, leaving behind all that We have bestowed on you. Nor do We see with you your intercessors, those whom you asserted to be your associates. The ties which bound you are broken, and that which you asserted has gone astray from you'\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
It is Allah who splits the grain and the datestone. He brings forth the living from the dead, and the dead from the living. So, that is Allah; how then are you perverted?\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
He splits the sky into dawn. He has ordained the night for rest and the sun, and the moon for reckoning. Such is the ordinance of the Almighty, the Knowing.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
It is He who has created for you the stars, so that you can be guided by them in the darkness of land and sea. We have made plain Our verses to a nation who know.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
It is He who originated you from one soul, then a lodging (place), and then a repository. We have made plain the verses to a nation that understands.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
He sends down water from the sky, and with it We bring forth the plant of every thing. From these We bring forth green foliage and composite grain, palmtrees laden with clusters of dates within reach, vineyards and olive groves and pomegranates alike and unlike. Behold their fruits when they bear fruit and ripen. Surely, in these there are signs for a nation who believe.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
Yet they regard the jinn as the partners of Allah, although He created them, and without knowledge ascribe to Him sons and daughters. Exaltations to Him! He is above what they describe.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dcccxc{%
He is the Creator of the heavens and the earth. How can He have a son when He had no female companion? He created all things and has knowledge of all things.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dcccxci{%
That is Allah, your Lord. There is no god except He, the Creator of all things. Therefore, worship Him. He is the Guardian of all things.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
No eye can see Him, though He sees all eyes. He is the Subtle, the Aware.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
Clear proofs have come to you from your Lord. Whosoever sees clearly it is for himself, and whosoever is blind, it is against himself. I am not an overseer for you.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
As such We make plain Our verses, so that they can say: 'You have studied' in order that We clarify it to a nation that knows.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Therefore, follow what has been revealed to you from your Lord there is no god except Him, and avoid the idolaters.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
Had Allah willed, they would not have associated. We have not made you an overseer for them, nor are you their guardian.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
Do not say crude words to those who call upon other than Allah, lest they use crude words about Allah in revenge without knowledge. As such we have made the actions of each nation seem pleasing. To their Lord they shall return, and He will inform them of that they were doing.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
They solemnly swear by Allah that if a sign is given to them they would believe in it. Say: 'Signs are only with Allah' And how can you tell if it comes they will not believe'\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
We will turn away their hearts and eyes since they refused to believe in it at first. We will leave them in their insolence wandering blindly.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cm{%
Even if We sent down the angels to them and the dead spoke to them, and assembled all things in front of them, they would still not believe, unless Allah willed it. But most of them are ignorant.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cmi{%
As such We have assigned for every Prophet an enemy; the satans of humans and jinn, revealing varnished speech to each other, all as a delusion. But had your Lord willed, they would not have done so. Therefore leave them and what they invent,\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cmii{%
so that the hearts of those who have no belief in the Everlasting Life are inclined to it and, being pleased, persist in their sinful ways.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cmiii{%
Should I seek a judge other than Allah when it is He who has sent down the well distinguished Book for you? Those to whom We have given the Book know that it is the truth sent down from your Lord, so do not be among the doubters.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cmiv{%
Perfected are the words of your Lord in truth and justice, none can change His Words. He is the Hearing, the Knowing.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cmv{%
If you obeyed most of those on earth, they would lead you astray from the Path of Allah. They follow only supposition and they are but conjecturing.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cmvi{%
Your Lord knows best who stray from His Path and the guided.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cmvii{%
Eat then of that over which the Name of Allah has been mentioned (when slaughtered), if you truly believe in His verses.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cmviii{%
And why should you not eat of that over which the Name of Allah has been pronounced when He has already made plain to you what is forbidden, except when you are constrained? Many are those who mislead through ignorance on account of their fancies, but your Lord best knows the transgressors.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cmix{%
Forsake the revealed and hidden sin. Those who earn sin shall be recompensed for what they have committed.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cmx{%
Do not eat from that which the Name of Allah has not been mentioned, for it is a sin. The satans will reveal to their guided ones to argue with you. If you obey them, you shall indeed become idolaters.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cmxi{%
Is he who was dead whom We have revived and given a light with which he walks among people to be compared to him who blunders about in darkness from which he will never emerge? As such what the unbelievers have done appear decorated to them.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cmxii{%
And as such we have placed in every village its archtransgressors to scheme there. But they scheme only against themselves, though they do not sense it.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cmxiii{%
When a sign came to them they said: 'We will not believe in it unless we are given that which the Messengers of Allah have been given' But Allah knows best where to place His Message. Humiliation with Allah shall befall the sinners as well as a terrible punishment for what they devised.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cmxiv{%
Whomsoever Allah desires to guide, He expands his chest to Islam (submission). Whomsoever He desires to lead astray, He makes his chest narrow, tight, as though he were climbing to heaven. As such Allah lays the scourge on the unbelievers.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cmxv{%
This is the Path of your Lord, a Straight Path. We have made plain Our verses to a nation who remember.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cmxvi{%
Theirs is the abode of peace with their Lord. He is their Guardian for what they did.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cmxvii{%
On the Day when He assembles them all together, 'O company of Jinn, you have seduced mankind in great numbers' And their guided ones among the humans will say: 'Lord, we have enjoyed each other. But now we have reached the term which You have appointed for us' He will say: 'The Fire shall be your lodging, and there you shall remain for ever except as Allah will' Your Lord is Wise, Knowing.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cmxviii{%
So We make the harmdoers guides of each other for what they have earned.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cmxix{%
'Jinn and human, did there not come to you Messengers of your own who narrated to you My verses and warned you of encountering this Day' They will reply: 'We bear witness against ourselves' Indeed, the life of this world beguiled them. They will bear witness against themselves that they were unbelievers.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cmxx{%
That is because your Lord will not destroy villages unjustly, while their inhabitants were inattentive.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cmxxi{%
They all have their degrees according to their deeds. Your Lord is not inattentive of their actions.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cmxxii{%
Your Lord is Rich and the Owner of Mercy. He can destroy you if He will and replace you with whom He pleases, just as He raised you from the offspringof other nations.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
That which you are promised is sure to come. You shall not frustrate Me.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say: 'Work according to your station my people, for indeed I am working' You shall know to whom will be the good end of the abode. The harmdoers shall not be triumphant.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cmxxv{%
They set aside for Allah a share of what He has created of tilth and cattle saying: 'This is for Allah so they claim and this for our associates (gods)' The share of their associates never reaches Allah, but the share of Allah reaches their associates. How evil they judge!\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
As such their associates made it attractive to the idolaters to kill their children so that they ruin them and confuse them about their religion. But had Allah willed, they would not have done so. Therefore, leave them to their false inventions.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
They say: 'These cattle, and these crops are forbidden. None can eat of them except those whom we permit' so they claim 'and cattle whose backs are forbidden, and others over which they do not pronounce the Name of Allah' As such fabricating lies against Him. He will recompense them for their invented lies.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
They also say: 'What is in the bellies (wombs) of these cattle is reserved for our males but not for our wives' But if it is stillborn, they all partake of it. He will recompense them for their describing. He is Wise, Knowing.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Lost are those who, without knowledge, have foolishly slain their own children and made unlawful that which Allah has provided them, fabricating lies about Allah. They have gone astray and are not guided.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cmxxx{%
He brings forth gardens, trellised and untrellised, palmtrees and crops, different to eat, and the olive and pomegranates alike and unlike. When it bears fruit eat of it and pay what is due (the zakat) of it upon the harvest day. But do not be wasteful; He does not love the wasteful.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And of the cattle, some are for carrying burdens, and others for slaughter. Eat of that which Allah has provided you with and do not follow in satan's footsteps; he is your open enemy.\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
(He has given you) eight couples, a pair of sheep and a pair of goats. Say: 'Of these, has He forbidden you the males, the females, or what the wombs of the two females contain? Tell me with knowledge, if you are truthful'\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
Then a pair of camels and a pair of cattle. Say: 'Of these, has He forbidden you the males, the females, or what the wombs of the two females contain? Were you witnesses when Allah charged you with this? Who is more harmful than he who, without knowledge, invents a lie about Allah to mislead people? Allah does not guide the harmdoers.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say: 'I find nothing in what has been revealed to me that forbids any one to eat of any food except the dead, running blood, and the flesh of swine for these are unclean and that which has been hallowed in its slaughter to other than Allah. But whoever is constrained to eat of any of these, not intending to sin or transgress, then your Lord is Forgiving, the Most Merciful.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
We forbade the Jews all with undivided hoofs and the fat of sheep and cattle, except what is on their backs and entrails, and what is mixed with their bones. As such We recompensed them for their transgress ions. Indeed, We are truthful.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
If they belie you, say: 'Your Lord is the Owner of all Encompassing Mercy, but His Might cannot be withheld from the nation, the evildoers'\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
The idolaters will say: 'Had Allah willed, neither we nor our fathers would have associated (idols), nor would we have forbidden anything. As such, those who have gone before them belied until they tasted Our Might. Say: 'Have you any knowledge you can bring forth to us? You follow nothing but guessing and you are only speakers of conjecture'\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say: 'Allah alone has the conclusive proof. Had He willed, He would have guided you all'\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say: 'Bring those witnesses of yours who can testify that Allah has forbidden this' If they testify to it, do not testify with them, nor follow the wishes of those who belie Our verses, and disbelieve in the Everlasting Life and ascribe equals to their Lord.\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say: 'Come, I will recite to you what your Lord forbids you; that you shall associate anything with Him; that you shall be good to your parents, that you shall not kill your children because of poverty, We provide for you and for them, that you shall not commit foul deeds whether openly or in secret, and that you shall not kill the soul that Allah has forbidden except by right. With such Allah charges you, in order that you understand.\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@cmxli{%
Do not touch the wealth of the orphan, except in the fairer manner until he reaches maturity. Give just weight and full measure, We never charge a soul with more than it can bear. When you speak, be just, even if it affects your own kinsmen. Fulfill the covenant of Allah. With such He charges you, in order that you remember.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@cmxlii{%
This Path of Mine is straight. Follow it and do not follow other paths, for they will scatter you away from His Path. With such Allah charges you, in order that you be cautious.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then to Moses We gave the Book, complete for him who does good, and (to make) plain all things, and guidance, and mercy, so that they might believe in the ultimate meeting with their Lord.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And We have sent down this blessed Book (the Holy Koran). Follow it and be cautious in order that you receive mercy,\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@cmxlv{%
lest you should say: 'The Book was sent down only to two parties before us; we are inattentive to their study'\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or (you say), 'Had the Book been sent down to us, we would have been better guided than they' Indeed a clear sign has now come to you from your Lord; a guidance and a mercy. And who is more harmful than he who belies the verses of Allah and turns away from them! We shall recompense those who turn away from Our verses with an evil punishment for their turning away.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
Are they waiting for the angels or your Lord to come to them, or for some of the signs of your Lord? On the Day when some of the signs of your Lord come, no soul will be benefited by its belief had it not believed before or earned good in its belief. Say: 'Wait, we are waiting'\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
You have nothing to do with those who have made divisions in their religion and become sects. Their affair is with Allah and He will inform them of what they have done.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@cmxlix{%
He who brings a good deed shall have tenfold of its like, but he who brings a sin shall be recompensed only for its like. None shall be wronged.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@cml{%
Say: 'My Lord has guided me to a Straight Path, an upright religion, the creed of Abraham, he was upright, not from the idolaters'\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@cmli{%
Say: 'My prayers and my worship (for example, pilgrimage and sacrifice), my life and my death, are all for Allah, the Lord of the Worlds.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@cmlii{%
He has no partner, with that I am commanded, and I am the first of the submitters (Muslims)'\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say: 'Should I seek a lord other than Allah, who is the Lord of all things? Every soul earns only to its account no soul shall bear another's burden. Then to your Lord you shall be returned, and He will inform you about that in which you differed'\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@cmliv{%
It is He who has made you caliphs in the earth and raised some of you in rank above others, so that He might try you in what He has given you. Swift is your Lord in retribution; yet He is Forgiving, Merciful.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen AlifLaamMeemSaad.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@cmlvi{%
The Book has been sent down to you; so let your chest have no constriction because of it, in order to warn thereby and as a reminder to the believers.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@cmlvii{%
Follow that which is sent down to you from your Lord and do not follow guardians other than Him; little do you remember.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@cmlviii{%
How many a village have We laid in ruin! In the night Our Might fell upon it, or at midday when they were drowsy.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@cmlix{%
And when Our Might fell upon them they only said: 'We have indeed been harmdoers'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@cmlx{%
We will question those to whom Our Message was sent, as We shall question the Messengers.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@cmlxi{%
With knowledge We will narrate to them, for We are never absent.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@cmlxii{%
On that Day, the weighing is true. He whose scales are heavy those are the prosperers,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
but he whose scales are light those have lost their souls because they were harmful towards Our verses.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
We established you in the earth and made for you a livelihood but little is it that you give thanks.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@cmlxv{%
We created you then We shaped you, then We said to the angels: 'Prostrate yourselves before Adam' They all prostrated themselves except iblis he was not among the prostrated.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
He (Allah) asked: 'What prevented you to prostrate, when I commanded you' 'I am better than he' he replied. 'You created me of fire and You created him of clay'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
He (Allah) said: 'Descend from it! This is no place for you to be proud. Begone, you are of the humiliated'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
he replied: 'Respite me till the Day of Resurrection'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@cmlxix{%
Said He (Allah): 'you are among the respited'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@cmlxx{%
he answered: 'Because You have caused me to go astray, I will waylay them as they walk on Your Straight Path,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
and come upon them from the front and from the rear, from their right and from their left. Then, You shall find most of them ungrateful'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
'Begone' said He, 'despised and outcast. (As for) those of them that follow you, I shall fill Gehenna (Hell) with all of you'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
'O Adam dwell with your wife in Paradise, and eat from whatever you please; but never approach this tree or you shall both become harmdoers'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
But satan whispered to them, so that he might reveal to them their shameful parts which had been hidden from them, he said: 'Your Lord has prohibited you from this tree lest you both become angels or become among the immortal'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
he swore to both: 'Indeed, I am to you among the advisers'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
So he cheated both by delusion. And when they had tasted the tree, their shameful parts became apparent to them, and they both covered themselves with the leaves of Paradise. (Then) their Lord called to them, saying: 'Did I not prohibit you to approach that tree, and did I not warn you that satan was your clear enemy'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
Both replied: 'Lord, We have harmed ourselves. If You do not forgive us and have mercy on us, we shall surely be among the lost'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
He said: 'Descend, each of you an enemy to each other. The earth will be a dwelling place for you and an enjoyment for a time.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He said: 'There you shall live and there you shall die, and from there you shall emerge'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
Children of Adam! We have sent down to you clothing that covers your nakedness, and feathers. But the clothing of piety that is better. That is one of the signs of Allah, in order that they remember.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
Children of Adam! Do not let satan tempt you, as he brought your parents out of Paradise. He stripped them of their garments to show them their shameful parts. Indeed he and his descendants see you from where you cannot see them. We have made the satans supporters of those who do not believe.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
When they commit an indecency, they say: 'This is what we found our fathers practicing, and with it Allah has ordered us' Say: 'Allah does not order indecency. Would you tell of Allah what you do not know'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say: 'My Lord ordered justice. Turn your faces to Him in every place of prayer and supplicate to Him, making the religion sincerely to Him. As He originated you, you shall return'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
Some He has guided, and upon some justly is the straying; for they had chosen the satans for supporters instead of Allah and suppose themselves to be guided.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
Children of Adam, take your adornment at every place of prayer. Eat and drink, and do not waste. He does not love the wasteful.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say: 'Who has forbidden the adornment that Allah has brought for His worshipers and the good provision' Say: 'They are in this life for those who believe, and purely theirs on the Day of Resurrection' As such We distinguish the verses to people who know.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say: 'My Lord has forbidden all indecent acts whether apparent or disguised and sin, and unjust insolence, and that you associate with Allah that for which He has never sent down an authority, or to say about Allah what you do not know'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
To every nation a term; when their term comes they shall not delay it by a single hour, nor yet hasten it.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
Children of Adam, when Messengers of your own come to narrate to you My verses, those who are cautious and mend their ways will have nothing to fear neither shall they be saddened,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@cmxc{%
but, those who belie and grow proud against Our verses shall be the inhabitants of the Fire, and there they shall remain for ever.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@cmxci{%
Who is more harmful than he who invents a lie about Allah or belies His verses? Such shall have their share of the Book, and when Our Messengers come to take them away, they shall say to them: 'Where now are those whom you invoked, other than Allah' 'They have forsaken us' they will answer, and will bear witness against themselves that they were unbelievers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@cmxcii{%
He will say: 'Enter the Fire and join the nations of jinn and humans that have gone before you' As they enter, every nation will curse its sisternation, and when all are gathered in the pit, the last of them will say of the first: 'These, Lord, are those who led us astray. Give them a double punishment of the Fire. He will answer: 'For each double, although you do not know it'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@cmxciii{%
Then, the first will say to the last: 'You were no better than us' So taste the punishment for what you have earned.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@cmxciv{%
The gates of heaven shall not be opened for those who have belied and grew proud against Our verses; nor shall they enter Paradise until a camel shall pass through the eye of a needle. As such We shall recompense the sinners.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@cmxcv{%
Gehenna (Hell) shall be their cradle, and layers of fire shall cover them. As such We recompense the harmdoers.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
As for those who believe and do good works We never charge a soul with more than it can bear they are the companions of Paradise, and there they shall live for ever.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
We shall strip away all rancor from their chests. Rivers shall flow underneath them, and they shall say: 'Praise be to Allah who has guided us to this. Had Allah not given us guidance we should not have been guided. The Messengers of our Lord surely came with the truth' Then they are called: 'This is the Paradise which you have inherited for what you did'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
Then the companions of Paradise will call out to the companions of the Fire: 'What our Lord promised we have found to be true, have you too, found the promise of your Lord to be true' 'Yes' they shall answer, and a Caller will announce between them that the curse of Allah is upon the harmdoers,\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@cmxcix{%
who have barred others from the Path of Allah and sought to make it crooked, and who had no belief in the Everlasting Life.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@m{%
And between them is a veil, and on the ramparts there shall stand men who will know each by their marks. To the companions of Paradise they shall call: 'Peace be upon you' Yet they did not enter it on account of their eagerness.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mi{%
And when they turn their eyes towards the companions of the Fire, they will say: 'Lord, do not cast us among the harmdoers'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mii{%
And the companions of the ramparts call to men whose marks they recognize: 'Neither your amassing nor your pride have availed you.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@miii{%
Are these whom you swore that Allah would never have mercy upon them' (To them it will be said:) 'Enter Paradise. You have nothing to fear neither will you be saddened'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@miv{%
The companions of the Fire will call out to the companions of Paradise: 'Pour upon us some water, or some of that which Allah has provided you' But they shall reply: 'Allah has forbidden both to the unbelievers,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mv{%
who made their religion an amusement and play, and who were beguiled by their worldly life' On this Day We will forget them as they forgot the meeting of that Day; for they denied Our verses.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mvi{%
We have brought to them a Book which We have made plain based upon knowledge, a guidance and a mercy to believers.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mvii{%
Are they waiting but for its fulfillment? On the Day when it is realized, those who have forgotten it will say: 'The Messengers of our Lord have surely come with the truth. Have we then any intercessors to intercede for us, or shall we be returned to do other than that we have done' They have lost their souls, and that which they invented will have gone astray from them.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mviii{%
Your Lord is Allah, who, in six days created the heavens and the earth, and then willed to the Throne. He throws the veil of night over the day. Swiftly they follow one another. The sun, the moon, and the stars are compelled to His order. His is the creation, His is the command. Blessed is Allah, the Lord of the Worlds.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mix{%
Supplicate to your Lord with humility and in secret. He does not love the transgressors.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mx{%
Do not make mischief in the earth after it has been put right. Pray to Him with fear and hope; His Mercy is near to the righteous.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mxi{%
He sends forth the winds as carriers of the glad tidings between the hands of His Mercy, and when they have carried up a heavy cloud, We drive it on to some dead land and therewith send down water bringing forth all manner of fruit. As such We will raise the dead, in order that you remember.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mxii{%
Good land yields its vegetation by the permission of its Lord. While the corrupted yields only the scanty. So We make plain the verses to those who are thankful.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mxiii{%
We sent forth Noah to his nation. He said: 'Worship Allah, my people for you have no god except He. I fear for you the punishment of a great Day.'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mxiv{%
But the assembly of his nation said: 'We can see that you are in clear error.'\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mxv{%
'I am not in error, my nation' he replied. 'I am a Messenger from the Lord of the Worlds\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mxvi{%
(sent) to convey to you the messages of my Lord and to advise you, for I know from Allah what you do not know.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mxvii{%
Do you wonder that a Remembrance should come to you from your Lord to a man from yourselves in order that he may warn you and that you may be cautious so that mercy comes upon you'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mxviii{%
(But) they belied him, so We saved him and those who were with him in the Ark, and We drowned those who belied Our verses. Surely, they were a blind nation.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mxix{%
And to (the people of) Aad We sent their brother, Hood. He said: 'Worship Allah, my nation, for you have no god except He. Will you not then be cautious'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mxx{%
The disbelieving assembly of his nation said: 'We see you in foolishness, and think that you are of the liars'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mxxi{%
'My nation, there is no foolishness in me' he replied. 'I am a Messenger of the Lord of the Worlds\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mxxii{%
I deliver to you the messages of my Lord and I am your honest adviser.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mxxiii{%
Do you wonder that a remembrance should come to you from your Lord to a man from yourselves in order that he may warn you? Remember, that He has made you the heirs of Noah's nation and increased you in broad stature, remember the favors of Allah in order that you prosper'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said: 'Have you come to us in order that we worship Allah alone and renounce that which our fathers worshipped? Bring down that with which you threaten us if you are from the truthful!\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mxxv{%
He answered: 'The punishment and wrath of your Lord has already fallen upon you. Would you dispute with me about names which you and your fathers have invented, and for which no authority has been sent down from Allah? Wait if you will, I am waiting with you'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mxxvi{%
We saved him and all who were with him through Our Mercy and annihilated those who belied Our verses. They were not believers!\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And to Thamood We sent their brother Salih. He said: 'Worship Allah, my nation, for you have no god except He. A clear proof has come to you from your Lord. Here is the shecamel of Allah, a sign for you. Leave her to graze in the earth of Allah and do not touch her with evil, lest a painful punishment seizes you.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mxxviii{%
Remember, that He has made you the successor of 'Aad, and lodged you in the land. You have built palaces on its plains and hewed out houses in the mountains. Remember the favor of Allah and do not act mischievously in the earth, corrupting'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mxxix{%
The proud assembly of his nation said to the weak? amongst them who believed: 'Do you really believe that Salih is sent from his Lord' They answered: 'We believe in that with which he was sent'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mxxx{%
Those who were proud said: 'We disbelieve in that which you believed in'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mxxxi{%
(Then) they hamstrung the shecamel and defied the order of their Lord, saying to Salih: 'Bring down that which you have promised us if you truly are one of the Messengers'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mxxxii{%
Thereupon the earthquake seized them, at morning in their dwellings they were crouched, dead.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
He turned from them, saying: 'I conveyed to you, my nation the Message of my Lord and gave you counsel; but you had no love for sincere advisers'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And Lot, who said to his nation: 'Do you commit such indecency (sodomy) in a way that no one has preceded you in the worlds?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mxxxv{%
You approach men lustfully instead of women. Truly, you are a nation who exceed (in sin)'\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
The only answer of his nation was: 'Expel them from your village. They are people who keep themselves purified'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
We saved him and all his family, except his wife, who was made to remain,\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
and We rained down upon them a rain. So look how was the end of the evildoers.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And to Midian, their brother Shu'aib. He said: 'Worship Allah, my nation, for you have no god except He. A clear sign has come to you from your Lord. Give just weight, and full measure; and do not diminish the goods of people. Do not corrupt the land after it has been set right, that is best for you, if you are believers.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mxl{%
'Do not sit in every road, threatening and barring from the Path of Allah those who believed it, nor seek to make it crooked. Remember how He multiplied you when you were few in number. Consider the end of the corrupters.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mxli{%
If there are some among you who believe in that which I have been sent and others who disbelieve it, be patient until Allah shall judge between us. He is the best of judges'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mxlii{%
The proud assembly of his nation said: 'We will expel you Shu'aib and those who believe with you from our village unless you return to our creed' He replied: 'Even though we hate it?\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mxliii{%
We would have invented lies about Allah if we returned to your creed from which Allah has saved us, it is not for us that we return into it again except if Allah, our Lord wills. For our Lord has embraced everything with knowledge, and in Allah we have put our trust. Our Lord, open between us and our nation with truth, You are the Best of openers'\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mxliv{%
But the unbelieving assembly of his nation said: 'If you follow Shu'aib, you shall assuredly be losers.'\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mxlv{%
So the earthquake seized them, at the morning they were crouched in their dwellings, dead.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mxlvi{%
It seemed as if those who had belied Shu'aib had never lived there. Those who belied Shu'aib were the losers.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mxlvii{%
He turned away from them saying: 'I conveyed to you, my nation, the messages of my Lord and advised you. How can I grieve for the unbelieving nation'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mxlviii{%
We sent no Prophet to a village but seized its inhabitants with misfortune and adversity in order that they might be humble in supplication.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then We changed evil for good, until they multiplied and said: 'Our fathers were indeed touched by misfortune and adversity' So We seized them suddenly while they were unaware.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ml{%
Had the people of the villages believed and been cautious, We would have opened upon them the blessings from heaven and earth. But they belied, and We seized them for what they earned.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mli{%
Do the inhabitants of the villages feel secure from Our Might coming to them at night whilst they sleep?\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mlii{%
Or do the inhabitants of the villages feel secure from Our Might coming to them in the midmorning while they play?\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mliii{%
(In reply to your devising) do they feel secure from the devising of Allah? None feels secure from the devising of Allah except the loosing nation.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mliv{%
Is it not plain to those who inherit the earth after its inhabitants that if We willed We could smite them for their sins and set a seal upon their hearts, so that they do not hear.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mlv{%
Those villages We narrate their news to you. Their Messengers came to them with clear proofs, yet they would not believe what they had belied before; as such Allah seals the hearts of the unbelievers.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mlvi{%
We did not find the covenant upheld by the majority of them, but We found most of them evildoers.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mlvii{%
After those We sent forth Moses with Our signs to Pharaoh and his assembly, but with it they harmed. Look at the end of the corrupters.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mlviii{%
Moses said: 'Pharaoh, I am a Messenger from the Lord of the Worlds,\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mlix{%
incumbent upon me is that I say nothing of Allah except the truth. I bring you a clear proof from your Lord. So let the Children of Israel depart with me'\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mlx{%
He answered: 'If you have come with a sign, show it to us if you are of the truthful'\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mlxi{%
He threw down his staff, and it was clearly a serpent.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mlxii{%
Then he drew out his hand and it was luminous to the onlookers.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mlxiii{%
The assembly of Pharaoh's nation said: 'This man is a wellversed sorcerer\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mlxiv{%
who seeks to drive you from your land what do you command'\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mlxv{%
Others said: 'Put them off a while, he and his brother, and send forth to your cities gatherers\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mlxvi{%
to summon every wellversed sorcerer to you'\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mlxvii{%
The sorcerers came to Pharaoh. They said: 'Shall we be rewarded if we are the winners'\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mlxviii{%
'Yes' he answered, 'and you will be among those near'\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said: 'Moses, will you throw first or shall we be the throwers'\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mlxx{%
'Throw' he replied. And when they threw, they bewitched the people's eyes and terrified them, and produced great sorcery.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mlxxi{%
Then We revealed to Moses: 'Now, throw down your staff' And thereupon it swallowed up their false invention.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mlxxii{%
So, the truth prevailed and what they were doing was annulled;\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
they were defeated and turned belittled,\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
and the sorcerers prostrated themselves,\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mlxxv{%
saying: 'We believe in the Lord of the Worlds,\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
the Lord of Moses and Aaron'\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Pharaoh said: 'Do you believe in Him before I permit? This is a plot that you have contrived in the city in order to expel its people from it. Now you shall know!\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
I will cut off on opposite sides a hand and a foot, and then crucify you all'\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They replied: 'We shall surely turn to our Lord.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mlxxx{%
You would take revenge on us only because we believed in the signs of our Lord when they came to us. Lord, pour patience upon us and let us die as submitters (Muslims)'\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
The assembly of Pharaoh's nation said: 'Will you allow Moses and his nation to corrupt in the land and to forsake you and your gods' He replied: 'We will put their sons to death and spare their women, indeed we are conquerors over them'\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Moses said to his nation: 'Seek help from Allah and be patient. The earth belongs to Allah; He gives it as a heritage to whom He chooses amongst His worshipers. The outcome is for the cautious'\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They replied: 'We were hurt before you came to us, and after you came to us' He said: 'Your Lord may destroy your enemies and make you inheritors in the land. Then He will see how you conduct yourselves'\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
We seized Pharaoh's people with years of drought and scarcity of fruit so that they might remember.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
When good things came their way, they said: 'It is our due' but when evil befell them they blamed their ill fortune on Moses and those with him. Indeed their ill fortune was with Allah, though most of them did not know.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
They said: 'Whatever sign you bring to us, to cast a spell upon us, we will not believe in you'\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
So We sent upon them floods, locusts, lice, frogs, and blood. (All these were) clear signs, yet they were proud against them, for they were wicked people.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
And when the plague smote them, they said: 'Moses, pray to your Lord for us invoking the promise He has made with you. If you lift the plague from us, we will believe in you and let the Children of Israel go with you'\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But when We had lifted the plague from them for a term which they had to reach, they broke their promise.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mxc{%
So We punished them and drowned them in the sea, for they had belied Our signs and gave no heed to them.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mxci{%
We gave the persecuted nation dominion over the eastern and western lands which We had blessed. So the Word of your Lord, the finest, was fulfilled for the Children of Israel because of their patience; and We destroyed the edifices, and towers of Pharaoh and whatsoever they manufactured.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mxcii{%
and We moved the Children of Israel from one side of the sea to the other, and they came upon a nation zealously devoted to the idols they had. They said to Moses: 'Make a god for us, as they have gods' Moses replied: 'You are indeed an ignorant nation.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mxciii{%
That which they are engaged upon shall be shattered and all their works are vain.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mxciv{%
Should I seek any god for you except Allah? He has exalted you above the nations.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mxcv{%
And that We saved you from Pharaoh's family, who had oppressed you cruelly, putting your sons to death and sparing your women. Surely, that was a great trial from your Lord'\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mxcvi{%
We appointed for Moses thirty nights, and We completed them with ten more; so that the appointment with his Lord took forty nights. Moses said to Aaron, his brother: 'Take my place among my nation. Do what is right and do not follow the path of the corrupt doers'\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Moses came at the appointed time and his Lord spoke to him, he said: 'Lord, let me see, that I can look at You' He replied: 'You shall not see Me. But look at the mountain; if it remains firm in its place, then shall you see Me' And when his Lord was revealed to the mountain and caused it to be crushed and leveled whereupon Moses fell down senseless, and when he recovered, he said: 'Exaltations to You! I repent to You. I am the first of believers'\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mxcviii{%
He said: 'Moses, I have chosen you from all mankind with My Messages and My Words. Therefore, take what I have given you, and be among the thankful.'\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mxcix{%
We inscribed for him upon the Tablets all kinds of exhortation and clear explanations of all things. So take it forcefully, and order your nation to take what is best of it. I shall show you the home of the wicked.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mc{%
From My signs I will turn away the unrightfully, arrogant in the land, so that even if they witness every sign they would not believe it. If they see the path of righteousness, they shall not take it as a path; but if they see the path of error, they shall take it for their path because they belied Our signs and were inattentive towards them.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mci{%
Vain are the deeds of those who belie Our signs and the Everlasting Life. Shall they not be recompensed except for what they used to do?\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mcii{%
In his absence, the nation of Moses made a calf from their ornaments, a body with a hollow sound. Did they not see that it could neither speak to them, nor guide them to a path? Yet they took it in worship and were harmdoers.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mciii{%
But when it landed in their hands and saw that they had strayed, they said: 'If our Lord does not have mercy on us and forgive us, we shall be lost'\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Moses returned to his nation, angry and sorrowful, he said: 'Evil is what you have done in my absence! Would you hasten the retribution of your Lord' He threw down the Tablets, and seizing his brother by the head, dragged him towards him. 'Son of my mother' said (Aaron), 'the nation weakened me, and almost killed me. Do not let my enemies rejoice over me; do not number me among the harmdoers.'\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mcv{%
'Lord' said Moses, 'forgive me and forgive my brother. Admit us to Your Mercy, for You are Most Merciful of the merciful'\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mcvi{%
Those who worshipped the calf incurred the Anger of their Lord and abasement in this life, and as such We recompense the forgers.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mcvii{%
As for those who do evil and later repent and believe, your Lord is Forgiving, the Most Merciful thereafter.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mcviii{%
When his anger abated, Moses took up the Tablets upon which was inscribed guidance and mercy to those who fear their Lord.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mcix{%
Moses chose from among his nation seventy men for Our appointment, and when the quake seized them, Moses said: 'My Lord, had it been Your Will, You would have destroyed them before, and me. Will You destroy us for that which the fools amongst us did? It is only Your trial by which You leave in error whom You will, and guide whom You will. You alone are our Guardian. Forgive us and have mercy on us, You are the Best of those who forgive.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mcx{%
Write for us what is good in this life and in the Everlasting Life. To You alone we turn' He replied: 'I will smite with My punishment whom I will; yet My Mercy embraces all things. I will write it (My Mercy) to those who are cautious, give the obligatory charity, and believe in Our verses;\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mcxi{%
and to those who shall follow the Messenger the Unlettered Prophet (Muhammad) whom they shall find written with them in the Torah and the Gospel. He will order kindness upon them and forbid them to do evil. He will make good things lawful to them and prohibit all that is foul. He will relieve them of their burdens and of the shackles that weigh upon them. Those who believe in him and honor him, those who aid him and follow the light sent forth with him, shall surely prosper'\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say: 'O mankind, I am the Messenger of Allah to you all. His is the kingdom in the heavens and the earth. There is no god except He. He revives and causes to die. Therefore, believe in Allah and His Messenger, the Unlettered Prophet, who believes in Allah and His Words. Follow him in order that you are guided.'\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mcxiii{%
Yet among the people of Moses there was a nation who preached the truth and acted justly.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mcxiv{%
We divided them into twelve tribes, each a nation. And when his people demanded drink, We revealed to Moses: 'Strike the rock with your staff' Thereupon twelve springs gushed from the rock and each tribe knew its drinkingplace. We caused the clouds to cast their shadow over them, and sent down for them manna and quails, saying: 'Eat of the good things We have provided for you' Indeed, they did Us no wrong, but they wronged themselves.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mcxv{%
When it was said to them: 'Dwell in this village, and eat of whatever you please; and say, ``Unburdening" and enter the gate prostrating, We will forgive you your sins and increase the gooddoers'\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mcxvi{%
The wicked amongst them changed what was said for other words. Therefore We sent down upon them from heaven a punishment for their evil doing.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mcxvii{%
Ask them about the village that overlooked the sea and what befell (its people) when they broke the Sabbath. Each Sabbath, their fish came swimming towards the shore, but on other days they did not come to them. As such We tempted them (the people) because they had done wrong.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And when some asked: 'Why do you admonish a nation whom Allah will destroy or sternly punish' They replied: '(Seeking) a pardon from your Lord, and in order that they may be cautious'\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mcxix{%
Therefore, when they forgot that of which they were reminded, We saved those who were forbidding evil, and seized the evildoers with an evil punishment for that which they used to do of evil.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mcxx{%
And when they had scornfully persisted in what they had been forbidden, We said to them: 'Be apes, despised'\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mcxxi{%
Then your Lord declared He would send against them he who would oppress them cruelly till the Day of Resurrection. Swift is the retribution of your Lord, yet surely He is Forgiving, the Most Merciful.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mcxxii{%
We dispersed them through the earth in nations some were righteous, others were not, and tested them with good and evil in order that they return.\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
Then others succeeded them who inherited the Book and availed themselves of the vanities of this lower world, saying: 'It will be forgiven us' But if similar vanities came their way, they would again take them. Have they not taken the covenant of the Book, which they have studied, to tell nothing of Allah except what is true? Surely, the Everlasting Life is better for the cautious, do you not understand!\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
As for those who hold fast to the Book and are steadfast in prayer, We do not waste the wage of the righteous.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mcxxv{%
When We suspended the mountain over them as though it were a shadow and they feared that it was falling down on them: (We said): 'Take forcefully that which We have given you and remember what it contains, in order that you keep from evil'\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
When your Lord brought forth descendants from the loins of Adam's children, and made them testify concerning themselves (He said): 'Am I not your Lord.' They replied: 'We bear witness (that You are)' Lest you should say on the Day of Resurrection: 'We had no knowledge of this'\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
or you say: 'Our forefathers were idolaters before, and we were the descendants after them, will You destroy us for the deeds of the vaindoers'\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
As such We make plain Our verses in order that they return.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mcxxix{%
Recite to them the news of he to whom We gave Our verses and who turned away from them; how satan overtook him so he was led astray.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mcxxx{%
Had it been Our will We would have raised with it, but he clung to this earthly life and succumbed to his fancies. His likeness was that of a dog, whether you chase it away or let it alone it pants. Such is the example of a nation who belie Our signs. Recount to them these narratives, in order that they reflect.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
Evil is the example of those who belied Our verses; they wronged themselves.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
He whom Allah guides is one that is guided, but he whom Allah leaves in error shall surely be the lost.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
For Gehenna, We have created many jinn and many humans. They have hearts, with which they cannot understand; eyes, with which they do not see; and ears, with which they do not hear. They are like cattle, rather, they are the more misguided. Such are the heedless.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
To Allah belongs the Finest Names, so call Him by them, and keep away from those who pervert them. They shall be recompensed for the things they did.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
Among those whom We created there is a nation who guide with the truth and with it they are just.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
As for those who belie Our verses, We will draw them on little by little, from where they cannot tell;\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
and I respite them, My stratagem is firm.\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Have they not reflected? There is no madness in their companion, he is but a plain warner.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Will they not ponder upon the kingdom of the heavens and the earth, and all that Allah created, and that it may be that their term is drawing near? So, in which speech will they believe thereafter?\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@mcxl{%
None can guide those whom Allah leaves in error. He leaves them in their insolence, wandering blindly.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask you about the Hour and when it is to come. Say: 'None knows except my Lord. He alone will reveal it at the appointed time. It is heavy in the heavens and earth. It will not come to you but suddenly' They will question you, as though you had full knowledge of it. Say: 'Its knowledge is with Allah, though most people are unaware'\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say: 'I do not have the power to acquire benefits or to avert harm from myself, except by the Will of Allah. Had I possessed knowledge of the unseen, I would have availed myself of much that is good, and no harm would have touched me. But I am only a warner and a bearer of glad tidings for a nation who believe.\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He who created you from a soul. From it He created its mate, so that he might reside with her. And when he had covered her, she conceived, and for a time her burden was light. She carried it with ease, but when it grew heavy, they both supplicated to Allah, their Lord: 'Grant us a goodly child and we will be among the thankful'\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@mcxliv{%
Yet when He gave both of them (the parents) a goodly child, they set up associates with Him, in return for what He had given them. Exalted be Allah above that they associate with Him.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Will they associate that which cannot create a thing while they are created?\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
They cannot help them, nor can they help themselves.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
If you call them to guidance, they will not follow you. It is the same whether you call them or you are silent.\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Those whom you invoke, other than Allah, are worshipers like yourselves. Call them, and let them answer you, if what you say is true!\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Have they feet to walk with? Have they hands to punish with? Have they eyes to see with? Have they ears to hear with? Say: 'Call on your partners and then try to scheme against me. Give me no respite.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@mcl{%
My Guardian is Allah, who has sent down the Book. He guards the righteous.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@mcli{%
Those whom you invoke, other than Him, cannot help you, nor can they help themselves'\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@mclii{%
If you call them to guidance, they will not hear you. You see them looking towards you, but they cannot see.\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@mcliii{%
Accept the easing, order with fine jurisprudence, and avoid the ignorant.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@mcliv{%
When satan provokes you seek refuge in Allah; He is the Hearing, the Knowing.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@mclv{%
Indeed, when a visitation of satan touches the cautious (worshipers) they remember, and then see clearly.\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@mclvi{%
And their brothers, they prolong them in error, and they will never stop.\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@mclvii{%
When you do not bring them a verse, they say, 'Why have you not chosen one' Say: 'I follow only what is revealed to me from my Lord. This (Koran) is a veritable proof from your Lord, guidance and mercy for people who believe'\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@mclviii{%
When the Koran is recited, listen to it in silence in order that Allah has mercy upon you.\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@mclix{%
Remember your Lord in your soul with humility and fear, and not with a loud voice, morning and evening, and do not be among the inattentive.\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@mclx{%
Those who are with your Lord are not too proud to worship Him. They exalt Him and to Him they prostrate.\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask you about the spoils (of war). Say: 'The spoils belong to Allah and the Messenger. Therefore, have fear of Allah and set things right between you. Obey Allah and His Messenger, if you are believers'\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mclxii{%
Indeed the believers are those whose hearts quake at the mention of Allah, and when His verses are recited to them it increased them in faith. They are those who put their trust in their Lord.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mclxiii{%
Those who pray steadfastly, and spend of that which We have provided them,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mclxiv{%
those are, in truth, the believers. They shall have degrees with their Lord and forgiveness, and a generous provision.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mclxv{%
It is like when your Lord caused you to leave your home with the truth, though some of the believers disliked it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mclxvi{%
They argued with you about the truth after it had been made clear, as though they were being led to certain death while looking.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mclxvii{%
(Remember) when Allah promised to grant you one of the two parties (at Badr), and you wished for the one that was not strong. Allah wanted to establish the truth by His Words and to sever the unbelievers to the last,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mclxviii{%
in order that He might verify the truth and annul the falsehood, even though the wrongdoers hated it.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mclxix{%
And when you (Prophet Muhammad) prayed to your Lord for help, He answered: 'I am sending to your aid a thousand angels in succession'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mclxx{%
Allah only made it to be glad tidings and so that your hearts may be satisfied; victory comes only from Allah; He is Almighty, Wise.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mclxxi{%
When you were overcome by sleep, as security from Him, He sent down water from the sky to cleanse you and to purify you of satan's filth, to strengthen your hearts and to steady your footsteps.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mclxxii{%
And when Allah revealed to the angels, saying: 'I shall be with you. Give courage to the believers. I shall cast terror into the hearts of the unbelievers. Strike them above the necks, smite their finger tips'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
This is because they had made a breach with Allah and His Messenger. He who makes a breach with Allah and His Messenger indeed, Allah is stern in retribution.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
'That for you, so taste it, the punishment of the Fire is for the unbelievers'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mclxxv{%
Believers, when you encounter unbelievers on the march do not turn your backs to them in flight.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
If anyone on that day turns his back to them in flight, except when maneuvering to fight, or to join another party, he shall be laden with the Anger of Allah and Gehenna shall be his refuge an evil arrival.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
It was not you who killed them, but Allah slew them, neither was it you who threw at them. Allah threw at them in order that He confers on the believers a fair benefit. Indeed, Allah is Hearing, Knowing.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
Allah will surely weaken the guile of the unbelievers.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mclxxix{%
If you were seeking a victory, victory has now come to you. If you desist, it will be better for you. If you resume We will return, and even if your forces are numerous, they shall not help you at all. And Allah is with the believers.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mclxxx{%
Believers, obey Allah and His Messenger, and do not turn away from him when you are hearing.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
Do not be like those who say: 'We hear' but they do not listen.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
The worst beasts before Allah are those who are deaf, dumb, and do not understand.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
Indeed, had Allah known any good in them, He would have let them hear. But even if He had made them hear, they would have turned away, swerving aside.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
Believers, respond to Allah and the Messenger when he calls you to that which revives you. Know that Allah is between the person and his heart, and that toHim you shall all be gathered.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And be cautious against a sedition that will not smite the harmdoers alone. Know that the punishment of Allah is Stern.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember how He gave you shelter when you were few in number and considered weak in the land, ever fearing that the people would snatch you away; but He gave you refuge and supported you with His victory and provided you with goodness, so that you might give thanks.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
Believers, do not betray Allah and the Messenger, nor knowingly betray your trust.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
Know that your children and your wealth are but a temptation, and that the reward with Allah is great.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
Believers, if you fear Allah, He will give you a criteria and cleanse you of your sins and forgive you. Allah is the Owner of great bounty.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcxc{%
And when the unbelievers plotted against you (Prophet Muhammad). They sought to either take you captive or have you killed, or expelled. They plotted but Allah (in reply) also plotted. Allah is the Best in plotting.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcxci{%
Whenever Our verses are recited to them, they say: 'We have heard them, if we wished, we could speak its like. They are but tales of the ancients'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcxcii{%
When they say: 'O Allah, if this is indeed the truth from You, rain down upon us stones from heaven or bring us a painful punishment.'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcxciii{%
But Allah was not to punish them whilst you were living in their midst. Nor would Allah punish them if they repeatedly ask forgiveness of Him.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcxciv{%
And why should Allah not punish them, when they have barred others from the Sacred Mosque, although they were not its guardians? Its only guardians are the cautious, though most of them do not know.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcxcv{%
Their prayers at the Sacred House are nothing but whistling and clapping. Therefore, taste the punishment for your disbelief.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Those who disbelieve spend their wealth to bar (others) from the Path of Allah. They will spend it; but it will become a regret for them, then they will be overcome. The unbelievers shall be gathered in Gehenna,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
in order that Allah will separate the wicked from the good. He will heap the wicked one upon another, and then heap them together and cast them in Gehenna those shall be the losers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Tell the unbelievers that if they abandon their ways He will forgive them what is past; but, if they return, that was indeed the way of their forefathers who have passed away.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcxcix{%
Fight them until persecution is no more and the Religion of Allah reigns supreme. If they desist, Allah sees the things they do;\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcc{%
but if they turn away, know that Allah is your guardian, (He is) the best Guardian and the best Giver of victory.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that one fifth of whatever you take as spoils belong to Allah, the Messenger, kinsmen of the Messenger, the orphans, the needy, and the destitute traveler; if you believe in Allah and what We sent down to Our worshiper on the day of victory, the day when the two armies met. Allah has power over all things.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mccii{%
And when you were encamped on the nearside and they (the unbelievers) on the farther side, with the caravan below, had you made an appointment with them, you would have surely failed to keep it; but Allah sought to accomplish what He had ordained, so that by clear evidence, he who was destined to perish might perish, and he who was destined to live might live. Surely, Allah is Hearing, Knowing.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcciii{%
And when Allah made them appear to you in a vision as a small band, had He showed them to you as many, your courage would have failed you and you would have quarreled over the affair. But Allah saved; He knows the inner most thoughts in the chests.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcciv{%
And when you met them, He showed them in your eyes as being few, and decreased (your number) in their eyes so that Allah might determine what was ordained. To Allah all matters return.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mccv{%
Believers, when you meet an army stand firm and remember Allah abundantly, in order that you are prosperous.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mccvi{%
Obey Allah and His Messenger and do not dispute with one another lest you should lose courage and your resolve weaken. Have patience Allah is with those who are patient.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mccvii{%
Do not be like those who left their homes elated with insolence and showing off to people, barring others from the Path of Allah but Allah encompasses what they do.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mccviii{%
And when satan made their foul deeds seem fair to them. He said: 'No one shall conquer you this day. I shall be your savior' But when the two armies came within sight of each other, he took to his heels, saying: 'I reject you, for I can see what you cannot. I fear Allah, Allah is Stern in retribution'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mccix{%
And when the hypocrites and those in whose hearts was sickness said: 'Those, their religion has deceived them' But whosoever puts his trust in Allah, indeed Allah is Mighty, Wise.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mccx{%
If you could see the angels when they carry off the souls of the unbelievers, beating their faces and their backs, saying: 'Taste the punishment of Burning!\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mccxi{%
That is for what your hands have forwarded, Allah is not unjust to His worshipers'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mccxii{%
Like Pharaoh's family and those who have gone before them, they disbelieved the signs of Allah. Therefore, Allah seized them in their sinfulness. Mighty is Allah and stern in retribution.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mccxiii{%
This is because Allah would never change His favor that He bestowed upon a nation until they change what is in their hearts. Allah is Hearing, Knowing.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mccxiv{%
Like Pharaoh's family and those who have gone before them, they belied the signs of their Lord, and so We destroyed them for their sins and drowned Pharaoh's family. They were all harmdoers.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mccxv{%
Indeed, the basest creatures before Allah are the unbelievers for they will not believe;\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mccxvi{%
those with whom you have made a treaty, then break their treaty with you every time; having no fear (of Allah),\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mccxvii{%
if you meet them in battle, cause their example to scatter those behind them so that they remember.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mccxviii{%
If you fear treachery from any of your allies, you can dissolve with them equally. Allah does not love the treacherous.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mccxix{%
Do not suppose that the unbelievers have outstripped (Allah). They cannot frustrate Me.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mccxx{%
Muster against them whatever you are able of force and tethers (ropes) of horses, so that you strike terror into the enemies of Allah and your enemy, and others besides them whom you do not know but Allah does. All that you spend in the Way of Allah shall be repaid to you. You shall not be wronged.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mccxxi{%
If they incline to peace, incline to it also, and put your trust in Allah. Surely, He is the Hearing, the Knowing.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mccxxii{%
Should they seek to deceive you, Allah is sufficient for you. It is He who supported you with His victory and with believers,\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
and brought their hearts together. If you had given away all the riches of the earth, you could not have so united them, but Allah has united them. He isAlmighty, Wise.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Prophet, Allah suffices you and whosoever follows you of the believers.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Prophet, urge the believers to fight. If there are twenty patient men among you, you shall overcome two hundred, and if there are a hundred, they shall overcome a thousand unbelievers, for they are a nation who do not understand.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
Allah has now lightened it for you, for He knows that there is weakness amongst you. If there are a hundred patient men among you, they shall overcome two hundred; and if there are a thousand, they shall, by the permission of Allah, defeat two thousand. Allah is with the patient.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It is not for any Prophet to have prisoners in order to slaughter many in the land. You want the gains of this life, and Allah wants the Everlasting Life, and Allah is Mighty, Wise.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Had there not been a previous writing from Allah, you would have been afflicted by a mighty punishment.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mccxxix{%
Eat of what you have taken from the spoils; such is lawful and good, and fear Allah. Allah is Forgiving and Most Merciful.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet, say to those you have taken captive in your hand: 'If Allah finds goodness in your hearts, He will give you that which is better than what has been taken from you, and He will forgive you. Allah is Forgiving, the Most Merciful'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
But if they seek to betray you, they had betrayed Allah before, but He has let you overcome them. Allah is the Knower, the Wise.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Those who believe and migrated, and fought for the Cause of Allah with their wealth and their persons; and those who sheltered them and helped them shall be guides to each other. And those who believe, but have not emigrated you have no guidance towards them till they emigrate. But if they seek your help in the cause of your religion, it is your duty to help them, except against a nation with whom you have a treaty. Allah sees the things you do.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
The unbelievers, they are guides of one another. Unless you do this, there will be persecution in the land and great corruption.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
Those who believe and migrated from their homes and fought for the Way of Allah, and those who have sheltered them and helped them they are truly the believers. Theirs shall be forgiveness and a generous provision.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who believed afterwards and emigrated, and struggled with you they are of you. And in the Book of Allah, the near kinsmen deserve one another (in inheritance). Allah has knowledge of all things.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen An acquittal from Allah and His Messenger to the idolaters with whom you have made agreements;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
'For four months you shall journey freely in the land. But know that you shall not render Allah incapable, and that Allah will humiliate the unbelievers'\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
A proclamation from Allah and His Messenger, to the people on the day of the Grand Pilgrimage; 'Allah rejects, and His Messenger (rejects) the idolaters. So if you repent, that will be better for you; but if you turn your backs, know that you cannot frustrate Allah. And give glad tidings to the unbelievers of a painful punishment,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
except those idolaters who have fully honored their treaties with you and aided none against you. With these fulfill your covenant till their term. Surely, Allah loves the righteous.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mccxl{%
When the sacred months are over, slay the idolaters wherever you find them. Take them and confine them, then lie in ambush everywhere for them. If they repent and establish the prayer and pay the obligatory charity, let them go their way. Allah is Forgiving and the Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mccxli{%
If an idolater seeks asylum with you, give him protection in order that he hears the Word of Allah, and then convey him to his place of safety, because they are a nation who do not know.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can the idolaters have any treaty with Allah and His Messenger, except those with whom you have made treaties by the Sacred Mosque? So long as they are straight with you, so be straight with them. Allah loves the righteous.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How? If they prevail against you they will respect neither agreements nor ties of kindred. They satisfy you with their tongues, but their hearts are averse; and most of them are wicked.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They sell the verses of Allah for a small price and bar others from His Path. Evil is what they have been doing.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mccxlv{%
They honor with the believers neither bonds nor treaties. Such are the transgressors.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
If they repent and establish the prayer and pay the obligatory charity, they shall become your brothers in the religion. So We make plain Our verses for a nation that knows.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
But if, after coming to terms with you, they break their oaths and revile your belief, fight the leaders of the disbelief for they have no oaths in order that they will desist.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will you not fight against those who have broken their oaths and conspired to expel the Messenger? They were the first to attack you. Do you fear them? Surely, Allah has better rights that you fear Him, if you are believers.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight them, Allah will punish them with your hands and degrade them. He will grant you victory over them and heal the chests of a believing nation.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mccl{%
He will take away all anger from their hearts: Allah turns to whomsoever He will. Allah is Knowing, Wise.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mccli{%
Did you suppose that you would be left before Allah has known those of you who fought and did not take a confidant other than Allah, His Messenger, and the believers? Allah is Aware of what you do.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcclii{%
Idolaters should not inhabit the mosques of Allah bearing witness against themselves with disbelief. Those, their deeds have been annulled, and in the Fire they shall live for ever.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mccliii{%
None should inhabit the mosques of Allah except those who believe in Allah and the Last Day, establish their prayers and pay the obligatory charity, and fear none except Allah. May these be among the guided.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mccliv{%
Do you consider giving drink to the pilgrims and inhabiting the Sacred Mosque is the same as one who believes in Allah and the Last Day, and struggles in the Way of Allah? These are not held equal by Allah. Allah does not guide the harmdoers.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who believe, and migrated, and struggle in the Way of Allah with their wealth and their persons are greater in rank with Allah. It is they who are the winners.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord gives them glad tidings of mercy from Him, and pleasure; for them await gardens in which there is eternal bliss.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcclvii{%
where they shall live for ever. The wage with Allah is great indeed.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcclviii{%
Believers, do not take your fathers or your brothers for a guide if they love disbelief rather than belief. Whosoever of you takes them for guides are the harmdoers.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say: 'If your fathers, your sons, your brothers, your wives, your tribes, the property you have acquired, the merchandise you fear will not be sold, and the homes you love, are dearer to you than Allah, His Messenger and the struggling for His Way, then wait until Allah shall bring His command. Allah does not guide the evildoers'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcclx{%
Allah has helped you on many a battlefield. In the Battle of Hunain, when your numbers were pleasing you they availed you nothing; the earth, for all its vastness, seemed to close in upon you and you turned your backs and fled.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then, Allah caused His tranquility (sechina) to descend upon His Messenger and the believers; He sent legions you did not see and sternly punished the unbelievers. Such is the recompense of the unbelievers.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Yet thereafter, Allah turns to whom He will. He is the Forgiving, the Most Merciful.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
Believers, the idolaters are unclean. Do not let them approach the Sacred Mosque after this year. If you fear poverty, Allah, if He wills, will enrich you through His bounty. He is Knowing, Wise.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight those who neither believe in Allah nor the Last Day, who do not forbid what Allah and His Messenger have forbidden, and do not embrace the religion of the truth, being among those who have been given the Book (Bible and the Torah), until they pay tribute out of hand and have been humiliated.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcclxv{%
The Jews say Ezra is the son of Allah, while the Christians (who follow Paul) say the Messiah is the son of Allah. Such are their assertions, by which they imitate those who disbelieved before. Allah fights them! How perverted are they!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They take their rabbis and monks as lords besides Allah, and the Messiah, son of Mary, though they were ordered to worship but one God, there is no god except He. Exalted is He above that they associate with Him!\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
They desire to extinguish the Light of Allah with their mouths; but Allah seeks only to perfect His Light, though the unbelievers hate it.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
It is He who has sent forth His Messenger with guidance and the religion of truth to uplift it above every religion, no matter how much the idolaters hate it.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcclxix{%
Believers, many are the rabbis and monks who in falsehood defraud people of their possessions and bar people from the Path of Allah. Give glad tidings of a painful punishment to those who treasure gold and silver and do not spend it in the Way of Allah.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcclxx{%
On that Day they (the treasures) will be heated in the fire of Gehenna (Hell), and their foreheads, sides, and backs will be branded with them, and told: 'These are the things which you have treasured. Taste then that which you were treasuring'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
The number of the months, with Allah, is twelve in the Book of Allah, the day when He created the heavens and the earth; of these, four are sacred. That is the right religion. Therefore, do not wrong yourselves in them and fight against the unbelievers all together as they themselves fight against you all together; know that Allah is with the cautious.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
The postponement of sacred months is an increase in disbelief in which the unbelievers are misguided. They allow it one year and forbid it another year, so that they can make up for the months that Allah has sanctified so making lawful what Allah has forbidden. Their foul acts seem fair to them Allah does not guide the unbelievers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
Believers, why is it that when it is said to you: 'March in the Way of Allah' you linger with heaviness in the land? Are you content with this life rather than theEverlasting Life? Yet the enjoyment of this life in (comparison to) the Everlasting Life is little.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If you do not go forth, He will punish you with a painful punishment and replace you by another nation. You will in no way harm Him; for Allah has power over all things.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If you do not help him, Allah will help him as He helped him when he was driven out with one other (Abu Bakr) by the unbelievers. When the two were in the cave, he said to his companion: 'Do not sorrow, Allah is with us' Then Allah caused His tranquility (shechina) to descend upon him and supported him with legions (of angels) you did not see, and He made the word of the unbelievers the lowest, and the Word of Allah is the highest. Allah is Mighty, Wise.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
Whether lightly or heavily, march on and fight for the Way of Allah, with your wealth and your persons. This will be best for you, if you but knew.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Had the gain been immediate or the journey easy, they would have followed you; but the distance seemed far to them. Yet they will swear by Allah: 'Had we been able, we would have gone out with you' They bring destruction upon their souls. Allah knows that they are lying.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
Allah has forgiven you! Why did you give them leave (to stay behind) until it was clear to you which of them was truthful and knew those who lied?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in Allah and the Last Day will not ask your permission so that they may struggle with their wealth and their selves. Allah knows best the righteous.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
Only those who ask your permission do not believe in Allah and the Last Day and whose hearts are filled with doubt. And in their doubt, they waiver.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
Had they intended to set forth with you, they would have prepared themselves for it. But Allah did not like their going forth and held them back, and it was said: 'Stay back with those who stay back'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they gone forth among you, they would only have increased your burden, and run to and fro in your midst, seeking to stir up sedition between you; and some of you would listen to them; and Allah knows the harmdoers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
Beforehand they had already sought to stir up sedition, and turned things upside down for you, until the truth came, and the command of Allah appeared, although they were averse.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
Among them are some that say: 'Give us leave and do not expose us to temptation' Surely, they have already succumbed to temptation. Gehenna shall encompass the unbelievers.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good comes to you, it grieves them; but if hardship befalls you, they say: 'We have taken our precautions' and they turn away, rejoicing.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say: 'Nothing will befall us except what Allah has ordained. He is our Guardian. In Allah, let the believers put their trust'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say: 'Are you waiting for anything to befall us except one of the two excellent things (victory or martyrdom)? We are waiting for the punishment of Allah to smite you, either from Him or at our hands. Wait if you will, we are waiting'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say: 'Whether you spend voluntarily or reluctantly it shall not be accepted from you; for you are a wicked nation'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
Nothing prevents their offerings from being accepted except that they do not believe in Allah and His Messenger. They do not come to the prayer except lazily and spend grudgingly.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mccxc{%
Let neither their wealth nor their children please you. Through these Allah seeks to punish them in this life, and that their souls depart while they are unbelievers.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mccxci{%
They swear by Allah that they belong with you, yet they are not of you. They are a nation that are afraid.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mccxcii{%
If they could find a shelter or caverns, or any place to creep into they will turn stampeding to it.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mccxciii{%
There are some among them who find fault with you concerning the distribution of alms. If a share is given to them they are contented, but if they receive nothing then they are angry.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mccxciv{%
Would that they were wellpleased with what Allah and His Messenger have given them, and would say: 'Allah is sufficient for us. Allah will provide for us from His abundance, and so will His Messenger. To Allah, we hope'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mccxcv{%
The obligatory charity shall be only for the poor and the needy, and for those who work to collect it, and to influence hearts (to belief), for ransoming captives, and debtors in the Way of Allah and the destitute traveler. It is an obligation from Allah. Allah is Knowing, Wise.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And there are others among them who hurt the Prophet saying: 'He lends an ear (to everything)' Say: 'He lends an ear of good for you; he believes in Allah and trusts the believers, and he is a mercy to the believers among you. Those who hurt the Messenger of Allah for them there is a painful punishment'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear in the Name of Allah in order to please you. But it is more just that they should please Allah and His Messenger if they are believers.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Are they not aware that whosoever opposes Allah and His Messenger shall live for ever in the Fire of Gehenna? That surely is the greatest degradation.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites are afraid lest a chapter be sent down against them telling them what is in their hearts. Say: 'Mock if you will; Allah will surely bring forth what you are fearing'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mccc{%
If you question them, they will say: 'We were only plunging and playing' Say: 'Were you mocking Allah, His verses, and His Messenger?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mccci{%
Do not make excuses. You have disbelieved after you believed. If we forgive some of you, We will punish others, for they were sinners'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcccii{%
Be they men or women, the hypocrites are all alike. They order what is evil, forbid what is just, and tighten their purse strings. They forsook Allah, so Allah forsook them. Surely, the hypocrites are evildoers.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah has promised the hypocrites, both men and women, and the unbelievers the Fire of Gehenna. They shall live in it for ever. It is sufficient for them. Allah has cursed them and for them is a lasting punishment.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mccciv{%
You are like those before you. They were stronger than you in might, and had greater riches and more children. They took enjoyment in their share, so do you take enjoyment in your share as those before you took enjoyment in their share. You have plunged as they plunged. Those, their works are annulled, failed in this world and in the Everlasting Life, those, they are the losers.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcccv{%
Have they not heard the news of those who have gone before them? The news of the nations of Noah, Aad and Thamood, of Abraham's nation, and the people of Midian and the ruined cities? Their Messengers showed them clear signs. Allah did not harm them, but they harmed themselves.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcccvi{%
The believers, both men and women, are guides to each other. They order what is just and forbid what is evil; they establish their prayers and pay the obligatory charity and obey Allah and His Messenger. On these Allah will have mercy. He is Mighty, Wise.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah has promised the believing men and women gardens underneath which rivers flow, in which they shall live for ever. Goodly mansions in the Gardens of Eden, and the pleasure from Allah which is greater. That is the greatest winning.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet, struggle with the unbelievers and the hypocrites and be harsh with them. Gehenna shall be their refuge an evil arrival.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by Allah that they said nothing. Yet they did utter the word of disbelief and disbelieved after they had submitted. They intended what they never attained to, and took revenge only that Allah enriched them, and His Messenger, of His Bounty. If they repent, it will indeed be better for them; but if they turn away, Allah will sternly punish them both in this world and in the Everlasting Life. They have none on earth to protect or help them.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcccx{%
Some of them have made a covenant with Allah, 'If Allah gives to us of His bounty, we will give charity and be of the righteous'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcccxi{%
But when Allah had bestowed His bounty on them they became greedy and turned away, swerving aside.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcccxii{%
He has caused hypocrisy to be in their hearts till the Day they meet Him, because they have changed what they promised Allah and because they were liars.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Did they not know that Allah knows their secret and what they conspire together, and that Allah knows all the unseen?\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
As for those who taunt the believers who give charity voluntarily, and scoff at those who give according to their means, Allah will scoff at them. Theirs shall be a painful punishment.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcccxv{%
(It is the same) whether or not you beg forgiveness for them. If you beg forgiveness for them seventy times Allah will not forgive them, for they have disbelieved in Allah and His Messenger. Allah does not guide the evildoers.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who were left behind were glad that they were left behind by the Messenger of Allah, for they disliked to struggle in the Way of Allah with their wealth and their persons. They said: 'Do not go forth in the heat' Say: 'The Fire of Gehenna is more hot' Would that they understood!\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
They shall laugh but little and shed many tears. So shall they be recompensed for their earnings.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
If Allah brings you back to a party of them and they ask permission to march with you, say: 'You shall never march with me, nor shall you fight with me against any enemy. You were pleased to remain on the first occasion, therefore, you shall now stay with those who remain behind'\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcccxix{%
You shall never pray over any one of them when he is dead, nor stand over his tomb. For they disbelieved in Allah and His Messenger and died whilst they were sinners.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcccxx{%
Let neither their riches nor their children please you. With it Allah wants to punish them in this life, so that their souls depart while they disbelieve.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
Whenever a chapter is sent down, saying: 'Believe in Allah and struggle with His Messenger' the rich among them asked you to excuse them, saying: 'Leave us with those who are to stay behind'\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They were content to be with those who stayed behind, a seal was set upon their hearts, so they do not understand.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the Messenger and those who believed with him struggled with their wealth and their selves For them awaits goodness and those are the winners.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
Allah has prepared for them gardens underneath which rivers flow, in which they shall live for ever. That is the greatest winning.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
Some Arabs of the desert who had an excuse came asking permission to stay behind; whilst those who belied Allah and His Messenger remained behind. A painful punishment shall fall on those of them that disbelieved.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is no fault for the weak, the sick, and those lacking the means to spend (to stay behind), if they are true to Allah and His Messenger. There is no way against the righteous; Allah is Forgiving, the Most Merciful.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor shall those who came to you to be provided with mounts. And when you said: 'I can find no mounts for you' they turned back, their eyes streaming with tears grieving that they could not find the means to spend.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
But the blame is to be laid on those who asked permission of you whilst they are rich. They are content to remain with those who stay behind. Allah has set a seal upon their hearts so they do not know.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
When you return, they will apologize to you. Say: 'Make no excuses; we will not believe you. Allah has already told us of your news. Surely, Allah and His Messenger will see your work; then you will be returned to the Knower of the unseen and the visible, and He will inform you of what you were doing'\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
When you return to them, they will swear to you by Allah that you might turn aside from them. Let them alone, they are unclean. Gehenna shall be their refuge, a recompense for their earnings.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They will swear to you in order to please you. But if you will be pleased with them, Allah will not be pleased with the evildoing nation.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The Bedouin Arabs surpass (the city dwellers) in disbelief and hypocrisy, and are more likely not to know the bounds that Allah has sent down to His Messenger. But Allah is Knowing, Wise.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
Some Arabs (Banu Asad and Ghatfan tribes) regard what they spend as a (compulsory) fine and wait for some misfortune to befall you. Theirs shall be the evil turn! Allah is Hearing, Knowing.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
Yet there are some Arabs (Juhaina and Muszaina tribes) who believe in Allah and the Last Day, and regard what they spend as a means of bringing them close to Allah and to the prayers of the Messenger. Indeed, they are an offering for them; Allah will admit them to His Mercy. He is Forgiving, Merciful.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
As for the first outstrippers among the migrants and supporters and those who followed them in doing good, Allah is pleased with them and they are pleased with Him. He has prepared for them gardens underneath which rivers flow, where they shall live for ever. That is the greatest winning.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
Some of the Bedouin Arabs around you are hypocrites, and so are some of the people of Madinah who are well versed in hypocrisy. You do not know them, but We do. Twice We will punish them then they shall return to a mighty punishment.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
There are others who have confessed their sins; they intermixed good deeds with another evil. It may be that Allah will turn towards them in mercy. Allah is Forgiving, Merciful.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Take charity from their wealth, in order that they are thereby cleansed and purified, and pray for them; for your prayer is a comforting mercy for them. Allah is Hearing, Knowing.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Do they not know that Allah accepts the repentance of His worshipers and takes their charity, and that Allah is the Forgiving, the Merciful?\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mcccxl{%
Say: 'Allah will see your works and so will His Messenger and the believers; then you shall be returned to the Knower of the unseen and the visible, and He will inform you of what you were doing'\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mcccxli{%
There are others who must wait for the Commandment of Allah. He will either punish or turn towards them. And Allah is Knowing, Wise.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And there are those who have taken a mosque to cause harm, disbelief, and to divide the believers, and as a place of ambush for those who fought Allah and His Messenger before. They swear: 'We desired nothing but good', but Allah bears witness that they are liars.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
You shall never stand there. A mosque founded upon piety from the first day is worthier for you to stand in. In it are men who love to purify themselves. Allah loves those who purify themselves.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Is he who founds his building on the fear of Allah and His pleasure, better or he who founds his building on the brink of a crumbling edge so that it will tumble with him into the Fire of Gehenna? Allah does not guide the harmdoers.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
The buildings they have built will always cause doubt in their hearts, unless their hearts are torn into pieces. Allah is Knowing, Wise.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Allah has purchased from the believers their selves and possessions, and for them is Paradise. They fight in the Way of Allah, slay, and are slain. That is a binding promise upon Him in the Torah, the Gospel and the Koran; and who is there that more truthfully fulfills his covenant than Allah? Therefore, rejoice in the bargain you have bargained with Him. That is the mighty winning.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
Those who repent, those who worship Allah and praise (Him); those who journey, those who bow, those who prostrate themselves; those who order righteousness and forbid evil, and those who observe the limits of Allah give glad tidings to the believers.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not for the Prophet or the believers to ask forgiveness for idolaters, even though they are near kindred, after it has become clear that they are the inhabitants of Hell.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
Abraham only asked for forgiveness for his father because of a promise he had made to him. But when it became clear to him that he was an enemy of Allah, he declared himself quit of him. Surely, Abraham was earnest in his supplication and tenderhearted.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mcccl{%
Nor will Allah lead a nation astray after He has given them guidance until He has made clear to them all that they should guard against. Allah has knowledge of all things.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mcccli{%
Indeed, to Allah belong the kingdom of the heavens and the earth; He gives life and causes death. Other than Allah, you have neither a guardian nor a helper.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mccclii{%
In the hour of adversity, Allah turned (in mercy) to the Prophet, the Emigrants (of Mecca) and the Supporters (of Madinah) who followed him when some of their hearts were about to swerve away. He turned to them, indeed, He is Gentle, the Most Merciful.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And to the three who were left behind (at the Battle of Tabuk), until the earth became narrow with all its vastness, and their souls became narrow for them, they knew there was no shelter from Allah except in Him. Then He turned to them (in mercy) so that they might also turn (in repentance). Allah is the Turner, the Most Merciful.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mcccliv{%
Believers, fear Allah and stand with the truthful.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mccclv{%
The people of Madinah and the Arabs who dwell around them have no cause to stay behind the Messenger of Allah, or to prefer their lives to his. They are neither stricken by thirst, nor by tiredness, nor yet by hunger in the Way of Allah, nor do they take steps that anger the unbelievers, nor gain any gain from an enemy, but that it is counted as a righteous deed. Allah does not waste the wage of the gooddoers.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Each sum they spend, be it small or large, and each valley they cross is written to their account, so that Allah may recompense them for their best deeds.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mccclvii{%
The believers should not go forth altogether, rather, a party from each section should go forth to become well versed in the religion, and when they return to their people warn them in order that they may beware.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mccclviii{%
Believers, fight the unbelievers who are near you. Let them find firmness in you. Know that Allah is with those who are cautious.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mccclix{%
Whenever a chapter is sent down to you, some ask: 'Which of you has it increased in belief' It will surely increase the belief of the believers and they are joyful.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mccclx{%
As for those whose hearts are diseased, they will be increased in filth added to their filth, so that they die as unbelievers.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mccclxi{%
Do they not see how once or twice every year they are tried? Yet still they neither repent nor remember.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mccclxii{%
Whenever a chapter is sent down, they glance at each other, (asking): 'Does anyone see you' Then they turn away. Allah has turned away their hearts, for they are a nation who do not understand.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
Indeed, there has come to you a Messenger from your own, he grieves for your suffering, and is anxious about you, and is gentle, merciful to the believers.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
Therefore, if they turn away, say: 'Allah is sufficient for me. There is no god except He. In Him I have put my trust. He is the Lord of the Mighty Throne'\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen AlifLaamRa. Those are the verses of the Wise Book.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Is it a wonder to the people that We revealed to a man from among themselves: 'Warn mankind, and bear the glad tidings to those who believe that they stand firm with their Lord' (Yet) the unbelievers say: 'This is a clear sorcerer'\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Indeed, your Lord is Allah, who, in six days created the heavens and the earth and then willed to the Throne, directing affairs. There is no intercessor except by His permission. Such is Allah your Lord, therefore worship Him. Will you not remember?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
To Him all of you will return together. This is, in truth, the promise of Allah. He originates creation, then He revives it so that He may recompense those who believe and do righteous deeds. As for the unbelievers, theirs is a drink of boiling water and a painful punishment for their disbelief.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mccclxix{%
It was He that made the sun a brightness and the moon a light, and determined it in phases so that you might know the number of years and the reckoning. Allah did not create them except in truth, and distinguishes the verses to a nation who know.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mccclxx{%
In the alternation of the night and day, and in all that Allah has created in the heavens and the earth, surely there are signs for people who are cautious.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Those who do not expect to meet Us, and are wellpleased with this life and are satisfied with it, and those who are inattentive to Our signs,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
for them, their refuge is the Fire for what they have been earning.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Indeed, those who believe and do righteous works, their Lord will guide them for their belief, beneath them rivers will flow in gardens of bliss.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
(In it) their supplication will be: 'Exaltations to You, Allah' And their greeting will be: 'Peace' They will end their supplication with 'Praise be to Allah, Lord of the all the Worlds'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
If Allah should hasten evil to people as they would hasten good, their term would already have been decided. But We leave those who do not expect to meet Us to wander blindly in their insolence.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
When affliction befalls a man, he supplicates to Us (lying) on his side, sitting or standing. But as soon as We relieve him from his affliction, he continues (in the same way), as though he never supplicated to Us when harm touched him. So it is, that which the sinners were doing seem fairly decorated to them.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
We destroyed generations before you when they did evil. (When) their Messengers came to them with clear verses they would not believe; so We recompense the sinning nation.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
After them We made you their successors in the earth, so that We might see how you would do.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
When Our verses, clear verses, are recited to them, those who do not reckon to meet Us say: 'Bring a Koran other than this, or make changes in it' Say: 'It is not for me to change it by myself. I follow nothing, except what is sent down to me. Indeed, if I should rebel against my Lord I fear the punishment of a Great Day.'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say (Prophet Muhammad): 'Had Allah willed, I would not have recited it to you, nor would He have made it known to you. I lived among you all my life before it (was sent down). Will you not understand?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
Who does greater evil than he who forges a lie about Allah or belies His verses? Indeed, the evildoers do not prosper.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
They worship, other than Allah, that which can neither harm nor benefit them, and say: 'These are our intercessors with Allah' Say: 'Will you tell Allah of something He does not know about either in the heavens or earth? Exaltations to Him! Exalted be He above what they associate'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
(Before) mankind were but one nation, then they differed with one another. But for a Word that preceded from your Lord, it (the matters) over which they differed had already been decided.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
They say: 'Why has no sign been sent down to him from his Lord' Say: 'The Unseen belongs to Allah alone. Wait if you will I am one of those who wait'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
When We let people taste (Our) mercy after they had been afflicted by hardship, they devise against Our verses. Say: 'Allah is more swift in devising' Indeed, Our Messengers (the angels) are writing down whatever you devise.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
It is He who conveys you by land and sea. When you are on board the ship and the ships run with them upon a fair breeze they are joyful. (But when) a strong wind and waves come upon them from every side, and they think they are encompassed, they supplicate to Allah, making their religion His sincerely, (saying): 'If You save us from this, we will indeed be among the thankful'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
But when He has saved them, see how they become wrongfully insolent in the land. People, your insolence is only against yourselves; the enjoyment of this present life, then to Us you shall return and We shall tell you what you did.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
This present life is like the water We send down from the sky. The plants of the earth mix with it and from it mankind and cattle eat; then when the earth has become lush and adorned, its inhabitants think they have power over it, Our command comes upon it by night or day, and We cause it to be stubble, just as though it had not flourished the day before. In this way We distinguish Our verses for those who reflect.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
Allah invites you to the House of Peace. He guides whom He will to a Straight Path\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcccxc{%
for those who do good is a fine reward and a surplus. Neither dust nor shame shall cover their faces. Those are the companions of Paradise in it they shall live for ever.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcccxci{%
As for those who have earned evil deeds, evil shall be recompensed with its like. Abasement will cover them, they shall have none to defend them from Allah as though their faces were covered with parts of the blackness of night. Those, they are the companions of the Fire, in it they shall live for ever.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
And on the Day when We assemble them all together, We shall say to those who associated (other gods with Allah): 'Go to your place, you and your associates' Then, We will separate them, and their associates will say (to them): 'It was not us that you worshipped'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
Allah is a Sufficient witness between us and you, surely, we were heedless of your worship.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
There, each soul shall prove its past deeds. They shall be restored to Allah, their Guardian, the True, and that which they forged will escape from them.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say: 'Who provides for you from heaven and earth, or who owns the hearing and the sight? Who brings forth the living from the dead, and the dead from the living' Who directs the affair? Surely, they will say: 'Allah' Then say: 'Then, will you not be fearful'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
Such is Allah, your Lord, the True. What, is there after truth, anything except error. Then how are you turned around (from faith)'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
So the Word of your Lord is realized against the evildoers that they do not believe.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say: 'Is there any (among) your associates who originates creation, then cause it to be revived yet again' Say: 'Allah, He originates creation, then revives it yet again. How is it that you are so perverted'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say: 'Do any of your partners guide you to the truth' Say: 'Allah, He guides to the truth. Who then is worthier to be followed He who guides to the truth or he who cannot guide unless he (himself) is guided? What is the matter with you, how then can you judge'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcd{%
Most of them follow nothing except conjecture. But conjecture does not help against the truth. Allah knows the things they do.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcdi{%
This Koran could not have been forged by other than Allah. It confirms what was before it; a distinguishing Book, in which there is no doubt, from the Lord of all the worlds.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcdii{%
Do they say: 'He has forged it'. Say: 'Compose one chapter like it, and call upon whom you will, other than Allah (to help you), if what you say is true'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcdiii{%
They have belied that which they did not understand of its knowledge, nor has its interpretation reached them. Those who were before also belied. But see how was the end of the harmdoers.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcdiv{%
Some believe in it, while others do not believe it. Your Lord knows well the corrupters.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcdv{%
If they belie you, say: 'I have my work, you have your work. You are quit of what I do, and I am quit of what you do'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcdvi{%
Some of them listen to you. But can you make the deaf hear you, even though they cannot understand?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcdvii{%
Some of them look to you. But can you guide the blind, even though they do not see?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Indeed, Allah does not wrong mankind a thing, but they wrong themselves.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcdix{%
The Day when He will gather them, (it will be) as though they had lingered but an hour of the Day and they will recognize one another. Lost are those who belied the meeting with their Lord and were not guided.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcdx{%
Whether We let you see some of that with which We promised them, or We call you to Us, to Us they shall return. Allah is witness of the things they do.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcdxi{%
Every nation has its Messenger. Then, when their Messenger comes the matter is justly decided between them; they are not wronged.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcdxii{%
They ask: 'If what you say is true, when will this promise come'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say: 'I have no power to benefit or harm myself except as Allah wills. To every nation is a fixed term and when their term comes they cannot delay it for an hour, nor can they bring it forward.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say: 'Have you considered? Should His punishment come upon you by night or by day, what (part) of it would the sinners try to hasten'\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcdxv{%
And when it overtakes you, is it then that you will believe in it, now, when you already try to hasten it!\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Then it shall be said to the evildoers: 'Taste the punishment of eternity! Shall you be recompensed except according to what you earned'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
They ask you to tell them if it is true. Say: 'Yes, by my Lord! It is true, and you cannot frustrate it'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
If each soul that has done evil had all that is in the earth, it would offer it for its ransom. And secretly they will feel regret when they see the punishment, and the matter is justly decided between them, and they are not wronged.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Indeed, to Allah belongs everything in the heavens and the earth. Indeed, the promise of Allah is true though most of them do not have knowledge.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mcdxx{%
It is He who gives life and causes death, and to Him you shall be returned.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
People, an admonition has now come to you from your Lord, and a healing for what is in the chests, a guide and a mercy to believers.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say: 'In the Bounty of Allah and His Mercy let them rejoice, it (the Koran) is better than that which they hoard'\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say: 'Have you considered the provision that Allah has sent down for you, and some you have made unlawful and some lawful' Say: 'Has Allah given you His permission, or do you forge (falsehood) against Allah'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
What will those who forged falsehood about Allah think on the Day of Resurrection? Allah is Bountiful to mankind; yet most of them do not give thanks.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
You are not engaged in any matter, neither do you recite any portion of the Koran, nor do you do any work, except that We are witnesses over you when you press upon it? Not even as much as the weight of an ant in earth or heaven escapes your Lord, nor is there anything smaller or greater, but it is (recorded) in a Clear Book.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Indeed, there shall be neither fear nor sorrow upon the guided by Allah.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who believe and are cautious\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
there is for them glad tidings in this present life and in the Everlasting Life. The Word of Allah is unchanging, that is the mighty triumph.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
Do not let their speech grieve you. All might belongs to Allah. He is the Hearing, the Knowing.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Attention: Indeed to Allah belongs everyone that is in the heavens and in the earth. Those who call upon associates, other than Allah, follow nothing but assumptions, (they are) only lying.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
He it is who has made the night for your rest and the day to see. Surely, in this there are signs for people who listen.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They say: 'Allah has taken a son' Exaltations be to Him (Allah)! Rich is He. To Him belongs all that is in the heavens and the earth you have no authority for this! What, do you say of Allah what you do not know?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say: 'Those who forge falsehoods against Allah shall not prosper'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
(They take their) enjoyment in this world, but to Us they shall return, then, We shall let them taste the terrible punishment because they were unbelievers'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
And recite to them the story of Noah. He said to his nation: 'O my nation, if my standing here, reminding you of the verses of Allah grieves you, and in Allah I have put my trust; decide upon your affair with your associates, then do not let your affair worry you. Come to a decision about me, and give me no respite.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
Then, if you turn your backs, I have not asked of you a wage. My wage falls only on Allah. I am commanded to be from those who surrender (Muslims)'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
But they belied him. Therefore We saved him and those who were with him in the Ark, and We made them caliphs, and We drowned those who belied Our verses. See what was the end of those who were warned!\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
After him We sent Messengers to their nation. They brought them clear signs, but they were not of those to believe because they had belied it previously. SoWe seal the hearts of the evildoers.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then, after them We sent Moses and Aaron with Our signs to Pharaoh and his Council. But they were arrogant, for they were a sinful nation.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcdxl{%
When the truth came to them from Us they said: 'This is indeed clear magic'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Moses said: 'Is this what you say of the truth when it has come to you? Is this sorcery? Sorcerers do not prosper'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said: 'Have you come to turn us away from that which we found our fathers practicing (in order that) the domination of the land might belong to you two? We do not believe you'\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
(Then) Pharaoh said: 'Bring every skilled sorcerer'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
When the sorcerers came, Moses said to them: 'Cast down what you will cast'\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
And when they had cast, Moses said: 'What you have brought is sorcery. Surely, Allah will render it as nothing. Allah does not put right the work of the corrupt'\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
Allah verifies the truth by His Words, even though the sinners hate it.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
So none believed Moses except a few of his nation because they feared that Pharaoh and their Council would persecute them. Pharaoh was mighty in theland, and one of the evildoers.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
Moses said: 'O my nation, if you believe in Allah, put your trust in Him, if you have surrendered (Muslims)'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They said: 'We have put our trust in Allah. Our Lord, do not let us be a temptation to the harmdoing nation.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcdl{%
Save us, through Your Mercy, from the unbelieving nation'\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcdli{%
We revealed to Moses and his brother: 'Take certain houses for your people in Egypt. Make your houses a direction (for pray); establish the prayer; and give glad tidings to the believers'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcdlii{%
'Our Lord' supplicated Moses. 'You have given Pharaoh and his Council adornments and possessions in this life. Our Lord, let them go astray from YourPath. Our Lord, destroy their possessions and harden their hearts so that they shall not believe until they see the painful punishment.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcdliii{%
He (Allah) said: 'Your supplication is answered; so go straight and do not follow the way of those who do not know'\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcdliv{%
We brought the Children of Israel through the sea, and Pharaoh and his legions pursued them arrogantly and frantically. But as he was drowning he cried out: '(Now) I believe that there is no god except He in whom the Children of Israel believe. I am of those that surrender (Muslims)'\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcdlv{%
(Allah said): 'Now (you believe)! But before this you rebelled and were of the corrupt.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
We shall deliver you (Ramsis II) with your body this day, so that you may be a sign to those after you. Indeed many people pay no heed to Our signs!\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
(Thereafter) We settled the Children of Israel in a blessed land and provided them with good things. They did not differ until knowledge was given them. Indeed, your Lord will decide between them on the Day of Resurrection.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
If you are in doubt of what We have sent down to you, ask those who recite the Book before you. The truth has come to you from your Lord, therefore do not be of the doubters.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcdlix{%
Do not be among those who belie the verses of Allah, for then you would be among the losers.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Those against whom the Word of your Lord will be realized will not believe,\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
even though every sign comes to them, until they see the painful punishment.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
Why, was there never a village that believed and its belief benefited them? Except Jonah's nation, when they believed, We spared them from a degrading punishment in this life and We gave them enjoyment for awhile.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
Had your Lord willed, whosoever is in the earth, all would have believed. Would you then constrain people until they believe?\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
No soul can believe except by the permission of Allah. Upon those who do not understand lays His punishment.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say: 'See what is in the heavens and the earth' But neither signs nor warnings help the unbelievers.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
Do they watch and wait for anything except for days similar to those who passed away before them? Say: 'Wait; I shall be with you among those who arewaiting'\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then we shall save Our Messengers and the believers. It is Our obligated duty, We shall save those who believe.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say: 'O people! If you are in doubt concerning my religion, I worship none of those you worship, other than Allah but I worship Allah, who will cause you to die, for I am commanded to be among the believers,\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
and, set your face towards the religion, being of pure faith, and do not be among the idolaters.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
Do not pray to, other than Allah, to anything that can neither help nor harm you, for if you do, you will become a harmdoer.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
If Allah touches you an affliction none can remove it except He; and if He wills any good for you, none can repel His Bounty. He causes it to fall upon whosoever of His worshippers that He will. He is the Forgiving, the Most Merciful.'\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say: 'O people! The truth has come to you from your Lord. Whosoever is guided is guided only for himself, and whosoever goes astray, he is astray for himself. I am not a guardian over you'\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
Follow what is revealed to you, and be patient till Allah shall judge, and He is the Best of judges.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen AlifLaamRa. (This is) a Book whose verses are clear, and then distinguished from Him, the Wise, the Aware.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
Worship none except Allah. I am for you, a warner sent from Him and a bearer of glad tidings.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
And ask forgiveness of your Lord and then repent to Him. He will give you enjoyment till a stated term and will give of His Bounty to those of grace. But if you turn away, I fear for you the punishment of a Mighty Day.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
To Allah you shall all return. He has power over all things.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
See, they cover their chests to conceal from Him. But when they wrap themselves in their clothes He knows what they hide and what they reveal. Indeed, He knows every thought within the chest.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
There is not a crawling (creature) on the earth whose provision is not by Allah. He knows its resting place and its repository. All is in a Clear Book.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
It is He who created the heavens and the earth in six days and His Throne was upon the waters that He might try you, (and see) which of you excel in works. If you say: 'After death you shall be raised up' the unbelievers will say: 'This is nothing but clear sorcery'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We delay the punishment till an appointed time, they will ask: 'What has detained it' Indeed, the Day will come to them, it will not be turned awayfrom them, and that they mocked at will encompass them.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
If We let a human taste Our Mercy and then withhold it from him, he becomes desperate and ungrateful.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
And if after adversity had come upon him, We let him taste prosperity, he says: 'Evil has left me' see, he is jubilant and boastful,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
except those who are patient and do good deeds, for them awaits forgiveness and a mighty wage.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
Perhaps you are leaving part of what has been sent down to you, and your chest is straitened by it, because they say: 'Why has no treasure been sent down to him, or an angel come with him' You are only a warner, and Allah is a Guardian over everything.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or do they say: 'He has forged it' Say (to them): 'Then produce ten forged chapters like it. Call, if you are able, upon other than Allah, if what you say is true'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
But if they do not answer you, know that it has been sent down with the knowledge of Allah, and that there is no god except He. So, have you surrendered (become Muslims)?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
We shall pay those who desire the present life and its adornments in full for the work they have done therein, they shall not be defrauded;\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
those are they who in the Everlasting Life will have only the Fire. There, their deeds will have failed and their works will be void.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcdxc{%
Then what of he who stands upon a clear proof from his Lord, recited by a witness from Him and before him is the Book of Moses for a guide and a mercy? Those believe in it. But as for those partisans who disbelieve in it, their promised land shall be the Fire. Therefore do not doubt it. It is the truth from your Lord, yet most people do not believe.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mcdxci{%
And who is greater in evil than he who forges a lie against Allah? Those, they shall be brought before their Lord, and witnesses will say: 'Those are they who lied against their Lord' Indeed, the curse of Allah shall fall upon the evildoers,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
who bar others from the Path of Allah and seek to make it crooked, they disbelieve in the Everlasting Life.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
They are unable to frustrate Him on the earth; there is none to protect them, except Allah. Those, their punishment shall be doubled; they could neither hear nor see.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
Those are they that have lost their souls, and that which they forged has left them;\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
without doubt they will be the greatest losers in the Everlasting Life.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
Whereas those who believe and do good deeds and humble themselves before their Lord, they are the companions of Paradise, and there they shall live for ever.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The likeness of the two parties is as one who is blind and deaf, and one that sees and hears, are they equally alike, will you not remember?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
We sent Noah to his nation. (He said:) 'I am a warner for you, and a bearer of glad tidings.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
Worship none except Allah. I fear for you the punishment of a painful Day'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@md{%
The unbelieving Council of his nation said: 'We do not see you other than a human like ourselves. We see your followers are none but the lowliest amongst us, and their opinion is not to be considered. We do not see you superior to us, rather, we consider you liars'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdi{%
He said: 'What do you think my nation! If I have a clear proof from my Lord and He has given me mercy from Him, though it is hidden from you, can wecompel you to accept it when you hate it?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdii{%
My nation, for this I do not ask you for your wealth for my wage is only with Allah. Nor will I drive away the believers, for they will surely meet their Lord. But, I can see that you are ignorant.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdiii{%
Were I to drive you away my nation, who would help me from Allah? Will you not remember?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdiv{%
I do not say to you that I possess the treasuries of Allah, and I do not know the unseen. I do not say I am an angel, nor do I say to those whom you despise, Allah will not give them any good. Allah knows best what is in their hearts. Indeed, if this were so then I would be amongst the harmdoers'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdv{%
They said: 'O Noah, you have disputed, and disputed too much, with us. Bring (down) upon us that which you promised us, if what you say is true'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdvi{%
He replied: 'Allah will bring it (down) upon you if He will; you will never frustrate Him.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdvii{%
Nor will my sincere counsel benefit you if I sincerely desire to counsel you if Allah desires to lead you astray. He is your Lord, and to Him you shall return'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdviii{%
Or do they say: 'He has fabricated it (himself)' Say: 'If I had fabricated it, then the sin rests upon me. I reject the sins you do'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was revealed to Noah: 'None of your nation will believe except whosoever has already believed. Do not distress yourself with what they may do.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdx{%
Build the Ark with Our seeing (and protection), and as We reveal. Do not speak to Me concerning the evildoers; they shall be drowned'\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdxi{%
Whenever an assembly of his nation passed by him as he was building the Ark, they mocked him. Whereupon he said: 'If you mock us, we shall indeedmock you, just as you mock.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdxii{%
You shall know to whom a degrading punishment will come, and upon whom an everlasting punishment will fall'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdxiii{%
And when Our command came and the oven gushed (forth with water), We said (to Noah): 'Take on board (the Ark) a pair from every species and yourfamily, except he of whom the word has already been spoken, and those who believe. And none except a few believed with him.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdxiv{%
He (Noah) said: 'Embark. In the Name of Allah will be its course and berthing. Indeed, my Lord is Forgiving, the Most Merciful'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdxv{%
And so it (the Ark) ran with them amidst the mountainous waves, and Noah cried out to his son, who was standing apart, 'Embark with us, my son, do not be with the unbelievers'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdxvi{%
But he replied: 'I shall seek refuge on a mountain, which will protect me from the water' He (Noah) said: 'Today, there is no defender from the command of Allah, except those to whom He has mercy' And the waves came between them, and he was drowned.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was said: 'Earth, swallow up your waters. Heaven, cease' The water subsided and the matter was accomplished. And the Ark came to rest upon (the mountain of) AlJudi, and it was said: 'Be gone, evildoing nation'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdxviii{%
Noah called out to his Lord, saying: 'O Lord, my son was of my family, and Your promise is surely the truth. You are the most Just of judges'\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said: 'Noah, he is not of your family. It is not a good deed. Do not ask Me about things of which you have no knowledge. I reproach you lest you become among the ignorant'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdxx{%
He said: 'My Lord, I seek refuge with You from asking You of that which I have no knowledge. If You do not forgive me and have mercy on me, I shall be among the losers'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said: 'O Noah, descend with peace from Us and blessings on you and on the nations of those with you; and nations We shall give them enjoyment, and then from Us they shall be visited with a painful punishment'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdxxii{%
That is from the news of the unseen which We reveal to you; neither you nor your nation knew this before now. Have patience; the outcome is for the cautious.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
To Aad (We sent) their brother Hood. He said: 'My nation, worship Allah; you have no god except He. You are only forgers.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
My nation, for this I ask of you no wage. My wage is only with He who created me. Will you not understand?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdxxv{%
My nation, ask your Lord to forgive you and turn to Him in repentance. From the sky He will loose an abundance (of rain) upon you; He will add strength to your strength. Do not turn away as sinners'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They replied: 'Hood, you have not brought us a clear sign. We will not forsake our gods because of what you say. We do not believe you.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
We say nothing except our gods have afflicted you with some kind of evil' He said: 'I call Allah to witness, and you to bear witness, that I reject what you associate,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
other than Him, so all of you, scheme against me, then you shall give me no respite.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdxxix{%
In truth, I have put my trust in Allah, (who is) my Lord and your Lord. There is no crawling creature that He does not take by the forelock. Indeed, my Lord is on a Straight Path.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdxxx{%
If you turn away, I have delivered to you that with which I was sent, and my Lord will cause people other than you to be your successors. You cannot harm Him a thing. My Lord is the Guardian over every thing'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our command came, We saved Hood, together with those who believed with him through Our Mercy, and saved them from a harsh punishment.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
Such was Aad. They disbelieved the verses of their Lord, rebelled against His Messengers, and did the bidding of every rebellious tyrant.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
They were overtaken by a curse in this world, and (they shall be cursed) on the Day of Resurrection. Indeed, Aad disbelieved in their Lord. Gone are Aad, the nation of Hood.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And to Thamood, (We sent) their brother Salih. He said: 'My nation, worship Allah; you have no god except He. It is He who made you from the earth and let you live upon it. Ask His forgiveness then repent to Him. Indeed, my Lord is near and answers (prayers)'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said: 'Salih, before this you were a source of hope to us. What, would you now forbid us to worship what our fathers worshipped? Indeed, we are disquieted, and doubt that to which you invite'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said: 'My nation, think! If I have a clear proof from my Lord and He has given me His Mercy, who would help me against Allah if I rebel against Him? Indeed, you would do nothing for me except increase my loss'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
'My nation, this is the shecamel of Allah, a sign for you. Leave her to graze upon the earth of Allah and do not touch her with evil lest you be seized by a punishment that is near'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
Yet they hamstrung her. He (Salih) said: 'Take your enjoyment in your homes for three days! This is a promise that cannot be belied'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
And when Our command came, We saved Salih together with those who believed with him through Our Mercy, and from the ignominy of that day. YourLord is Strong and Mighty.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdxl{%
And the harmdoers were seized by the Shout (of the angel), and in the morning, they were found crouched in their dwellings, dead,\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdxli{%
as though they had never lived there. Indeed, Thamood disbelieved in their Lord. So, begone Thamood.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdxlii{%
Our Messengers came to Abraham with glad tidings. They said: 'Peace' He replied 'Peace' and in a while brought them a roasted calf.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdxliii{%
But when he saw that their hands did not reach towards it, he was wary and became fearful of them, but they said: 'Do not be afraid. We are sent to thenation of Lot'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdxliv{%
His wife (Sarah), who was standing nearby, laughed. Thereupon, We gave her the good news of Isaac, and after Isaac of Jacob.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She replied: 'Alas for me! Shall I bear (a child) when I am old woman and my husband is advanced in years? This is indeed a strange thing'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said: 'What, do you marvel at the command of Allah? The Mercy of Allah and His Blessings be upon you, O people of the House. Indeed, He isPraised, Exalted'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
And when the wonderment departed from Abraham and the glad tidings reached him, he pleaded with Us for the nation of Lot;\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
indeed, Abraham was forbearing, tenderhearted and penitent.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdxlix{%
(It was said:) 'Abraham, turn away from this; your Lord's command has indeed come, and there is coming upon them a punishment that will not be turned back'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our messengers came to Lot, he was troubled and distressed for them, and said: 'This is a harsh day'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdli{%
His nation came running towards him; whilst they were doing evil deeds. 'My nation' he said: 'here are my daughters (take them in marriage), they are cleaner for you. Fear Allah and do not humiliate me by my guests. Is there not one man amongst you of right mind'\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdlii{%
They replied: 'You know we have no right for your daughters. You know very well what we desire'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said: 'Would that I were powerful over you, or might take refuge in a strong pillar'\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdliv{%
They (the angels) said: 'Lot, we are the Messengers of your Lord, they shall not touch you. Depart with your family in the watch of the night and let none of you turn round, except your wife. She shall be struck by that which strikes them. Their appointed time is the morning. Is it not that the morning is near'\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdlv{%
And when Our command came, We turned it upside down, and rained on it, stone after stone of baked clay,\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdlvi{%
marked with your Lord, and never far from the evildoers.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And to Midian, (We sent) their brother Shu'aib. He said: 'My nation, worship Allah; you have no god except He. Do not reduce the measure nor the scale. I see you are prosperous, and fear the punishment of an encompassing day for you.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdlviii{%
'My nation, be just in filling the measure and the scale. Do not reduce people's goods and do not corrupt the land with mischief.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdlix{%
What remains with Allah is better for you, if you are believers. I am not your guardian'\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdlx{%
'Shu'aib' they replied, 'does your prayer command you that we should abandon that which our fathers worshipped or do as we please with our goods? You are clement and rightminded'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said: 'Think, my nation! If I have a clear sign from my Lord and He has provided me with good provision, I do not desire to go behind you, taking for myself that which I forbid you. I seek but to reform as much as I can, my help comes only from Allah. In Him I have put my trust and to Him I turn in penitence.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdlxii{%
And my nation, do not let your breaking with me bring upon you something similar to that which struck the nation of Noah, Hood, and Salih and it is not long since the people of Lot (were punished).\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
Ask the forgiveness of your Lord and turn to Him in repentance. Indeed, my Lord is the Most Merciful, Loving'\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said 'Shu'aib, we do not understand much of what you say to us. Indeed, we see you weak among us. If it was not for your tribe we would have stoned you because you are not strong against us'\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said: 'My nation, is my tribe stronger against you than Allah? You have taken Him to be thrown behind you, my Lord encompasses all that you do.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
My nation, do according to your position; as I am doing; and certainly you will know to whom the degrading punishment will come and who is a liar. Be watchful; I shall be watching with you'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our command came We saved Shu'aib through Our Mercy, together with those who believed. (Then) the evildoers were seized by a Shout, and when morning came they were crouched in their dwellings, dead,\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
as if they had never have lived there. Begone, the nation of Midian, just as Thamood are gone.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdlxix{%
We sent Moses with Our signs and with clear authority\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdlxx{%
to Pharaoh and his Council. But they followed the command of Pharaoh, and Pharaoh's command was not rightminded.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He shall go before his nation on the Day of Resurrection and lead them into the Fire. Evil is the wateringplace to be led down to!\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
A curse was sent to follow them in this world and then upon them on the Day of Resurrection. Evil is the offering to be offered.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
That, which We have related to you, is the news of the villages; some of them still stand, whereas others are stubble.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
We did not wrong them, rather, they wronged themselves. Their gods that they called upon, other than Allah, did not help them when your Lord's command came they did not increased them except in their destruction.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
Such is the seizing of your Lord, when He seizes the evildoing villages. His seizing is painful, stern.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Indeed, for he who fears the punishment of the Everlasting Life that is a sign. That is a Day on which everyone shall be assembled. That shall be a witnessed Day.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
We shall not postpone it except until a counted term.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
When that Day arrives no soul shall speak except by His permission. Some shall be wretched, and others happy.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
The wretched shall be (cast) in the Fire where they will moan and sigh,\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
and there they shall live for ever, as long as the heavens and the earth endure, and as your Lord wills. Indeed, your Lord accomplishes whatsoever He will.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
As for the happy, they shall live in Paradise for ever, so as long as the heavens and the earth endure, and as your Lord wills an unbroken gift.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
Therefore do no be doubtful as to what these worship. They worship only that which their fathers worshiped before them. We shall indeed pay them in full their undiminished measure.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
We gave Moses the Book, but they differed regarding it, but for a word that preceded from your Lord, it had been decided between them; and they are indisquieting doubt of it.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
Indeed, your Lord will pay each one of them in full for their deeds. He is aware of the things they do.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So you and whosoever repents with you go straight as you have been commanded and do not be insolent, indeed, He sees what you do.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And do not incline to the wrongdoers lest you are touched by the Fire, for then you shall not be helped. You have no guardians other than Allah.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And establish your prayer at the two edges of the day and in part of the night. Good deeds will repel evil deeds. That is a remembrance for those whoremember.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
Therefore have patience; Allah will not let the wage of the gooddoers go to waste.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
If (only) there had been except for a few among them whom We saved among the generations that have gone before you, some that remained forbidding corruption in the land, but the wrongdoers pursued the ease they had been given to delight in and became sinners.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mdxc{%
Your Lord would never destroy the villages unjustly, whilst their people were reforming.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mdxci{%
Had your Lord willed, He would have made mankind a single nation. But they continue in their differences\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mdxcii{%
except those on whom your Lord shows mercy. For this end He has created them. The Word of your Lord shall be perfectly completed: 'I shall fillGehenna (Hell) with jinn and people, all together'\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mdxciii{%
And all We relate to you of the tidings of the Messengers is that whereby We strengthen your heart and through these the truth has come to you, and anadmonition and a reminder to the believers.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mdxciv{%
Say to those who disbelieve: 'Do according to your station; we are doing according to our station'\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mdxcv{%
Wait; we too are waiting'\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
To Allah belongs the unseen in the heavens and in the earth; to Him the matter, in its entirety, shall be returned. Worship Him, and put your trust in Him. Your Lord is not inattentive of the things you do.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen AlifLaamRa. Those are the verses of the Clear Book.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
We have sent it down, an Arabic Koran, in order that you understand.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdxcix{%
In the sending down of this Koran, We will narrate to you (Prophet Muhammad) the best of narratives, of which you were previously unaware.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdc{%
When Joseph said to his father: 'Father, I saw eleven planets, and the sun and the moon; I saw them prostrating themselves before me'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdci{%
He said: 'O my son, say nothing of this vision to your brothers lest they should cunningly plot against you indeed, satan is the clear enemy of the human,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcii{%
so your Lord will choose you and teach you the interpretation of visions, and perfect His Favor upon you and upon the House of Jacob, as He perfected it on your fathers Abraham and Isaac before you. Your Lord is Knowing, Wise.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdciii{%
Indeed, in Joseph and his brothers there were signs for those who inquire.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdciv{%
They said: 'Joseph and his brother are dearer to our father than ourselves, even though we are many. Truly, our father is obviously wrong.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcv{%
(Let us) kill Joseph, or cast him away in some (far off) land, so that your father's face will be left for you, and afterwards you will be a righteous nation'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcvi{%
One of them said: 'No, do not kill Joseph, if you do anything, cast him into a dark pit, a traveler will pick him up'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said: 'Father, what is the matter with you, do you not trust us with Joseph? Indeed, we are sincere advisors.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcviii{%
Send him with us tomorrow to frolic and play. We will look after him'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcix{%
He said: 'It grieves me to let him go with you, for I fear lest the wolf should devour him when you are not paying attention to him'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said: 'We are many, if a wolf devours him, then we are losers'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcxi{%
When they went with him, they agreed to put him in the bottom of a well. We revealed to him: 'You shall tell them of what they did when they are not aware (it is you)'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcxii{%
At nightfall, they returned weeping to their father.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
They said: 'We went racing and left Joseph with our things. The wolf devoured him, but you will not believe us, though we speak the truth'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought his shirt (stained) with blood, a lie. He said: 'No, your souls have tempted you to do something. But come sweet patience! The help ofAllah is always there to seek against that which you describe'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcxv{%
Thereafter travelers came, and sent their waterman. And when he had let down his pail, (he cried:) 'Rejoice, a boy' Then they concealed him among their merchandise, but Allah knew what they did.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
Then, they sold him for a trifling price, a number of dirhams, because they considered him to be of little value.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
The Egyptian that bought him said to his wife: 'Make his stay honorable. He may benefit us, or take him for our son' As such We established Joseph in the land, so that We might teach him the interpretation of visions. Allah prevails in His affairs, though most people do not know.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And when he reached maturity, We bestowed on him judgment and knowledge. As such We recompense those who do good.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcxix{%
And she, in whose house he was, sought to seduce him and closed the doors saying: 'Come' 'In Allah is my refuge' he replied. 'My Lord has made my dwelling a good one. Harmdoers never prosper'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcxx{%
She desired him, had he not been shown the proof of his Lord he would have taken her. But We turned him away from evil and abomination, for he was one of Our sincere worshipers.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
They raced to the door and she tore his shirt from behind. And by the door, they met her husband whereupon she said: 'What is the recompense of one whose intent is evil against your people other than being imprisoned, or sternly punished'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
He (Joseph) said: 'It was she who sought to seduce me' and a witness (an infant) of her people bore witness, saying: 'If his shirt is torn from the front, she is speaking the truth and he is one of the liars,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
but, if his shirt is torn from behind, she lied, and he is of the truthful'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
And when he saw his shirt torn at the back, he said: 'This is one of your (women's) guiles. Your guile, (O woman), is great indeed!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
Joseph, turn away from this. And you, ask forgiveness for your sin. You are indeed one of the sinners'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
Certain women in the city said: 'The Governor's wife has sought to seduce her servant. He has made her heart stricken with love for him. Clearly, we perceive her to be in error'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
When she heard of their sly whispers, she sent for them and prepared a banquet. To each she gave a knife, (then called Joseph saying:) 'Come and attend to them' When they saw him, they were so taken with him that they cut their hands, and said: 'Allah save us! This is no mortal, he is no other but a noble angel'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
Whereupon she said: 'Now you see, this is he on whose account you blamed me. Yes, I sought to seduce him, but he was unyielding. If he declines to do what I command, he shall be imprisoned and be one of the humiliated'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He supplicated: 'Lord, prison is dearer to me than that to which they invite me. Yet if You do not shield me from their guile I shall yield to them and be one of the ignorant'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
His Lord answered him and He turned their guile away from him. Indeed, He is the Hearer, the Knower.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then it seemed good to them, even after they had seen the signs, that they should imprison him for some time.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
Two young men went to prison with him. One of them said: 'I saw (in a vision) that I was pressing grapes' And the other said: 'I saw (in a vision) that I was carrying bread upon my head, and that birds ate of it. Tell us its interpretation, for we can see you are among the good'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said: 'Before any food comes to feed either of you, I will give you its interpretation. That which I will tell you has been taught to me by Allah. I reject the belief of a nation who do not believe in Allah and disbelieve in the Everlasting Life.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
I follow the creed of my fathers, Abraham, Isaac, and Jacob. It is not for us to associate anything with Allah. Such is the favor of Allah to us, and to mankind. Yet most people do not give thanks.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
My fellowprisoners, say which is better, many gods at variance, or Allah the One, the Conqueror?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
That which you worship, other than Him, are nothing but names which you and your fathers have named and for which Allah has sent down no authority. Judgement rests with Allah alone. He has commanded you to worship none except Him. That is the right religion, yet most people do not know.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
My fellowprisoners, one of you will pour wine for his lord whereas the other will be crucified, and birds will peck at his head. The matter you inquired about has been decided.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And he said to the one of the two who he knew would be saved: 'Mention me in the presence of your lord' But satan made him forget to mention him to his master, so that he remained in prison for a certain number years.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
The king said: 'I saw in a vision seven fatted cows being devoured by seven lean ones; and seven green ears of corn and seven others withered. My counselors, tell me the meaning of my vision, if you can interpret visions'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They said: 'They are confused nightmares, nor do we know anything of the interpretation of visions'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdcxli{%
After all that time, the one of the two who had been saved remembered, he said: 'I will interpret it for you, so let me go'\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
(He said:) 'Joseph, the truthful, tell us of the seven fatted cows that were devoured by seven lean ones also of the seven green ears of corn and the other seven which were withered, so that I can go back to the people and then they will then know'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
He replied: 'You shall sow for seven years as is your way. Leave in the ear (of corn) you reap, except a little which you eat.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
Thereafter, seven hard years will come upon you, which will consume all but little of that which you have stored.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
Then, there will come a year in which people are helped, in which the people will press'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
The king said: 'Bring him before me' But when the king's envoy came to him, he said: 'Go back to your lord and ask him: ``What about the women who cut their hands. Indeed, my Lord knows their guile'\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
'What was your business, women' he asked, 'when you solicited Joseph' 'Allah save us' they replied. 'We know no evil against him' The Governor's wife said: 'The truth has been discovered at last; I solicited him; he is among the truthful.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
This (I have done) so that he will know I did not secretly betray him, and that Allah does not guide the guile of the treacherous.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
Yet I do not consider my soul was innocent, surely the soul incites to evil except to whom my Lord has mercy; indeed, my Lord is Forgiving, the MostMerciful'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdcl{%
The king said: 'Bring him before me. I will assign him to myself' And when he had spoken with him he said: 'Today, you are firmly established in both our favor and trust'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdcli{%
He (Joseph) said: 'Give me charge of the storehouses of the land, I am a knowledgeable guardian'\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdclii{%
And as such We established Joseph in the land to live wherever he liked. We bestow Our Mercy on whom We will, and We never waste the wage of therighteous.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdcliii{%
Indeed, the reward of the Everlasting Life is better for those who believe and are cautious.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdcliv{%
Joseph's brothers came and presented themselves before him. He recognized them, but they did not know him.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he had given them their provisions, he said: 'Bring me a certain brother from your father. Do you not see that I give just measure and am the bestof hosts?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdclvi{%
If you do not bring him to me, you shall receive no measure (of corn) from me, nor shall you come near me (again)'\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They replied: 'We will ask our father for him. This we will surely do'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdclviii{%
Then he said to his attendants: 'Put their merchandise in their saddlebags, hopefully they will recognize it when they return to their people. Perhaps they will come back'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdclix{%
When they returned to their father, they said: 'Father, we have been denied the measure. Send our brother with us and we shall receive our measure. We will indeed look after him'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdclx{%
He replied: 'Am I to trust you with him as I once trusted you with his brother? Why, Allah is the Best of guardians, and He is the Most Merciful of theMerciful'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdclxi{%
When they opened their saddlebags, they found that their merchandise had been given back to them. 'Father' they said 'what more do we desire? Look, our merchandise has been returned to us. We will receive provisions for our family and we will look after our brother. We shall receive an extra camelload, that is an easy measure'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdclxii{%
He replied: 'I will never send him with you until you swear by Allah that you will bring him back to me, unless you are prevented' And when they had given him their oath, he said: 'Allah is the Guardian of what we say'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
Then he said: 'My sons, do not enter from one gate. Enter through different gates. I cannot be of any help to you against Allah; judgement belongs to Allah alone. In Him I have put my trust. In Him let all put their trust'\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered from where their father had instructed them, nothing helped them against (the decree of) Allah. It was but a need in Jacob's soul which he had fulfilled. He possessed knowledge because of what We had taught him, though most people do not know.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdclxv{%
When they presented themselves before Joseph, he took his brother in his arms, and said: 'I am your brother. Do not grieve at what they did'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
And when he had given them their provisions, he hid a drinkingcup in his brother's saddlebag. Then a herald called out after them: 'Cameleers, you are thieves!'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They turned back and asked: 'What have you lost'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
'We are missing the goblet of the king' he replied. 'Whosoever restores it shall have a camelload, that I guarantee'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdclxix{%
'By Allah' they said, 'you know we did not come to do evil in this land. We are not thieves'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdclxx{%
They said: 'What shall be the recompense, if you prove to be lying'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They replied: 'Its recompense in whosoever's saddle bag it is found, he shall be its recompense. As such we punish the harmdoers'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
He searched their bags before his brother's and then took out the goblet from his brother's bag. As such We directed Joseph. By the king's law he had no right to seize his brother unless Allah willed otherwise. We raise whom We will in rank; over every knowledgeable person is One who knows.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said: 'If he is a thief know then that a brother of his has committed theft before him' But Joseph kept it secret and did not reveal it to them. He said:'You are in a worse position. And Allah knows well what you describe'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said: 'Mighty prince, his father is old, advanced in years, take one of us instead of him. We can see you are amongst the gooddoers'\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He replied: 'Allah forbid that we should seize any but he with whom our property was found, for then we should be harmdoers'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
When they despaired of him, they went in private to confer together. The eldest said: 'Do you not know that your father took a pledge from you in the Name of Allah, and that you failed before regarding Joseph? I shall never stir from this land until my father gives me leave or Allah makes known to me His judgement: He is the Best of judges.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
Return, all of you to your father and say to him: 'Father, your son has committed a theft. We testify only to what we know. How could we guard against the unforeseen?\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
Ask the village where we were and the caravan in which we traveled, we speak the truth'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
'No' he (Jacob) said, 'your souls have tempted you to do something. But come sweet patience. Allah may bring them all to me. He alone is the Knowing, the Wise'\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away and said: 'Alas for Joseph' His eyes turned white with the grief he repressed within him.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said: 'By Allah, will you not cease to mention Joseph until you are consumed, or are among the perishing'\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He replied: 'I complain to Allah of my anguish and sadness. I know from Allah what you do not know.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
Go and seek news of Joseph and his brother. Do not despair of the Comfort of Allah, none but unbelievers despair of the Comfort of Allah'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
And when they presented themselves before him they said: 'O mighty prince, we and our people are afflicted with distress. We have brought but little merchandise. Fill up the measure, and be charitable to us; Allah rewards the charitable'\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
'Do you know' he replied, 'what you did to Joseph and his brother in your ignorance'\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said: 'Are you Joseph' 'I am Joseph' he answered, 'and this is my brother. Allah has been gracious to us. Those who keep from evil and are patient, indeed, Allah does not let the wage of the good doers go to waste'\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
'By Allah' they said, 'Allah has preferred you above us all. We have indeed been sinful'\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He replied: 'Let no reproach be on you this day. Allah will forgive you He is the Most Merciful of the merciful.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
Go, take this shirt of mine and cast it over my father's face, he will recover his sight. Then return to me with all your family'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdcxc{%
As the caravan departed, their father said: 'I smell the scent of Joseph, unless you think I am foolish'\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdcxci{%
'By Allah' they said, 'this is but your old illusion'\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
And when the bearer of glad tidings arrived, he laid Joseph's shirt over him, and he saw once again. He said: 'Did I not tell you that I know from Allah what you do not know'\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
His sons said: 'Father, ask forgiveness for our sins. We have indeed been sinners'\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said: 'I shall ask my Lord to forgive you. He is Forgiving, the Most Merciful'\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
And when they entered before Joseph, he took his father and mother into his arms and said: 'Welcome to Egypt, safe, if Allah wills'\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
He lifted his parents to the throne, and (the others) bowed before him. Joseph said to his father: 'This is the meaning of my vision of long ago, my Lord has verified it. He has been gracious to me. He brought me out of prison and brought you out of the desert after satan had corrupted (the relationship) between me and my brothers. My Lord is Gentle to whom He will. He alone is the Knower, the Wise.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
Lord, You have given me the kingdom and taught me to interpret visions. Originator of the heavens and the earth, my Guardian in this world and in the Everlasting Life. Let me die in submission (as a Muslim) and let me join the righteous'\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
That is of the news We reveal to you of the unseen. You were not present when they agreed upon their plan, scheming.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
Even though you are so eager, most people will not believe.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mdcc{%
You shall ask no wage for it. It is nothing except a reminder to all mankind.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mdcci{%
How many signs in the heavens and earth do they pass by and turn away from.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them do not believe in Allah, but they associate others with Him.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Do they feel secure that the punishment of Allah will envelop them, or that the Hour will overtake them suddenly when they are unaware?\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say: 'This is my Path. I call to Allah with sure knowledge, I and my followers. Exaltations be to Allah! I am not among the idolaters'\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mdccv{%
We did not send any before you from the inhabitants of the village, but men to whom a revelation was sent. Have they not traveled in the land and seen what was the end of those before them? Better is the dwelling in the Everlasting Life for those who keep from evil. Do you not understand?\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mdccvi{%
And when at length Our Messengers despaired and reckoned that they would be belied, Our help came down to them, saving whom We pleased. OurMight cannot be withheld from the guilty nation.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mdccvii{%
Indeed, in their stories is a lesson for those of understanding. This is no forged tale, rather, it is a confirmation of the previous, a distinguishing of all things, a guidance and a mercy to a nation who believe.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen AlifLaamMeemRa. Those are the verses of the Book. That which is sent down to you (Prophet Muhammad) from your Lord is the truth, yet most people do not believe.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdccix{%
It is Allah who raised the heavens without pillars that you see. Then He willed to the Throne and subjected the sun and the moon, each pursuing an appointed course. He directs the affair. He makes plain His verses so that you will firmly believe in meeting your Lord.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdccx{%
It is He who stretched out the earth and placed upon it firm mountains and rivers. And of all fruits, He has put in it two pairs and drew the veil of night over the day. Surely, in these there are signs for a nation who think.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And in the land, there are adjoining plots, gardens of vines, sown fields and palmtrees in pairs and single that are watered with one water, yet We make some excel others in produce. Surely, in that are signs for a nation who understand.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdccxii{%
If you would wonder, then wondrous is their saying: 'When we are dust, shall we be raised to life again, a new creation' Such are those who disbelieve in their Lord. Their necks shall be fettered. They shall be the inhabitants of the Fire, in it they shall live for ever.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
They bid you to hasten the evil before the good, yet examples have passed away before them. Your Lord is Forgiving to people despite their evildoing; yet your Lord is Stern in retribution.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
The unbelievers say: 'Why has no sign been sent down to him from his Lord' You are only a warner, and there is a guide for every nation.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah knows what every female bears, and what shrinks and swells the womb. And everything with Him has its measure.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
(He is) the Knower of the unseen and the seen, the Great, the Exalted.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
Similar to yourself is he who conceals his saying, and he who proclaims it, he who hides himself in the night, and he who goes forth by day,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
he has attendant angels before him and behind him, who, by the Command of Allah watch over him. Allah does not change what is in a nation unless they change what is in themselves. Whenever Allah wants evil for a nation, none can ward it off. Other than Him, they have no guardian.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdccxix{%
It is He who shows you the lightning, for fear and hope, and Who produces laden clouds.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdccxx{%
The thunder exalts His praise, and so are the angels are in awe of Him. He looses the thunderbolts and smites whosoever He will. Yet they dispute aboutAllah who is Mighty in power.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
To Him is the Call of truth. Those to whom they call, other than Him, give them no answer. They are like he who stretches out his hands to the water andbids it rise to his mouth, it does not reach it! The prayers of the unbelievers goes astray.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
All who dwell in the heavens and earth shall prostrate themselves before Allah, either willingly or unwillingly; as do their shadows in the mornings andevenings.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say: 'Who is the Lord of the heavens and the earth' Say: 'Allah' Say: 'Why then have you chosen guardians other than Him, even though they have neither the power to benefit nor harm themselves' Say: 'Are the blind and the seeing equal? Are darkness and light equal? Or, have they ascribed to Allah associates who create as He creates so that all creation is alike to them?" Say: 'Allah is the Creator of everything. He is the One, the Conqueror'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sends down water from the sky and the valleys (wadis) flow each in their measure, and the torrent carries a swelling scum; and fire from that which they kindle; desiring ornament or ware, from that rises a scum like it. As such, Allah strikes both the truth and the false. As for the scum it is cast away as jetsam, but, that which profits people remains on the earth. As such Allah strikes the parables.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who answer their Lord is a most fine reward. But for those who do not answer Him if they possessed all that the earth contains, and as much besides, they would offer it for their ransom. Theirs shall be an evil reckoning. Gehenna (Hell) shall be their refuge, an evil cradling!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
Then is he who knows what is sent down to you from your Lord is the truth like he who is blind? Indeed, only those possessed with minds remember\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
who fulfill their promise to Allah and do not break their pledge;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
who join together what Allah has bidden to be united; who fear their Lord and dread the evil reckoning.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
Patient men, desiring the Face of their Lord, establish their prayers, and spend of what We have given them in private and in public; and who wardoff evil with good. Theirs shall be the Ultimate Abode.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
They shall enter the Gardens of Eden together with the righteous among their fathers, their wives, and their descendants. From every gate the angels will come to them,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
'Peace be to you, for that you were patient' Best is the Ultimate Abode.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
As for those who break the covenant of Allah after accepting it, who part what He has commanded to be united and worked corruption in the land, a curse shall be laid on them, and they shall have an evil abode.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah gives abundantly and sparingly to whom He will. They rejoice in this present life; but this present life, beside the Everlasting Life, is nothing but a passing enjoyment.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
And those who disbelieve say: 'Why has no sign been sent down to him by his Lord' Say: 'Allah leads astray whom He will, and guides those who repent,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
those who believe, and whose hearts find comfort in the remembrance of Allah. Is it not with the remembrance of Allah that hearts are satisfied.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
For those who believe and do good works is blessedness and blessed resort'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
As such, We have sent you forth to a nation before whom others have passed away in order that you recite to them what We have revealed to you. Yet they disbelieve the Merciful. Say: 'He is my Lord. There is no god except He. In Him I have put my trust, and to Him I turn'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
If only a Koran whereby the mountains were set in motion, or the earth cleaved asunder, or the dead spoken to. No, but to Allah is the affair altogether. Do those who believe know that had Allah willed He could have guided all people? As for those who disbelieve, because of what they do, disaster will not cease to afflict them, or it alights near their home until the promise of Allah comes. Allah will not break His promise.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
Other Messengers were mocked before you but I respited the unbelievers, then I seized them. And how was My retribution!\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdccxl{%
What, He who stands over every soul for what it has earned, yet they made partners for Allah. Say: 'Name them. Or would you tell Him of that which is unknown in the earth to Him? Or in outward speech only' Indeed, their devising seems fair to the unbelievers, for they are barred from the Right Way. None can guide those whom Allah leads astray.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdccxli{%
They shall be punished in this life but the punishment of the Everlasting Life is more grievous. None shall defend them from Allah.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
The likeness of Paradise which the righteous have been promised beneath it rivers flow, its produce and shade are eternal. Such is the payment of the righteous. But the payment of the unbelievers is the Fire.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
Those to whom We have given the Book rejoice in what is sent down to you, while some factions reject a part of it. Say: 'I am commanded to worship Allah and to associate none with Him. To Him I supplicate, and to Him I turn'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
And as such We have sent it down an Arabic judgment. And if you follow their desires, after the knowledge that has come to you, you shall have no guardian other than Allah, nor yet a defender.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
We have sent forth other Messengers before you and given them wives and descendants. Yet none of them could bring a sign except by the permission of Allah. Every term has its Book.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah blots out, and He establishes what He will. With Him is the Essence of the Book.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
Whether We show you part of that We promise them, or We call you to Us, it is only for you to deliver the Message, and Ours is the accounting.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
Do they not see how We come to the land and reduce its extremities? Allah judges; none repel His judgement. Swift is His reckoning.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
Those who have gone before them devised, but to Allah is the devising altogether. He knows what every soul earns. The unbelievers shall know without doubt for whom is the Ultimate Abode.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdccl{%
Those who disbelieve say: 'You are not a Messenger' Say: 'Allah is a Sufficient witness between me and you, and whosoever possess knowledge of the Book'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen AlifLaamRa. We have sent down to you (this Book) in order that you bring mankind from darkness to the light by the permission of your Lord, to the Path of the Almighty, the Praised.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdcclii{%
Allah to whom belongs all that is in the heavens and the earth. Woe to the unbelievers for a terrible punishment.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdccliii{%
Those who prefer this life more than the Everlasting Life, and bar others from the way of Allah and seek to make it crooked they are in far error.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdccliv{%
We have sent no Messenger except in the tongue of his own nation, so that he might make everything plain to them. But Allah leads astray whom He will and guides whom He will. He is the Almighty, the Wise.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdcclv{%
We sent Moses with Our signs, 'Bring your nation out of darkness into the light, and remind them of the Days of Allah' Surely, in that are signs for every patient, thankful (person).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
Moses said to his nation: 'Remember the blessing of Allah to you when He saved you from Pharaoh's family, who had oppressed you cruelly, and who slew your sons and spared your women. Surely, that was a great trial from your Lord.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And when your Lord proclaimed: ``If you give thanks, I will increase you, but, if you are unthankful My punishment is indeed stern.'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Moses said: 'If you and all mankind are thankless, He is surely Rich, Praised'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Have you not heard what befell the nations that have gone before you? The nations of Noah, Aad, and Thamood, and those who came after? None knows them but Allah. Their Messengers came to them with clear signs, but they thrust their hands into their mouths and said: 'Without doubt we disbelieve the Message you have been sent with. That which you call us to is disquieting'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their Messengers said: 'Is there any doubt about Allah, the Originator of the heavens and the earth? He calls you to Him in order that He forgives you your sins and defers you till a stated term' They said: 'You are only mortals like us. You wish to bar us from that which our fathers worshipped. Give us some clear proof.'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their Messengers said to them: 'We are nothing except humans like you. But Allah bestows His Mercy on those of His worshipers whom He chooses. We cannot give you proof, except with the permission of Allah. In Allah, let believers put their trust.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
And why should we not put our trust in Allah, when He has already guided us to our Paths? We will endure your hurt patiently. In Allah, let all who trust place their trust'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
Those who disbelieved said to their Messengers: 'Return to our faith or we will banish you from our land' But Allah revealed to them: 'We shall destroy the harmdoers\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
and let you live in the land after them. This is for him who fears My station and fears My threat'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
They sought a judgment, then every tyrant was disappointed.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
Gehenna (Hell) is before him and he is given oozing pus to drink,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
which he gulps and can scarcely swallow. Death will come to him from every side, yet he cannot not die, and yet to come is a dreadful punishment.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
As for the likeness of those who disbelieve in their Lord, their works are like ashes which a strong wind scatters on a stormy day; they are powerless over that they have earned; that is the far error.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Do you not see that Allah has created the heavens and the earth with truth? He can put you away if He will and bring into being a new creation;\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
indeed, that is no great thing for Allah.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
Together they shall all come before Allah. Then the weak will say to those who were proud: 'We were your followers. Can you help us in anything against the punishment of Allah' They will say: 'Had Allah guided us we would have guided you. It is now the same for us whether we cannot endure or bear patiently, we have no place of refuge'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And when the issue has been decided, satan will say (to them): 'The promise which Allah made you was true. I promised you, but failed to keep it. I had no authority over you except that I called you, and you answered me. Do not bame me, rather, blame yourselves. I cannot help you, nor can you help me. I disbelieved in your associating me (with Allah) before' Indeed, for the evildoers there is a painful punishment.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
As for those who believe and do good works, they shall be admitted to gardens underneath which rivers flow in which, by the permission of their Lord, they shall live for ever. Their greeting shall be: 'Peace'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Have you not seen how Allah sets forth a parable that a good deed is like a good tree, its roots are firm and its branches are in the heaven,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
yielding its fruit every season by the permission of Allah? Allah gives parables to mankind so that they might remember.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
The likeness of a corrupt word is like a corrupt tree uprooted from the earth having no stability.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Allah will strengthen the believers with a steadfast Word, both in this life and in the Everlasting Life. Allah leads the evildoers astray. Allah does what He will.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Have you not seen those who exchanged the favor of Allah with disbelief and landed their nation in a house of ruin?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
They shall be roasted in Gehenna; an evil establishment!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
They set up rivals with Allah to lead others astray. Say to them: 'Take your pleasure; your arrival shall be the Fire'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Tell My worshippers, those who believe, who establish the prayer, and spend of what We have given them in private and in public, before the coming of that Day in which there is neither bargaining, nor the taking of friends,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
it is Allah who created the heavens and the earth, and sends down water from the heaven with which He brings forth fruits for your provision. He has subjected to you ships which, by His command, run upon the sea. He has subjected to you rivers,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
and He subjected to you the sun and the moon, which are constant in their courses. And, He has subjected to you the night and the day, and gave you all that you asked of Him.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
If you count the blessings of Allah, you will never number them. Indeed, the human is wicked and thankless.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And when Abraham said: 'My Lord, make this a land secure. Turn me and my children away from worshipping idols.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
My Lord they have led many people astray. Whosoever follows me belongs to me. Whosoever rebels against me, You are surely Forgiving, the MostMerciful.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
'Our Lord, I have settled some of my offspring in a barren valley near Your Holy House; our Lord, in order that they establish the prayer. Make the hearts of people yearn towards them, and provide them with fruits, in order that they are thankful.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
Our Lord, You have knowledge of all that we hide and all that we reveal; nothing in heaven or earth is hidden from Allah.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
Praise be to Allah who has given me Ishmael and Isaac in my old age! Indeed, my Lord is the Hearer of the supplication.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdccxc{%
My Lord, make me and my descendants establishers of prayer. Our Lord, accept my prayer.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdccxci{%
Forgive me, our Lord, and forgive my parents and all the believers on the Day of Reckoning'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
Do not think that Allah is unaware of the harmdoers work. He only gives them respite till the Day on which all eyes will stare,\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
when they shall run with their necks outstretched and heads erect, their glances never return to themselves, their hearts are empty.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
Warn mankind of the Day when the punishment will overtake them, when the evildoers will say: 'Our Lord, grant us respite for awhile, we will answer Your call, and follow the Messengers' Did you not once swear that you would never cease?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
You lived in the dwellings of those who wronged themselves, and it was clear to you how We dealt with them, and how We struck parables for you.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
They plotted their plots, but their plots are (known) to Allah, even though their plots were such as to move mountains.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
Do not think that Allah will break the promise He gave to His Messengers. Mighty is Allah, and Vengeful.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
On the Day when the earth is changed into other than the earth and the heavens, all shall come before Allah, the One, the Conqueror.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
On that Day, you shall see the sinners coupled together in fetters;\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdccc{%
their garments shall be of melted tar, and their faces enveloped by the Fire.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdccci{%
Allah will recompense each soul according to its earnings. Swift is the Reckoning of Allah.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This is a message to be delivered to mankind so that they may be warned by it, and know that He is (Allah) One God, and so all those possessed of minds may remember.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen AlifLaamRa. Those are the verses of the Book, the Clear Koran.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdccciv{%
It could be that those who disbelieve will wish that they were Muslims.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Let them eat and enjoy; and let their hopes deceive them, soon they shall know.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
We never destroyed a village whose term had not already been decreed.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No nation can outstrip its term, nor do they put it back.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
They say: 'You to whom the Remembrance is sent down, you are indeed mad.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdcccix{%
Why do you not bring down the angels, if what you say is true'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We do not send angels except with the truth. Then they shall have no respite.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
It is We who sent down the Koran, and We watch over it.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
We have sent forth before you Messengers among the factions of the ancients.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
But no Messenger came to them except he was mocked.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
So We make it enter the hearts of the sinners.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
They do not believe in it even though the practice of the ancients has already gone.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
If We opened a gate in the heaven and they kept ascending through it,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
still they would say: 'Our eyes were dazzled; truly, we must have been a bewitched people'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
We have set constellations in the heavens and made them pleasing to the beholders,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
and guarded them from every stoned satan.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
Except for he who steals the listening and is then pursued by a visible flame.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
We have spread out the earth and set upon it firm mountains. Everything We have caused to grow therein is justly weighed;\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
and there appointed for you is a livelihood, and for those you do not provide.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
And there is not a thing but with Us are its treasuries, and We do not send it down except in a known measure.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
We send the winds fertilizing, and We send down out of heaven water, from which you drink and you are not its treasurers.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
And surely, it is We who give life and make to die. We are the Inheritor.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
We know those of you who press forward, and We know the laggards,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
and it is your Lord who will gather them. He is Wise, Knowing.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
We created mankind from clay, molded from mud,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
and before him We created the jinn from smokeless fire.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
When your Lord said to the angels: 'See, I am creating a mortal from clay of molded mud.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
When I have shaped him and ran My created soul in him fall down prostrating towards him'.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
All the angels prostrated themselves,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
except iblis (father of the jinn) who refused to be one of those who prostrated themselves.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
He said: 'iblis, what is the matter with you, that you do you not prostrate yourself'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
He replied: 'I will not prostrate to a mortal You have created of clay, from molded mud'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
(Allah) said: 'Begone, you are accursed!\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
A curse shall be on you till the Day of Recompense'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
He said: 'My Lord, reprieve me till the Day they are raised'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
He answered: 'You are among those reprieved\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
till the appointed time.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
(satan) said: 'My Lord, for Your perverting me, I shall make (matters) in the earth seem most fair to them and I shall pervert all,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
except the devoted amongst Your worshippers.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
He (Allah) said: 'This is for Me the Right Path\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
over My worshipers you have no authority, except the perverse that follow you.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
Gehenna (Hell) will be the promise for all of them.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
It has seven gates, and through each gate a portion of them belong.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
But the cautious shall live amongst gardens and fountains:\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
'In peace and security, enter them'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
We shall remove all rancor from their hearts, and as brethren they shall recline on couches face to face.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdcccl{%
There, no fatigue shall smite them, nor shall they ever be driven from it'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Tell My worshipers that I am the Forgiving, the Most Merciful,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdccclii{%
and that My punishment is the painful chastisement.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
Tell them of Abraham's guests.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
They entered to him and said: 'Peace' but he replied: 'We are afraid of you'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdccclv{%
'Do not be afraid' they answered. 'We come to give you glad tidings of a knowledgeable child'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said: 'What is this, do you bring me glad tidings even though I am old' Of what do you give me glad tidings'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They replied: 'In truth we have given you glad tidings, do not be one of those who despair'\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He replied: 'And who despairs of the mercy of his Lord, except those that are astray?\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdccclix{%
He asked: 'Messengers, what is your errand'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They replied: 'We are sent to sinful nation.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
Except Lot's family, of whom we shall save all,\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
but his wife. We decreed that she should be amongst those who remain behind.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
And when the envoys came to the family of Lot,\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
he said to them: 'I do not know you'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
'No' they replied: 'We bring you (news) of that concerning which they were doubting.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
We bring you the truth, and indeed we are truthful.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
Depart with your family in a part of the night and walk behind them and let none of you turn round. Go to a place where you are commanded'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We made known to him this decree that the wrongdoers were to be utterly cut off in the morning.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
The people of the city came to him rejoicing.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
He said: 'These are my guests; do not shame me.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
Fear Allah and do not disgrace me'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They replied: 'Have we not forbidden you (the people of) the worlds'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
He said: 'Here are my daughters; take them (in marriage), if you would be doing'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
By your life, they wandered blindly in their dazzlement.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
At sunrise a dreadful Shout seized them.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
We laid it (the city) upside down and rained stones of baked clay upon them.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Surely, in that there are signs for those who contemplate.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
Indeed, it is on a way which still exists.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Surely, in that there is a sign for those who believe.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
The dwellers of the Thicket were harmdoers.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
On them, too, We took vengeance, and they are both on a clear roadway.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
And the dwellers of Al Hijr also belied the Messengers.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
We brought them signs, but they turned away.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
They hewed their dwellings out of the mountains in safety.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
But the Shout seized them in the morning,\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
and that which they had earned did not help them.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
We did not create the heavens and the earth, and what is between them except in truth. The Hour is sure to come, therefore, forgive them with a graciouspardon.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Your Lord is the Creator, the Knower.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
We have given you the seven dual (verses, Al Fatihah) and the Mighty Holy Reading (Koran).\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Do not stretch your eyes to that We have given pairs of them to enjoy, nor sorrow for them, and lower your wing to the believers.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And say: 'I am the plain warner'\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
So We sent it down to the partitioners,\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
who have broken the Koran into parts,\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
so by your Lord, We will question them all\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
about what they did.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
Proclaim then, what you are commanded and turn away from the unbelievers.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
We suffice you against those who mock,\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
and those who set up other gods with Allah, indeed, they will soon know.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
Indeed, We know your chest is straitened by that they say.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcm{%
Exalt with the praise of your Lord and be one of those who prostrate.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcmi{%
Worship your Lord till the certainty (death) comes to you.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen The Command of Allah will surely come; do not seek to hasten it. Highly exalted is He above that they associate with Him.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sends down the angels with the Spirit (Gabriel) by His command to those of His worshipers whom He chooses, (saying:) 'Warn, there is no god except Me, therefore fear Me'\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He created the heavens and the earth with truth. Exalted is He above what they associate (with Him)!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mcmv{%
He created mankind from a sperm drop, yet he is a clear adversary.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And the cattle He created for you. In them, you have warmth and other uses, and of them you eat.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mcmvii{%
In them there is beauty for you when you bring them home and when you lead them to pasture.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mcmviii{%
They carry your loads to a land which you could not otherwise reach except by painful toil to oneself. Your Lord is the Clement, the Most Merciful.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mcmix{%
(He has created for you) horses, mules, and donkeys, which you ride and as an adornment; and He creates what you do not know.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mcmx{%
It is for Allah to show the way. Some swerve from it, but had He willed, He would have guided all of you.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mcmxi{%
It is He who sends down water from heaven, which provides drink for you and brings forth trees on which your herds feed.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mcmxii{%
And thereby He brings forth crops and olives, palms and vines, and all the fruits. Surely, in this there is a sign for a nation who think.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
He has subjected to you the night, the day, the sun and the moon. The stars are subjected by His Command. Surely, in that there is a sign for a nation who understands.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And what He has multiplied for you in the earth is of various hues; surely, in that there is a sign for a nation who remember.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mcmxv{%
It is He who has subjected the sea to you, so that you eat of its soft flesh and bring up from it ornaments which you wear. And you see the ships plowingtheir course through it in order that you seek His bounty and give thanks.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
He set firm mountains upon the earth lest it should shake with you; and rivers, and roads, in order that you are guided.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And waymarks; and by the star they are guided.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is He who creates as he who does not create? Will you not remember?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mcmxix{%
If you count the favors of Allah, you could not number them. Indeed, Allah is Forgiving and the Most Merciful.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mcmxx{%
Allah has knowledge of all that you hide and all that you reveal.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
But those whom you invoke, other than Allah do not create anything they are themselves created.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
They are dead, not living; and they do not know when they will be raised (to life).\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your God is One God. Those who do not believe in the Everlasting Life their hearts disbelieve, and are puffed up with pride.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Allah knows without doubt what they hide and what they make known. He does not love the proud.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And if they are asked: 'What has your Lord revealed' they say: 'Tales of the ancients, fairytales'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
They shall carry their sins completely on the Day of Resurrection, and some of the sins of those who were led astray by them without knowledge. Evil is that which they sin.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Those who have gone before them also plotted. Then, Allah came upon their building from the foundations, and the roof fell down on them from above them. And the punishment overtook them from where they did not know.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
He will degrade them on the Day of Resurrection. He will say: 'Where are My partners, for whose sake you opposed' And those to whom knowledge has been given will say: 'Degradation today and evil are on the unbelievers,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
whom the angels take while they were still harming themselves' Then they will offer submission, saying: 'We have done no evil' No, surely Allah knows what you have done.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
Enter the gates of Gehenna (Hell) to be in it for ever. Evil is the lodging of the proud.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
It is said to the cautious: 'What has your Lord revealed' They will reply: 'Good' For those who did good in this world is goodness; indeed the lodging in the Everlasting Life is better an excellent dwelling for the cautious.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
They shall enter the Gardens of Eden, under which rivers flow, and there they shall have all they desire. So Allah recompenses the cautious,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
whom the angels take while they are goodly, saying: 'Peace be on you. Enter Paradise for what you were doing'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Are they looking for the angels to come down or the order of your Lord to come? As such did those who have gone before them. Allah did not wrong them, but they wronged themselves,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
so the evil things which they did coiled around them, and they were encompassed by that they mocked.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
The idolaters say: 'Had Allah willed, neither we nor our fathers would have worshipped anything other than Him, nor would we have forbidden anything without Him', as such did those before them. Yet what should Messengers do but give a clear deliverance?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
We sent a Messenger to every nation, saying: 'Worship Allah and avoid the idols' Amongst them were some whom Allah guided, and some justly disposed to error. Travel in the land and see what was the end of those who belied (the Revelation and the prophets)!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
Though you are ever so eager to guide them, Allah will not guide those who mislead (others). There shall be none to help them.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
They solemnly swear by Allah that Allah will never raise the dead to life. No, surely the promise of Allah is binding upon Him, though most people do not know.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcmxl{%
This is in order that He may make clear to them that which they differed upon, and in order that those who disbelieve might know that they were indeed lying.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcmxli{%
When We decree a thing, We only say: 'Be' and it is.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
And those who after they have been wronged emigrated for the Cause of Allah, We will lodge them with a good (life) in this world, but greater still is the wage of the Everlasting Life, if they but knew;\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
such are those who are patient, and put their trust in their Lord.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
We never sent but men before you to whom We revealed, ask the people of the Remembrance, if you do not know.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
(We sent them) with clear signs and the Psalms. And We sent down to you the Remembrance so that you can make clear to people what has been sent down to them, in order that they reflect.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Do those who do evil feel secure that Allah will not make the earth to swallow them, or that the punishment will not fall upon them from where they do not know?\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or, that He will not seize them in their going to and fro, and they will not be able to frustrate Him?\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or, that He will not seize them, a little at a time and destroy them? Indeed, your Lord is Clement, the Most Merciful.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Do they not see how every thing Allah created casts its shadow right and left, prostrating itself before Allah in all humility?\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcml{%
Everything in the heavens and every crawling creature on earth, and the angels prostrate to Allah and they are not proud;\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcmli{%
they fear their Lord from above them and do as they are commanded.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcmlii{%
Allah says: 'Do not take to yourself two gods. He is only One God; so have awe of Me'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcmliii{%
To Him belongs all that is in the heavens and the earth. His is the Religion for ever. Would you then fear any but Allah?\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcmliv{%
Whatever favor you have is from Allah. Whenever you are afflicted you groan to Him.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcmlv{%
When He removes your affliction then some of you set up associates to their Lord\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
that they may show ingratitude for what We gave them. So, take your pleasure, you shall soon know.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
They set aside a share of that which We have provided them for what they did not know. By Allah, you shall be questioned about your forgeries!\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
They ascribe daughters to Allah exaltations to Him! But they themselves would have what they desire!\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mcmlix{%
When good news of the birth of a female is given to any of them, his face grows dark and inwardly he chokes.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mcmlx{%
Because of the evil of the good news he hides himself from people, (pondering) whether he will keep her and be humiliated, or trample her into the dust. Evil is their judgement!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
Those who do not believe in the Everlasting Life, theirs is the evil likeness; and for Allah is the highest likeness. He is the Mighty, the Wise.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
If Allah punished people for their sins, He would not leave one creature that crawls on the earth. He reprieves them to an appointed term; when their term is come, they shall neither delay it by a single hour nor can they hasten it.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
They ascribe to Allah what they themselves dislike. Their tongues utter falsehoods (when they say) the finest of wages shall be theirs. Without doubt, the Fire shall be theirs and they will be hastened to it.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
Indeed, by Allah, We have sent Messengers before you to other nations. But satan made their deeds seem fair to them so that today he is their guardian, and a painful punishment awaits them.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
We have not revealed to you (Prophet Muhammad) the Book except that you may clarify for them that upon which they differ, and as guidance and mercy to a nation who believe.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
Allah sends down water from the sky with which He revives the earth after its death. Surely, in this there is a sign for people who listen.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
Indeed, in the cattle there is a lesson for you. We give you to drink of that which is in their bellies, between the filth (bowels) and blood, pure milk, which is sweet to those who drink.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And the fruits of the palm and of the vine, from which you derive intoxicants and wholesome provisions. Surely, in this there is a sign for nation who understand.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
Your Lord revealed to the bee: 'Build your homes in the mountains, in the trees, and in what they are building.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
Eat every kind of fruit, and follow the easy ways of your Lord' From its belly comes forth a drink (honey) of many hues in which there is healing for people. Surely, in this there is a sign for a nation who reflect.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
Allah created you, and causes you to die. There are some of you who, after knowing something, will be kept back to the vilest state of life, knowing nothing. Allah is the Knowing, Powerful.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
In your provisions Allah has preferred some of you above others. But, those who have been preferred do not give their provisions to those whom their right hand possess so that they might be equal therein. What, do they vainly disbelieve the favor of Allah?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
Allah has given you wives from among yourselves, and has given you and your wives, sons and grandsons and He has provided you with good things. What, do they believe in vanity; do they disbelieve in the favor of Allah?\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
Do they worship, other than Allah, that which has no power to provide them with anything either from the heavens or earth, and can do nothing!\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
Therefore, do not strike parables for Allah; Allah knows, but you do not!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah strikes a parable. A servant owned by his master, having no power over anything, and one to whom We have given from Us a fine provision who spends it secretly and openly, are they equal? Praise be to Allah! No, most of them do not know!\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
And Allah strikes a parable. Two men, one is dumb and powerless, a burden to his master wherever he sends him he returns with no good. Is he equal with one who orders justice and follows the Straight Path?\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
To Allah belongs the unseen of the heavens and the earth. The matter of the Final Hour shall be like the twinkling of an eye, or even less. Allah has power over all things.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
Allah brought you out of your mothers' wombs, and gave you hearing, sight and hearts, in order that you be thankful.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Have they not seen the birds that are subjected in the air of the heaven? Nothing holds them except Allah. Surely, in this are signs for those who believe.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
And it is Allah who has given you houses in which to rest, and from the hides of cattle homes so they are light for you on the day you travel and on the day of settling; while from their wool, fur, and hair (He has given you) furnishing and enjoyment for a while.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
From the things He created, Allah has given you a covering shade, and He has made for you refuges in the mountains. He has given you garments to protect you from the heat, and garments to protect you from your own violence. As such it is that He perfects His favors upon you, in order that you submit.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
But, if they turn away, your mission is only to give plain warning.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognize the favors of Allah, then they disbelieve them; most of them are unbelievers.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
On the Day We shall raise up from every nation a witness, then permission will not be given to the unbelievers, nor shall they be allowed to make restitution.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
And when the harmdoers see their punishment, it shall never be lightened, nor shall they ever be respited.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when the idolaters see their associates they will say: 'Our Lord, these are our associates on whom we called other than You' But they will throw back at them saying: 'Surely, you are truly liars'\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
On that Day they shall offer to submit to Allah, and what they forged will forsake them.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those who disbelieve and bar others from the Path of Allah, We shall add punishment upon their punishment because they were corrupting.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcmxc{%
And on that Day We shall raise up from every nation a witness from their own against them, and We shall bring you (Prophet Muhammad) as a witness against those. And We have sent down to you the Book making everything clear, as a guidance, and mercy, and glad tidings to those who submit.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Allah orders justice, and good deeds, and giving to one's kindred. He forbids indecency, dishonor and insolence. He admonishes you in order that you take heed.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
Fulfill the covenant of Allah, when you make a covenant and do not break your oaths after they have been confirmed (by swearing in His Name) for you make Allah your surety. Allah has knowledge of what you do.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
Do not be like the woman who breaks her thread, after it is firmly spun into fibers, by taking your oaths as mere mutual deceit, one nation being more numerous than the other. Allah tries you with it. On the Day of Resurrection, He will clarify to you everything on which you were at variance.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
Had Allah willed, He would have made you one nation. But He leads astray whomsoever He will and gives guidance to whomsoever He will. You shall be questioned about what you did.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
Do not take oaths to deceive each other, lest your foot should slip after its firmness, lest you should taste evil, for you barred others from the Path of Allah, and lest a mighty punishment awaits you.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
Do not sell the covenant of Allah for a trifling price. What is with Allah is better for you if you but knew.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
That which you have is transitory, but that which is with Allah endures. We shall reward the patient according to the best of their deeds,\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
For whosoever does a righteous deed, be they believing men or women, We shall recompense them with their wage according to the best of their deeds.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
When you recite the Koran, seek refuge in Allah from the stoned satan:\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mm{%
he has no authority over the believers who put their trust in their Lord.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmi{%
He has authority over those who are guided by him, and those who ascribe associates to Him (Allah).\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmii{%
When We exchange a verse for another and Allah knows best what He is sending down they say: 'You are but a forger' No, most of them do not know.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say: 'The Holy Spirit (Gabriel) brought it down from your Lord in truth to confirm those who believe, and to give guidance and glad tidings to those who surrender'\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmiv{%
We know very well that they say: 'A mortal teaches him' The tongue of him at whom they hint is a nonArab; and this is a clear Arabic tongue.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmv{%
Those who disbelieve in the verses of Allah, Allah does not guide them for them is a painful punishment.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmvi{%
None forge lies except those who disbelieve the verses of Allah those, they are the liars.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmvii{%
Whosoever disbelieves in Allah after believing except he who is forced while his heart remains in his belief but he who opens his chest for disbelief, shall receive the Anger of Allah and for such awaits a mighty punishment.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmviii{%
That is because they loved this present life above the Everlasting Life. Allah does not guide the unbelievers.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmix{%
They are those whose hearts, hearing and sight are sealed by Allah; they are the heedless.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmx{%
In the Everlasting Life, they shall assuredly be the losers.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmxi{%
Then indeed your Lord? to those who emigrated, after they were persecuted, and then strove and were patient, surely, your Lord is thereafter Forgiving, the Most Merciful.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmxii{%
On the Day when every soul will come pleading for itself and when every soul will be recompensed in full for what it did they shall not be wronged.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmxiii{%
Allah strikes a parable of the village which was safe and peaceful. Its provisions came in abundance from everywhere; but it was thankless for the favors of Allah. Therefore, for what they were doing, Allah let it taste the garment of hunger and fear.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmxiv{%
A Messenger from their own was sent to them, but they belied him. So while they were harmdoers they were seized by the punishment.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmxv{%
Eat of the lawful and good things with which Allah has provided you and be thankful for the favors of Allah if it is He you worship.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmxvi{%
These things alone He has forbidden to you: what is already dead, blood, the flesh of swine, what has been offeredup to other than Allah. But to whoever is forced to eat any of these, neither desiring nor wanting to transgress, Allah is Forgiving, Merciful.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And do not say what your tongues falsely describe 'This is lawful, and that is forbidden' in order to forge a lie about Allah. Indeed, those who forge a lie about Allah shall never prosper.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmxviii{%
Brief (is their) enjoyment, after which a painful punishment awaits them.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmxix{%
We have forbidden the Jews what We have already related to you. We did not wrong them, but they wronged themselves.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmxx{%
Surely, your Lord to those who commit evil through ignorance and afterwards repent, and mend their ways your Lord thereafter is surely Forgiving, Merciful.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Abraham was (equal to) a nation, obedient to Allah, of pure faith and was not among the idolaters,\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmxxii{%
ever thankful for His favors. He chose him and He guided him to a Straight Path.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
We gave goodness to him in this world, and in the Everlasting Life he shall be amongst the righteous.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
Then, We revealed to you: 'Follow the Creed of Abraham, he of pure faith, he was not among the idolaters'\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The Sabbath was ordained only for those who differed about it. On the Day of Resurrection, your Lord will decide the differences that were between them.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Call to the Path of your Lord with wisdom and fine admonition. Dispute with them in the best manner. Your Lord is well aware of those who have gone astray from His Path and He is well aware of those who are guided.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
If you punish, let your punishment be proportionate to the punishment you received. But if you are patient, it is better for the patient.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
Be patient; yet your patience is only by the help of Allah. Do not grieve for them (the unbelievers), nor distress yourself because of their devising.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmxxix{%
Allah is with the cautious and those who do good.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Exalted is He who carried His worshiper (Prophet Muhammad) to travel in the night from the Sacred Mosque to the Furthest Mosque which We have blessed around it so that We might show him some of Our signs. He is the Hearer, the Seer.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
We gave Moses the Book and made it a guide for the Children of Israel. 'Take no guardian other than Me.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
(You are) the descendants of those whom We carried (in the Ark) with Noah. He was a truly thankful worshiper'\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We decreed for the Children of Israel in the Book: 'You shall corrupt the land twice, and you shall ascend exceedingly high'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
And when the promise of the first came, We sent against you Our worshipers, those of great might, and they went through the habitations, and the promise was accomplished.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then, We gave the turn back to you to prevail over them, and We helped you with wealth and children, and made you the greater host.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
(We said): 'If you do good, it shall be for your own souls; but if you do evil it is likewise' And when the second promise came (We sent them against you), to sadden your faces and to enter the Mosque as they entered it the first time, they utterly destroyed whatever they came across.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
Perhaps Allah will have mercy on you. But if you return, We will return. We have made Gehenna (Hell) a prison for the unbelievers.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
This Koran guides to the straightest way. It gives glad tidings of a great wage to the believers who do good deeds,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
and for those who do not believe in the Everlasting Life We have prepared for them a painful punishment.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmxl{%
Yet the human prays for evil as he prays for good mankind is always hasty.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmxli{%
We appointed the night and the day as two signs. Then, We blotted out the sign of the night and made the sign of the day to see, so that you seek the bounty of your Lord and that you know the number of years and the reckoning. And We have clearly distinguished everything.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmxlii{%
And to every human? We have fastened to him his bird of deeds upon his neck; and on the Day of Resurrection We shall bring forth to him a book spread open wide.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmxliii{%
'Read your book. Your self suffices you this Day as a reckoner against you'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whosoever is guided is only guided for his own self, and whosoever goes astray it is only against it. No soul shall bear another's burden. Nor do We punish until we have sent a Messenger.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmxlv{%
When We desire to annihilate a village, We command those who live in ease, but they commit evil therein, then the Word is realized against it and it is utterly annihilated.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
How many generations have We destroyed since Noah! Your Lord suffices as One who is Aware of and sees the sins of His worshipers.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
For whosoever desires this fleeting life We hasten for him whatever We will and to whom We want. Then, We have prepared Gehenna for him where he will be roasted, condemned and rejected.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
Whosoever, being a believer, desires the Everlasting Life and strives for it as he should those their striving will be thanked.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmxlix{%
We help these and those, a gift from your Lord; and your Lord's gift is not restricted.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mml{%
See how We have preferred some above others. Yet the Everlasting Life is greater in rank and greater in preferment.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmli{%
Do not set up with Allah another god, or you will sit condemned and forsaken.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmlii{%
Your Lord has ordered you to worship none except Him, and to be good to your parents. If either or both of them attain old age with you, do not say: ``Fieon you", nor rebuke them, but speak to them with words of respect.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmliii{%
And lower to them the wing of humbleness out of mercy and say: 'My Lord, be merciful to them, as they raised me since I was little'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord knows very well what is in your hearts. If you are good, He is forgiving to those who are penitent.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmlv{%
Give to the near of kin, the needy and the destitute traveler their rights and do not squander,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmlvi{%
for the wasteful are the brothers of satan; and satan is ungrateful to his Lord.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmlvii{%
But if you turn away from them to seek the Mercy of your Lord, hoping to attain it, then speak to them with gentle words.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And do not keep your hand chained to your neck (when spending), nor open it completely, so that you will sit blamed and destitute.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmlix{%
Your Lord gives to whom He will His provisions both abundantly and sparingly. He is aware and sees His worshipers.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmlx{%
Do not kill your children because you fear poverty. We will provide for you and them. Killing them is a great sin.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmlxi{%
Do not draw near to fornication, for it is an indecency, and its way is evil.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmlxii{%
Do not kill the soul whom Allah has forbidden except by right. If he is slain unjustly, We have given his heir authority. But let him not exceed the limit in slaying, for he will be helped.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
Do not draw near the wealth of the orphan except in the best manner, until he reaches maturity. And keep your promise. Surely, the promise will be questioned.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
Give full measure when you measure, and weigh with even scales. That is better, and fairer in the end.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmlxv{%
Do not follow what you do not know. The hearing, sight and heart about all these you shall be questioned.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
Do not walk proudly in the earth. Indeed, you will never tear open the earth, nor attain the height of mountains.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
The wickedness of all this is hateful with your Lord.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
That is of the wisdom your Lord has revealed to you. Do not set up with Allah another god, or you will be cast into Gehenna, condemned and rejected.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmlxix{%
What! Has your Lord favored you with sons and taken to Himself females from among the angels? Indeed, you utter a monstrous thing!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmlxx{%
In this Koran We have clarified so that they may remember; but it has only increased their aversion.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say: 'If there had been other gods with Him, as they say, they would surely have sought a way to the Lord of the Throne'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Exaltations be to Him! High indeed be He exalted above what they say!\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens, the earth, and whosoever in them, exalt Him. There is nothing that does not exalt with His praise, but you do not understand their exaltation. Surely, He is Clement, Forgiving.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
When you recite the Koran, We place between you and those who do not believe in the Everlasting Life an obstructing barrier.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
We lay veils upon their hearts and heaviness in their ears, lest they understand it. When you (Prophet Muhammad) mention your Lord alone in the Koran, they turn their backs in aversion.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
When they listen to you, We know very well how they listen. When they conspire, when the evildoers declare: 'You are only following a man who is bewitched'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
See what they compared you to. They have surely gone astray and cannot find a Path.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
'What' they say. 'When we are (turned to) bones and broken bits, shall we be raised again in a new creation'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say: 'Let you be stones or iron,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
or any other creation yet more monstrous in your minds' They will ask: 'Who will restore us' Say: 'He who originated you at first' They will shake theirheads and ask: 'When will this be' Say: 'Maybe it is near,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
on that Day, He will summon you, and you shall answer Him with praise and you shall think you have stayed but for a little'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
Tell My worshipers, that they should say words that are the finest, satan would arouse discord among them; he is the clear enemy of mankind.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord knows you very well. He will have mercy on you if He will, or punish you if He will. We have not sent you to be their guardian.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
Your Lord knows very well all who are in the heavens and the earth. We have preferred some Prophets above others, and to David We gave the Psalms.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say: 'Call to those whom you assert, other than Him. They have neither the power to remove your affliction nor to transfer it'\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those, they call upon are themselves seeking a means to come to their Lord, competing with each other to be nearer; they hope for His Mercy and fear His punishment. Indeed, the punishment of your Lord is the subject of caution.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
There is no village except that it shall be destroyed or that We will punish it with a stern punishment before the Day of Resurrection. That is inscribed in theBook.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
Nothing prevented Us from sending the signs but that the ancients belied them. To Thamood, We brought the shecamel as a visible (sign), yet they wronged her. We do not send signs except to frighten.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
When We said to you: 'Indeed, your Lord encompasses all people' We did not make the vision which We showed to you, and the tree cursed in the Koran except to be a trial for people, and We frighten them, but it only increases them in great insolence.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmxc{%
When We said to the angels: 'Prostrate yourselves before Adam' they all prostrated themselves, except iblis (father of the jinn), who said: 'Shall I prostrate to him whom You have created from clay?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmxci{%
What do You think' he said: 'This whom You have honored above me, if You defer me until the Day of Resurrection, I will root out all but a few of his seed (by misleading them)'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmxcii{%
'Begone' said He. 'Indeed, Gehenna is your recompense, and the reward of those who follow you, an ample recompense.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmxciii{%
Rouse with your voice whoever you are able from among them. Rally against them your cavalry and those on foot. Share their wealth and children with them, and promise them' But satan promises them nothing except delusion.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmxciv{%
'Over My worshipers you shall have no authority' Your Lord is their Sufficing Guardian.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmxcv{%
It is your Lord who drives your ships at sea so that you may seek His bounty. He is indeed the Most Merciful towards you.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
When misfortune befalls you at sea, all except He of those to whom you supplicate forsake you; yet when He delivers you safely to the land, you turn away. The human is unthankful.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Do you feel secure that He will not cause the shore to swallow you, or let loose a squall of pebbles upon you? Then you shall find no guardian for yourself.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or, do you feel secure that He will not send you back into it a second time, and send against you a violent tempest and drown you because of disbelief? Then you shall find no prosecutor (to help) you against Us.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmxcix{%
We have honored the children of Adam and carried them on both land and sea. We have provided them with good things and greatly preferred them above much of Our creation.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmc{%
On the Day when We call all the people with their record, whosoever is given his book in his right hand shall read their book, and they shall not be wronged by as much as a single datefiber.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmci{%
But he who is blind in this life, shall be blind in the Everlasting Life and will be further astray from the Path.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcii{%
Indeed, they were near to seducing you from that We revealed to you, so that you might forge against Us another, and then they would surely have taken you as a friend;\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmciii{%
and if We had not fortified you, you would have been very slightly inclining towards them;\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmciv{%
then We would have let you taste the double of life and death; and you would have found none to help you against Us.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcv{%
They very nearly provoked you to drive you out of the land, but they would have only lingered for a little while after you.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcvi{%
Such was Our way with those whom We sent before you. You shall find no change in Our way.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Establish the prayer at the decline of the sun till the darkening of the night and the Koran recital at dawn. Surely, the Koran recital at dawn is witnessed.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcviii{%
As for the night there is a voluntary deed for you to keep vigil in part it. Perhaps your Lord will raise you to a praiseworthy station.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcix{%
Say: 'Lord, grant me an entrance of sincerity and an exit of sincerity, and give me from Yours a victorious power'\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcx{%
Say: 'Truth has come and falsehood has vanished. Indeed, falsehood will certainly vanish'\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcxi{%
We sent down of the Koran that which is a healing and a mercy to believers, but to the harmdoers it does not increase them, except in loss.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcxii{%
Yet when We bestow favors upon mankind he turns his back and withdraws to one side. But when evil befalls him, he despairs.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say: 'Each human works in his own manner. But your Lord knows very well who is best guided on the way'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
They question you about the spirit. Say: 'The spirit is from the command of my Lord. Except for a little knowledge you have been given nothing'\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcxv{%
If We pleased We could take away that which We have revealed to you then you should find none to guard you against Us,\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
except for Mercy from your Lord; for His favor to you is great indeed.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say: 'If mankind and jinn combined together to produce the like of this Koran, they would never be able to produce one like it, not even if they were to help one another'\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
Indeed, We have set forth for mankind in this Koran every kind of parable, yet most people refuse all except disbelief.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcxix{%
They say: 'We will not believe in you until you make a spring gush from the earth for us,\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcxx{%
or, until you own a garden of palms and vines and cause rivers to gush forth with abundant water in them;\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
or, until you cause the sky to fall upon us in pieces, as you have claimed, or, as a surety bring Allah with the angels in front;\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
or, until you possess an ornate house of gold, or ascend into the heavens; and we will not believe in your ascension until you have brought down for us a book which we can read' Say: 'Exaltations to my Lord! Am I anything except a human Messenger'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
Nothing prevented people from believing when guidance came to them but (the excuse): 'Has Allah sent a human as a Messenger'\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say: 'Had there been angels walking at peace in the earth, We would have sent down an angel from heaven to them as a Messenger'\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say: 'Allah is sufficient as a witness between me and you. He knows and observes His worshipers'\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
Those whom Allah guides are rightly guided; but for those whom He leads astray you shall find no guardian, other than Him. On the Day of Resurrection We shall gather all of them upon their faces, blind, dumb, deaf. Gehenna shall be their refuge, whenever it dwindles, We will increase the Blaze for them.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
That will be their recompense because they disbelieved Our verses and said: 'When we are turned to bones and broken bits, shall we really be raised up once more as a new creation'\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
Have they not seen that Allah, who has created the heavens and the earth, has power to create their like? There is no doubt that He has appointed for them aterm, yet the unbelievers refuse all but disbelief.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say: 'If you possessed the treasuries of my Lord's Mercy, you would hold them back for fear of spending and mankind is ever grudging!\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
To Moses We gave nine clear signs. Ask the Children of Israel about how he came to them. When Pharaoh said to him: 'Moses, I think you are bewitched.'\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
'You know' he replied, 'that none except the Lord of the heavens and the earth has sent down these as clear proofs. Pharaoh, I believe you are destroyed.'\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
Pharaoh sought to provoke them so that they would leave the land, but We drowned him, together with all who were with him.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And thereafter We said to the Children of Israel: 'Dwell in the land. When the promise of the Everlasting Life comes We shall bring you all together'\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
We have sent it down with the truth, and with the truth it has come down. We have not sent you except a bearer of glad tidings and a warner,\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
and We have divided the Koran for you to recite at intervals to mankind and We have sent it down successively.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say: 'Believe in it, or do not believe. When it is recited to those to whom knowledge was given before they fall prostrate upon their faces\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
and say, ``Exaltations be to our Lord! The promise of our Lord is done.'\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
They fall down upon their chin, weeping and it increases them in humility.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say: 'Call upon Allah, or call upon the Merciful; whichever (Name) you call upon, to Him belong the Most Beautiful Names' Pray neither loudly nor to quietly, rather, seek a middle course between them.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmcxl{%
Say: 'Praise be to Allah who has not taken a son; who has no associate in the Kingdom; nor out of humility any guardian' And exalt Him repeatedly with exaltations.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen Praise belongs to Allah who has sent down the Book to His worshiper (Prophet Muhammad) and has not made any crookedness in it,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
unswerving. To warn of great violence from Him, and to give good tidings to the believers who do good deeds that theirs shall be a goodly wage\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
and they will live for ever therein.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
And it (the Koran) warns those who say: 'Allah has taken a son'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
. Surely, of this they have no knowledge, neither they nor their fathers; it is a monstrous word that comes from their mouths, they say nothing but a lie.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Yet perchance, if they do not believe in this tiding, you will consume yourself with grief and follow after them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
We have appointed all that is on the earth an adornment for it, in order that We try which of them is finest in works.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
We will surely reduce all that is on it to barren dust.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Or, do you think the companions of the Cave and the tomb stone were a wonder among Our signs?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcl{%
When the youths sought refuge in the Cave, they said: 'Lord give us from Your Mercy and furnish us with rectitude in our affair'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcli{%
For many years We sealed up their hearing in the Cave,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmclii{%
and thereafter We revived them to find out which of the two parties could best calculate the length of their stay.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcliii{%
In truth We tell to you their news. They were young men who believed in their Lord, and We increased them in guidance.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcliv{%
We strengthened their hearts when they stood up and said: 'Our Lord is the Lord of the heavens and the earth. We will call on no other god except Him; (for if we did), we would have spoken outrageously (in disbelief),\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmclv{%
These, our nation have taken to themselves gods, other than Allah. Why do they not bring some clear authority regarding them! Who does greater evil than he who forges a lie against Allah'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmclvi{%
When you depart from them and from what they worship, other than Allah, seek refuge in the Cave. Allah will extend His Mercy to you and will furnish you with a gentle issue of your affair.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmclvii{%
You might have seen the rising sun incline towards the right of their Cave, and, as it set go past them on the left, while they stayed within an open space in the Cave. That was one of the signs of Allah. He whom Allah guides is rightly guided; but he whom He leads astray you shall not find for him a guardian to guide him.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmclviii{%
You might have thought them awake, though they were sleeping. We turned them about to the right and to the left, while their dog stretched its paws at the entrance. Had you seen them you would surely have become filled with terror and turned your back on them in flight.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmclix{%
As such We revived them so that they might question one another. 'How long have you stayed here' asked one of them. 'We have been here a day, or part of it' they replied. They said: 'Your Lord knows best how long we have stayed here. Let one of you go to the city with this silver (coin) and let him search for one who has the purest food and bring provision from it. Let him be courteous, but let no one sense it is you.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmclx{%
For, if they appear in front of you, they will stone you to death or restore you to their religion. Then you will never prosper'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmclxi{%
And so We made them (the unbelievers) stumble upon them, so that they might know that the promise of Allah is true and that there is no doubt about theHour. They argued among themselves over their affair, then (the unbelievers) said: 'Build a building over them (their remains). Their Lord knows best who they were. 'But those who prevailed over the matter said; 'We will build around them a Mosque'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmclxii{%
Some will say: 'They were three; their dog was the fourth' Others, guessing at the Unseen, will say: 'They were five and their dog was the sixth' And yet others: 'Seven; their dog was the eighth' Say: 'My Lord knows best their number. Except for a few none know their number' Therefore, do not dispute with them except in outward disputation, and do not ask any of them concerning them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
Do not say of anything: 'I will do it tomorrow'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
unless (you add) 'if Allah wills' And remember your Lord when you forget and say: 'It may be that my Lord will guide me to something nearer to rectitude than this'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And they stayed in the Cave three hundred years and to that they added nine more.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say: 'None but Allah knows how long they stayed. To Him belong the Unseen in the heavens and the earth. How well He sees, and how well He hears! They have no other guardian, other than Him, and He allows no one (to share) His rule'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
Recite what is revealed to you in the Book of your Lord. No one can change His Words. You shall find no refuge other than Him.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And be patient with those who call to their Lord in the morning and evening, desiring His Face. And do not turn your eyes away from them desiring the good things of this life, nor obey he whose heart We have made neglectful of Our remembrance; so that he follows his own lust, and his affair has become excessive.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmclxix{%
Say: 'This is the truth from your Lord. Let whosoever will, believe, and whosoever will, disbelieve it' For the harmdoers, We have prepared a Fire, the pavilion of which encompasses them. When they cry out for relief, they shall be showered with water as hot as molten copper, which will scald their faces; how evil a drink, and how evil a restingplace!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmclxx{%
As for those who believe and do good works We do not waste the wage of whosoever does good works.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
Those, they shall live in the Gardens of Eden, underneath which rivers flow. They shall be adorned with bracelets of gold and arrayed in green garments of silk, and brocade, reclining therein on couches; how excellent is their reward and how fine is their resting place!\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
Give them the parable of two men. To one we gave two gardens of vines and surrounded them with palm trees and in between the two we placed a sownfield.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Each of the two gardens yielded its produce and did not fail in the least and We made a river to gush through them,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
so he had fruit. As he spoke with his companion, as he was conversing with him, 'My wealth is more abundant than yours and men have a greater respect for me'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
And when, having wronged himself, he entered his garden, he said: 'I do not think that this will ever perish!\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
Nor do I think that the Hour will come. Even if I returned to my Lord, I should surely find a better place than this'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His companion said, during his conversation with him: 'What, do you disbelieve in Him who created you from dust, then from a spermdrop, and then fashioned you into a man!\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
He is Allah, my Lord, and I will not associate anyone with My Lord.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
When you entered your garden why did you not say: ``If Allah wills; there is no power except by Allah." Though you see me lesser than yourself in wealth and children,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
maybe my Lord will give me a garden better than yours, and send down a thunderbolt from heaven, so that in the morning it will be a slope of dust,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
or, in the morning its water will be drained into the earth so that you will not have a means to reach it'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
And all his fruit were destroyed, and in the morning he wrung his hands with grief at all he had spent on it, for it had collapsed upon its trellises, and he said: 'Would that I had not associated anyone with my Lord'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
He had no host to help him besides Allah, and he was helpless\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
that Day. Supremacy belongs only to Allah, the True. He is the best to reward and the best ending.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
Give to them a parable about this present life. It is like water We have sent down from the sky with which the plants of the earth mingle, and in the morning it is straw the wind scatters. Allah is Powerful over all things.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and children are the ornament of this present life. But the things that last and good deeds, are better with your Lord in reward and hope.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
And on the Day when We shall set the mountains in motion and you shall see the earth a leveled plain; when We gather them together, and would not leave even one behind,\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
and they shall be presented in ranks before your Lord (who will say to them:) 'You have returned to Us as We created you the first time. No, you claimed We would not appoint a meeting for you!\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the Book shall be set in place, and you will see the sinners fearful of what is in it' They shall say: 'Woe to us! How is it, this book omits nothing small or great, all are counted' And they shall find what they did is present, and Your Lord will wrong no one.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcxc{%
When We said to the angels: 'Prostrate yourselves before Adam' all prostrated themselves except iblis, who was one of the jinn, disobedient to the command of his Lord. Would you then take him and his descendants to be your guardians, other than Me, when they are your clear enemy? How evil is the exchange for the harmdoers!\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcxci{%
Neither did I make them witnesses at the creation of the heavens and the earth, nor at their own creation. I would never take those who lead others astray to be My supporters.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
And the Day He will say: 'Call on those whom you claimed to be My associates' They will invoke them, but they will receive no answer, for We shall place a gulf between them.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And when the evildoers see the Fire of Hell they will reckon it is there they shall fall. They shall find no escape from it.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
We have set forth for people in this Koran all manner of parables; the human is the most disputatious of things.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
Nothing prevented people from believing and seeking the forgiveness of their Lord when guidance came to them, unless they are waiting for the fate of the ancients to overtake them, or that the punishment should come upon them face to face.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
We send Our Messengers only to proclaim glad tidings and to give warning. But the unbelievers dispute with false arguments so that they may belie the truth. They have taken My verses and warnings in mockery.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
Who is greater in evil than he who, when reminded of the verses of his Lord, turns away from them and forgets what his hands have sent before him? We have placed veils over their hearts lest they should understand it, and there is heaviness in their ears. Even if you call them to guidance, they will never be guided.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
Your Lord is Forgiving, Owner of Mercy. Had it been His will to take them to task for what they earned, He would have hastened their punishment; but they have an appointed hour from which they will never escape.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And those villages! When they became evil We destroyed them and appointed a meeting for their destruction.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcc{%
When Moses said to his (assisting) youth: 'I will not give up until I reach the point where the two seas meet even though I should go on for many years'\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcci{%
But when they came to the point where the two met, they forgot their fish, which made its way burrowing into the sea.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmccii{%
And when they had gone further, he said to his assisting youth; 'Bring us our breakfast; we are worn out from our journey'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He replied: 'What do you think, I forgot the fish when we were resting on the rock. None but satan made me forget to mention this it made its way into the sea in a marvelous fashion'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcciv{%
'This is what we have been seeking' said he, and they retraced their footsteps\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmccv{%
and found one of Our worshipers to whom We had given from Our Mercy, and to whom We had taught knowledge of Ours.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Moses said to him: 'May I follow you so that you can teach me of that you have learned of righteousness'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmccvii{%
'You will not bear patiently with me' He replied.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmccviii{%
'For how can you bear patiently with that which you have never encompassed in your knowledge'\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmccix{%
He (Moses) said: 'If Allah wills, you shall find me patient, I shall not disobey your order'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmccx{%
He said: 'If you follow me, you must not question me about anything till I myself speak to you concerning it'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they departed. When they boarded a ship, he bored a hole in it. 'What, have you made a hole in it' he said, 'is it to drown its passengers? You have done a dreadful thing'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmccxii{%
'Did I not I tell you' he replied, 'that you would not bear patiently with me'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
Moses said: 'Do not blame me for what I forgot, nor press me to do something which is too difficult'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
and so they departed. Thereafter they met a boy and he killed him. He (Moses) exclaimed: 'What, have you killed a pure soul and it was not done (in retaliation) for a soul you have done a terrible thing'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmccxv{%
'Did I not tell you' he replied, 'that you would not be able to bear patiently with me'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
He (Moses) said: 'If I question you again do not let me be your companion; you already have enough excuse'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
So they departed and thereafter they came to the inhabitants of a village. They asked its inhabitants for some food, but they declined to host them. There, they found a wall about to fall down whereupon his companion restored it. He (Moses) said: 'Had you wished, you could have taken payment for that'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
He said: 'This is the parting between me and you. But now I will tell you the interpretation of that which you could not patiently bear.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmccxix{%
As for the ship, it belonged to poor people working on the sea. I rendered it imperfect because behind them there was a king who was taking every ship by brutal force.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmccxx{%
As for the boy, his parents are believers, and we were afraid lest he should impose on them with his insolence and disbelief.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
It was our wish that their Lord should grant them another in exchange, another better in purity and tenderness.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
As for the wall, it belonged to two orphan boys in the city. Beneath it was (buried) a treasure which belonged to them. Their father had been a righteous person and your Lord willed that when they reach manhood to bring out their treasure as a mercy from your Lord. What I did was not done by my own command. That is the interpretation of what you could not bear with patience'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
They will ask you about ThulKarnain (the pious and chosen). Say: 'I will recite to you something of his story.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
We established him in the land and gave him means to all things.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
He journeyed on a way\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
until, when he reached the setting of the sun, he found it setting in a muddy spring, and nearby he found a nation. 'ThulKarnain' We said, 'you must either punish them or show them kindness'\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He replied: 'The evildoer we shall punish. Then he shall return to his Lord and He will punish him with a stern punishment.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
As for he who believes and does good works he shall receive a fine reward in recompense and we shall speak to him with a mild command'\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then he followed the road,\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
until he reached the rising of the sun, he found it rising upon a nation for whom We provided no veil against it to shade them.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
So, We encompassed in knowledge what was with him.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then he followed the road,\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
when he reached between the two barriers he found on one side of them a nation who could barely understand speech.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
'ThulKarnain' they said, 'Look, Gog and Magog are corrupting the earth. Build for us a barrier between us and them, and we will pay you a tribute'\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He replied: 'That which my Lord has given me is better, therefore help me with all your power, and I will build a barrier between you and between them.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
Bring me ingots of iron' After he had leveled between the two cliffs, he said: 'Blow' And when he made it a fire, he said: 'Bring me molten copper so that I may pour over it'\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
Thereafter they could neither scale it, nor could they pierce it.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
He said: 'This is a mercy from my Lord. But when my Lord's promise is come, He will make it dust. The promise of my Lord is true'\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
On that day, We will let them surge on one another, and the Horn shall be blown, and We will gather them all together.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmccxl{%
On that Day We shall present Gehenna (Hell) to the unbelievers,\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmccxli{%
whose eyes were blinded to My remembrance and they were not able to hear.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Do the unbelievers think that they can take My worshipers as guides other than Me? We have prepared Gehenna to be the hospitality of the unbelievers.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say: 'Shall we tell you of those who are the greatest losers in deeds'\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
(They are) those whose striving in this world go astray, while they think that what they are doing are good deeds.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
Those are they who disbelieve the verses of their Lord and deny that they will ever meet Him their deeds have failed. On the Day of Resurrection, We shall not give any weight to them.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
Gehenna is their recompense; because they disbelieved and mocked My verses, and My Messengers.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
The hospitality of those who believe and do good works shall be the Gardens of Paradise\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
where they will live for ever and never wish that they should be removed from it.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say: 'If the sea were ink for the Words of my Lord, the sea would surely be spent before the Words of my Lord are spent, even if We brought its like for replenishment'\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say: 'I am only a human like you, revealed to me is that your God is One God. Let him who hopes for the encounter with his Lord do good work, and not associate anyone with the worship of his Lord'\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen KaafHaYa'aeenSaad.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcclii{%
A mention of the Mercy of your Lord to his worshiper Zachariah,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmccliii{%
when he called upon his Lord in secret,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmccliv{%
saying: 'O my Lord, my bones are enfeebled, and my head glows silver with age. Yet, never Lord, have I been unblessed in prayer to You.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcclv{%
Indeed, I fear my kinsmen who will succeed me, for my wife is barren. Grant me a kinsman\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
who will be my heir and an heir to the House of Jacob, and make him, my Lord, satisfied'\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
'O Zachariah, We give you good tidings of a son, and he shall be called John (Yahya); a name We have never given before'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
'How shall I have a son, Lord' he asked, 'when my wife is barren, and I am advanced in years'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcclix{%
He replied: 'It shall be so; your Lord says: ``It is easy for Me, indeed, I created you before time when you were not a thing."\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcclx{%
He (Zachariah) said: 'Lord, make for me a sign' He replied: 'Your sign is that you shall not speak to people for three nights being without fault'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
Then he came out from the Sanctuary to his nation, and gestured to them to exalt (their Lord) at the dawn and at the evening.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
(We said): 'O John, hold fast to the Book', and We bestowed on him judgment while yet a child\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
and tenderness from Us and purity, and he was cautious;\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
honoring his parents, being neither arrogant nor rebellious.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
Peace be upon him on the day he was born and the day he dies, and on him the day when he is raised up alive.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And mention in the Book, Mary, how she withdrew from her people to an eastern place and she took a veil apart from them;\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
We sent to her Our Spirit (Gabriel) in the resemblance of a perfect human.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
(And when she saw him) she said: 'I take refuge in the Merciful from you! If you are fearful'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
'I am the Messenger of your Lord' he replied, 'and have come to give you a pure boy'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
'How shall I bear a son' she answered, 'when I am not touched by a human and not unchaste'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
``Even so" he replied, ``as such your Lord has said: 'Easy it is for Me. And We shall make him a sign to mankind and a mercy from Us. It is a matter decreed.'"\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
Thereupon she carried him, and retired to a far off place.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
And when the birthpangs came upon her by the trunk of a palmtree, she said: 'Oh, would that I had died before this and become a thing forgotten'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
He called from below to her: 'Do not sorrow, look, your Lord has provided a rivulet below you,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
and shake the trunk of this palmtree it will drop fresh ripe dates upon you.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
Therefore eat and drink and rejoice with your eyes. If you meet any human say to him: ``I have vowed a fast to the Merciful and will not speak with anyone today.'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
She came to her nation, carrying him; and they said: 'O Mary, you have committed a monstrous thing.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
O sister of Aaron, your father was never an evil man, nor was your mother unchaste'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
So she pointed to him (Prophet Jesus). But they replied: 'How can we speak with a baby in the cradle'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
He (the baby) said: 'I am the worshiper of Allah. Allah has given me the Book and made me a Prophet.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
He made me to be blessed wherever I am, and He has charged me with prayer and charity for as long as I shall live.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
(He has made me) kind to my mother; He has not made me arrogant, unprosperous.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
Peace be upon me on the day I was born, and on the day I die; and on the day when I shall be raised up alive'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
Such was (Prophet) Jesus, the son of Mary. A saying of truth, concerning what they doubt.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It is not for Allah to take a son! Exaltations to Him! When He decrees a thing He only says: 'Be' and it is.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
Indeed, Allah is my Lord and your Lord therefore worship Him. That is the Straight Path.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
But the parties have fallen into variance among themselves, then woe to those who disbelieve for the scene of a Dreadful Day.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
How well they will hear and see on the Day when they come before Us! The evildoers are today in clear error.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
Warn them of that Day of Anguish, when the matter is determined whilst heedlessly they disbelieve.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmccxc{%
For We shall inherit the earth and all that are on it. To Us, they shall return.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmccxci{%
Mention in the Book Abraham; He was truthful and a Prophet.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
He said to his father: 'O father, why worship that which can neither see nor hear, nor helps you in anything?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
Father, knowledge has come to me which has not come you, therefore, follow me. I will guide you to a Level Path.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
Father, do not worship satan; for satan has rebelled against the Merciful.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
Father, I fear that the punishment of the Merciful will fall upon you and you will become a guide of satan'\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
But he replied: 'Do you shrink away from my gods, Abraham? Surely, if you do not cease I will stone you, so leave me for awhile'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
'Peace be on you' he (Abraham) said, 'I shall call upon my Lord to forgive you, for to me He has been gracious.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
Now I will go away from you and that you call upon, other than Allah. I will call on my Lord. Perhaps I shall not be unblessed in calling my Lord'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
So when he turned away from them and those they worshipped, other than Allah, We gave him Isaac and Jacob. Each of them We made a Prophet,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmccc{%
and We gave them of Our Mercy and We appointed to them a truthful, highly sincere tongue,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmccci{%
Mention in the Book, Moses. He was devoted, a Messenger, and a Prophet.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcccii{%
We called out to him from the right side of the mountain, and drew him near in (Divine) conversation.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmccciii{%
From Our Mercy We gave him, his brother Aaron, a Prophet.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And mention in the Book, Ishmael; he too was true to his promise, a Messenger and a Prophet.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcccv{%
And he ordered his people to pray and to give charity and his Lord was pleased with him.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And mention in the Book, Idris; he too was of the truth and a Prophet,\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
We raised him to a high place.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
These are whom Allah has blessed among the Prophets from among the seed of Adam and of those whom We bore with Noah; the descendants ofAbraham, of Israel, and of those whom We have guided and chose. For when the verses of the Merciful were recited to them, they fell down prostrate, weeping.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcccix{%
But the generation that succeeded them wasted their prayers and followed their desires, so they shall encounter error\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcccx{%
except he who repents and believes and does good works; those shall be admitted to Paradise and shall not be wronged in any way.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
(They shall enter the) Gardens of Eden, which the Merciful has promised His worshipers in the Unseen. Indeed, His promise shall come.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
There, they shall hear no idle talk, but only peace. And there they shall be given their provision at dawn and at the evening.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
That is the Paradise which We shall give the cautious worshipers to inherit.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
(Gabriel said:) 'We do not descend except at the command of your Lord. To Him belongs all that is before us and all that is behind us, and all that lies between. Your Lord does not forget.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
Lord of the heavens and the earth and all that is between them, so worship Him, be patient in His worship. Do you know any that can be named with His Name'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
The human says: 'What, when I am dead, shall I be raised to life'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Will the human not remember that We created him before when he was not a thing.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
By your Lord, We will gather them and the satans, and We shall parade them hobbling on their knees in Gehenna:\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
from every party We will pluck out whichever of them was the most hardened in disdain of the Most Merciful.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
We alone know who deserves most to be burned therein.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
There is not one of you who shall not go down to it: such is a thing decreed, determined by your Lord.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then, We will save those who were cautious of Us, but the harmdoers shall be left there hobbling on their knees.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
When Our clear verses are recited to them the unbelievers say to the believers: 'Which of the two parties has a better position or company'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
How many generations have We destroyed before them, who were far greater in riches and more boastful!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say: 'Whosoever is in error, let the Most Merciful prolong his life span until they see that which they were threatened, be it a punishment, or the Hour. Thenshall they know whose is the worst place and who is weaker in hosts'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
Allah will increase those who were guided in guidance and things that abide. Good deeds are better in reward with your Lord, and, better in return.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Have you seen he who disbelieves Our verses and yet says: 'I shall surely be given wealth and children'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Has he gained knowledge of the Unseen? Or taken a covenant with the Merciful?\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
On the contrary, We will write down what he says and prolong the length of his punishment.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
We shall inherit that of which he speaks and he will come before Us alone.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have taken gods, other than Allah, that they might be a power from them.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
Indeed no! They will renounce their worship and turn against them.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Have you not seen how We send down to the unbelievers satans who prick them?\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
Therefore, do not hasten (things) against them, for We count out to them a number,\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
and on the Day when We will ceremonially gather the righteous to the Merciful,\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
and drive the evildoers as herds, into Gehenna\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
who have no power of intercession, except those who have taken a covenant with the Merciful.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And they say: 'The Merciful has taken a son'\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
Surely, you have brought a monstrous thing!\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
Thereby the heavens are nearly torn and the earth split asunder, and mountains fall crashing down\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
because they have ascribed a son to the Merciful.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
It is not for the Merciful to take a son!\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
There is none in the heavens and earth except he comes to the Merciful as a worshiper.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
He has counted them and exactly numbered all;\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
and each one shall come to Him on the Day of Resurrection, alone.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Those who believe and do righteous deeds, the Merciful will assign for them love.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
We have made it easy in your own tongue in order that you proclaim the glad tidings to the cautious and give warning to a stubborn nation.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
How many generations have We destroyed before them! Do you sense even one of them, or hear a whisper from them?\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen TaHa.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not sent down the Koran to you for you to be tired,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcccli{%
but as a reminder to he who fears.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmccclii{%
It is a sending down from Him who has created the earth, and the high heavens,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
the Merciful willed to the Throne.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
To Him belongs all that is in the heavens and the earth, and all that lies between them, and underneath the soil.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmccclv{%
If you speak loudly; He has indeed knowledge of the secret and the hidden.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah, there is no god except He. To Him belong the most Beautiful Names.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
Has the story of Moses reached you?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire, he said to his family: 'Stay here, for I can see a fire. Perhaps I can bring you a lighted torch or find at the fire guidance'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmccclix{%
When he reached it, he was called: 'O Moses,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmccclx{%
I am your Lord. Take off your shoes, for you are in Towa, the sacred valley.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
I have chosen you. Therefore, listen to what shall be revealed.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
Indeed, I am Allah. There is no god except Me. Worship Me, and establish the prayer of My remembrance.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
The Hour is coming. I almost conceal it, so that every soul will be recompensed for its labors.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
Do not let those who disbelieve in it and follow their desires bar you from it, or you will perish.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
What is that in your right hand, Moses'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
'It is my staff," Moses replied, ``upon it I lean and with it I beat down leaves to feed my sheep and for me there are other uses in it'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
He said: 'Moses, cast it down'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
So he cast it down, and thereupon it turned into a sliding serpent.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
'Take it, and do not fear' He said, 'We will restore it to its former state.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
Now, put your hand under your armpit. It shall come out white, without evil, a second sign.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
But We shall show you some of Our greatest signs.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
24 Go to Pharaoh, he has become insolent'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
'Lord' said Moses, 'expand my chest,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
and ease my task for me.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
Unloose the knot upon my tongue,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
that they may understand my speech.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
Appoint for me a minister from my family\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
Aaron, my brother.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
By him confirm my strength\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
and let him share my task,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
so that we exalt You\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
and remember You abundantly.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
You are surely seeing us'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
He replied: 'Moses, your request is granted.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
We had already shown you favor\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
when We revealed what was to be made known to your mother,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
saying: ``Put him in the box and cast it into the river. The river will cast him on to the bank, and he shall be taken up by an enemy of Mine and an enemy of his." I lavished My Love on you, and to be formed in My Sight.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
Your sister went (to them) and said: 'Shall I guide you to one who will nurse him' And so We restored you to your mother, so that her eyes might rejoice and that she might not sorrow. And when you killed a soul We saved you from grief and then We tried you with many trials. You stayed among the people of Midian for a number of years, and then, Moses, you came here according to a decree.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
I have chosen you for Me.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
Go, you and your brother with My signs, and do not be negligent of My Remembrance.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
Go to Pharaoh, for he has become insolent.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
Speak to him with gentle words; perhaps he will ponder or fear'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
'O our Lord' both said, 'We fear lest he may be excessive against us or become insolent'\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He replied: 'Have no fear I shall be with you, both hearing and seeing.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
Both of you go to him (Pharaoh) and say: ``We are the Messengers of your Lord. Let the Children of Israel depart with us, and do not punish them. We have come to you with a sign from your Lord; peace be on him who follows guidance!\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
It is revealed to us that a punishment will fall on those who belie and turn away."\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
He (Pharaoh) said: 'Moses, who is the Lord of you both'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
'Our Lord' he replied, 'is He Who gave everything its creation and then guided it'\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
He (Pharaoh) asked: 'How was it then, with the former generations'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcd{%
He (Moses) answered: 'The knowledge of them is in a Book with My Lord. My Lord neither goes astray, nor forgets.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcdi{%
It is He who has made for you the earth as a cradle and threaded roads for you and sends down water from the sky with which We bring forth every kind of plant.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcdii{%
You eat and let your cattle graze' Surely, in this there are signs for those of understanding.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
We created you from it (the earth), and to it We shall restore you; and from it We will bring you forth yet a second time.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
So We showed him (Pharaoh) Our signs, all of them, but he belied and refused them.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He said: 'Moses, have you come to drive us from our land with your sorcery?\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
We will indeed bring sorcery similar to yours. Appoint a meeting place between us and you, in a place which is agreeable to both which neither we nor you shall not fail (to keep)'\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
He (Moses) replied: 'Your meeting shall be on the day of the feast, and let the people be assembled by midmorning'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
So Pharaoh withdrew and gathered his guile, then returned,\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcdix{%
and Moses said to them: 'Alas! Do not forge a lie against Allah lest He destroys you with a punishment. Indeed, whosoever forges has failed'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcdx{%
They disputed upon their plan with one another, and spoke in secret\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
saying: 'These two are sorcerers whose aim is to drive you from your land by their sorcery and destroy your noble ways.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
Gather your guile and then lineup a rank those who gain the upper hand today shall indeed prosper'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said to Moses: 'Will you throw down or shall we be the first?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
Moses replied: 'No, you throw first' And by their sorcery it seemed to him that their ropes and staffs were sliding.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
Moses became fearful within himself.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
But We said to him: 'Do not be afraid; you shall surely be the uppermost.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
Throw that which is in your right hand. It will swallow up that which they have made, for that which they made is but the guile of a sorcerer. Wherever he goes the sorcerer does not prosper'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
Thereafter the sorcerers threw themselves down, prostrating, saying: 'We believe in the Lord of Aaron and Moses'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
'Have you believed him before I have given you permission' he (Pharaoh) said. 'Indeed, he (must be) your chief, the one who taught you sorcery. I will cut off on opposite sides a hand and a foot then crucify you on the trunks of palmtrees. Indeed, you shall know whose punishment is more stern, and more lasting'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
Their reply was: 'We will not prefer you over the clear signs that have come to us, nor over Him who has created us. So decide upon whatever you decide, you can only decided upon things in this present life.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
We believe in our Lord so that He forgives us our sins and the sorcery you have forced us to practice. Allah is Better, and Everlasting'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Gehenna (Hell) awaits whosoever comes before his Lord as a sinner, there he shall neither die nor live.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
But for whosoever comes before Him as a believer and having done good works there awaits the most highest degree;\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
living for ever in the Gardens of Eden, underneath which rivers flow. Such shall be the recompense of he who purifies himself.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
To Moses we also revealed: 'Set forth with My worshipers by night and strike for them a dry path in the sea. Do not fear that you will be overtaken, neither be afraid'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Pharaoh pursued them with his legions so they were overwhelmed from the sea with that which drowned them.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
For Pharaoh had misled his nation, and did not guide them.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
Children of Israel! We saved you from your enemies and made a covenant with you on the right side of the Mountain. We sent down manna and quails.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
'Eat of the good things with which We have provided you and do not transgress therein lest My Anger should fall upon you, and upon whosoever My Anger falls has assuredly fallen,\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
but to whosoever repents, believes and does good deeds, and is at last guided, I am Forgiving'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
'Moses, why have you come with such haste from your nation'\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
Moses replied: 'They are following me. My Lord, I made haste only so that I might please You'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
He (Allah) said: 'We tempted your nation in your absence, and the Samaritan has misled them into error'\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
With great anger and sorrow, Moses returned to his nation. 'My nation' he said, 'did your Lord not make you a fine promise? Did the time of the covenant seem long to you? Or did you desire that the anger of your Lord should fall upon you so that you failed in your coming to my appointment'\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They replied: 'We have not failed in our promise to you through our choosing. We were laden with fardels, even the ornaments of the nation, and threw them just as the Samaritan had thrown them (into the fire),\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
and made a calf for them, a figure that lowed. ``This," they said, ``is your god and the god of Moses but whom he has forgotten."\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
What! Did they not see that it did not speak a word to them in return, and for them it could own neither harm nor benefit?\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
Aaron had said to them before: 'My nation, you have been tempted by it. Your Lord is the Merciful. Follow me and obey my order'\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They replied: 'We will not stop; we will cling to it until Moses returns to us.'\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
He (Moses) said to Aaron: 'When you saw them in error, what prevented you,\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
from following after me, did you disobey my order'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
'Son of my mother' he replied, 'Do not seize my beard nor my head. I was afraid that you might say: ``You have divided the Children of Israel and did not uphold my word."\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
'You, Samaritan' said he (Moses), 'what was your business'\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
He replied: 'I saw what they did not see and seized a handful of dust from the foot print of the messenger and so I cast it this my soul prompted me to do'\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
'Begone! Your lot in this life is to cry: ``untouchable!' said he (Moses). 'An appointment awaits you that you cannot fail to keep. Look at your god which you clung to indeed we will burn it and scatter its ashes upon the sea'\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Your God is only One, Allah. There is no god, except He, alone. His knowledge encompasses all things.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
And so We narrate to you the stories of the past, and We have given you a remembrance from Us.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whosoever has turned away from it shall bear a burden on the Day of Resurrection.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
and live in it for ever; how evil will that burden be for them on the Day of Resurrection.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmcdl{%
The Day when the Horn shall be blown. On that Day, We shall assemble all the sinners with blued eyes,\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmcdli{%
and they shall murmur among themselves: 'You have stayed away but ten (days and nights)'\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We know well what they will say. The most just among them in the matter will declare: 'You have stayed away but one day'\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
They will question you about the mountains. Say: 'My Lord will scatter them as ashes\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
and leave them a desolate waste,\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
with neither crookedness nor any curving to be seen therein'\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that Day, they will follow the Summoner, who is not crooked, their voices hushed before the Merciful, and you shall hear nothing except a murmuring.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
On that Day intercession will not benefit them except him that has received the permission of the Merciful and whose words are pleased by Him.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knows what is before them and behind them, and they do not comprehend Him in knowledge.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
(All) faces shall be humbled before the Living One, the Eternal. Those who are burdened with wrong doing shall have failed,\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
but those who have believed and done good works shall fear neither wrong nor injustice.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
As such We sent it down, an Arabic Koran, and explained in it threats in order that they be cautious, or, that it prompts the Remembrance in them.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
Highly exalted be Allah, the true King! Do not hasten with the Koran before its revelation has been completed to you, but say: 'Lord, increase me in knowledge'\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
We made a covenant with Adam, but he forgot and We found in him no constancy.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And when We said to the angels: 'Prostrate yourselves before Adam' they all prostrated themselves except iblis, who refused.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
'Adam' We said, 'This is you and your wife's enemy. Do not let him expel you from the Garden, so that you (Adam) will be tired.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
It has been given to you so that you shall neither become hungry nor naked therein;\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
there, (you shall) neither thirst, nor suffer from the sun'\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
But satan whispered to him saying: 'Adam, shall I direct you the Tree of Eternity and a kingdom which never decays'\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
They both ate of it, and their shameful parts appeared to them, whereupon they began to stitch upon themselves leaves from the Garden. And so it was, Adam erred and disobeyed his Lord.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
But afterwards his Lord chose him; He turned again towards him and guided him.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
'Both of you, together, go down out of it (the Garden) each of you an enemy to the other' He said: 'but, if My Guidance comes to you, whosoever followsMy Guidance shall neither go astray nor be unprosperous;\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
but whosoever turns away from My remembrance, his life shall be narrow and on the Day of Resurrection We shall raise him blind'\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
'My Lord' he will say: 'why have You raised me blind when I was able to see'\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
He (Allah) will say: 'It is so, Our verses came to you and you forgot them. So this Day you are forgotten'\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
In this way We recompense the prodigal who disbelieves the verses of his Lord. But the punishment of the Everlasting Life is more terrible and everlasting.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Is it not a guidance to them, how many generations We destroyed before them in whose dwelling places they walk? Surely, in this there are signs for thoseof reason.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
Except for a Word that preceded from your Lord, and a stated term, it had been fastened.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
Therefore, be patient with what they say, and exalt with the praise of your Lord before sunrise and before sunset. And in the watches of the night and at the edges of the day, exalt Him, so that you will be pleasing.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
Do not stretch your eyes at the flower of this life which We have given couples to enjoy, it is with this that We might try them; and the provision of yourLord is better, and more enduring.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
Order your family to pray and be patient in it. We do not ask you for provisions, rather, it is We who provide for you. And the final outcome is for the cautious.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
They say: 'Why does he not bring us a sign from his Lord' Did not a clear sign come to them in the preceding Scrolls?\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
Had We destroyed them with a punishment before this, they would have said: 'Our Lord, why did You not send us a Messenger so that we could have followed Your verses before we were humiliated and degraded'\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Say: 'Everyone is waiting; so wait. Indeed, you shall know who are the companions of the Even Path, and those who are guided'\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen The Reckoning for mankind is drawing near, yet they are heedless and turn away.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
No recent revival of the remembrance comes to them from their Lord, except that they play with it as they listen\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
their hearts are diverted. The harmdoers mutter to one another: 'Is this anything else but a human like yourself? What, will you follow sorcery with your eyes open'\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
He said: 'My Lord has knowledge of what is said in the heavens and on earth. He is the Hearer, the Knower'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
Some say: 'No, it is only mixed dreams' 'No, he has forged it himself', or, 'no, he is a poet! Let him bring us a sign, just as the ancient ones were sent asMessengers'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
Of the villages We destroyed, there was not one that believed. What, will they not believe?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
We never sent (anyone) before you except men to whom We revealed to them. 'Ask the people of the Remembrance if you do not know'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
Nor did We make them bodies that ate no food, nor were they immortal.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
Then We were true to the promise, We saved them together with those whom We willed, and destroyed the transgressors.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
Now, We have sent down to you a Book in which is your Remembrance. Will you not understand?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
How many harmdoing villages have We shattered and replaced them with another nation.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
And when they felt Our Might they fled from it.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
'Do not run away. Return to your luxury that you rejoiced in, and your homes in order that you be questioned'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They said: 'Alas for us we were harmdoers'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
And this they did not stop crying out until We made them stubble, silent, and still.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
It was not in play that We created the heavens and the earth and all that lies between them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmd{%
Had We wished to take to Us an amusement We would have taken it to Us from Ours had We done so.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdi{%
No, We hurl truth at falsehood, and it shall conquer it, and see, falsehood vanishes. Woe to you for all you have described.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdii{%
To Him belongs whosoever is in the heavens and the earth. Those who are with Him are not too proud to worship Him, nor are they ever wearied.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They never fail to exalt Him either at night or in the day.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Or, have they taken earthly gods who revive the dead?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdv{%
Had there been gods in heaven or earth, other than Allah, both would indeed have been ruined. Exalted be Allah, Lord of the Throne, above that they describe.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He is not to be questioned about what He does, but they shall be questioned.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Have they taken gods, other than Him? Say: 'Bring us your proof! Here is the Remembrance of he who is with me and the Remembrance of those before me' But no, most of them do not know the truth, therefore they turn away.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdviii{%
We never sent a Messenger before you except that We revealed to him saying: 'There is no god except Me, therefore, worship Me'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdix{%
They say 'The Merciful has taken a son' Exaltations to Him! No, they are only His honored worshipers,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdx{%
who do not surpass Him in speech, and do as He commands.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows what is before them and what is behind them. They intercede for none except for him whom He is well pleased, and they tremble in awe of Him.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdxii{%
If any one of them says: 'I am a god other than Him' We will recompense him with Gehenna (Hell). As such We recompense the harmdoers.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Have the unbelievers not seen that the heavens and the earth were sewn up as one (solid) mass, then We unstitched them, and that We made every living thing of water? Will they not believe!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
We set firm mountains upon the earth lest it should shake with them, and We placed therein ravines to be paths so that they might be guided.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdxv{%
We established the heaven as a well protected roof, yet they still turn away from its signs.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
It is He who created the night and the day, and the sun and the moon; each floating in an orbit.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
We have never assigned immortality to a human before you, therefore, if you yourself die, will they live for ever?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every soul shall taste death. We will try you with a trial of evil and good. Then, to Us you shall be returned.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdxix{%
When the unbelievers see you, they take you only for mockery, saying: 'Is this he who talks about your gods' While they are unbelievers in the Remembrance of the Merciful.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdxx{%
The human was created of haste. Indeed, I will show you My signs; so do not ask Me to hasten them.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
They say: 'If you are truthful, when will this promise come'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If the unbelievers only knew when they will be unable to shield either their faces or their backs from the Fire; when they will not be helped!\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
It will overtake them suddenly, dumbfounding them. They shall be unable to ward it off, and they shall not be respited.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
Before you, other Messengers were mocked, but the mockers were encompassed by the very thing they mocked.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say: 'Who will guard you, by night and by day from the Merciful' But no, they turn away from their Lord's remembrance.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Or have they gods to defend them, other than Us? Indeed, they are unable to help themselves, neither shall they be guarded in safety from Us.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
We gave days of enjoyment to them and their fathers until their life became long. Are they unable to see how We come to their land and reduce its borders. Or, is it they who are the victors?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say: 'I warn you only by the Revelation' But the deaf hear nothing when they are warned.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
But if just a breath of your Lord's punishment were to touch them, they would say: 'Woe for us, we were harmdoers'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
On the Day of Resurrection We shall set up just scales, so that no soul shall in the least be wronged, even though it be the weight of a grain of mustard seedWe will bring it We Suffice as reckoners.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
We gave Moses and Aaron the Criterion, and gave them a light and a Remembrance for the cautious:\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
those who fear Allah in the Unseen, tremble because of the Hour.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
This is a blessed Remembrance which We have sent down. Do you disbelieve it?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
Before this We gave Abraham his virtue, for We knew him.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
He said to his father and to his nation: 'What, are these the statues to which you cling'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They replied: 'We found our fathers worshipping them'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said: 'Truly, you and your fathers are in clear error'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said: 'Is it the truth you have brought us, or are you one of those that play'\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
'No' he answered, 'your Lord is the Lord of the heavens and the earth, the Originator of them, and I am among those bearing witness to it.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdxl{%
By Allah, I will certainly outwit your idols as soon as you have turned your backs and gone'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdxli{%
He broke them all into pieces, except their great one so that they might return to it.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
'Who has done this to our gods' they exclaimed. 'He must surely be a harmdoer'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
'We have heard a young man called Abraham mention them' they replied.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said: 'Then bring him here so that the people may see, so that they may bear witness'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
'Abraham' they said, 'was it you who did this to our gods'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
'No' he replied. 'It was their great one amongst them that did it. Ask them, if they are able to speak'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
So they returned one to another saying, 'Surely, it is you who are the harmdoers'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
But then they reversed their minds: 'You know they do not speak'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
He said: 'Would you then worship that, instead of Allah, which can neither help nor harm you?\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdl{%
Shame on you and on that you worship other than Allah! Have you no understanding'\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said: 'Burn him and help your gods, if you are going to do anything'\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdlii{%
'O Fire' We said, 'be coolness and safety for Abraham'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdliii{%
They sought to outwit him, but We made them the worst of losers.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdliv{%
We saved him and Lot, and brought them to the land which We had blessed for all the worlds.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdlv{%
We gave him, in excess, Isaac, and Jacob (for a grandson); and We made each righteous\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
and appointed them leaders to guide by Our Command and We revealed to them to do good deeds, and to establish the prayer, and the giving of charity, and they were for Us worshipers.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
To Lot, We gave judgment and knowledge and saved him from the village that had been committing corrupt deeds; for they were an evil nation and were debauched.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
We admitted him to Our Mercy, he was among the righteous.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And (remember) Noah, when he supplicated to Us, We answered him, and We saved him and his nation from great distress,\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdlx{%
and helped him against the nation who had belied Our signs. They were an evil nation; We drowned them all.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And David and Solomon they passed judgment upon the tilled land on which the people? s sheep had strayed. We bore witness to their judgment, and\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
We made Solomon to understand it, and to both We gave judgment and knowledge. And with David We subjected the mountains and birds to exalt (Allah). All this We have done.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
We taught him the craft of making garments that fortify you against your own violence. Are you thankful?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
To Solomon the raging wind ran at his command to the land which We had blessed. We have knowledge of all things.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And some of the satans dived for him and others did work as well. We were watching over them.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And Job when he called to his Lord: 'Affliction has befallen me, and You are the Most Merciful of the merciful'\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
We answered him and removed his affliction, and We gave his people, and those like them that were with them, mercy from Us, as a reminder to those who worship.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And Ishmael, Idris, and ThulKifl (the son of Job) each were patient.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
We admitted them to Our Mercy, for they were of the righteous.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And ThulNun (Prophet Jonah), he went away in anger thinking We had no power over him. But in the darkness he cried: 'There is no god except You. Exaltations to You! I was among the harmdoers'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
We heard his prayer and saved him from grief. As such We shall save the believers.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And Zachariah when he called to his Lord saying: 'Lord, do not let me remain by myself; You are the Best of inheritors'\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We answered him, and gave him John, curing his wife (of sterility). They raced with each other in good works and called on Us out of yearning and awe, and they were humble to Us.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And she (Mary) who guarded her virginity. We breathed into her of Our spirit (Gabriel), and made her and her son a sign for the worlds.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Indeed, this nation of yours is one nation, and I am Your Lord, therefore worship Me.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
But they (the Christians and Jews) split their affair between them all shall return to Us.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
The endeavors of he who believes and does good works shall not go unthanked. We write it down for him.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
(It is ordained that) no village We have destroyed shall return\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
till Gog and Magog are let loose and slide down out of every slope;\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
when the true promise draws near; the eyes of the unbelievers will stare (and they will say): 'Alas for us! Of this we have been heedless. We have beenharmdoers'\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
You and all those who you were worshipping, other than Allah, shall be the fuel of Gehenna; there you shall all go down to it.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
If those had been gods, they would never have gone down to it, but in it they shall live for ever.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
There is groaning for them therein, and they do not hear.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
But those whom We have surpassed with the finest (rank) from Us shall be far removed from it,\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
neither shall they hear any of its whisper, but shall live for ever in that their souls desired.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The greatest terror shall not grieve them, and the angels will receive them: 'This is the Day you have been promised'\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
On that Day, We shall roll up the heaven like a written scroll is rolled. As We originated the first creation, so will We bring it back again. This is a binding promise on Us which We shall assuredly fulfill.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
We have written in the Psalms, after the Remembrance: 'The righteous among My worshipers shall inherit the earth'\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Surely, in this is a proclamation to a worshiping nation.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmdxc{%
We have not sent you (Prophet Muhammad) except as a mercy to all the worlds.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say: 'It is revealed to me that your God is One God, do you then surrender'\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
If they turn back, say: 'I have warned you all alike, though I cannot tell whether what you are promised is imminent or distant.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
He knows your spoken words and what you hide.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
And I do not know if this is a trial for you and an enjoyment for a time'\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
He said: 'My Lord, judge in truth. Our Lord is the Merciful whose help is ever to be sought against what you describe'\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O people, have fear of your Lord. The earthquake of the Hour shall be a great thing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
On that Day you will see every one that suckles shall forsake her suckling, and every carrier shall miscarry, and you shall see mankind drunk although they arenot drunk; dreadful will be the punishment of Allah.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
Among people there are those, who without knowledge, dispute about Allah and follow every rebel satan,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
against whom it is written down that whosoever takes him for a guide, he guides astray, and leads him to the punishment of the Blaze.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdc{%
O people, if you are in doubt about the Resurrection, remember that We first created you from dust, then, from a sperm drop, then from a clot, and then from a bitesize tissue formed and unformed, so that We might clarify for you. We establish in the wombs whatever We will for an appointed term, and then We bring you forth as infants, then you come of age. Some of you die, and some of you are kept back to the vilest state of life, after knowing somewhat, they know nothing. And you see the earth dry; but no sooner do We send down rain upon it than it begins to quiver and swell, putting forth every fine variety (of herbage).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdci{%
That is because Allah is the Truth; He revives the dead and has power over all things.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And the Hour is sure to come there is no doubt. And Allah will raise up those in the graves.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdciii{%
Some dispute about Allah, though they have neither knowledge nor guidance, nor an illuminating Book.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdciv{%
There is for him who turns his side to lead (others) astray from the Path of Allah, degradation in this life and We shall let him taste the punishment of theburning on the Day of Resurrection.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdcv{%
'This, is the reward for what your hands have forwarded. Allah is not unjust to the worshipers'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
There are among the people such who worship Allah and (yet stand) on the very edge. When goodness comes to him, he is content, but if a trial befalls him he falls upon his face, he loses this world and the Everlasting Life; that is indeed a clear loss.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He calls to other than Allah, to that which neither hurts him, nor benefits him; that is indeed far error.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He calls upon him whose harm is nearer than his benefit, an evil guide and an evil friend.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdcix{%
As for those who believe and do good works Allah will admit them to gardens underneath which rivers flow. Allah indeed does what He will.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdcx{%
If any one thinks that Allah will not give him (Prophet Muhammad) victory in this present world and in the Everlasting Life, let him stretch a rope to heaven, and let him sever it. Then, let him see if his guile does away with that which has enraged him.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
As such We have sent it in clear verses. Indeed, Allah gives guidance to whom He will.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Surely, they that believe, and those of Jewry, the Sabaeans, the Nazarenes, the Magians, and the unbelievers, Allah will judge them on the Day of Resurrection. Surely, Allah is witness over everything.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Have you not seen that to Allah prostrate all who are in the heavens and all who are in the earth, the sun and the moon, the stars and the mountains, the trees and the beasts, and many people? And many deserve the punishment. He who is abased by Allah has none to honor him. Allah does what He will.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
Those are two who disputed concerning their Lord. Garments of fire have been prepared for the unbelievers. Boiling water shall be poured over their heads,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
and that which is in their bellies and their skins shall be melted;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
for them are hooked rods of iron.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Whenever in their anguish they try to get out of it, they are restored to it. (It will be said): 'Taste the punishment of burning'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
Allah will admit those who believe and do good works to gardens underneath which rivers flow. They shall be adorned therein with bracelets of gold and with pearls, and their garments shall be of silk.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
For they shall be guided to good speech and guided to the praised path.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
The unbelievers who bar from the Way of Allah and from the Holy Mosque which We made equal for all peoples, he who cleaves to it and the tentdweller alike, and whosoever seeks to violate it wrongfully, We shall let him taste a painful punishment.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
And when We settled for Abraham (and Ishmael) the place of the Holy Mosque, (We said): 'You shall not associate with Me anything. Purify My House for those who circumambulate it and those who stand, for those who bow and prostrate.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
Proclaim the pilgrimage to the people. They will come to you on foot and on every lean camel, they shall come from every deep ravine;\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
that they witness profitable things for them and mention the Name of Allah on well known days over the flocks which He has provided them. Eat thereof, and feed the wretched poor.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Then, let the pilgrims accomplish their acts of cleansing, and let them fulfill their vows, and circumambulate the Ancient House.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
All that; and whosoever venerates the sacred rites of Allah it shall be better for him with his Lord. The flocks are lawful to you, except that which is recited to you. Therefore, avoid the filth of idols and avoid speaking falsely,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
being of pure faith to Allah, not associating anything with Him. He who associates others with Allah is like he who falls from heaven and is snatched away by the birds or carried by the wind to some faroff place.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
All that; and, he who venerates the waymarks of Allah, surely it is from the piety of the hearts.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
In them, you have benefits until an appointed time. After their place of sacrifice is at the Ancient House.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
For every nation We have appointed a holy ritual, that they pronounce the Name of Allah over the beast of flocks which He has provided them. Your God isOne God; to Him surrender yourselves. Give glad tidings to the humble,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
whose hearts, when Allah is mentioned, quake, who endure their misfortunes with patience, and establish their prayers, and spend of that which We have provided them.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
And the camels We have made a part of the waymarks of Allah. In them is good for you. Pronounce over them the Name of Allah, when they are hobbled; and when they have fallen down on their sides, eat of them and feed the impoverished nonrequestor and the requestor. As such We have subjected them to you, in order that you give thanks.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
Their flesh and blood does not reach Allah rather it is piety from you that reaches Him. As such He has subjected them to you, in order that you exalt Allahfor guiding you. And give glad tidings to the generous.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Allah will defend those who believe. Verily, Allah does not love the ungrateful cheat.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Permission is given to those who fight because they were wronged. Allah has power to grant them victory:\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
those who have been unjustly driven from their homes, just because they said: 'Our Lord is Allah' Had Allah not repelled some people by the means ofothers, the monasteries and churches, the synagogues and mosques in which the Name of Allah is remembered would have been destroyed. But whoever helps Allah shall be helped by Him. Allah is the Strong, the Almighty,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
those who, if We established them in the land, will establish the prayers and pay the obligatory charity, order with honor and forbid dishonor, and to Allah is the end of all affairs.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
If they belie you, so too before them, the nation of Noah belied, and Aad and Thamood\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
and the nation of Abraham and the nation of Lot;\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
and the inhabitants of Midian, to Moses they also belied. I respited the unbelievers, then I seized them, and how was My disapproval!\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
How many a village We have destroyed in its harmdoing, so that it lies fallen upon its turrets, and how many an abandoned well, and empty palace!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
Have they never journeyed through the land so that they have hearts to understand, or ears to hear with? It is not the eyes, but the hearts in the chests that are blind.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
They ask you to hasten the punishment. Allah will not break His promise. Each day with your Lord is like a thousand years in your reckoning.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
And how many a village have I respited in its evil doing! Then I seized it. To Me is the return.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say (Prophet Muhammad): 'O people, I have been sent to warn you plainly.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
Those who believe and do good works, theirs shall be forgiveness and a generous provision;\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
but those who strive to void Our verses, thinking they have escaped, shall be the people of Hell'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
Never have We sent a Messenger or a Prophet before you, but when he hoped, satan tampered with his hope. But Allah supersedes the tampering of satan and confirms His verses. And Allah is the Knower, the Wise.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
(This He permits) in order that He makes satan's interjections a temptation for those in whose hearts is a sickness and those whose hearts are hardened and the harmdoers are in a wide schism,\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
and so that those to whom knowledge has been given will know that this is the truth from your Lord and so believe in it and that their hearts will be humble to Him. Indeed, Allah will surely guide those who believe to a Straight Path.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdcl{%
The unbelievers will never cease to doubt it until the Hour overtakes them suddenly or the punishment of the Barren Day comes upon them.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdcli{%
The Kingdom upon that Day shall belong to Allah. He will judge between them. Those who believe and do good works shall be in Gardens of Bliss,\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdclii{%
but for those who disbelieved Our verses and belied there awaits a humbling punishment.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
As for those who emigrated in the way of Allah and were slain, or died, Allah will provide them with fine provisions. Allah is the Best of providers.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
He will admit them by a gate that is pleasing to them, and surely, Allah is the Knower, the Clement.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdclv{%
So shall it be. He who punishes after the manner that he was punished and then again is oppressed, shall be helped by Allah. Allah is Pardoning, Forgiving.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is because Allah causes the night to enter into the day, and the day enter into the night. Allah is the Hearer and the Seer.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because Allah is the Truth, and falsehood is all that they call upon, other than Him. Allah is the Most High, the Most Great.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Do you not see that Allah sends down water from the sky and in the morning the earth becomes green? Allah is Subtle, the Aware.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him belong all that is in the heavens and earth, surely, Allah is the Rich, the Praised.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Do you not see that Allah has subjected to you all that is on the earth, and the ships which run upon the sea by His command? He holds the sky back lest it should fall upon the earth except by His permission. Allah is Gentle to people, the Most Merciful.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
It is He who revives you, then He will cause you to die and then He revives you. Indeed, the human is ungrateful.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
For every nation We have appointed a Holy Rite which they shall perform. Do not let them dispute with you concerning the matter. Call to your Lord; surely, you are upon a Straight Path.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
If they argue with you, say: 'Allah knows best all that you do.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
On the Day of Resurrection, Allah will judge between you concerning that in which you vary.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Are you not aware that Allah has knowledge of what is in the heaven and earth? This is (recorded) in a Book. That is easy for Allah.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
Yet they worship that for which He did not send down authority, and that of which they have no knowledge. Indeed, the harmdoers shall have no helpers.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
When Our clear verses are recited to them, you will recognize denial upon the faces of the unbelievers. They nearly rush upon those who recite Our verses to them. Say: 'Shall I tell you what is worse than that' The Fire which Allah has promised those who disbelieve an evil arrival'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
People, this is a parable, listen to it. Those whom you call upon, other than Allah, could never create a fly, though they banded together to do this. And if a fly robs them of anything, they could never rescue it from it. The seeker and the sought are alike in their weakness.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They do not value Allah as He should be valued. For Allah is Powerful and Mighty.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooses Messengers from angels and from people. Allah is the Hearer, the Seer.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows what is before them and behind them. To Allah all things are returned.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O you who believe, bow down and prostrate yourselves. Worship your Lord and do good, in order that you prosper.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
Struggle for Allah as is due to Him. He has chosen you and has not laden a burden upon you in your religion, being the Creed of Abraham your father. He has named you Muslims before and in this so that the Messenger (Muhammad) can be a witness for you, and in order that you be witnesses against mankind. Therefore, establish the prayer and pay the obligatory charity and hold fast to Allah. He is your Guardian, the Excellent Guardian, the Excellent Helper!\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Prosperous are the believers,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
who are humble in their prayers;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
who turn away from idle talk;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
who give charity,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
who guard their privates,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
except with their wives and what their right hand possess, and then they are not blamed.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
Those who seek beyond that are transgressors.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
(Prosperous are those) who preserve their trusts and pledges\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
and those who observe their prayers.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
Those are the heirs\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
who will inherit Paradise; they shall live there for ever.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
We created the human from an essence of clay:\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
then We made him, a drop, in a secure receptacle (the womb).\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
Then We created of the drop, a clot (of congealed blood) and We created the clot into bitesize tissue, then We created the bitesize tissue into bones, thenWe clothed the bones with flesh, and then produced it an other creation. Blessed is Allah, the Best of creators!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
After that you shall surely die,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
and be resurrected on the Day of Resurrection.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
We have created seven ways above you; of Our creation, We are never inattentive.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
We sent down water from the sky in due measure, and lodged it in the earth, and We are able to take it all away.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
With it, We produced for you gardens of palms and vines, yielding abundant fruit for you to eat.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
Also, a tree which grows on the Tor of Sinai and gives oil and relish for its eaters.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
In the cattle, too, is a lesson for you. We let you drink of that which is in their bellies, and there are many benefits in them for you, and you eat of them,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
and upon them and on the ships you are carried.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
We sent Noah to his nation. 'Worship Allah, my nation' he said, 'for you have no god except He. Will you not be cautious'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
The unbelieving assembly of his nation said: 'This is but a human like you, who desires to gain superiority over you. Had Allah willed, He could have sent down angels. We never heard of this among our ancient forefathers.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
He is nothing else except a man who is mad, so watch him for awhile.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
He (Noah) said: 'Lord, help me, for they belie me'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcc{%
We said to him: 'Make the Ark under Our Eye, and Our Revelation, and then when Our command comes and the oven gushes water, take onboard a pair from every kind and your family, except him against whom the decision has already been passed. Do not address Me concerning those who have done evil; they shall be drowned.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcci{%
And when you and all those with you are seated in the Ark, say: 'Praise be to Allah who has saved us from the harmdoing nation'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say: 'Lord, let me land a blessed landing. You are the Best of harborers'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Surely, in that are signs, and surely We will put (nations) to the test.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then We produced after them another generation\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdccv{%
and We sent to them a Messenger from themselves, saying: 'Worship Allah, for you have no god except He. Will you not be cautious'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
The unbelieving assembly of his nation, who belied the encounter of the Everlasting Life, and on whom We had bestowed ease in this life, said: 'This is but a human like yourselves; he eats of what you eat and drinks of what you drink.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
If you obey a mortal like yourselves, you shall be lost.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
What, does he promise you that when you are dead and turned to dust and bones, you will be brought forth?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdccix{%
After, after with that which you are promised!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdccx{%
There is nothing but our present life; we die, and we live, and we shall not be resurrected.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
He is nothing but a man who has forged against Allah a lie, we will never believe him'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said: 'Help me, Lord, they belie me'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
He replied: 'Before long, by the morning, they shall be remorseful'\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
And the Cry seized them in justice and We made them withered. So begone with the harmdoing nation.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
After them We produced other generations\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
no nation outstrips its term, nor do they put it back.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then We sent Our Messengers in succession. Yet whenever its Messenger came to a nation they belied him, so We made them follow others, and We made them but as tales, so begone the nation who did not believe!\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Moses and his brother Aaron with Our signs and clear authority\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
to Pharaoh and his Council, but they were very proud, and they were a tyrannical nation.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
'What' they said, 'are we to believe in two mortals like us, whose nation are our worshipers'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they belied them, and they were among the destroyed.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And We gave Moses the Book, in order that they might be guided.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
We made the son of Mary and his mother a sign, and gave them a refuge on a hillside where there was a hollow and a spring.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
Messengers! Eat of that which is good and do good deeds; I have knowledge of the things you do.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
Your nation is but one nation, and I am your Lord, therefore fear Me.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
Yet they have split their affairs between themselves into sects, each rejoicing in what it has.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
Leave them in their perplexity for a time.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Do they think that in giving them wealth and children\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We hasten in good works for them? No, they are not aware.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Those who tremble in fear of their Lord,\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
who believe in the verses of their Lord;\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
who associate none with their Lord,\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
who give what they give, with their hearts quaking, that they will return to their Lord:\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
those, hasten in good works, outracing to them.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
We charge no soul with more than it can bear. We have a Book with Us which speaks the truth, and they shall not be wronged.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
But their hearts are in ignorance of this (Koran); and they have deeds besides that which they are doing.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
But when We seize with the punishment those of them that live in ease, they groan.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
(We shall say): 'Do not groan today, surely you shall receive no help from Us'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
My verses were recited to you, but you turned upon your heels,\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
being proud against it, talking foolishness by night.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Should they not think upon the saying? Or, did anything come upon them that had not come upon their ancient forefathers?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or, is it because they do not recognize their Messenger that they denied him?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Do they say he is mad! No, he came to them with the truth, but most of them hate the truth.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
Had the truth followed their fancies, the heavens, the earth, and all who live in them would have surely been corrupted. No, We brought them theirRemembrance; but from their Remembrance they turn away.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or, do you ask a tribute from them? Your Lord's tribute is better. He is the Best of providers.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
Indeed you are calling them to a Straight Path,\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
but those who disbelieve in the Everlasting Life deviate from the Path.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
If We had mercy on them and removed their afflictions, they would still persist in their insolence, blindly wandering.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
Already We have seized them with the punishment, but they neither humbled themselves to their Lord, nor did they beseech Him,\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdccl{%
when We opened on them a gate of severe punishment, they utterly despaired.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdccli{%
It was He who produced for you hearing, eyes, and hearts, yet little is that you thank.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
It was He who scattered you on the earth, and before Him you shall be gathered.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
It is He who revives and makes to die, and to Him belong the alternation of the night and the day. Will you not understand!\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
No, but they said what the ancients said before them:\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
'When we are dead and become dust and bones shall we be resurrected?\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
We and our fathers have been promised this before. It is but of the ancients' fictitious tales'\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say: ``If you have knowledge, 'to whom belongs the earth' and, 'whoever is in it? '"\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will say: 'To Allah' Say: 'Then will you not remember'\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say: 'Who is the Lord of the seven heavens, and of the Great Throne'\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will say: 'Allah' Say: 'Will you not be cautious'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say: 'In whose Hands is the Kingdom of all things, He protects, and none protects against Him, if you have knowledge'\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
'Allah' they will reply. Say: 'How then can you be so bewitched'\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
No, We have brought the truth to them, but they are liars.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
Allah has not taken to Himself any son, there is no other god with Him. Were this otherwise each god would have taken that which he created, and some ofthem would have risen above others; Exalted is Allah beyond that they describe!\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
(He is) the Knower of the Unseen and the Seen, High Exalted be He above that they associate.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say: 'Lord, if You should show me that which they are promised,\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
O my Lord, do not put me among the harmdoing people'\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
Indeed, We are able to show you that which We promised them.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel evil with that which is better. We know that which they describe.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say: 'O my Lord, I seek refuge in You from evil suggestions of the satans.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
O my Lord, I seek refuge in You lest they attend me'\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
Until, when death comes to one of them he says: 'My Lord, let me go back,\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
that I should do righteousness in that I forsook' No! It is only a word which he will speak. Behind them there shall stand a barrier till the Day that they shall be resurrected.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
And when the Horn is blown, on that Day their ties of kindred shall be no more, nor will they ask each other.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Those whose scales are heavy shall prosper,\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
but those whose scales are light shall forfeit their souls and live in Gehenna (Hell) for ever.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The fire lashes their faces and therein are shriveled lips.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
(We shall say): 'Were My verses not recited to you, and did you not belie them'\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
'Lord' they will reply, 'adversity prevailed over us and we were erring.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
Our Lord, bring us out of it. If we return (to sin), then we shall indeed be harmdoers'\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
He will say: 'Slink there in it and do not speak to Me'\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
Among My worshipers there were a party who said: ``Lord, we believed. Forgive us and have mercy on us: You are the Best of the merciful."\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
But you took them for laughingstock, mocking at them, until they caused you to forget My remembrance.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Today I shall recompense them for their patience, for it is they that have won.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
And He will ask: 'How many years did you live on earth'\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will reply: 'A day, or part of a day; ask those who have kept count'\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say: 'You have tarried a little, did you know?\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
Did you think that We had created you only for play, and that you would never be returned to Us'\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
High Exalted be Allah, the King, the Truth. There is no god except He, the Lord of the Noble Throne.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
Whosoever calls upon another god, other than Allah, having no proof his reckoning will be with his Lord. The unbelievers shall never prosper.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And say: 'My Lord, forgive and have mercy, for You are the Best of the merciful'\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen This is a chapter which We have sent down and appointed; and in it We have sent down clear verses in order that you will remember.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
You shall lash the fornicatress and the fornicator each with a hundred lashes. In the religion of Allah, let no tenderness for them seize you if you believe in Allah and the Last Day; and let their punishment be witnessed by a party of believers.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The fornicator shall marry none but a fornicatress or an idolatress; and the fornicatress none shall marry her but a fornicator or an idolater; that is forbidden to the believers.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
Those who accuse chaste women, and cannot produce four witnesses, you shall lash them with eighty lashes. And never accept their testimony, for they are evildoers,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
except those among them that afterwards repent and mend their ways. Allah is Forgiving, Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
And those who accuse their wives and have no witnesses except themselves, let them testify by swearing by Allah four times that he is of the truthful,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
and the fifth time, that the curse of Allah shall be upon him, if he should be of the liars.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
But the punishment will be averted from her if she swears four times that he is of the liars,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdccc{%
and on the fifth time the Wrath of Allah shall be upon her if he is of the truthful.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdccci{%
If it were not for the bounty of Allah to you and His Mercy, and that Allah turns, and is the Wise,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
those who came with the slander were a number of you. Do not regard it evil for you, rather it is good for you. Every person of them shall have the sin that he has earned charged to him. As for he who took upon himself the greater part there is a mightier punishment.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Had you heard it, and the believing men and women, thought good thoughts about one another said: 'This is a clear falsehood'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why, did they not bring four witnesses against it? But since they did not bring the witnesses, before Allah they are the liars.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
But for the bounty of Allah and His Mercy towards you in this life and in the Everlasting Life you would have been sternly punished for that which you were involved.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
You carried with your tongues and uttered with your mouths what you did not know. You have thought it a trifle, but before Allah it was a mighty thing.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
When you heard it, why did you not say: 'It is not right for us to speak of this. Exaltations to You! This is a mighty slander'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah exhorts you never again to repeat the like, if you are believers.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
Allah makes plain to you His verses, and Allah is the Knower, the Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Those who love that indecency should be broadcast about those who believe theirs is a painful punishment in this world and in the Everlasting Life. Allah knows, and you do not know.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
If it was not for the bounty of Allah to you and His Mercy, and Allah is the Gentle, the Most Merciful.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
Believers, do not follow in the steps of satan, for those who follow the steps of satan, he bids to indecency and dishonor. But for the bounty of Allah to you, and His Mercy no one of you would ever have been purified; but Allah purifies whom He will; Allah is the Hearer, the Knower.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
Do not let those of you who possess bounty and plenty swear not to give kinsmen, and the poor, and those who emigrate in the way of Allah. Let them pardon and forgive. Do you not yearn that Allah forgives you? And Allah is the Forgiver, the Most Merciful.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Surely, those who defame chaste, unsuspecting, believing women, shall be cursed in this world and in the Everlasting Life, and for them there is a mightypunishment.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On the Day when their tongues, hands and feet shall testify against them concerning what they were doing.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
Upon that Day Allah will pay them their due in full, and they will know that Allah is the clear truth.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Evil women for evil men, and evil men for evil women; good women for good men, and good men for good women these are clear of what has been said; for them is forgiveness, and a generous provision.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
Believers, do not enter houses other than your houses until you first ask permission and greet with peace the people thereof; that is better for you in order that you remember.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
And if you do not find anyone there, do not enter it until permission is given to you. And if you are told 'Return', so return, that is purer for you; and Allah knows the things you do.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
There is no fault in you that you enter uninhabited houses wherein there is benefit for you. Allah knows what you reveal and what you hide.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Say to the believers they should lower their gaze and guard their private parts that is purer for them. Allah is Aware of the things they do.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And say to the believing women, that they lower their gaze cast down their eyes and guard their chastity, and do not reveal their adornment except that which is outward (face and hands); and let them draw their veils over their neck, and not reveal their adornment except to their husbands, or their fathers, or their husbands' fathers, or their sons, or their husbands' sons, or their brothers, or their brothers' sons, or their sisters' sons, or their women, or what their right hands own, or such male attendants having no sexual desire, or children who have not yet attained knowledge of women's private parts; nor let them stamp their feet, so that their hidden ornament is known. And, O believers turn to Allah all together, in order that you prosper.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
Marry those among you who are spouseless and the virtuous among your male and female slaves (thereby freeing them), if they are poor, Allah will enrichthem of His bounty; Allah is Embracing, Knowing.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
Let those who do not find the means to marry be abstinent until Allah enriches them of His bounty. Those your right hand owns who seek their freedom, make a contract with them accordingly if you know some good in them, and give them from the wealth of Allah that He has given you. Do not force your slavegirls into prostitution in order to seek worldly gain for they wish to preserve their chastity. Whosoever compels them, surely Allah, after their being compelled, is the Forgiver (to the girls), the Most Merciful.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
Now We have sent down to you clarifying verses, and an example of those who passed away before you and admonition to the cautious.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the Lighter of the heavens and the earth. The example of His Light is like a tube, in which there is a wick. The wick is in a lamp and the lamp is as a glittering planet kindled from a Blessed Tree, an olive that is neither of the East nor of the West. Its oil would almost shine forth though no fire touched it. Light upon light; Allah guides to His Light whom He will. Allah strikes parables for people. Allah has knowledge of all things.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
In houses which Allah has allowed to be raised up, and His Name to be remembered therein. In the morning and evening\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
are men who exalt Him there, whom neither trade nor sale can divert from the remembrance of Allah, and establish the prayers, and pay the obligatorycharity; fearing a Day when hearts and eyes shall be turned about,\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
that Allah will recompense them for the finest deeds they did and increase them from His bounty. Allah provides without measure to whom He will.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
As for the unbelievers, their works are like a mirage in the wilderness. The thirsty person thinks it is water, but when he comes near he finds that it is nothing. He finds Allah there, who pays him his account in full. Allah is Swift in reckoning.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or, they are like darkness upon a deep sea covered with a wave above which is another wave, above which are clouds, darkness piled one upon the other; when he stretches out his hand he can scarcely see it. Indeed, to whomsoever Allah assigns no light, he shall have no light.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Have you not seen how Allah is exalted by those in the heavens and earth, and the birds with outspread wings? He knows its prayers and its exaltations and Allah has knowledge of the things they do.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
To Allah belongs the Kingdom of the heavens and the earth. To Him is the arrival.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
Have you not seen how Allah drives the clouds, then gathers them and converts them into a mass, then you see rain coming from the midst of them? And He sends down out of heaven mountains in which there is hail, pelting with it whom He will, and turning it away from whom He will. The flash of its lightning almost snatches away the sight.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
Allah turns about the night and the day (to succeed one another); surely, in this there is a lesson for those who have eyes.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
Allah created everything that walks from water. Some creep upon their bellies, others walk on two feet, and others walk on four. Allah creates whatever He will. Allah is Powerful over everything.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
We have sent down clarifying verses. Allah guides whom He will to a Straight Path.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
They say: 'We believe in Allah and the Messenger and obey' But a party of them turn away after this. Those are not believers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
And when they are called to Allah and His Messenger so that he judges between them, a party of them swerve away.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
If the right is theirs, they would have hastened to him obediently.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Is there a sickness in their hearts, or, are they in doubt? Do they fear that Allah and His Messenger will be unjust? No, but those they are the harmdoers.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
But when the believers are called to Allah and His Messenger, in order that he judges between them, their reply is: 'We hear and obey' Such are theprosperous.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
Those who obey Allah and His Messenger, and fear Allah, and have awe of Him, shall be the winners.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
They swear by Allah in the most earnest oaths, that if you order them, they would go forth. Say: 'Do not swear, known obedience (is better). Allah is Aware of the things you do'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say: 'Obey Allah and obey the Messenger. If you turn away, upon him only rests what is laid upon him, and upon you rests what is laid on you. If you obey him, you shall be guided. It is only for the Messenger to deliver a clear message'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah has promised those of you who believe and do good works that He will indeed make them successors in the land as He made those who were before them successors, and that He will indeed establish their religion for them; that which He has approved for them, and will exchange safety for them after their fear. They worship Me and associate nothing with Me. After that, those who disbelieve are the impious.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
Establish the prayers, pay the charity, and obey the Messenger, in order to have mercy.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Never think that the unbelievers will be able to frustrate (Us) in the earth. Their refuge is the Fire, an evil arrival.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
Believers, let those your right hand owns and those who have not come of age ask permission of you three times before the dawn prayer, when you put aside your garments, in the heat of noon, and after the night prayer. These are the three occasions of privacy. There is no fault in you or them, apart from these, that they go about you, you are of each other. As such Allah makes plain to you His verses, Allah is the Knower, the Wise.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
And when children reach the age of puberty, let them ask permission as those before them asked permission. As such Allah makes clear to you His verses. Allah is the Knower, the Wise.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
(As for) women that are past childbearing who have no hope of marriage there is no fault in them that they discard their cloaks provided they do not reveal their adornments, but it is better if they abstain. Allah is the Hearer, the Knower.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
It shall be no fault for the blind, the lame, the sick and yourselves to eat from your houses. Nor the houses of your fathers', your mothers', your brothers', your sisters', your paternal uncles, your paternal aunts, your maternal uncles, your maternal aunts or in houses the keys of which you own, or in those of your friend, there is no fault in you that you all eat together, or separately. When you enter houses, greet (with peace) one another with a salutation from Allah, blessed and good. As such Allah makes clear to you His verses so that you understand.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
The believers are only those who believe in Allah and His Messenger, and who, when gathered with him upon a common matter do not depart till they have asked his permission. Surely, those who ask your permission are those who believe in Allah and His Messenger. When they ask your permission for some of their affairs, grant it to whomever you please and ask Allah for forgiveness for them; Allah is the Forgiver, the Merciful.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Do not make the calling of the Messenger among yourselves like your calling to one another. Allah knows those of you who slip away surreptitiously, so let those who disobey His command beware, lest they are struck by sedition, or, they are stricken with a painful punishment.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
To Allah belongs all that is in the heavens and the earth. He has Knowledge of what state you are upon. On the Day when they shall be returned to Him, He will tell them all what they have done. And Allah has knowledge of everything.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blessed is He who has sent down the Criterion to His worshiper (Prophet Muhammad), that he is a warner to all mankind;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
to whom the Kingdom of the heavens and the earth belongs, who has not taken a son, nor does He have an associate in the Kingdom, and He created everything, then He ordained it very precisely.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
Yet they worship, other than Him, gods which cannot create anything and were themselves created. They own neither harm nor benefit for themselves, neither do they own death nor life, nor a resurrection.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
The unbelievers say: 'This is but a falsehood he has forged? another nation has helped him' So they have come with wrong and falsehood.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
They say: 'He has written tales of the ancients, they are recited to him at dawn and at the evening'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say: 'It was sent down by Him who knows the secrets of heavens and earth. He is Forgiving, the Most Merciful.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
They also say: 'How is it that this Messenger eats food and walks about the markets? Why has no angel been sent down with him to warn us?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
Or, why has no treasure been thrown to him, or a garden for him to eat from' And the harmdoers say: 'The man you follow is surely bewitched'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
See how they strike examples for you, surely they have gone astray and are unable to find a way.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blessed be He who, if He wills, can assign you better things than these; gardens underneath which rivers flow, and He shall assign for you palaces.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
No, they belied the Hour. We have prepared for him who belied the Hour a Blaze.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it sees them from a far off place, they shall hear it raging and sighing.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when, chained in (iron) fetters, they are cast into some narrow space of the Fire, they will call out for destruction.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
'Do not call out today for one destruction; call out for many destructions'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say: 'Is that better, or the Garden of Eternity which the cautious have been promised? It is their recompense and their arrival'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
Living there for ever, they shall find in it all that they desire. That is a promise binding upon your Lord, and to be asked of Him.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
On the Day when He gathers them with all that they worship, other than Allah, He will say: 'Was it you who misled My worshipers, or did they themselves go astray'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will answer: 'Exaltations to You. We should not have taken others for a guardian, but You gave them and their fathers enjoyment until they forgot Your Remembrance and they were a destroyed nation'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
So they belie what you say, and you can neither turn it aside, nor find any help. Those of you who have done evil, We let them taste a great punishment.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
We did not send Messengers before you but that they ate food and walked about in the markets, We have appointed some of you to be a trial for others. Will you endure? Your Lord is the Seer.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
Those who do not hope to meet Us ask: 'Why have no angels been sent to us? Why can we not see our Lord' How proud they are within themselves, and have become greatly disdainful.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
On the Day when they behold the angels, there will be no glad tidings for the sinners. They will say: 'A refuge which is forbidden'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
Then We shall advance upon the work which they have done and render it as scattered dust.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
On that Day, the companions of Paradise (will have) a better abode and a finer restingplace.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
On that Day, the heaven is split asunder with clouds and the angels are sent down in majesty,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
the true Kingdom on that Day shall belong to the Merciful a harsh day for the unbelievers.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
Upon that Day the harmdoer shall bite his hands, and say: 'Would that I had taken a Path with the Messenger!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
Would that I had never chosen soandso for my companion!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
He led me astray from the Remembrance after it had reached me, satan is ever the foresaker of humans'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
The Messenger says: 'O my Lord, my people have taken this Koran while deserting it'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
To every Prophet We have appointed an enemy among the harmdoers; your Lord is Sufficient for you, a Guide and a Helper.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
The unbelievers ask: 'Why was the Koran not sent down to him all at once' As such We strengthen your heart thereby, and We have recited it very distinctly.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
They do not bring to you any parable but that which We bring to you is the truth and better in explanation.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
Those who will be gathered into Gehenna (Hell) upon their faces shall be in the worst in place, and have gone further astray from the Path.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
We gave the Book to Moses and gave him his brother Aaron as a minister.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
(Then) We said: 'Go to the nation who have belied Our signs' And We utterly destroyed them.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
The nation of Noah, We drowned them when they belied their Messenger, and made of them a sign to the nation. For the harmdoers We have prepared a painful punishment\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
also to Aad and Thamood and the nation of ErRass and many generations in between;\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
to each of them We gave examples, and each of them We utterly ruined.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
They have surely passed by the village which was rained upon by evil rain (of stones); what, have they never seen it? No, they look for no resurrection.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
Whenever they see you, they mock you (saying): 'Is this whom Allah has sent as a Messenger?\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
He would have mislead us from our gods, if we had not been steadfast to them' But they shall know who is further astray from the Path when they see the punishment.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Have you seen him who has made gods of his own desires? Would you be a guardian over him?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Do you think that most of them can hear or understand? They are like cattle, no, they are further astray from the Path.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcm{%
Do you not see how your Lord stretches the shadow? Had it been His will, He could have made it constant. Then He appointed the sun to be a guide to it;\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcmi{%
thereafter We seize it to Us withdrawing it gently.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcmii{%
It is He who has appointed the night a mantle for you and sleep for a rest. The day He has appointed for rising.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
It is He who loosens the winds, bearing glad tidings before the Hands of His Mercy, and We have sent down pure water from the heaven,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
so, that with it We revive dead lands and provide drink for the cattle and the human We created.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcmv{%
We have indeed turned it about them, so that they remember; yet most people refuse all except disbelief.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
Had it been Our will, We could have raised a warner in every village.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So do not obey the unbelievers, but struggle mightily with it (the Koran).\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
It was He who let forth the two seas, this one is palatably sweet and this salt, a bitter taste, and He set a barrier between them, and a refuge which is forbidden.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He who created the human from water and gave him kindred of blood and of marriage. Your Lord is the Powerful.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcmx{%
Yet they (the unbelievers) worship, other than Allah, that which can neither benefit nor harm them. Surely, the unbeliever is ever a partisan against his Lord.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
We did not send you but as a bearer of glad tidings and as a warner.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say: 'I demand of you no wage for this except for he who wishes to take the Path to his Lord'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
Put your trust in the All Living who never dies, and exalt with His praise, He is sufficiently aware of His worshipers' sins.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
(It is) He who, in six days created the heavens and the earth and all that lies between them, and then He willed to the Throne. The Merciful; ask about Him from he who knows Him.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
When it is said to them: 'Prostrate yourselves before the Merciful', they ask: 'And what is the Merciful? Shall we prostrate ourselves to whatever you bid us' And it increases their aversion.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blessed be He who has set the constellations in the heaven, and set amongst them a sun, and an illuminating moon.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
It is He who has made the night and day follow each other for those whom He desires to remember or He desires to be thankful.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
The worshipers of the Merciful are those who walk humbly on the earth, and when the ignorant address them say: 'Peace'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
who pass the night prostrating and standing to their Lord.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
Who say: 'Our Lord, turn from us the punishment of Gehenna, for its punishment is the most terrible;\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
it is an evil settling, and an evil residence'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
who when they spend are neither wasteful nor miserly, between that is a just stand,\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
who do not call upon another god with Allah, nor slay the soul which Allah has forbidden except by right; who do not fornicate, for he who does this shall face punishment\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
doubled for him on the Day of Resurrection is his punishment, and therein he shall live, humbled,\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
except he who repents and believes and does good works those, Allah will change their evil deeds into good deeds; Allah is ever Forgiving and Merciful.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
He who repents and does good works truly turns to Allah in repentance,\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
and those who do not bear false witness, and when they pass by idle talk, pass by with honor\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
and who when they are reminded of the verses of their Lord, they do not fall down deaf and blind.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
Those who say: 'Lord give us of our wives and children what pleases our eyes and make us leaders to the fearful'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Those shall be recompensed with the highest rank for their patience. There they shall receive a greeting, and peace!\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
There they shall live for ever; a fine dwelling place, and residence.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say: 'My Lord cares little for you if it was not for your supplication, indeed you have belied (the Messenger and the Koran) so it (the punishment) will be fastened'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen TaSeenMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
Those are the verses of the clear Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
Perhaps you consume yourself that they are not believers.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We will, We can send down on them a sign from heaven before which their necks will remain humbled.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
A fresh remembrance has never come to them from the Merciful, except they turn away from it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
So, they belied, but surely the tidings of that they mocked will come to them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Have they not seen the earth, how many We caused to grow in it every generous kind?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Surely, in this there is a sign yet most of them do not believe.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
Your Lord, He is the Almighty, the Most Merciful.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
And when your Lord called to Moses, saying: 'Go to the harmdoing nation,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
the nation of Pharaoh. Will they not fear Me'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
'My Lord' he replied, 'I fear they will belie me\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
and my chest will become constricted and my tongue will not be loosed (in my speech), therefore, send to Aaron.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
They hold a sin against me, and I fear that they will kill me'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
He said: 'Never so, go both of you with Our signs; We shall be with you, listening\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
go both to Pharaoh and both of you say to him: 'We are (each) a Messenger from the Lord of all the Worlds.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
Send forth with us the Children of Israel'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmcml{%
He (Pharaoh) said (to Moses): 'Did We not bring you up when you were a child? And have you not spent years of your life amongst us?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmcmli{%
Yet you were ungrateful and have done the deed you did'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
He (Moses) replied: 'Indeed, I did that when I was among those who stray.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
I fled from you because I feared you. But my Lord has given me judgment and made me one of the Messengers.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
Is this then the blessing with which you reproach me, that you have the Children of Israel for worshipers'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Pharaoh said: 'And what is the Lord of the Worlds'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
'He' (Moses) replied: 'is the Lord of the heavens and the earth and all that is between them, if you believe'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
'Do you not hear' said he (Pharaoh) to those around him.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
He said, 'Your Lord and the Lord of your fathers, the ancients'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
(Pharaoh) said: 'Surely, the Messenger who has been sent to you is mad!'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
'He is the Lord of the East and the West' said he (Moses), 'and all that is between them, if you could understand'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
'If you take any other god except myself' he (Pharaoh) replied, 'you shall be thrown into prison'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
'What, even if I brought you something clear' said he (Moses).\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
He (Pharaoh) replied: 'Show us your sign, if you are of the truthful'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
He cast down his staff and thereupon it was a clear serpent.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
Then he drew out his hand, and it was luminous to the onlookers.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
'This', said he (Pharaoh) to his Council, 'is a cunning sorcerer\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
who seeks to expel you from your land by his sorcery. What is your counsel'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They replied: 'Put him and his brother off for a while, and send heralds to your cities\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
to bring every knowledgeable sorcerer'\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
The sorcerers were gathered at the appointed time on a wellknown day,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
and the people were asked: 'Will you gather\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
in order that we shall follow the sorcerers if they are the victors'\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
Then, when the sorcerers came to Pharaoh, they said: 'Shall we receive a wage if we win'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
'Yes, indeed' he answered, 'and you shall become among those who are near stationed'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Moses said to them: 'Cast down what you cast'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
So they cast their ropes and staffs, saying: 'By Pharaoh's might, we shall be the victors'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Moses cast down his staff and it swallowed up their lying invention,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
so the sorcerers were cast down, prostrating themselves,\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
saying: 'We believe in the Lord of the Worlds,\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
the Lord of Moses and Aaron'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
He (Pharaoh) said: 'You have believed him before I have given you permission. He is the chief of you who has taught you sorcery. But you shall know. I will surely cut off on opposite sides a hand and a foot, and crucify you all.'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
'There is no harm' they replied, 'for surely to our Lord we are turning.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
We are eager that Our Lord should forgive us our offenses, for we are the first of the believers'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
Also, We revealed to Moses, saying: 'Go with My worshipers by night, for you will be followed'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Pharaoh sent gatherers to the cities.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
'These' they said, 'are a small band,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
they have enraged us,\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
and we are a host on our guard'\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
As such We expelled them from their gardens and their fountains,\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
their treasures and a noble station.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
As such we gave it to the Children of Israel.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
At sunrise, they followed them.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
And when the two hosts came in view of each other, Moses' companions said: 'We have been reached'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
'No, indeed' he replied, 'my Lord is with me and He will guide me'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We revealed to Moses: 'Strike the sea with your staff', so it divided and each part was as a mighty mount.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
And there We brought the others on,\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
and We saved Moses and those who were with him together,\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
then, We drowned the others.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Surely, in that there is a sign; yet most of them do not believe.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmm{%
Surely, your Lord is the Almighty, the Most Merciful.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmi{%
And recite to them the news of Abraham.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmii{%
He said to his father and to his nation: 'What do you worship'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They replied: 'We worship idols and continue cleaving to them'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmiv{%
'Do they hear you when you call on them' He asked.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmv{%
'Can they benefit you or harm you'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They replied: 'No, but we found our fathers doing so'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said: 'Have you considered what you worship,\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmviii{%
you, and your elderly fathers?\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmix{%
They are enemies to me except the Lord of all the Worlds\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmx{%
who created me; and He guides me,\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmxi{%
and He gives me to eat and drink,\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmxii{%
who, when I am sick, heals me;\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
who makes me to die and then revives me,\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
and whom I am eager shall forgive me my sins on the Day of Recompense'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmxv{%
My Lord, give me judgment, and join me with the righteous.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
And appoint me a tongue of truthfulness among the latter.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
and place me amongst the inheritors of the Garden of Bliss.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
and forgive my father, for he was among the astray.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmxix{%
Do not degrade me on the Day when they are resurrected.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmxx{%
The Day when neither wealth nor sons shall benefit\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
except him who comes before Allah with a pure heart;\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
and Paradise shall be brought forward to the cautious.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
And Hell is brought near to the perverse'\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
It will be said to them: 'Where is that you worshipped,\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
other than Allah? Do they help you or even help themselves'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
And they will be pitched into it, they and the perverse\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
and the hosts of iblis all together.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
And they will say while they dispute with one another,\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
'By Allah, we were certainly in clear error,\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
when we made you equal with the Lord of the Worlds.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
It was nothing but the evildoers who led us astray.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
We have no intercessors now,\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
no caring friend.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
Would that we might return again, and be among the believers'\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Surely, in that there is a sign, yet most of them do not believe.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
Surely, Your Lord is the Almighty, the Most Merciful.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The nation of Noah, belied their Messengers.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
when Noah, their brother, said to them: 'Will you not be cautious?\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
I am for you an honest Messenger,\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmmxl{%
so fear Allah, and obey me.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmmxli{%
For this I ask of you no wage, for my wage falls only on the Lord of the Worlds.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
So fear Allah and obey me'\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They replied: 'Are we to believe you whom the lowliest follow'\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said: 'I have no knowledge of what they have done.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
Their account falls only upon My Lord, if you were but aware.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
I will not drive away the believers.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
I am only a clear warner'\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
'Noah' they replied, 'if you do not desist you shall be of those stoned'\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said: 'My Lord, my nation have belied me.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmml{%
So open between me and them an opening, and save me and the believers who are with me'\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmmli{%
We saved him and those who were with him in the laden ship,\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmmlii{%
afterwards, We drowned the rest.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Surely, in that there is a sign; yet most of them do not believe.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmmliv{%
Your Lord is the Almighty, the Most Merciful.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmmlv{%
(The nation of) Aad belied their Messengers.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
When their brother Hood said to them: 'Will you not be cautious?\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
I am for you an honest Messenger.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
Fear Allah and obey me.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmmlix{%
For this I ask of you no wage, for my wage falls only on the Lord of the Worlds.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmmlx{%
Do you build over each high place a sign to amuse yourselves!\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
And do you take to yourselves underground reservoirs, in order to live for ever!\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
When you assault, you assault like tyrants.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
So fear Allah, and obey me.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
Fear Him who has given you all the things you know.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
He has given you flocks and sons,\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
gardens and fountains.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
Indeed, I fear for you the punishment of a dreadful Day'\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They replied: 'It is the same to us whether you admonish or whether you are not one of the admonishers.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
That is nothing but a habit of the ancients,\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
and we shall never be punished'\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
So they belied him, so We destroyed them. Surely, in that there is a sign; yet most of them do not believe.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
Surely, your Lord is the Almighty, the Most Merciful.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
Thamood, belied their Messengers.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
Their brother Salih said to them: 'Will you not be cautious?\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
I am for you an honest Messenger.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
So fear Allah, and obey me.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
For this I ask of you no wage; my wage falls only upon the Lord of the Worlds.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
Will you be left secure in this,\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
amidst gardens and fountains,\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
sown fields and palmtrees, with slender spathes.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
Will you still hew your dwellings in the mountains?\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
So fear Allah and obey me.\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
Do not obey the order of the wasteful,\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
who corrupt in the earth, and do not reform'\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They replied: 'Surely, you are one of those bewitched.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
You are but a human like ourselves. Produce for us a sign, if you are of the truthful'\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said: 'Here is a shecamel. She shall have her share of water as you have yours on an appointed day.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
Do not touch her with malice so that punishment of a dreadful day seizes you'\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
Yet they hamstrung her, and in the morning they were remorseful,\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mmmxc{%
and the punishment seized them. Surely, in that there is a sign. Yet most of them do not believe.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mmmxci{%
Your Lord, He is the Almighty, the Most Merciful.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
Lot's nation, belied their Messengers.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
When their brother Lot said to them: 'Will you not be cautious?\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
I am for you an honest Messenger.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
So fear Allah, and obey me.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
I ask of you no wage for this; my wage is only with the Lord of the Worlds.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
What, do you come to the males of the world,\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
and leave your wives whom your Lord has created for you? No, but you are a transgressing nation'\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
'Lot' they replied, 'if you do not desist, you shall be thrown out'\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said: 'Truly, I am a detester of what you do'\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mmmci{%
'My Lord, save me and my people from that they are doing'\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So We saved him and all his people,\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mmmciii{%
except an old woman who stayed behind,\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mmmciv{%
then We destroyed the others.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mmmcv{%
We rained upon them a rain, and evil is the rain (of stones) on those that are warned.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Surely, in that there is a sign. Yet most of them do not believe.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
Your Lord, He is the Almighty, the Most Merciful.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The dwellers of the Thicket belied their Messengers.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mmmcix{%
Shu'aib said to them: 'Will you not be cautious?\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mmmcx{%
I am for you an honest Messenger.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
So fear Allah, and obey me.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
I ask of you no wage for this; my wage is only with the Lord of the Worlds.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
Fill up the measure, do not be among the cheats,\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
and weigh with the straight scale,\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
and do not diminish the goods of the people, and do not make mischief in the earth, working corruption.\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
Fear He who created you, and the generations of the ancient'\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They replied: 'You are surely one of those bewitched.\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
You are but a human like ourselves, we think that you are one of the liars.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
Drop down on us lumps from heaven, if you are one of the truthful'\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said: 'My Lord knows what you are doing'\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
But they belied him, then the punishment of the Day of Shadow (raining fire) seized them. Truly, it was the punishment of a dreadful day.\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Surely, in that there is a sign; yet most of them do not believe.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
Your Lord, He is the Almighty, the Most Merciful.\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
Truly, it is the sending of the Lord of the Worlds.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
The honest Spirit (Gabriel) brought it down\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
upon your heart (Prophet Muhammad), in order to be one of the warners,\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
in a clear, Arabic tongue.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
Truly, it is in the Books of the ancients.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Was it not a sign for them known to the learned of the Children of Israel?\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
If We had revealed it to a nonArab,\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
and he had recited it to them, they would not have believed.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Even so, We have caused it to enter into the hearts of harmdoers:\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
they shall not believe in it until they see the painful punishment\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
so that it will come upon them suddenly, while they are unaware,\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
and then they will say: 'Shall we be respited'\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
Do they wish to hasten Our punishment?\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
What do you see? If We gave them enjoyment for years,\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
and then what they were promised comes to them,\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
what avail will their past enjoyments be to them?\qt@no{(207)}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
We never destroyed a village that did not have warners\qt@no{(208)}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
for a reminder, and We never harmed.\qt@no{(209)}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
It was not the satans who brought it down:\qt@no{(210)}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
it is not for them, nor are they able.\qt@no{(211)}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Truly, they are expelled from hearing.\qt@no{(212)}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So do not call upon another god with Allah, lest you should be one of those who are punished.\qt@no{(213)}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
Warn your tribe and your near kinsmen.\qt@no{(214)}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
and lower your wing to the believers who follow you.\qt@no{(215)}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
If they disobey you, say: 'I am quit of what you do'\qt@no{(216)}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
Put your trust in the Almighty, the Most Merciful,\qt@no{(217)}}%
\qt@newcmd\qurantrans@en@mmmcl{%
who sees you when you stand\qt@no{(218)}}%
\qt@newcmd\qurantrans@en@mmmcli{%
and when you turn among those who prostrate themselves.\qt@no{(219)}}%
\qt@newcmd\qurantrans@en@mmmclii{%
Surely, He is the Hearer, the Knower.\qt@no{(220)}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I tell you on whom the satans descend?\qt@no{(221)}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend on every guilty impostor.\qt@no{(222)}}%
\qt@newcmd\qurantrans@en@mmmclv{%
They listen, but most of them are liars.\qt@no{(223)}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
Poets are followed by the perverse.\qt@no{(224)}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
Have you not seen how they wander in every valley,\qt@no{(225)}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
and they say what they do not do?\qt@no{(226)}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Except those who believe, and do good works and remember Allah in abundance and became victorious after they had been wronged. The wrongdoers will surely know which turn they will be returning to (Hell).\qt@no{(227)}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen TaSeen. Those are the verses of the Koran, a clear Book,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
a guidance and glad tidings to believers,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
who establish their prayers, and pay the obligatory charity, and are certain of the Everlasting Life.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
As for those who do not believe in the Everlasting Life, We have decorated for them their works, and they wander blindly.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
Such are those for whom there is an evil punishment, and in the Everlasting Life are the greatest losers.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
You have received the Koran from the Wise, the Knower.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
When Moses said to his household: 'Indeed, I can see a fire far away. I will go and bring you news of it or I will bring you a lighted flame so that you can warm yourselves'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
And when he came near it he was called: 'Blessed be who is (Moses) in the fire and (the angels) who are around it! Exaltations to Allah, Lord of the Worlds!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
Moses, it is I, Allah, the Almighty, the Wise.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
Cast down your staff' And when he saw it writhing like a serpent, he turned about retreating, and did not turn back. 'Moses, do not fear, indeed theMessengers do not fear (when they are) with Me,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
except he who has done evil, then, after evil, has changed into good. I am the Forgiving, Most Merciful.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
Put your hand inside your collar and it will come out luminous without evil? among the nine signs to Pharaoh and his nation, indeed they were an impious nation'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
But when Our signs came to them visibly, they said: 'This is plain sorcery.'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
They denied them unjustly out of pride, though their souls acknowledged them. See, how was the end of the corrupt workers!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
We gave knowledge to David and Solomon. They said: 'Praise be to Allah who has preferred us above many of His believing worshipers'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
Solomon inherited David. He said: 'Know, my people, we have been taught the speech of birds and given everything. Surely, this is a clear bounty'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
We gathered to Solomon his army of jinn, humans and birds; gathered and dispersed,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
and when they came to the Valley of the Ants, an ant said: 'Ants, go into your dwellings lest Solomon and his army should, unknowingly, crush you'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
He smiled, and laughed at its words, and said: 'My Lord, inspire me that I should be thankful for Your blessing with which You have blessed me and my parents, and that I may do good works that will please You. Admit me, by Your Mercy, among Your righteous worshipers'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
He reviewed the birds and said: 'Why is it that I do not see the hoopoe here? Or is he among the absent?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
Surely, I will punish him with a terrible punishment, or I will slaughter him or he gives me a good reason'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
He was not long in coming, and said: 'I know what you do not know. I come to you from Sheba with certain news.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
There I found a woman ruling over them. She possess everything and has a great throne.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
But she and her people prostrate to the sun instead of Allah. And satan has made their deeds seem pleasing to them and barred them from the Path, and therefore they are not guided.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
Do they not prostrate themselves to Allah who brings forth all that is concealed in the heavens and earth and He knows what they hide and what they reveal?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
Allah, there is no god except He, the Lord of the Mighty Throne'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
He replied: 'We shall see if what you have said is true or whether you are among those who lie.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
Take my letter, and drop it to them. Then turn aside and see what they shall return'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
She (the Queen of Sheba) said: 'O Council, look, an honorable letter has been dropped to me.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
It is from Solomon and it is ``In the Name of Allah, the Merciful, the Most Merciful.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
Do not rise up against me, but come to me in surrender (Muslims)."\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said: 'O Council, let me hear your counsel, concerning my affairs, for I am not used to deciding an affair until you bear me witness'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They replied: 'We are possessors of force and great might. It is for you to command, so consider what you will'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said: 'When kings enter a village, they ruin it and humiliate its nobles. And this they will do.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
But I shall send them a gift and see what the messengers bring back'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
But when he came to Solomon, he said: 'Is it wealth that you would give me, when Allah has given me that which is better than He has given to you? No, but instead you rejoice in your gift!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
Go back then, we shall surely come against them with soldiers of which they have no power to oppose, and we shall drive them from there abased and humiliated'\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
And he said: 'O Council, which of you will bring me her throne, before they come to me, Muslims (submissive to Allah)'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
An efreet (an extremely strong jinn) among the jinn replied: 'I will bring it to you before you rise from your place; I have the strength and am trustworthy'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
But he who had knowledge of the Book, said: 'I will bring it to you before your glance comes back to you' And when he saw it set before him, he (Solomon) said: 'This is a favor from my Lord that He might test me whether I am thankful or ungrateful. Whosoever gives thanks gives thanks only for his (own soul's) good, but he who is ungrateful, truly my Lord is Rich and Generous'\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmcc{%
(Then) he said: 'Let her throne be disguised, so that we can see whether she is guided or if she is among those who are not guided'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmcci{%
And when she came she was asked: 'Is your throne like this' And she replied: 'It looks like it' And we were given the knowledge before her, and wereMuslims.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccii{%
That which she worshipped, other than Allah, had prevented her, for she came from an unbelieving nation.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
It was said to her: 'Enter the pavilion' And when she saw it, she thought it was a pool of water, and bared her legs. But he said: 'It is a pavilion smoothed with crystal' She said: 'My Lord, I have wronged myself, and I become a Muslim (submissive) with Solomon to Allah, Lord of the Worlds'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
To Thamood We sent their brother Salih saying: 'Worship Allah' But they were two parties in dispute with one another.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccv{%
'My nation' he said, 'why do you wish to hasten evil rather than good? Why do you not ask the forgiveness of Allah, in order that you find mercy'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said: 'We predict an evil omen from you and those who are with you' He replied: 'Your prediction is with Allah, you are a nation being tested'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
In the city there were nine people who were corrupting the land and did not reform.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said: 'Let us swear by Allah to attack him and his family at night, then we will tell his guardian we were not witnesses of the destruction of his family; and surely we are truthful'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmccix{%
And they devised a scheme and, without their knowledge, We devised a scheme.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmccx{%
And behold the consequences of their devising! We destroyed them, and their nation altogether.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
Those are their houses, all are in ruins because of the evil they committed; surely in this there is a sign for nation who know.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We saved those who believed and were cautious.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And Lot, he said to his nation: 'Do you commit indecencies with your eyes open!\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
Do you approach men lustfully instead of women! No, you are an ignorant nation'\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
Yet the only answer of his nation was that they said: 'Expel the family of Lot from your village, they are people who purified themselves'\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
So We saved him and his family, except his wife, whom We decreed should stay behind.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And we rained on them a rain (of stones); indeed it is an evil rain that rains on those that are warned.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say: 'Praise belongs to Allah and peace be upon His worshipers whom He has chosen' Who is more worthier, Allah or that which they associate!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Is He who created the heavens and the earth, and sent water from the sky for you and caused gardens to grow full of beauty of which its tree you could never grow, is there a god with Allah? No, but they are a nation who set up equals with Him!\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Who has established the earth a fixed place and set therein rivers; and set for it firm mountains and placed a barrier between the two seas, is there a god with Allah? No, most of them are without knowledge.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Who answers the oppressed when he supplicates to Him and removes evil and appoints you as inheritors of the earth, is there a god with Allah? How little you remember!\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Who guides you in the darkness of the land and sea, and sends the winds bearing glad tidings of His Mercy, is there a god with Allah? Exalted is Allah above what they associate.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Who originates creation, then brings it back again, who gives you sustenance from the heaven and the earth, is there a god with Allah? Say: 'Bring us your proof if you are among the truthful'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say: 'None in the heavens or the earth knows the Unseen except Allah, and they are not aware when they shall be resurrected'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
No, their knowledge fails them as to the Everlasting Life; no, they are in doubt about it, no, they are blind to it.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
The unbelievers say: 'When we and our fathers are turned to dust, shall we be brought forth?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
We were promised this before, and so were our fathers. It is but the fictitious story of the ancients'\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say: 'Journey in the land and see what was the end of the sinners'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
Do not be sorry for them, nor be distressed for what they devise.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
And they ask: 'When will this promise come, if what you say is true'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say: 'It may be that part of what you seek to hasten on is already riding behind you'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
Surely, your Lord is bountiful to the people; yet most of them do not give thanks.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
Surely, your Lord knows what they hide in their hearts and what they reveal.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
There is not a thing hidden in the heaven and earth except that it is in a Clear Book.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Surely, this Koran relates to the Children of Israel most of that which they are at variance.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
It is a guidance and a mercy to believers.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Surely, by His Judgement, your Lord will decide between them. He is the Mighty, the Knower.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
Therefore put your trust in Allah, for you are upon a clear truth.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
You do not make the dead hear, nor do you make the deaf hear you call when they turn about, retreating.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
Nor do you guide the blind out of their error, nor do you make any to hear, except those who believe in Our verses and are Muslims.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the Word falls on them, We will bring out from the earth a beast that shall speak to them: 'Indeed the people were not certain of Our verses.'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
On that Day We shall gather a crowd from every nation of those who belied Our verses, so they are gathered.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
When they have come, He will say: 'Did you belie My verses, although you knew nothing, or what was it you were doing'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word shall fall upon them because of the evil they committed, and they shall be speechless.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
Have they not seen how We have made the night for them to rest in and the day to see? Surely, there are signs in this for the nation who believe.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
On the Day the Horn shall be blown all who live in the heavens and earth will be terrified, except those whom Allah wills. All shall come to Him humbled.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
And you will see the mountains which you think to be firm pass by like clouds. (Such is the) making of Allah, who has created everything well. He is Aware of the things you do.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whosoever comes with a good deed shall have better than it, and shall be secure from the terrors of that Day.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
But those who come with an evil deed shall have their faces thrust into the Fire: 'Are you recompensed except for your deeds'\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmccl{%
(Say Prophet Muhammad): 'I am only ordered to worship the Lord of this country, which He has made sacred, everything belongs to Him. And I am ordered to be of the Muslims,\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmccli{%
and to recite the Koran. Whosoever is guided is only guided for himself, and to whosoever goes astray, say: 'I am only a warner'\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say: 'Praise belongs to Allah! He will show you His signs and you will recognize them. Your Lord is not inattentive of what you do'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen TaSeenMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
Those are the verses of the Clear Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We shall in truth recite to you some of the news of Moses and Pharaoh for a nation who believe.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Pharaoh had exalted himself in the land and had divided its people into sects, one group he abased, putting their sons to death and sparing their women, for he was one of those who corrupted.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
But We wanted to be gracious to those abased in the land, and to make them leaders and inheritors,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
and to establish them in the land; and to show Pharaoh and Haman, and their armies, the very thing they dreaded.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
We revealed this to Moses' mother: 'Suckle him, but when you fear for him cast him into the water. Neither fear, nor sorrow because We shall restore him to you and make him among the Messengers'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
Then the family of Pharaoh picked him out to be an enemy and a sorrow for them, indeed Pharaoh and Haman, and their army were sinners.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
Pharaoh's wife said to him: 'He will be a comfort to me and you. Do not slay him, perhaps he may benefit us, or we will take him for our son' But they were unaware.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
In the morning the heart of Moses' mother became empty. She would have revealed (who he was) had We not settled her heart so that she might be among the believers.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
She said to his sister: 'Follow him' And she watched him from a distance, but they were unaware.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
We had forbidden to him before that he should be suckled by foster mothers, therefore she (Moses' sister) said (to them): 'Shall I direct you to a people of a household who will take charge of him for you and advise him'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
So, We restored him to his mother, so that she might be comforted and not sorrow, and that she might know that the promise of Allah is true. Yet most of them do not know.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he was full grown, and reached the perfection of his strength, We gave him judgment and knowledge. As such We recompense the gooddoers.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the city unnoticed by the people and found two men fighting, one was of his own party, and the other of his enemies. The one of his party appealed for his help against his enemy, Moses struck and killed him, and said: 'This is the work of satan, he is surely a clear, misleading enemy.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
Forgive me, my Lord, for I have wronged myself' and so He forgave him; for He is indeed the Forgiving, the Most Merciful.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said: 'My Lord as You have favored me, I will never be a helper to the wrongdoer'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
In the morning, he was in the city, fearful and vigilant, then he whom he had helped the day before cried out to him again for help. 'Clearly' said Moses, 'you are quarrelsome'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
And when Moses was about to seize he who was the enemy of both of them, he said: 'Moses, would you kill me as you killed a living soul yesterday? You desire only to be a tyrant in the land, and you do not want to be among the reformers'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
Then a man came running from the furthest part of the city, 'Moses' he said, 'the Assembly are plotting to kill you. Leave, for I am one of your sincere advisers'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he left, fearful and vigilant, saying: 'My Lord, save me from the harmdoing nation'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
And when he turned his face towards Midian, he said: 'It may be that my Lord will guide me on the right way'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
When he came to the water wells of Midian he found there some people drawing water, and he found two women apart from them who were keeping back (their flocks). 'What is your business' he asked. They replied: 'We cannot draw water until the shepherds have driven away (their flocks), and our father is an elderly man'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
So he drew water for them and then retired to the shade, saying: 'O my Lord, surely I have need of whatever good You send me'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Then, one of the two came to him walking shyly, and said: 'My father invites you, so that he can recompense you with a wage for having drawn water for us.' So when he came to him and told him his story, (the father) said: 'Do not be afraid, you have been saved from the nation of harmdoers'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
One of the two women said: 'Father, hire him. The best who you can hire, is the strong, the honest'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said: 'I will let you marry one of these two daughters of mine on condition that you hire yourself to me for eight years. If you complete ten that is of your own accord; I shall not press you. Surely, you will find me, if Allah wills, among the good'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
'So be it between me and you' said Moses. 'Whichever of the two terms I fulfill, it will be no injustice to me. Allah is the Guardian of what we say'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
And when Moses had fulfilled the term and departed with his household, he saw from far away on the side of the Tor a fire. He said to his household: 'Stay here, for I can see a fire. Perhaps I can bring you news, or a flame from the fire so that you can warm yourselves'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
When he came to it, he was called from the right bank in the blessed plot of the tree (he heard speech without letter or voice coming from all directions):'Moses, I am Allah, Lord of the Worlds.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
Cast down your staff' And when he saw his staff writhing as though it were a serpent, he turned about in retreat, and did not turn back. 'O Moses, approach and have no fear. You are surely safe.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
Put your hand in the neck (of your shirt), it will come out luminous, unharmed, and draw your arm to you so that you are not afraid. These are two signs from your Lord to Pharaoh and his Assembly. Surely, they were an impious nation.'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
'My Lord' (said Moses), 'I have killed a living soul among them, and fear that they will slay me.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
Aaron my brother has a more eloquent tongue than I, (please) send him with me as a helper to confirm I speak truly, I fear that they will belie me'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
He said: 'We will strengthen your arm with your brother, and appoint for you both an authority so that they shall not reach you. With our signs you and those who follow you shall be the victors.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
And when Moses came to them with Our clear signs, they said: 'This is nothing but forged sorcery. We have never heard of this among our fathers, the ancients.'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
Moses replied: 'My Lord knows well who brings guidance from Him and who shall possess the Last Residence. The harmdoers will not prosper'\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
'Assembly' said Pharaoh, 'I do not know that you have any god except me' 'O Haman, kindle a fire upon clay and make me a tower so that I can climb to see the God of Moses, I think that he is one of the liars'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
He and his hosts became wrongfully proud in the land and they thought that they would never be returned to Us.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
Therefore, We seized him and his hosts, and cast them into the sea. See how was the end of the harmdoers.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
We made them leaders inviting to the Fire, and on the Day of Resurrection they shall not be victors.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
In this world We laid Our curse on them, and on the Day of Resurrection they shall be among the exiled.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
And We gave Moses the Book, after We had destroyed the former generations, to be reflections for people and a guidance, and a mercy in order that they might remember.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
(Prophet Muhammad) you were not on the western side (of the mountain) when We decreed the commandment to Moses, nor were you among thosewitnessing.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
We raised generations who lived long. You did not live among the people of Midian, nor did you recite to them Our verses; but We were sendingMessengers.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
You were not present on the side of the Tor when We called. Yet as a mercy from your Lord to warn a nation to whom no warner has been sent before, in order that they remember\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
and not say, when evil befalls them on account of that which their hands forwarded: 'Our Lord, why did You not send a Messenger to us so that we might follow Your verses and so that we might be among the believers'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccc{%
So when the truth (Prophet Muhammad) came to them from Us, they said: 'Why is he not given the like of that which was given to Moses' But did they not also disbelieve in that which Moses was given before! They say (about Moses and Aaron): 'Two sorcerers supporting one another' And they said: 'We disbelieve both'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say: 'If what you say is true, bring down from Allah a Book that is a better guidance than both, I will follow it'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
If they do not answer you, know that they are only following their desires. And who is further astray than he who is led by his desires without guidance fromAllah! Allah does not guide the harmdoers.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
We have brought them the Word in order that they remember.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those to whom We gave the Book before, believe in it.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
When it is recited to them, they say: 'We believe in it, because it is the truth from Our Lord. We surrendered ourselves before it came.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
'Their wage shall be given them twice, because they have endured patiently, averting evil with good and spending from what We have given them;\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
and because when they hear idle talk they turn away from it and say: 'We have our deeds, and you have your deeds. Peace be upon you. We do not desire the ignorant'\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
You cannot guide whom you please; it is Allah who guides whom He will. He knows well those who are guided.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
They say: 'If we follow the guidance with you, we shall be driven from our land' But have We not given them a secure sanctuary from which fruits of every kind are collected as a provision from Us? Indeed, most of them do not know.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
How many a village have We destroyed that were ungrateful in their life! Those are their dwellings, (they are) uninhabited after them except for a little; We are the inheritors.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
Nor did your Lord destroy the villages until He had sent a Messenger to its mother village reciting to them Our verses. We never destroyed villages unless their inhabitants were harmdoers.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
The things you have been given, and its adornments, are but the enjoyment of this present life. What is with Allah is better and everlasting. Do you not understand?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Is he to whom We promised a fine promise and receives it, like he who has been given the enjoyment of this present life, then on the Day of Resurrection shall be among those that are arraigned?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
On that Day He will call to them, saying: 'Where are those whom you alleged to be My associates'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those against whom the Word is realized shall say: 'Our Lord, those whom we led astray, we led them astray even as we ourselves were astray. We are quit of them to You; it was not us that they worshipped'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
It will be said to them: 'Call on your associates' And they will call on them, but they will not respond to them, and they shall see the punishment if only they had been guided.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
On that Day He will call to them and He will say: 'What response did you give Our Messengers'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
And on that Day the news will be blinded for them, and they will not ask each other.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But, as for he who repents and believes, and does good deeds, he will be among those who prosper.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
Your Lord creates whosoever He will and He chooses the choice was not theirs (the unbelievers). Exalted is Allah, above that they associate!\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
Your Lord knows what their chests hide and what they reveal.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is Allah; there is no god except He. The Praise is His in the former as in the latter. His is the Judgement, to Him you shall be returned.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say: 'Think! What if Allah should enshroud you in unceasing night till the Day of Resurrection, what god, other than Allah, shall bring you light! Will you not hear?'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say: 'What would you think if Allah should make the day unceasing over you till the Day of Resurrection, what god, other than Allah, shall bring you the night to sleep in. Will you not see'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
In His Mercy He has appointed for you the night and the day, so that you can rest in it, and seek His bounty, in order that you will be thankful'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
Upon that Day He will call to them saying: 'Now, where are those whom you alleged to be My associates'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
From every nation We will bring a witness, and We shall say to them: 'Produce your proof' Then they shall know the truth is with Allah, and their own fabrications will forsake them.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
. Korah was one of Moses' nation. But he was insolent to them, for We had given him such treasures that their very keys were too heavy a burden for even the strong. His people said to him: 'Do not exult; Allah does not love the boastful.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
But seek, in that which Allah has given you to attain the Everlasting residence. Do not forget your share in this world. Do good, as Allah has been good to you, and do not corrupt in the land, Allah does not love those who corrupt.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
But he replied: 'What was given me is only because of the knowledge I possess' Did he not know that from the generations before him Allah had destroyed a mightier and more numerous in multitude? The sinners shall not be questioned about their sins.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
So he went out in all his finery among his nation, those who desired this life said: 'Would that we had the like of that Korah has been given! He has indeed a mighty fortune'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those to whom knowledge had been given said: 'Alas for you! Better is the reward of Allah for him who believes and does good works; but none shall receive it except the patient'\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
We caused the earth to swallow him, together with his dwelling, and there was no host to help him, other than Allah; and he was not amongst the victorious.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And in the morning those who had wished to be in his place the previous evening said: 'Indeed, Allah outspreads to whom He will among His worshipers, and He restrains. Had He not shown us favor, He could have caused the earth to swallow us. Indeed, the unbelievers shall never prosper'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
That is the Last Abode, We shall assign it to those who desire neither exorbitance in the earth, nor corruption. The outcome is for the cautious.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whosoever does a good deed shall have better than it. But whosoever does evil deeds, they shall be recompensed for what they were doing.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
He who has obligated the Koran will bring you to an appointment. Say: 'My Lord knows well who comes with guidance, and who is in clear error'\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
You did not hope that the Book would be given to you except as mercy from your Lord. So do not be a supporter of the unbelievers.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
Let no one bar you from the verses of Allah after they have been sent down to you, but call to your Lord, and do not be amongst the idolaters.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And do not call upon another god with Allah, there is no god except He. All things perish, except His Face, Judgement is His, and to Him all of you shall return.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen AlifLaamMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do people think that they are left alone by saying: 'We are believers' and will not be tried?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
We tried those who have gone before them. Allah knows those who are truthful and those who lie.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or do the evildoers think that they will outstrip Us? How evil is their judgment!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
He who hopes to meet Allah (must know) that the term of Allah is coming. He is the Hearer, the Knower.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
He who strives, strives for himself. Allah is the Rich, independent of the worlds.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
As for those who believe and do good works, We shall acquit them of their sins, and recompense them with the best for what they were doing.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
We have charged the human to be kind to his parents. But if they bid you to associate with Me that which you have no knowledge, do not obey them. To Me you will return, and I shall inform you of all that you have done.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
Those who believe and do good works shall be admitted among the righteous.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
There are some people who say: 'We believe in Allah' yet when such is hurt in the cause of Allah, he makes the persecution of people as though it were the punishment of Allah. But then if help comes from his Lord, he will say: 'We were with you' Does Allah not know what is in the (people's) chests of the worlds?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
Most certainly Allah knows the believers and the hypocrites.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
The unbelievers say to those who believe: 'Follow our path, and we will carry your sins' Yet they cannot carry even a thing of their sins. They are surely lying.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
They shall certainly carry their loads, and other loads besides their loads, and on the Day of Resurrection, they shall be questioned about what they forged.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
Indeed, We sent Noah to his nation, and he lived amongst them for a thousand years, less fifty (but they belied him), then the Flood seized them while they were harmdoers.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
But We saved him and all who were in the Ark, and made (the event) a sign to the worlds.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And (remember) Abraham. When he said to his people 'Worship Allah and fear Him. That would be best for you, if you but knew.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
You only worship, other than Allah, idols and invent falsehoods. Those whom you worship, other than Allah, have no power to give you provision. Therefore seek the provision of Allah, and worship Him. Give thanks to Him, to Him you shall return'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
If you belie me, other nations before you also belied. It is only for a Messenger to deliver the clear deliverance.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
Do they not see how Allah originates the Creation, and then brings it back? That is an easy matter for Allah.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say: 'Travel in the land and see how He started the Creation. Then Allah will originate the Everlasting Life. Allah has power over all things.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He punishes whom He will and has mercy to whom He will. To Him you shall be turned.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
You are not able to frustrate Him either in the earth or heaven, nor have you, other than Allah, a guardian or helper.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
Those who disbelieve the verses of Allah and the meeting with Him shall despair of My Mercy, for them there awaits a painful punishment.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
The only answer his nation gave was that they said: 'Kill him, or burn him! 'But Allah saved him from the fire. Surely, in this there are signs for a nation who believe.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
He said: 'Other than Allah, you have taken to yourselves idols as an affection between yourselves in the present life. Then, on the Day of Resurrection, you shall deny one another and curse one another, and your refuge will be the Fire, and none shall help you'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
Lot believed him, and said: 'I will migrate to my Lord; He is the Almighty, the Wise'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And, We gave him (Abraham), Isaac and Jacob and appointed on his descendants the Prophethood and the Book. We gave him his wage in this world, and in the Everlasting Life he shall be among the righteous.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And Lot who said to his nation: 'You commit indecency which no other being in all the world has committed before you.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
What, do you approach men and cause a detour on the road, and commit dishonor (sodomy) in your assembly' But the only reply of his nation was: 'Then bring down the punishment of Allah, if what you say is true'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
'My Lord' he said, 'help me against this corrupt nation'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our Messengers brought Abraham the glad tidings they said: 'We are destroying the people of this village, because its people are harmdoers'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
He said: 'Lot is in it' They replied: 'We know who are in it, we shall save him and his family, except his wife, she has become of those that shall remain behind'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
And when Our Messengers came to Lot, he was troubled and distressed on their account. But they said: 'Have no fear, and do not be sad. Surely, we will save you and your family except your wife, she has become of those that shall remain behind'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
We shall send down anger out of heaven upon the people of this city because they are debauchers.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
Indeed, We left a clear sign for a nation that understands.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And to Midian their brother Shu'aib. He said: 'Worship Allah, my nation. Look to the Last Day. Do not make mischief in the land, doing corrupt works.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
But they belied him, so the earthquake seized them, and when morning came, they were found fallen crouched in their dwellings, dead.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
Aad and Thamood, it has become clear to you from their dwellings; satan made their works seem fair to them and barred them from the Path, although they saw clearly.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And Korah, Pharaoh, and Haman Moses came to them with clear signs, but they became very insolent in the earth, yet they did not outstrip Us.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
Each of them We seized for his sin. On some We loosed a squall of pebbles, and others were seized by the Cry. Some We caused to be swallowed up by the earth, and some We drowned. Allah would never wrong them but they wronged themselves.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The likeness of those who have taken guardians, other than Allah, is as the likeness of the spider that takes to itself a house; surely the spider's house is the weakest house if they but knew.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Allah knows whatever they call upon other than Him; He is the Almighty, the Wise.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
And We strike these parables for the people, but none understands except the knowledgeable.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
Allah has created the heavens and the earth with the truth. Surely, in that there is a sign for believers.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite what has been sent down to you of the Book, and establish the prayer. Prayer forbids indecency and dishonor. The remembrance of Allah is greater, and Allah knows what you do.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And do not dispute with the People of the Book (Nazarenes) except in the best manner, except for those among them who do wrong and say (to them): 'We believe in that which was sent down to us and that which was sent down to you. Our God and your God is One, and to Him we have surrendered'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
As such, We have sent down to you the Book. Those to whom We gave the Book believe in it, and so do some of these. None reject Our verses except the unbelievers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
Never before did you recited any Book, or inscribe it with your right hand. If you had done so, those who follow falsehood would have doubted.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
No, rather they are clear verses in the chests of those who have been given knowledge. None disbelieves Our verses except the harmdoers.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
They ask: 'Why has not a sign been sent down upon him from his Lord' Say: 'The signs are only with Allah. I am only a clear warner'\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
Is it not enough for them that We have sent down to you the Book that is recited to them? Surely, in this there is a mercy and a reminder to a nation who believe.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say: 'Allah suffices as a witness between me and you. He knows whatsoever is in the heavens and the earth. Those who believe in falsehood and disbelieve in Allah those are they who are the losers'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
They demand that you hasten the punishment! But had it not been for the stated term, the punishment would come to them; it will come upon them suddenly when they are unaware.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They demand that you hasten on the punishment! Gehenna (Hell) will encompass the unbelievers.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
On the Day the punishment shall cover them from above them and from beneath their feet, He shall say: 'Taste now what you were doing'\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My worshipers who believe, My earth is vast, therefore worship Me!\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every soul shall taste death, and to Us you shall be returned.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
Those who believe and do good deeds We shall lodge them in the rooms of Paradise underneath which rivers flow, therein living for ever, an excellent wage for those who labor,\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
those who are patient, and put their trust in their Lord.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcd{%
How many a beast does not bear its own provision. Allah provides for it, as (He provides) for you. He is the Hearer, the Knower.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
If you ask them: 'Who has created the heavens and the earth and subjected the sun and the moon' They will say: 'Allah' How perverted they are!\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah outspreads and restricts His provision to whomsoever He will of His worshipers. Allah has knowledge of all things.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
If you were to ask them: ''Who sends down water out of the sky and thereby revives the earth after it was dead' they will reply: 'Allah' Say: 'Praise, belongs to Allah' No, but most of them do not understand.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
The life of this world is nothing but a diversion and play. Indeed, the Everlasting Residence is the Eternal Life, if they but knew.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
When they embark upon ships, they call to Allah making their religion sincerely His; but when He brings them safe to the land, they associate others with Him\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
showing ingratitude for what We have given them and take their enjoyment; soon they shall know!\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Do they not see how We appointed a safe Sanctuary while all around them people are snatched away? Would they believe in falsehood and do they disbelieve in the favor of Allah!\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who does greater evil that he who forges a lie against Allah or belied the truth when it comes to him! Is there not a lodging in Gehenna for the unbelievers?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
Those who struggle in Our cause, We will surely guide them to Our ways; and Allah is with those who do good.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen AlifLaamMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Romans have been defeated (by the Persians)\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
in a land close by. But, in a few years after their defeat they shall become the victors.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
To Allah belongs the Command before and after, and on that Day the believers will rejoice\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
in the victory of Allah. Allah gives victory to whosoever He will, and He is the Mighty, the Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
The promise of Allah! Allah does not fail His promise, yet most people do not know.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know an outward part of this life, but of the Everlasting Life they are inattentive.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Have they never thought to themselves that Allah did not create the heavens and the earth and all that is between except with truth, and for a stated term? Yet most people disbelieve that they will ever meet their Lord.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
What, have they never journeyed in the land and seen what was the end of those before them? They were stronger in might than themselves, and they plowed the land and cultivated it more than they themselves have cultivated it. And to them, their Messengers came with clear signs, and Allah did not wrong them, but they wronged themselves.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Evil was the end of the harmdoers, because they belied the verses of Allah and mocked at them.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
Allah originates creation, then brings it back again, then to Him you shall be returned.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
On the Day when the Hour comes, the wrongdoers will be speechless.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
They shall have none to intercede for them amongst their associates, and they shall disbelieve in their associates.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
On the Day when the Hour has come, they will be divided,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
those who believe and did good deeds shall be well pleased in a garden,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
but those who disbelieved and belied Our verses and the meeting of the Everlasting Life, shall be arraigned for punishment.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
Therefore, exalt Allah when you enter the evening and in the morning.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
His is the praise in the heavens and the earth, at the setting sun and at noon.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He brings out the living from the dead, and the dead from the living. He revives the earth after its death. Likewise you shall be brought forth.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And of His signs is that He created you from dust and you became humans scattered throughout the earth.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And of His signs is that He created for you wives from among yourselves, that you might reside with them, and has put kindness and mercy between you. Surely, there are signs in this for those who think.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And His signs are the creation of heavens and earth and the diversity of your tongues and colors. Surely, there are signs in this for all the worlds.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And of His signs is that you sleep at night and day, and seek His bounty. Surely, there are signs in this for those who hear.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And of His signs is that He shows you the lightning for fear and hope. He sends down water from the sky and with it He revives the earth after its death. Surely, in this there are signs for a nation that understand.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And of His signs is that the heaven and earth stand firm at His command. And when He calls you once out of the earth, you shall come forth.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
To Him belongs whosoever is in the heavens and the earth. All are obedient to His Will.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
It is He who originates the creation, and then brings it back again, that is easier for Him. For Him is the Highest Example in the heavens and earth He is the Almighty, the Wise.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He sets for you an example, drawn from yourselves. Do you have from among those whom your right hand possesses associates in what We have given you, who share it equally with you? Do you fear them as you fear one another? So We made plain Our signs to a nation of understanding.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
No, the wrongdoers follow their own desires without knowledge. And who can guide those whom Allah has led astray? There shall be none to help them.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
Therefore set your face to the religion purely, the upright creation upon which He originated people. There is no changing of the creation of Allah. This is the valuable religion, although most people do not know?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
turning to Him. And fear Him, establish the prayer and do not be of the idolaters,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
those who have divided their religion, and become sects, each rejoicing in what they have.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
When affliction befalls mankind they turn to Him calling their Lord in prayer, but when He lets them taste His Mercy, some of them assign associates to their Lord,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
disbelieving in what We have given them. Enjoy, but you shall soon know.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We sent down to them an authority that speaks of that they associate with Him?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
When We give people a taste of mercy, they rejoice in it, but when evil befalls them through the forwarding of their own hands, they become despondent.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
Do they not see that Allah outspreads and restricts His provision to whom He will? Surely, there are signs in this for those who believe.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
And give to the kinsman his due, and to the needy, and to the destitute traveler. That is best for those who desire the Face of Allah; such will surely prosper.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
That which you give in usury so that it increases in other people's wealth, will not increase with Allah; but the charity you give desiring the Face of Allah, to those, they shall be recompensed many times over.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
It is Allah who has created you and given you your provision. He will cause you to die, and will then revive you. Can any of your associates do any of that? Exalted is He above what they associate.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Corruption has appeared on land and sea with what the hands of the people earned. Therefore, they taste some of what they did in order that they return.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say: 'Journey in the land and see what was the end of those who were before you. Most of them were idolaters'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
Therefore in purity set your face to the religion, before there comes from Allah a Day that cannot be turned back. On that Day mankind will be separated.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Those who disbelieve will be charged for their disbelief, while the righteous are making provision for themselves\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
so that He will recompense those who believe and do righteous deeds from His bounty. He does not love the unbelievers.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And of His signs is that He looses the winds as bearers of glad tidings, so that He lets you taste His Mercy and that the ships may sail at His command in order that you can seek His bounty and be thankful.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
Before you We sent other Messengers to their people; and they came with clear signs. We took revenge upon the sinners, and it was an incumbent duty upon Us to give victory to the believers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
It is Allah who looses the winds that stir the clouds. He spreads them as He will in heaven and disperses them, so that you can see the rain falling from their midst. When He smites with it whom He will of His worshipers they rejoice,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
though before its coming they had despaired.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
Look then at the marks of Mercy of Allah; how He revives the earth after its death. He is the Reviver of the dead. He has power over all things.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
Yet if We sent a wind so they see it yellow, indeed after that they would still be unbelievers.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
You cannot make the dead hear you, nor can you make the deaf hear the call when they retreat, turning about.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
You cannot guide the blind out of their error. Nor shall you make any to hear except those who believe in Our verses, and are submissive.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
Allah creates you weak; after weakness He gives you strength and after strength weakness and gray hairs. He creates whatever He will. He is the Knower, the Capable.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
Upon the Day when the Hour has come, the harmdoers will swear that they had stayed no more than an hour. As such they are deceived.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
But those to whom knowledge and belief have been given will say: 'You have stayed in the Book of Allah (the Protected Tablets) till the Day of Resurrection. This is the Day of Resurrection, yet you did not know'\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
On that Day, excuses shall not benefit the harmdoers, nor shall they be asked to make amends.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
In this Koran We have set forth for mankind all manner of examples. Yet if you bring to them a sign the unbelievers will surely say: 'You are but falsifiers'\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
As such Allah seals the hearts of those who do not know.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
Therefore, have patience. The promise of Allah is true. Do not let those who are uncertain make you unsteady.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen AlifLaamMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
Those are the verses of the Wise Book,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
a guidance and a mercy to those who do good,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
who establish the prayer, pay the obligatory charity, and firmly believe in the Everlasting Life.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
Those are guided by their Lord and will surely prosper.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
There are some people who would purchase distracting talk, to lead astray from the Path of Allah without knowledge, and take it in mockery; for those is a humiliating punishment.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
When Our verses are recited to him, he turns his back in pride, as though he never heard them, and in his ears was heaviness. Give glad tidings to him of a painful punishment!\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
But for those who believe and do good works are Gardens of Bliss,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
where they shall live for ever. The promise of Allah is the truth; He is the Almighty, the Wise.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He created the heavens without pillars that you see and cast on the earth firm mountains lest it should shake with you. Upon it He dispersed all manner of crawling thing, and He sent down water from the sky with which He caused to grow in it every generous kind.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
Such is the creation of Allah; now show me what, other than Him, created! No, the harmdoers are in clear error.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
We gave wisdom to Lokman (saying): 'Give thanks to Allah. He who gives thanks, thanks only for himself, but whosoever is ungrateful, surely, Allah is the Rich, the Praised'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And when Lokman said to his son, in warning: 'My son, associate none with Allah, to associate others with Allah is a tremendous wrong'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
And We charged the human concerning his parents, for his mother bore him in weakness upon weakness, and his weaning was in two years. Be thankful to Me and to your parents, to Me is the arrival.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
But if they strive with you to make you associate with Me that of which you have no knowledge, do not obey them. And accompany them in this life with kindness; and follow the Path of he who turned to Me. To Me you shall return and I will inform you of all that you have done.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
(Lokman said:) 'My son, if it should be but the weight of one grain of mustardseed, and though it be on a rock, or in the heavens, or in the earth, Allah shall bring it. Surely, Allah is the Subtle, Aware.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
My son, establish the prayer, order with honor but forbid dishonor, and bear patiently with whatever may fall upon you, indeed that is true constancy.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
Do not turn your cheek in scorn away from people, nor walk proudly on the earth; Allah does not love the proud and the boastful.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
Walk modestly, and lower your voice; the most hideous of voices is the braying of the donkey.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
Do you not see how Allah has subjected to you all that is in the heavens and the earth, and lavished on you His visible and unseen favors? Yet some people would argue about Allah without knowledge, or guidance, or an Illuminating Book'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
When it is said to them: 'Follow what Allah has sent down' they reply: 'No, rather we will follow that which we found our fathers upon' What! Even though satan is inviting them to the punishment of the Fire!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
He who surrenders himself to Allah and is a good doer, has grasped the firmest handle. To Allah the issue of affairs return.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
As for those who disbelieve, do not let their disbelief grieve you, to Us they shall return and We will tell to them what they did. Allah has knowledge of what is innermost in their chests.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We give to them a little enjoyment for awhile, and then will compel them to a tremendous punishment.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
If you ask them: 'Who has created the heavens and the earth' They will reply: 'Allah' Say: 'Praise belongs to Allah' But most of them do not have knowledge.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
To Allah belongs all that is in the heavens and the earth. He is the Rich, the Praised.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
If all the trees in the earth were pens, and the sea, with seven more seas to replenish it (with ink), the Words of Allah would never end. Allah is the Almighty, the Wise.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
Your creation and your resurrection are but as a single soul. Allah is the Hearer, the Seer.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
Do you not see how Allah causes the night to enter into the day, and the day enter into the night and has subjected the sun and the moon, each running to a named term? Allah is Aware of what you do.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
For Allah is the Truth, while that which they call upon, other than Him, is false. For that Allah is the Most High, the Great.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmd{%
Do you not see how the ships run upon the sea, by the Favor of Allah so that He may show you His signs? Surely, there are signs in this for every steadfast, thankful person.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdi{%
When the waves, like shadows, envelop them, they call to Allah making their religion sincerely His, but no sooner does He bring them safely to land then some of them are halfhearted. None denies Our verses, except the ungrateful traitor.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdii{%
People, fear your Lord, and fear the Day when no father shall ransom a thing for his child nor a child for his father. The promise of Allah is surely true. So do not let the life of this present world delude you, nor let the deluder (satan) delude you concerning Allah.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Allah, He alone has knowledge of the Hour. He sends down the rain and He knows what is in the wombs. No soul knows what he will earn tomorrow; and no soul knows in what land it will die. Surely, Allah is the Knower, the Aware.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen AlifLaamMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdv{%
The sending down of the Book in which there is no doubt that is from the Lord of the Worlds.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Or do they say: 'He has forged it himself' Say: 'No, it is the truth from your Lord so that you can warn a nation to whom none has warned before you, in order that they are guided.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
It was Allah, who, in six days created the heavens and the earth and all that is between them, and then willed to the Throne. You have no guardian nor intercessor other than Him. Will you not remember?\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He directs the affair from heaven to earth. Then it will ascend to Him in one day, a day whose value is a thousand years by your reckoning.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdix{%
He is the Knower of the Unseen and the Visible, the Almighty, the Most Merciful,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdx{%
who perfected everything He created. He originated the creation of the human from clay,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
then He made his offspring from a clot of weak water (semen).\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
Then He created him and (caused the angel to) breathe into him his (created) spirit. He gave you eyes and ears, and hearts, yet little do you thank.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
They say: 'What, when we have been destroyed in the earth, shall we indeed be in a new creation' Indeed, they disbelieve that they will meet their Lord.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say: 'The Angel of Death, who has been given charge of you will gather you then to your Lord you shall be returned'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
Would that you could see the wrongdoers when they lower their heads before their Lord! They will say: 'Our Lord, we have now seen and heard. Send us back and we will do righteous deeds, we are certain'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
Had We Willed, We would have guided every soul. But My Word shall be realized, 'I will fill Gehenna (Hell) with jinn and people all together'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
(We shall say to them): 'Now taste, for you forgot the encounter of this Day, We have forgotten you. Taste Our eternal punishment, for that which you were doing'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
Only those who believe in Our verses, when reminded of them, prostrate themselves and exalt with the praise of their Lord in humility;\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
whose sides forsake their couches as they supplicate to their Lord in fear and hope; who give in charity of that which We have given them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
No soul knows what pleases the eye is in store for them as a recompense for what they used to do.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Can he, then, who is a believer, be compared to he who is wicked? They are not equal.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
As for those who believe and do good works, there are for them the Gardens of Refuge, in hospitality for that which they have done.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
But those who do evil their refuge is the Fire. As often as they desire to come out of it they shall be driven back, and it will be said to them: 'Taste the punishment of the Fire, which you have belied'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
But We will let them taste the nearest punishment (in this life) before the greater punishment, so that they may return (to faith).\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who is more wicked than he who, when reminded of the verses of his Lord turns away from them? We take revenge on the sinners.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
We have given the Book to Moses, so (Prophet Muhammad) do not be in doubt concerning the meeting with him (Prophet Moses) and made it a guidance to the Children of Israel.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
When they were patient, We made from them leaders, guiding with Our Command and they were certain of Our verses.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
On the Day of Resurrection your Lord will distinguish between them that on which they varied.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Is it not a guidance to them, how many generations We destroyed before them in whose dwelling places they walk? Surely, in this there are signs. Will they not then hear!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Do they not see how We drive the water to the parched lands and bring forth therefrom crops from which their cattle and themselves eat? Will they not see!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
They also ask: 'When will this Opening come, if what you say is true'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say: 'On the Day of Opening the faith of the unbelievers will not benefit them, nor shall they be respited'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
Therefore turn away from them, and wait, they are waiting.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet, fear Allah, and do not obey the unbelievers and the hypocrites. Allah is the Knower, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
Follow what is revealed to you from your Lord, for Allah is Aware of what they do,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
put your trust in Allah; Allah suffices as a Guardian.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah has never made any man with two hearts inside him. Nor has He made your wives, when you divorce, saying: 'Be as my mother's back' your mothers. Neither has He made your fostered sons as your own sons. These are your own sayings, words which you utter with your mouths; but Allah speaks the truth and guides to the Path.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Name them after their fathers, that is more just with Allah. If you do not know their fathers, regard them as your brothers in the religion, or those under your sponsorship. There is no fault in you if you make mistakes, but only in what your hearts intended. Allah is Forgiving and the Most Merciful,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet has a greater right on the believers than their own selves, his wives are their mothers. Kinsmen are closer to one another in the Book of Allah than to other believers and the emigrants; although you should act honorably towards those you sponsor, that is written in the Book\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
We took from the Prophets their covenant and from you (Prophet Muhammad), from Noah and Abraham, from Moses and Jesus the son of Mary. We took a solemn covenant from them,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
so that Allah might question the truthful about their truthfulness. But for the unbelievers He has prepared a painful punishment.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
Believers, remember the Favor of Allah to you when there came against you hosts (armies). We unleashed against them a wind and hosts (angels) you could not see. Allah sees the things you do.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
They came on you from above and from below, and when your eyes swerved and your hearts leapt to your throats, and you thought thoughts about Allah;\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
there the believers were tried, they were shaken, a severe quake.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
The hypocrites and those in whose hearts there is a disease said: 'Allah and His Messenger promised nothing but delusion'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a party of them said: 'People of Yathrib (Madinah), there is no place for you here, therefore return' And a party of them asked leave of theProphet, saying: 'Our houses are exposed' whereas they were not, they only wished to flee.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
And if an entrance had been forced against them from its quarters, and then they had been asked to incite, they would have done so, and remained in it (the city) but a little (time).\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
Yet before that, they made a covenant with Allah never to turn their backs. And covenants with Allah shall be questioned.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say: 'Flight will not avail you, if you flee from death or slaughter, you would enjoy (this world) only for a little (time)'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say: 'Who can defend you from Allah if He desires harm for you, or if He desires mercy for you' They shall find for themselves none, other than Allah, to protect or help them.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Allah knows those of you who hinder, and those who say to their brothers: 'Come to us' and they do not come to the battle but a little,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
being mean towards you. When fear comes to them, you see them looking at you, their eyes rolling as though they were on the point of death. But once the fear departs they assail you with their sharp tongues, being greedy to possess good things. Those have never believed; Allah has annulled their deeds. That is easy for Allah.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They think the confederates have not departed. Indeed, if the confederates should come again they would sooner be in the desert among the Bedouins asking news of you. If they were among you, they would fight but a little.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
In the Messenger of Allah you have a fine example for he who hopes for Allah and the Last Day and remembers Allah abundantly.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
When the believers saw the confederates they said: 'This is what Allah and His Messenger have promised us. Surely, Allah and His Messenger have spoken in truth' And this did not increase them except in belief and submission.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Among the believers there are men who have been true to their covenant with Allah. Some have fulfilled their vow dying, and others await, unyielding tochange,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
so that Allah will recompense the truthful for their truthfulness and punish the hypocrites if He will, or turn again to them. Surely, Allah is the Forgiver and the Most Merciful.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
Allah sent back the unbelievers in their rage, and they gained no good. Allah spared the believers from fighting, surely Allah is the Strong, the Mighty.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
He brought down from their fortresses those who had supported them from among the People of the (Jewish) Book and cast terror into their hearts, so that some you killed and others you took captive.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
He made you inheritors of their land, their houses, and their possessions, and another land on which you had never set foot before. Truly, Allah is Powerful over everything.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet, say to your wives: 'If you seek this life and its finery, come, I will release you with a fine release.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
But if you seek Allah and His Messenger and the Everlasting Residence, know that Allah has prepared for those of you who do good works a mighty wage'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O wives of the Prophet! Whosoever among you commit a flagrant indecency, for her the punishment shall be doubled, that is easy for Allah.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
But she who obeys Allah and His Messenger and does good works shall be doubly recompensed; for her We have made a generous provision.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
O wives of the Prophet, you are not like other women. If you fear (Allah), do not be to complaisant in your speech, lest he in whose heart there is a sickness may desire (of his mother); but speak honorable words.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
Stay in your homes and do not display your finery as pagan women used to do in the olden Days of Ignorance. Establish your prayers, pay the obligatory charity, and obey Allah and His Messenger. O family of the House, Allah only wishes to distance fault from you, and to cleanse you, and to purify you abundantly.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And remember that which is recited in your houses of the verses of Allah and the Wisdom. Allah is the Subtle, the Knower.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
For men and women who have surrendered believing men and women; obedient men and women; truthful men and women, patient men and women, humble men and women, men and women who give charity, men and women who fast, men and women who guard their privates, men and women who remember Allah in abundance, for them Allah has prepared forgiveness and a mighty wage.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
It is not for any believer man or woman to have the choice in the affair when a matter is decreed by Allah and His Prophet. Whosoever disobeys Allah and His Messenger strays into clear error.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
And when you said to he whom Allah had favored and yourself have favored: 'Keep your wife and fear Allah' and you sought to hide in yourself what Allah was to reveal, fearing people; although Allah has a better right for you to fear Him. And when Zayd had accomplished what he would of her (divorce), We gave her to you (Prophet Muhammad) in marriage, so that there is no fault in believers concerning (marriage to) the former spouse of their foster children if they divorced them. The decree of Allah must be done.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
No fault shall be attached to the Prophet for doing what Allah has obligated for him. Such was the way of Allah with those who passed away before the decree of Allah is a decree determined\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
who were delivering the Messages of Allah, fearing Him and fearing none except Allah. Allah suffices as a Reckoner.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of any of your men. He is the Messenger of Allah and the Seal of the Prophets. Allah has knowledge of all things.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
Believers, remember Allah frequently,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
exalt Him at dawn and in the evening.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
It is He who has mercy on you, and His angels to bring you out from the darkness into light. He is the Most Merciful to the believers.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
On the Day they meet Him, their greeting shall be 'Peace' A generous recompense He has prepared for them.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Prophet, We have sent you as a witness, a bearer of glad tidings, and to bear warning;\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
a caller to Allah by His permission and as a light shedding lamp.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
Give to the believers the glad tidings that with Allah there is for them a great bounty.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
Do not obey the unbelievers and the hypocrites, pay no attention to their hurt. Put your trust in Allah; Allah suffices as a Guardian.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
Believers, if you marry believing women and divorce them before the marriage is consummated, you have no period to count against them. Provide for them and release them kindly.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet, We have made lawful to you the wives to whom you have given dowries and those whom your right hand possesses, of whatever spoils of war that Allah has given you; and the daughters of your paternal uncles and paternal aunts, and of your paternal and maternal aunts who migrated with you; and any believing woman who gives herself to the Prophet, if the Prophet wishes to take her in marriage. This is only for you and not any other believer. We know the duties We have imposed on them concerning their wives and those whom their right hand possesses, so that there should be no fault in you. Allah is the Forgiving and Merciful.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
You may defer any of them (your wives) if you please and invite any of them if you please. If you seek any you have put aside there is no fault in you. So that it is likelier they will be comforted, and not sorrow, and every one of them will be pleased, and all are pleased with what you give them. Allah knows what is in your hearts. Allah is the Knower, the Clement.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
It shall be unlawful for you to take more wives or to exchange your present wives for other women, though their beauty pleases you, except those whom your right hand possesses. Allah is watchful over everything.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
Believers, do not enter the houses of the Prophet for a meal without waiting for the proper time, unless you are given permission. But if you are invited, enter, and when you have eaten, disperse, not desiring conversation, for that is hurtful to the Prophet and he would be shy before you; but of the truth Allah is not shy. And when you ask his wives for anything, speak to them from behind a curtain, that is cleaner for your hearts and theirs. You must not hurt the Messenger of Allah, nor shall you ever wed his wives after him, surely, this would be a monstrous thing with Allah.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether you reveal a thing or conceal it, Allah has knowledge of all things.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
It shall be no offense for them (to be seen unveiled) by their fathers, their sons, their brothers, their brothers' sons, their sisters' sons, their women, and those whom their right hands possess. And fear Allah, for Allah is witness of everything.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Allah and His angels praise and venerate the Prophet. Believers, praise and venerate him and pronounce peace upon him in abundance.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Those who (try to) hurt Allah and His Messenger shall be cursed by Allah in this present life and in the Everlasting Life, and He has prepared for them a humbling punishment.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
Those who hurt believing men and believing women undeservedly, shall bear the guilt of slander and a major sin.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet, tell your wives, your daughters and the believing women to draw their veils close to them, so it is likelier they will be known, and not hurt. Allah is the Forgiver, the Most Merciful.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites and those who have a disease in their hearts, and those who make a commotion in the City do not desist, We will surely urge you against them. Then they will be your neighbors for only a little (while),\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
cursed wherever they are found, they will be seized and put to death.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
Such has been the way of Allah with those who have passed before them, and you shall find no change in the ways of Allah.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
The people will ask you about the Hour. Say: 'The knowledge of it is with Allah alone, what makes you to know that the Hour is near'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Allah has cursed the unbelievers and prepared for them a Blaze.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
Living there for ever, they shall neither find a guardian nor a helper.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
On that Day when their faces are turned about in the Fire, they shall say: 'Would that we had obeyed Allah and obeyed the Messenger'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they shall say: 'Our Lord, We obeyed our masters and our eminent ones, but they misled us from the way.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdci{%
Our Lord, let their punishment be doubled; and curse them with a mighty curse'\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
Believers, do not be like those who hurt Moses. Allah cleared him of what they said. His face is honorable with Allah.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O you who believe, fear Allah and say sound statements,\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
and He will mend your deeds for you and forgive your sins. Whosoever obeys Allah and His Messenger shall win a great victory.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
We offered the trust to the heavens, and the earth, and the mountains, but they refused to bear it, and were afraid of it, and the human carried it. Surely, he is a harmdoer, and ignorant.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
Allah punishes the hypocrites, men and women alike, and the idolaters, both men and women alike; and Allah turns to the believers, men and women alike. Allah is the Forgiver, the Most Merciful.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen Praise is for Allah, to whom belongs all that is in the heavens and the earth! And the Praise belongs to Him in the Everlasting Life. He is the Wise, the Knower.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows all that penetrates the earth and all that comes forth from it, all that comes down from heaven and all that ascends to it. He is the Most Merciful, the Forgiver.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
The unbelievers say: 'The Hour will never come to us' Say: 'By my Lord, yes, it is surely coming to you! By Him who knows the Unseen, not even the weight of an atom in heavens and earth escapes Him; neither is there anything smaller than that, nor greater except that it is in a Clear Book,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
in order that He recompenses those who believe and do good works; theirs shall be forgiveness and a generous provision.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
But those who labor against Our verses (thinking they are) frustrating (Our Messengers), theirs shall be the painful punishment of anger'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
Those to whom the knowledge has been given can see that what has been sent down to you from your Lord is the truth, guiding to the Path of the Almighty, the Praised.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
The unbelievers say: 'Shall we direct you to a man who will tell you that when you have been utterly torn into pieces you will be raised in a new creation?'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
What, has he forged a lie about Allah, or is he mad' No, those who do not believe in the Everlasting Life are in the punishment and in far error.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
Have they not seen what is before them and behind them in heaven and earth? If We willed, We would make the earth swallow them up, or We would let lumps from heaven fall down on them. Surely, there is a sign in this for every penitent worshiper.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
We gave David bounty from Us. 'O mountains, and birds, echo (the praise of Allah) with him' And We softened iron for him,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
(saying): 'Make large coats of mail and measure their links well. Do good deeds, for surely I see the things you do'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
To Solomon the morning course of the wind was a month's journey, and its evening course was also a month's journey. We caused copper to be (as a) molten spring for him. And the jinn, some served him by the permission of his Lord. But as for those amongst them that swerved away from Our Command, We shall let them taste the punishment of the Blaze (the Fire).\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They made for him whatever he wanted, arches, statues, bowls as basins, and fixed cauldrons. (We said:) 'Give thanks, House of David and work' Yet only a few of My worshipers are thankful.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
And when We decreed (Solomon's) death, they had no indication that he was dead until (they saw a termite), a crawler of the earth eating away his staff. And when he fell down, the jinn realized that had they known the unseen, they would not have continued in their humiliating punishment.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
For Sheba there was indeed a sign. In their dwelling place there were two gardens, on the right and left side. (We said): 'Eat of your Lord's provisions and give thanks to Him, a good land, and a Lord who is the Forgiving'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away. So We sent against them the Flood (at the city) of Arim, and exchanged their gardens with two others bearing bitter fruit andTamarisks, and here and there a few Lotus trees.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
As such We recompensed them for their disbelief; do We recompense any except the unbelievers?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
Between them and the villages which We had blessed, We placed easily visible villages, and We spaced the journey between them exactly. (We said):'Travel through them by day and night in safety'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But they said: 'Lord, make the stages between our journeys longer' so they wronged themselves; so We made them news and We tore them utterly into pieces. Surely, there are signs in this for every one who is patient, thankful.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
iblis' made his guess true to them; and all except for a party of believers followed him.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
Yet he had no authority over them except that We would know who believed in the Everlasting Life, from he who doubted. Your Lord is the Watcher over all things.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say: 'Call on those whom you assert, other than Allah. They do not possess as much as the weight of an atom in the heavens or earth, nor do they have a partnership in either, neither does He have supporters among them'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
Intercession with Him will not help, except for him to whom He gives permission. When terror is lifted from their hearts, they shall say: 'What did your Lord say' 'The truth' they shall answer. 'He is the Most High, the Great'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say: 'Who provides for you from the heavens and earth' Say: 'Allah' Surely, either we or you are rightly guided or in clear error.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say: 'You will not to be questioned about our sins, neither will we be questioned for your actions'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say: 'Our Lord will bring us all together, then, with truth, He will rightly judge between us. He is the Opener, the Knower.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say: 'Show me those whom you joined with Him as associates; no, indeed; rather He is Allah, the Almighty, the Wise.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
We did not send you (Prophet Muhammad) for all mankind except to bring them glad tidings and to warn, but most people do not know.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
They ask: 'When, if what you say is true, will this promise come'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say: 'You are promised a Day. You can neither hold it back, nor can you hasten it by a single hour'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
The unbelievers say: 'We will not believe in this Koran, nor in (the Books) that were before it' If you could only see the harmdoers when they are brought before their Lord! They will argue against each other. Those who had been abased will say to those who were proud: 'But for you, we would have been believers'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
Then, those who were proud will say to those who were abased, 'Was it we who barred you from the Guidance after it had come to you? No, you yourselves were sinners'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
Those that were abased will say to those who were proud: 'Rather, it was scheming night and day, when you ordered us to disbelieve in Allah and set up equals to Him' And they will regret in secret when they see the punishment and We put (iron) fetters on the necks of the unbelievers. Shall they be recompensed except for what they were doing?\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
We never sent a warner to a village except that those (who lived) in luxury said: 'We disbelieve in the Message you have been sent with'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
And they said: 'We have been given an abundance of wealth and children we shall never be punished'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say: 'My Lord outspreads and withholds His provision to whomsoever He will. But most people do not know'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
It is neither your riches nor your children that shall bring you close in nearness to Us, except he who believes and does good work. For those their awaits a double recompense for their deeds, they shall live in safety in their lofty chambers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
But those who labor to negate Our verses shall be arraigned in to the punishment.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say: 'My Lord outspreads and withholds His provision to whomsoever He will of His worshipers. Whatsoever you expend He will replace it. He is the Best of providers'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
On the Day when He gathers them all together, He will say to the angels: 'Was it you that these worshipped'\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
'Exaltations to You' they will answer. 'You are our Guardian other than them! No, rather they worshipped the jinn, and it was them which most believed'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
Therefore, today none of you shall have the power to either benefit or harm one another' To the evildoers We shall say: 'Taste the punishment of the Fire, which you belied'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
When Our clear verses, are recited to them, they say: 'This is nothing but a man whose wish is to prevent you from that which your fathers used to worship. 'And they say: 'This is nothing but a forged lie' And those who disbelieve say of the truth when it reaches them: 'This is nothing but clear sorcery.?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
Yet We have not given them any Books to study, nor, before you, have We sent them a warner.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
Those who have gone before them belied, yet they did not reach a tenth of what We gave them; yet they belied My Messengers. And how was (My) rejection (their destruction)!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say: 'I give you only one admonition, that you stand before Allah either two by two, or one by one and reflect. There is no madness is in your companion. He (Prophet Muhammad) is only a warner to you, before a terrible punishment'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say: 'I ask no wage of you; that shall be yours. My wage is only upon Allah and He is Witness over everything'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say: 'My Lord hurls the truth the Knower of the Unseen'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say: 'Truth has come. Falsehood has vanished and shall return no more.'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say: 'If I go astray, then I go astray only against myself; if I am guided it is because of that which my Lord has revealed to me. He is the Hearer, and theNear'\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
If you could only see when they (the unbelievers) are seized with terror, and there is no escape. They shall be seized from a nearby place,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
and say: 'We believe in it' But how can they reach from a place that is distant,\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
since they disbelieved in it before, guessing at the Unseen from a distant place?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And a barrier is set between them and that which they desire, as it was done before with their like; they were in suspicious doubt'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen Praise belongs for Allah, the Originator of the heavens and earth, who appointed the angels to be Messengers, with wings, two, three, and four. He increases the creation as He wills. Allah has power over all things.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
Whatever mercy Allah opens to people, none can withhold; and whatever He withholds none can release after Him. He is the Almighty, the Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
People, remember the blessings of Allah to you. Except for Allah, is there any other creator who provides for you out of heaven and earth? There is no god except He. Where then do you turn?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
If they belie you, other Messengers have been belied before you. To Allah all matters are returned.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
People, the promise of Allah is true, so do not let this present life delude you, and do not let the deluder (satan) delude you about Allah.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
satan is indeed your enemy; therefore take him for an enemy. He calls his party so that they will become the companions of the Blaze.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
For the unbelievers awaits a terrible punishment, but for those who believe and do good deeds is forgiveness and a great recompense.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
What then of he whose evil deeds have been decorated fair to him and thinks them to be good? Allah leads astray whomsoever He will and whomsoever He will He guides. Do not let your soul be wasted in regrets for them; Allah has knowledge of all they do.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
Allah is He who sends the winds that stir up the clouds. Then, We drive them on to a dead land and revive the earth after it's death. Such is the Raising Up.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
He who wants might, the Might belongs to Allah altogether. To Him ascend good words, and the righteous deed He raises. But those who devise evil deeds theirs shall be a terrible punishment, and their plotting shall be annulled.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
Allah created you from dust, then from a (sperm) drop. Then he made you pairs. No female conceives or is delivered except by His Knowledge. He whose life is long, whatsoever is increased or decreased of his age is in a Clear Book. Surely, that is easy for Allah.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
The two seas are not alike. One is fresh, sweet and pleasant to taste, while the other is salt and bitter. Yet, from each you eat fresh flesh and bring forth out of it ornaments for you to wear. And you see the ships plow their course through it so that you may seek His bounty, and in order that you give thanks.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He causes the night to enter into the day and the day into the night. He has subjected the sun and the moon each running for a named term. Such is Allah, your Lord. To Him belongs the Kingdom; and those whom you call upon, other than Him, do not possess even as much as the membrane of a datestone.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If you supplicate to them they cannot hear your supplication, and if they heard, they cannot answer you. On the Day of Resurrection they will disown your associating. None can tell you like He who is the Aware.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
People, it is you who are in need of Allah. He is the Rich, the Praised.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
He can put you away, if He will, and bring a new creation\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
this is not a great matter for Allah.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
No laden soul shall bear another's load. If one is heavyburdened and calls for his load to be carried, nothing of it will be carried, not even if he is a close relative. You warn only those who fear their Lord in the Unseen, and establish the prayer. He who purifies himself, purifies himself for the good of his own soul. To Allah is the arrival.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
The blind and the seeing are not equal,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
nor are darkness and light.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
The shade and the hot wind are not equal,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
nor are the living and the dead equal. Allah makes to hear whosoever He will, but you cannot make those who are in their graves hear.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
You (Prophet Muhammad) are but a warner.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
We have sent you with the truth, a bearer of glad tidings and warning, for there is no nation, that has not had a warner pass away in it.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
If they belie you, those before them also belied. Their Messengers came to them with clear signs; the Psalms, and the Illuminating Book.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then I seized those who disbelieved, and how was My rejection!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Did you not see how Allah sends down water from the sky and with it brings forth different colored fruits? In the mountains there are paths of various colors, of white and red, and jetblack.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
People too, and beasts and cattle have their different colors. But it is only those amongst His worshippers that fear Allah who have knowledge. Indeed, Allah is the Almighty and the Forgiving.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Indeed, those who recite the Book of Allah and establish their prayers and spend, in secret and in public of that which We have provided them, look for a trade that does not come to nothing,\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
so that He may pay them in full their wages and enrich them from His bounty. Surely, He is the Forgiver and the Thanker.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
That which We have revealed to you of the Book is the truth and it confirms what was before it. Allah is Aware and sees His worshipers.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then, We gave the Book as an inheritance to those of our worshipers whom We chose. Among them, is he who was harmful to himself, and some who minimize, and some who, by the permission of Allah, race in charity, this is the greatest virtue.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
They shall enter the Gardens of Eden, where they shall be adorned with bracelets of gold and with pearls, and there, their robes shall be of silk.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
They shall say: 'Praise belongs to Allah who has removed all sorrow from us. Indeed, our Lord is the Forgiver, the Thanker.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
Through His bounty He has made us to live in the abode of Everlasting Life, where neither weariness nor fatigue shall touch us'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
As for the unbelievers, theirs is the Fire of Gehenna. They shall neither be done away with nor die, and its punishment shall never be lightened for them. As such shall We recompense every unbeliever.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
There they will cry out: 'Our Lord, bring us out, and we will do good, other than what we have done' What, did We not make your lives long enough to remember for whosoever would remember? A warner came to you, so taste now! None shall help the harmdoers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Allah knows the Unseen in the heavens and earth. He knows that which is in the innermost of the chests.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
It is He who made you caliphs in the earth. He who disbelieves, his disbelief shall be charged against him. The unbelievers disbelief does nothing for them, except, increase them in hate with Allah their disbelief increases the unbelievers only in loss.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say: 'Have you considered your associates who you call upon, other than Allah? Show me what they have created in the earth! Or, have they a partnership in the heavens' Or, have We given them a Book so that they have proof of it? No, the harmdoers promise each other nothing else but delusion.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
It is Allah who holds the heavens and the earth lest they vanish. Should they vanish, none would hold them after Him. He is the Clement, the Forgiving.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
They solemnly swore by Allah that if a warner came to them they would be more rightly guided than any other of the nations. Yet, when a warner came to them, it only increased their aversion,\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
behaving arrogantly in the land and devising evil. But, evil devising coils only those who do it. Do they look except for the ways of former nations? You shall never find any change in the way of Allah.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
What, have they not journeyed through the land and seen the end of those who went before them? They were stronger and mightier than themselves. Allah! There is nothing in heavens or earth that can frustrate Him, He is the Knower, the Able.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
If Allah should take people to task for what they have earned, He would not leave one creature that crawls upon the face (of the earth)! But, He is deferring them to a named time. And when their time comes, indeed, Allah is the Seer of His worshipers.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen YaSeen.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the Wise Koran,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
you (Prophet Muhammad) are truly among the Messengers sent\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
upon a Straight Path.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
The sending down of the Mighty, the Most Merciful\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
so that you may warn a people whose fathers were not warned, and so were heedless.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
The Phrase has become obligatory upon most of them, yet they do not believe.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
We have bound their necks with fetters up to their chin, so that their heads are raised and cannot be lowered.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
We have set a barrier before them and a barrier behind them, and, We have covered them so that they do not see.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
It is the same whether you have warned them or you have not warned them, they do not believe.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
You only warn he who follows the Remembrance and fears the Merciful in the Unseen. Give to him glad tidings of forgiveness and a generous wage.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
Surely, it is We who revive the dead and write down what they have forwarded and what they have left behind; We have counted everything in a Clear Book.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
Give to them a parable; to the people of the village there came Messengers,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
We sent to them two, but they belied them so We reinforced them with a third. They said: 'We have surely been sent as Messengers to you'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
But they said: 'You are only humans like ourselves. The Merciful has not sent down anything, your speech is but lies'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
They said: 'Our Lord knows that we are Messengers to you.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
And it is only for us to deliver a Clear Message'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
They answered: 'We predict evil of you. If you do not desist, we will stone you and a painful punishment from us will befall you'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They said: 'Your prediction is with you, if you are reminded. Surely, you are but a wayward nation'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
Then, a man came running from the furthest part of the village 'My nation' he said, 'follow the Messengers,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
follow those who ask no wage of you and are rightly guided.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
Why should I not worship Him who has originated me and to whom you shall all be returned?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
What, shall I take, other than Him, gods whose intercession, if the Merciful desires to afflict me, cannot help me at all, and they will never save me?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
Surely, I should then be in clear error.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
I believe in your Lord, so hear me'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said (to him): 'Enter Paradise' and he said: 'Would that my people knew\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
that my Lord has forgiven me, and caused me to be amongst the receivers of generosity'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
And We did not send down to his nation after him any army from heaven, neither would We send any down.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was only one Shout and they were silent, still.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Woe, for those (unbelieving) worshipers! They mocked every Messenger that came to them.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Have they not seen how many generations We destroyed before them? They shall never return to them,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
all shall be arraigned before Us.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
The dead land is a sign for them. We revive it, and from it produce grain from which they eat.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And there We made gardens of palms and vines, and in it We caused fountains to gush forth,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
so that they might eat of its fruit and the labor of their hands. Will they not give thanks?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Exaltations to Him who created pairs of all the things the earth produces and of themselves, and that of which they have no knowledge.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
A sign for them is the night. From it We withdraw the day and they are in darkness.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
The sun runs to its fixed restingplace; that is the decree of the Almighty, the Knower.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And the moon, We have determined it in phases till it returns like an old palmbranch.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
The sun shall not outstrip the moon, nor shall the night outstrip the day. Each is floating in an orbit.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And a sign for them is that We carried their offspring in the laden Ark (of Noah).\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And We have created for them the like of it in which they board.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
We drown them if We will, then they have none to cry to, nor can they be saved,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
except through Our Mercy and as enjoyment for awhile.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
When it is said to them: 'Have fear of that which is before you and behind you in order that you find mercy'\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
Yet there never comes to them any sign of their Lord's signs, but they turn away from it.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said to them: 'Spend of that which Allah has given you' the unbelievers say to the believers: 'Are we to feed those whom Allah can feed if He chooses? Surely, you are only in clear error'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
They also say: 'When will this promise be, if what you say is true'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They await but one Shout, which will seize them while they dispute.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
Then they will be unable to make a will, nor shall they return to their kinsmen.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
And the Horn is blown, and, from the graves they rush forth to their Lord.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
'Woe for us' they will say. 'Who has roused us from our sleepingplace? This is what the Merciful promised; the Messengers have spoken the truth'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
And it is but one Shout and they are all arraigned before Us.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
Today, no soul shall be wronged a thing. You shall not be recompensed except according to your deeds.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Indeed, the companions of the Garden are this Day busy in their rejoicing.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
Together with their spouses, they shall recline on couches in the shade.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
They shall have fruits and all that they call for.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
Peace, a saying from the Most Merciful Lord.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
(And He will say): 'Distance yourselves, O sinners, this Day.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
Children of Adam, did I not make a covenant with you, that you should not worship satan he is surely a clear enemy to you\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
and that you worship Me? Surely, that is the Straight Path.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
Yet he has led many a host of you astray, did you not understand?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
This, then is Gehenna (Hell), that which you were promised.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
Roast well therein this Day for you were unbelievers'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
This Day We set a seal on their mouths and their hands speak to Us, and their feet will testify to their earnings.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
Had it been Our will We would have obliterated their sight so that they raced to the Path. But, how would they see?\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
Had it been Our will We would have transmuted them (into monkeys, pigs and stones) where they were, so that they could neither go forward nor yet return.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
To whoever We give a long life We make him stoop. Do they not understand?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
We have not taught him (Prophet Muhammad) poetry, nor does it become him. This is only a Remembrance and a Clear Holy Reading (Koran)\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
that he may warn the living, and so that Judgement may be passed against the unbelievers.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Have they not seen how We have created for them the cattle they master with Our Hands?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
We have subdued these to them, and some of them they ride and some of them they eat;\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
they also have other uses in them and drinks. What, will they not give thanks!\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
And yet they have taken gods, other than Allah, so that they might helped!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They cannot help them, for them (the socalled) army are brought (with them to Hell).\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
So do not let their sayings grieve you. Surely, We have knowledge of what they hide and all that they reveal.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Has the human not seen how We created him from a drop (of sperm)? Yet he is a clear opponent.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he has struck for Us a parable, and forgotten his own creation. He asks: 'Who will quicken the bones after they have decayed'\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say: 'He will quicken them who originated them the first time; He has knowledge of every creation;\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
who has made fire for you from the green tree with which you kindle'\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Is He who created the heavens and the earth unable to create their like? Yes, indeed, He is the Creator, the Knower.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
When He wills a thing, His command is to say to it 'Be', and it is!\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
Exaltations to Him in whose Hand is the Kingdom of all things, and to Him you will be returned.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By the aligners (angels) aligning.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
and the drivers driving,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
and those who recite the Remembrance\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
surely, your God is One,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
the Lord of the heavens and the earth and of all that is between them; the Lord of the Easts.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
We have adorned the lower heaven with the adornment of the planets,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
a protection against every rebel satan;\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
so they cannot listen to the High Assembly, for they are pelted from every side.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
They are rejected and theirs is an everlasting punishment;\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
except such as snatches a fragment, and he is pursued by a piercing flame.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
So ask them, are they stronger in constitution, or those whom We have created. We have created them of sticky clay.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
No, you marvel, while they scoff.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
When they are reminded, they do not remember.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
When they are shown a sign, they scoff at it\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
and say: 'This is nothing but clear sorcery'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
What, when we are dead and become dust and bones, shall we be resurrected.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
What, and our forefathers, the ancients'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say: 'Yes, but worthless'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
It will be but one Shout, then see, they are watching\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
and they will say: 'Woe for us. This is the Day of Recompense'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
This is the Day of Decision which you belied.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
Gather together the evildoers, their wives, and that they were worshipping,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
other than Allah, and guide them to the Path of Hell!\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
And halt them so that they may be questioned.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
'Why do you not help one another?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
No, today they will resign themselves in submission,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
and approach each other with questions,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
saying: 'You used to come to us from the right hand'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
But they reply: 'Rather, you were not believers.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
We had no authority over you, but you were an insolent nation.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
The statement of Our Lord is realized against us, and we are tasting it,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
we perverted you, indeed, we were perverts'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
Therefore, on that Day they will all share Our punishment.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
As such We shall deal with the evildoers.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
For when it was said to them: 'There is no god except Allah' they were always proud\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
and said: 'Are we to renounce our gods for the sake of a mad poet'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
No, indeed, he has brought the truth, and confirmed the Messengers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
You shall certainly taste the painful punishment:\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
but you shall not be recompensed except for what you were doing.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
But for the sincere worshipers of Allah,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
there is waiting for them a known provision;\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
fruits. And they are receivers of generosity\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
in the Gardens of Delight,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
sitting face to face upon couches,\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
a goblet from a spring shall be passed round to them\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
white, a delight to the drinkers,\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
there is neither sickness in it, nor intoxication.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
And with them will be maidens (houris) who restrain their wide glances\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
as if they were hidden pearls.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
They will go to one another asking each other questions.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
One of them will say: 'I had a companion\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
who would say: ``Are you among the believers (of the resurrection)?\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
When we are dead and turned to dust and bones, shall we be recompensed?"\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
And he will reply: 'Are you looking down (into Hell)'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
Then, he will look and see him in the midst of Hell.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
'By Allah' he will say, 'you almost destroyed me!\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
But for the Favor of Allah I should have surely been among those who were arraigned (with you in Hell).\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
What then, shall we not die\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
except our first death, and shall we not be punished'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
Indeed, this is the mighty victory,\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
and for the like of this let the workers work.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is this a better hospitality or the tree of AzZakkum!\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
We have made this (tree) a trial for the evildoers.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
It is a tree that grows from the bottom of Hell;\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
its spathes are like the heads of satans\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
on it they shall feed, and with it they shall fill their bellies.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
On top of it they shall have a brew of boiling water,\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
then their return is to Hell.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
They found their fathers in error,\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
yet they run in their footsteps,\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
yet before them most of the ancients went astray,\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
though We had sent among them warners.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
See then the end of those who were warned,\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
except the sincere worshipers of Allah.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
Noah called to Us, and We are the Best to answer.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
We saved him and his people from the great distress,\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
and We made his offspring the survivors.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And We let it remain upon him in the latter:\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
'Peace be upon Noah among all the worlds'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
As such We recompense the gooddoers,\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
he was one of Our believing worshipers.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Afterwards We drowned the others.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
Of his party was Abraham.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
(Remember when) he came to his Lord with a pure heart;\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
and when he said to his father and to his nation: 'What do you worship?\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
It is falsehood that you desire gods other than Allah!\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
What do you think of the Lord of the Worlds'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
He cast a glance at the stars\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
and said: 'Surely, I am sick (of what you worship)'\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
But they turned their backs and went away from him.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then he turned to their gods, and said: 'What do you eat?\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
What is the matter with you, that you do not speak'\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
And he turned upon them striking them with the right hand.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
Thereafter they (the people) came to him in haste.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said: 'Do you worship what you, yourselves have carved\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
when it is Allah who created you and all that you do'\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They replied: 'Build for him a building and cast him into the fire'\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
Their desire was to outwit him, but We made them to be the humiliated.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
He said: 'I will go to my Lord; He will guide me.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
My Lord, grant me a righteous (son)'\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
And We gave him the glad tidings of a very gentle son (Ishmael).\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
And when he reached the age of traveling with him, he said: 'My son, while I was sleeping I saw that I shall slaughter (sacrifice) you, tell me what is your opinion' He replied: 'Father, do as you are ordered (by Allah). Allah willing, you shall find me one of those who are steadfast'\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
And when they had both submitted, and his son had laid down prostrate upon his forehead,\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We called to him, saying: 'O Abraham,\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
you have confirmed your vision' As such We recompense the gooddoers.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
That was indeed a clear trial.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
So, We ransomed him with a mighty sacrifice,\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
and We let it (the beautiful praise) remain upon him in the latter (generations),\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
'Peace be upon Abraham'\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
As such We recompense the gooddoers.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
He was one of Our believing worshipers.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmmcm{%
Then, We gave him the glad tidings of Isaac, a Prophet, one of the righteous,\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
and We blessed him and Isaac, and from their offspring are some gooddoers, and others who clearly wronged themselves.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
We also favored Moses and Aaron\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
and We saved them with their nation from a great distress.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
We helped them, and they became victorious,\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
and We gave them the Clear Book,\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
and guided them upon the Straight Path.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We let it (the beautiful praise) remain upon on both of them in the latter (generations),\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
'Peace be upon Moses and Aaron'\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
As such We recompense the gooddoers.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
They were among Our believing worshipers.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
And Elias (El Yaseen) was among the Messengers.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
He asked his people: 'Do you not fear (Allah)?\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
Do you call on Ba'lan (the idol Baal) and abandon the Best Creator,\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
Allah is your Lord and the Lord of your fathers, the ancients'\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
But they belied him, so they will be among the arraigned (in Hell),\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
except the sincere worshipers of Allah.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And We let it (the beautiful praise) remain upon him in the latter (generations),\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
'Peace be upon El Yaseen'\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
As such We recompense the gooddoers.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
He was among Our believing worshipers.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
Lot, too, was among the Messengers.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
We saved him and all his kinsmen,\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
except an old woman who lingered,\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
and We destroyed the others.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
You pass by them in the morning\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
and at night, will you not understand?\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
Jonah, too, was one of the Messengers.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
He ran away to the laden ship,\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
and cast lots, and he was among the losers (of the lots that were cast).\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
So the whale swallowed him, for he was blameworthy,\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
and had he not been among those who exalt (Allah),\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
he would have lingered in its belly till the Day they are resurrected.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
But We cast him, upon the shore, and he was ill,\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
and We caused a pumpkin tree to grow over him.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
Then We sent him to a hundred thousand or more,\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
and they believed, and We gave them enjoyment for awhile.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
Now, ask them, has your Lord daughters, and they sons?\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or, did We create the angels females while they were witnessing?\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Then is it of their lying that they say:\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
'Allah has begotten' They are truly liars.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
Has He chosen daughters above sons?\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What is the matter with you? How do you judge?\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
What, will you not remember?\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or, do you have a clear authority?\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Bring your Book, if what you say is true!\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
They assert kinship between Him and the angels. But the angels know that they (the liars) will be arraigned (in Hell).\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Exaltations to Allah above what they describe,\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
except for the sincere worshipers of Allah.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
But as for you, and that you worship,\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mmmcml{%
you shall tempt none against Him\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
except for he who shall roast in Hell.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
(Gabriel said to the Prophet): 'Each of us has a known place.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
We are surely those who are arranged in ranks.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
And we are they who exalt (Allah)'\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
What, would they then say:\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
'If only we had a reminder from the ancients,\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
we would have been sincere worshipers of Allah'\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
But they disbelieve in it (the Koran), but soon they shall know!\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
Our Word had already preceded Our worshipers, the Messengers,\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
that they shall receive Our help\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
and Our armies shall be the victors.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So turn (away) from them for a while.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
See them and soon they shall see.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
What, do they seek to hasten Our punishment?\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
When it descends upon their courtyards, evil will be the morning of those forewarned.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
So turn (away) from them for a while,\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
and see, soon they shall see!\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Exaltations be to your Lord, the Lord of Might, above that they describe!\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
Peace be on the Messengers.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And praise belongs to Allah, Lord of the Worlds.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Saad, by the Holy Reading (Koran) of the Remembrance.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
No, the unbelievers exalt in their division.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many generations have We destroyed before them. They called: 'The time is neither of escape, nor safety'\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
They marvel now that, from among themselves, a warner has come to them. The unbelievers say: 'This is a lying sorcerer.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
What, has he made the gods One God? This is indeed a wondrous thing'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
Their assembly left (saying): 'Go, and be patient to your gods, this is something to be desired.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
We never heard of this in the former religion. It is nothing but an invention.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
What, out of all of us, has the Remembrance been sent down to him (Prophet Muhammad)' No, they are doubtful about My Remembrance, no, they have not yet tasted My punishment.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or, have they the treasuries of the Mercy of your Lord, the Almighty, the Giving?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or, is theirs the Kingdom of the heavens and the earth and all that is between them? Then let them ascend by (their) means!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
The army is defeated as (were) the confederates.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Before them the nations of Noah, Aad and Pharaoh, and he of the tentpegs belied,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
Thamood, the nation of Lot and the dwellers of the Thicket such were the confederates.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
There was not one of those that did not belie the Messengers. Therefore, My retribution was realized.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
These only wait for a single Shout for which there will be no delay.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
They say: 'Our Lord, hasten to us our share before the Day of Recompense'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Bear patiently with what they say, and remember Our worshiper David, a man of might. He was ever turning in repentance.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
We subjected the mountains to exalt (Me) with him in the evening and at sunrise,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
and the birds, too, gathered each obedient to him.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
We made his kingdom strong and gave him wisdom and decisive speech.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
Has the news of the dispute reached you (Prophet Muhammad)? When they scaled the Sanctuary\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
they went to David whereupon he was afraid of them, but they said: 'Do not be afraid, we are two that have a dispute, one of us has wronged the other. Judge between us justly, and do not transgress, and guide us to the Right Path.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
This, my brother has ninetynine ewes, but I have only one ewe (a female sheep). He said: ``Give her into my keeping" and overcame me in the argument'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
He (David) replied: 'He has without doubt wronged you in seeking to add your ewe to his sheep. Many intermixers wrong one another; except those who believe, and do good works, and they are few indeed' David realized that We had tried him and sought the forgiveness of his Lord and fell down, prostrate and repented.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
So, We forgave him that, and he has a near place with Us and a fine return.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
(We said): 'David, We have made you a caliph in the earth. Judge with justice among people and do not yield to your own preference in case it should lead you from the Path of Allah. Surely, a terrible punishment awaits those who stray from the Path of Allah, because they forget the Day of Reckoning'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
It was not in falsehood that We created the heavens and the earth and all that is between them. That is the thought of the unbelievers. But woe to the unbelievers because of the Fire!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Are We to make those who believe and do good works the same as those who corrupt the earth? Are We to make the righteous as the wicked?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
It is a Blessed Book that We have sent down to you (Prophet Muhammad), so that those possessed with minds might ponder its verses and remember.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmm{%
We gave Solomon to David; and he was an excellent worshiper, he was penitent.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmi{%
When his dressage steeds were presented to him in the evening,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmii{%
he said: 'Indeed I have loved the love of good things better than the remembrance of my Lord until the sun has vanished behind a veil.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
Bring them back to me' And he hacked their legs and necks (slaughtering them for Allah).\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
Indeed, We tried Solomon and placed a body (of a child) upon his throne, then he repented.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said: 'Forgive me my Lord, and give me a kingdom the like of which will not befall any after me, surely, You are the Giver'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
So We subjected the wind to him, so that it ran softly by his command wherever he wished;\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
and the satans, every builder and diver\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
and others joined together by (iron) fetters.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmix{%
'This is Our gift, give or withhold without reckoning'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And he has a place near to Us, and a fine return.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
Also, remember Our worshiper Job. He called out to his Lord, (saying): 'satan has afflicted me with harm and pain'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
(We said): 'Stamp your foot on the ground, here is cool water with which to wash and a drink'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
We restored to him to his family and like those with them, a mercy from Us and a reminder to a nation that understand.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
(We said to him): 'Take a bundle of rushes and strike with it; and do not break your oath' We found him to be patient, a good worshiper and he was penitent.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
Also, remember Our worshipers Abraham, Isaac, and Jacob, those of might and vision.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Indeed, We purified them with a most pure quality, the remembrance of the Everlasting Life.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
Indeed with Us they are among the chosen, the excellent.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
Also, remember our worshipers Ishmael, Elisha, and ThulKifl, they are among the good.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is a Reminder, and indeed for the cautious is a fine return,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
the Gardens of Eden whose gates shall be open to them,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
in which they will recline, and call for abundant fruit and drink therein.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
And with them will be maidens of equal age with modest gaze.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
'This is what you are promised on the Day of Recompense,\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
this is Our unending provision'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
All of this; but, for the proud there is an ill return.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
They shall roast in (the Fire) of Gehenna, an evil cradling.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
All of this; so let them taste it, boiling water and pus,\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
and other similar to it, joined together.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
(We shall say to their leaders): 'This is a troop rushing in with you, there is no welcome for them, they shall roast in the Fire'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
But they will say: 'No, it is you that has no welcome. It was you who brought it upon us, an evil place'\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They will say: 'Our Lord, give those who brought this upon us double the punishment of the Fire'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they will say: 'Why do we not see the men that we counted as being among the wicked in here?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
Have we taken them in mockery? Or, have our eyes swerved from them?'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Surely that is true the disputing of the inhabitants of the Fire\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say: 'I am only a warner. There is no god except Allah, the One, the Conqueror,\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
the Lord of the heavens and the earth and all that is between them; the Almighty, the Forgiving'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say: 'This is a mighty message\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
from which you turn away.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
I had no knowledge of the High Assembly's dispute.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
This alone is revealed to me, I am only a clear warner'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
When your Lord said to the angels: 'I am creating a human from clay,\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
after I have shaped him and breathed of My spirit (I created) into him, fall down prostrate before him'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
So all the angels prostrated themselves\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
except iblis (satan, the father of the jinn), he became too proud, for he was one of the unbelievers.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
He (Allah) said: 'iblis, what prevented you from prostrating yourself towards that which I have created with My Hands? Have you become too proud, or areyou among the grand'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
He (satan) replied: 'I am better than he. You created me from fire, and You created him from clay'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
'Begone' said He, 'you are stoned'.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
'My curse shall rest on you until the Day of Recompense'\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
He (satan) replied: 'Respite me my Lord till the Day of Resurrection'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmml{%
He (Allah) said: 'You are among those that are respited\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmli{%
till the Day of the known time'\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
He (satan) said: 'I swear by Your Might, that I will seduce all of them\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
except those among them who are Your sincere worshipers'\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
He (Allah) said: 'This is the truth, and I speak the truth:\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
I shall certainly fill Gehenna with you and every one of them that follows you'\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say (Prophet Muhammad): 'For this I ask of you no wage, and I am not of those who take things upon themselves.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
This is nothing else but a reminder to all the worlds,\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
and after a while you shall know its news'\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The sending down of the Book is from Allah, the Almighty, the Wise,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
We have sent down the Book with the truth to you (Prophet Muhammad), therefore worship Allah, and make your religion sincerely His.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Is it not that the sincere religion belongs to Allah? As for those who choose guardians, other than Him, (saying): 'We only worship them so that they will bring us near to Allah' Indeed, Allah will judge between them concerning their differences. Indeed, Allah does not guide he who is an unthankful liar.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
If Allah had desired to take a son, He would have chosen whatever He willed out of His creation. Exaltations to Him! He is Allah, the One, the Conqueror.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He created the heavens and the earth in truth, wrapping the night about the day and wrapping the day about the night, He has subjected the sun and the mooneach to run for a stated term. Is He not the Almighty, the Forgiving?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you from a single soul, then from it He created its spouse. And He sent down to you eight pairs of the cattle. He creates you in your mothers' womb, creation after creation, in three (stages of) darkness. Such then is Allah, your Lord. For Him is the Kingdom. There is no god except Him. How, then, can you turn away?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If you disbelieve, Allah is Rich, independent of you. Yet He does not approve of disbelief to His worshipers, but if you believe He will approve it in you. No laden soul shall bear another's load. Then, to Allah you shall return and He will tell to you what you have done. He knows the innermost of your chests.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
When an affliction befalls a human, he supplicates to his Lord and turns to Him (in repentance) yet, no sooner does He bestow on him His blessing than he forgets that for which he had just supplicated and sets up associates with Allah in order to lead (people) away from His Path. Say: 'Enjoy your disbelief for awhile, you shall surely be among the companions of the Fire.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Or, is he who is obedient that prostrates himself and stands during parts of the night, being afraid of the Everlasting Life but hoping for the Mercy of the Lord (to be compared to the unbeliever)' Say: 'Are they equal, those who know and those who do not know' Only those with minds remember.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say: 'My worshipers who believe, fear your Lord. For those who do good in this world there is good and the earth of Allah is wide surely, those who are patient will be recompensed in full without count'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say: 'I am ordered to worship Allah making my religion sincerely His.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
I am ordered to be the first of those to be submissive (Muslims to Him)'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say: 'Indeed, if I rebel against my Lord I fear the punishment of a dreadful Day'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say: 'I worship Allah and make my religion sincerely His.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
(As for yourselves) worship what you will, other than Him' Say: 'The losers are surely those who lose themselves and their families on the Day ofResurrection. Is that not a clear loss'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
Above them they shall have layers of fire and beneath them layers. By this Allah puts fear into His worshipers' 'O My worshipers, fear Me'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
Those who shun the worship of idols and turn in repentance to Allah for them glad tidings. Therefore give good tidings to My worshipers,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
who listen to the Words and follow what is finest of it. These are they whom Allah has guided. They are those of understanding.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
Can you save from the Fire he whom against the word of punishment has been realized?\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
As for those who fear their Lord, there await high mansions above which are built (more) high mansions, beneath which rivers flow, such is the promise ofAllah; Allah will not fail His promise.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Have you not seen how Allah sends down water from the sky and threaded it as springs in the earth? Then, He brings forth plants of various colors, after which they wither, and you see them turning yellow, and then He makes them into broken stubble. Surely, in this there is a reminder for those of understanding.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
Is he whose chest Allah has expanded to Islam, so that he walks upon a light from his Lord (as those whose heart is sealed)? But woe to those whose hearts are hardened against the Remembrance of Allah! Those are in clear error.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah has sent down the best discourse, a Book, consimilar in its oftrepeated (verses) that the skins of those who fear their Lord tremble; and thereafter their skins and hearts soften to the Remembrance of Allah. Such is the Guidance of Allah, whereby He guides whosoever He will; and whosoever Allah leads astray, he has no guide.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
Is he whose face is cautious of the evil of the punishment on the Day of Resurrection (to be compared to the unbeliever)! To the evildoers it shall be said:'Now taste that which you have been earning'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those who went before them also belied, then Our punishment overtook them from where they were unaware;\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
Allah let them taste degradation in this present life, but the punishment of the Everlasting Life shall be greater if they but knew.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
Indeed, We have struck of every manner of parable for mankind in this Koran in order that they will remember.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
It is an Arabic Koran free from all crookedness, in order that they will be cautious.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah has struck an example of a man shared by disagreeing partners, and a man who is owned by just one man, are the two equally alike? Praise belongs toAllah, but most of them do not know.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
You are mortal, and they are mortal\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
then, on the Day of Resurrection, you shall dispute before your Lord.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
Who does greater evil than he who lies against Allah and belies the truth when it comes to him? Is there not a lodging in Gehenna (Hell) for the unbelievers?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And he who comes with the truth, and confirms it, those are they who surely fear Allah.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They shall have whatever they want with their Lord, that is the recompense of the gooddoers,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
that Allah may acquit them of the worst of what they did, and recompense with the finest wages for what they did.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Is it not that Allah suffices His worshiper, even though they frighten you with those other than Him? He whom Allah leads astray has no guide.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
But he whom Allah guides, none can lead astray. Is not Allah the Almighty, capable of retribution?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
If you ask them who created the heavens and the earth, they will reply: 'Allah' Say: 'Do you think that, if Allah wills to afflict me those you call upon, other than Him, could remove His affliction, or, that if He wills to let me have mercy, they could withhold His Mercy' Say: 'Allah suffices me. Those who put their trust, put their trust in Him'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say: 'O nation, work according to your status, I am working according to my status, and soon you will know\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
upon whom the punishment will come that will degrade him, and who will be overtaken by an everlasting punishment'\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
Surely, We have sent down to you the Book for mankind with the truth. Whosoever is guided, is guided for himself, and he who goes astray, it is only for his own loss, you (Prophet Muhammad) are not their (compulsory) guardian.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmc{%
Allah takes away souls at the time of their death (the temporary death of sleep), and those who do not die during their sleep He withholds that upon whichHe has decreed death, but turns lose the other till a stated term. Surely, there are signs in this for a nation who contemplate.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Have they chosen, other than Allah, to intercede for them? Say: 'What, even though they have no power at all, nor understanding'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say: 'Intercession belongs altogether to Allah. His is the Kingdom of the heavens and the earth. To Him you shall be returned'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
When Allah is mentioned alone, the hearts of those who do not believe in the Everlasting Life shrink in aversion. But when those, other than Him, are mentioned, see, they are filled with glad tidings.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say: 'O Allah, the Originator of the heavens and the earth who has knowledge of the Unseen and Visible, You shall judge between the differences of Your worshipers'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
On the Day of Resurrection, if the harmdoers owned all that is in the earth and as much again besides, they would offer it to ransom themselves from the evil of the punishment. From Allah will come to them that with which they had never reckoned,\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
and the evils of their earnings will appear to them, and that which they mocked at will encompass them.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
When an affliction befalls a human he calls upon Us, but when We confer Our Favor on him, he says: 'I have only been given it on account of knowledge. 'Rather, it is but a trial, yet most do not know.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Those before them said the same, but what they earned did not help them;\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
and the evil of their earnings coiled upon them. The harmdoers among these will also be coiled by the evils of their earnings, they will be unable to defeat it.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Do they not know that Allah outspreads and withholds His provision to whosoever He will? Surely, there are signs in this for a believing nation.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say: 'O My worshipers, who have sinned excessively against themselves, do not despair of the Mercy of Allah, surely, Allah forgives all sins. He is theForgiver, the Most Merciful.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
Turn to your Lord and surrender yourselves to Him before the punishment overtakes you, for then you will not be helped.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
Follow the best of what has been sent down from your Lord before the punishment overtakes you suddenly, while you are unaware'\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
Lest any soul should say: 'Sadly, I have neglected my duty to Allah and was of those that mocked'\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
Or, lest it should say: 'If Allah had only guided me I would have been one of the cautious'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
Or, lest when it sees the punishment should say: 'O that I might return, and be among those that did good'\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
'Indeed, My verses did come to you, but you belied them. You were proud and became one of the unbelievers'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
On the Day of Resurrection, you shall see those who lied about Allah with blackened faces. In Gehenna is there not a lodging for those who were proud?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
But, Allah will save those who fear Him with their winnings (Paradise). No evil shall touch them, nor shall they ever grieve.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is the Creator of all things, and of all things He is the Guardian.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
To Him belong the keys of the heavens and the earth. Those who disbelieve in the verses of Allah they are the losers.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say: 'O you who are ignorant, is it other than Allah that you would order me to worship'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
It has already been revealed to you and to those who have gone before you, that if you associate (partners) with Allah, your works would be annulled and you will be among the losers.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
No, worship Allah and be with those who give thanks!\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
They have not valued Allah with His true value. But on the Day of Resurrection, the entire earth will be in His grip, and the heavens shall be rolled up upon in His Right. Exaltations to Him! Exalted high is He above all that they associate!\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
The Horn shall be blown and all who are in heavens and earth shall swoon, except those whom Allah wills. Then, the Horn will blow again and they shall stand and gaze.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
The earth will shine with the Light of its Lord, and the Book (of deeds) will be set (in place). The Prophets and witnesses shall be brought and the matter will be justly decided between them, and they will not be wronged.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
Every soul shall be paid in full according to what it has done, for He knows well what they did.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
In companies the unbelievers shall be driven into Gehenna. As they draw near, its gates will be opened and its keepers will ask them: 'Did there not come to you Messengers of your own, who recited to you the verses of your Lord and warned you of the encounter of this your Day' 'Yes indeed' they will answer. And the word of the punishment has been realized against the unbelievers.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It will be said to them: 'Enter the gates of Gehenna and live there for ever' Evil is the lodging place of the proud.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
Then, those that feared their Lord shall be driven in companies into Paradise. When they draw near its gates will be opened, and its keepers will say to them: 'Peace be upon you, you have done well. Enter and live in it for ever'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
They will say: 'Praise belongs to Allah who has been true to His promise to us and given us the earth to inherit, that we shall live in Paradise wherever we wish' How excellent is the recompense of those that labor!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And you shall see the angels encircling the Throne exalting with the praise of their Lord. And the matter will be justly decided between them, and it shall be said: 'Praise belongs to Allah, Lord of all the Worlds'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen HaMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The sending down of the Book is from Allah, the Almighty, the Knower.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
The Forgiver of sins and the Acceptor of repentance. Stern in retribution, the Bountiful, there is no god except He and to Him is the arrival.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None but the unbelievers dispute concerning the verses of Allah. So do not be deluded by their going to and fro in the land.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
The nation of Noah before them belied, and so did the parties after them. Every nation strove against their Messenger to seize him, disputing with false arguments to refute the truth. Then I seized them, how was My punishment!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
And so it is that the Word of your Lord shall be realized against the unbelievers they are the inhabitants of the Fire.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those who bear the Throne and those around it exalt with the praise of their Lord and believe in Him. They ask forgiveness for the believers (saying): 'Our Lord, You embrace all things in mercy and knowledge. Forgive those who repent and follow Your Way. Shield them against the punishment of Hell.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
Admit them, Our Lord, to the Gardens of Eden which You have promised them, together with those who were righteous among their fathers, their wives, and their offspring. You are the Almighty, the Wise,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
and guard them against all evil deeds. Whosoever You guarded against evil deeds on that Day, surely, You have had mercy upon them, and that is indeed the mighty triumph'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
It shall be proclaimed to the unbelievers: 'Surely, the hatred of Allah for you is greater than your hatred of yourselves. You were called to belief but disbelieved.'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They shall say: 'Our Lord, twice You have made us die, and twice You have given us life, now, we confess our sins. Is there any way we can be brought out of this'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
(They shall be answered): 'That is because you disbelieved when Allah alone was supplicated to, but when others were associated with Him you believed.' Judgement belongs to Allah, the Most High, the Great.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
It is He who shows to you His signs and sends down your provision from the sky. Yet no one remembers except he who is penitent.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
Supplicate then to Allah making your religion sincerely His, even though the unbelievers oppose it.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
Exalter in ranks, Owner of the Throne. He lets the spirit (the revelation) descend at His order on those of His worshipers whom He chooses, in order that He warns of the Day of the Meeting;\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
the Day when they shall rise up with nothing hidden from Allah. And who is the Owner of the Kingdom on that Day? Allah, the One, the Conqueror!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
On that Day every soul shall be recompensed for its earnings and on that Day none shall be wronged. The reckoning of Allah is swift.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
Warn them against the Imminent Day when, choking with anguish, the hearts will be in their throats, the harmdoers will not have a single, loyal friend, and there will be no intercessor to be obeyed.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
He (Allah) knows the furtive looks of the eyes and what the chests conceal.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
With justice Allah will judge, but those upon whom they call, other than Him, can not judge anything at all! Allah is the Hearer, the Seer.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Have they never journeyed through the land and seen what was the end of those who have gone before them? They were stronger than themselves in might and left firmer traces in the earth, but Allah seized them for their sinning, and they had none to protect them from Allah.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That was because they disbelieved their Messengers when they came to them with clear signs, and so Allah seized them. Surely, He is Strong, and Stern in retribution.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
We sent Moses with Our signs and with clear authority\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
to Pharaoh, Haman, and Korah. But they said: 'A sorcerer, a liar'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
And when he brought them the truth from Us they said: 'Kill the sons of those who believe with him, but spare their women' But the scheming of the unbelievers is always in error.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
Pharaoh said: 'Let me kill Moses, then let him call to his Lord! I am fearful that he will change your religion or cause mischief in the land'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
Moses said: 'I take refuge in my Lord and in your Lord from every proud (person), who does not believe in Day of Reckoning'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
But one of Pharaoh's people, who was in secret a believer, asked: 'Would you kill a man because he says: ``My Lord is Allah?" He has brought you clear signs from your Lord. If he is lying, let his lie be on his head, but, if he is speaking the truth then at least a part of what he promises will befall you. Allah does not guide the lying sinner.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
O my nation, today the kingdom is yours and you are the masters in the land. But, if the might of Allah should come against us, who will help us' Pharaoh said: 'I only let you see what I see. I guide you to the path of righteousness'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
The one who believed said: 'I fear for you the like of the day of the confederates my nation,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
or, something similar to the circumstances of the nations of Noah, Aad, and Thamood, and those who came after them. Allah does not want to wrong His worshipers.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
And, my nation, I fear for you the Day of Calling,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
the Day when you will turn in retreat with none to protect you from Allah. He whom Allah leads astray has no guide.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
Before this, Joseph brought you clear signs, but you continued to be doubtful of that which he brought. When he passed away you said: ``Allah will never send another Messenger after him." As such Allah leads astray the sinner, the doubter.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
Those who dispute the signs of Allah without any authority having reached them are very hateful before Allah and the believers. As such Allah sets a seal on every heart that is proud and arrogant.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
Pharaoh said: 'Haman, build me a tower that I can reach the ways,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
the ways of heaven so that I may look upon the God of Moses, because I think that he is a liar' And so Pharaoh's evil deeds were made to seem fair to him, and he was barred from the Way. And Pharaoh's guile came to nothing except ruin.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
He who was a believer said: 'Follow me, my nation, so that I may guide you to the Right Path.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
O my nation, the life of this world is nothing but an enjoyment, but surely, the life of the Everlasting Life is the stable abode.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
Those who do an evil deed shall only be rewarded with its like, but those who believe and do good works, either men and women, shall enter the Gardens of Paradise and are provided for without reckoning.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
My nation, how is it that I call you to salvation and you call me to the Fire?\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
You call me to disbelieve in Allah and to associate with Him that of which I know nothing; while I call you to the Almighty, the Forgiving.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
There is no doubt that what you call me to has neither a call in this world, nor in the Everlasting Life. To Allah we shall return, and the excessive sinners are the inhabitants of the Fire.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
You will remember what I say to you. To Allah I commit my affair, surely, Allah sees His worshipers'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
Allah saved him from the evils that they devised, and an evil punishment encompassed Pharaoh's people.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
(Before) the Fire they shall be exposed morning and evening, and on the Day when the Hour comes, (it will be said): 'Admit the family of Pharaoh into the most terrible punishment'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
And when they argue with one another in Hell, the weak will say to the proud: 'We were your followers, will you help us against any share of the Fire'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
But those who were proud will reply: 'All of us are in it (Hell). Allah has judged between His worshipers'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those in the Fire will say to the keepers of Gehenna (Hell): 'Call your Lord to lessen our punishment for one day'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
But they will say: 'Did your Messengers not come to you with clear signs' 'Yes indeed' they will answer. And they will reply: 'Then you call' But the calling of the unbelievers is only in error.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Surely, We shall help Our Messengers and the believers both in this world and on the Day when the witnesses rise.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
On that Day no excuse will benefit the harmdoers. Theirs shall be the curse, and an evil lodging.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
We gave Moses the Guidance and bequeathed upon the Children of Israel the Book\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
for guidance and a reminder for those of understanding.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
Therefore have patience; the promise of Allah is true, and ask forgiveness of your sins, and exalt with the praise of your Lord in the evening and at dawn.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
(As for) those who dispute the verses of Allah without authority having been given to them, there is nothing in their chests but pride; that, they shall never attain. Therefore seek refuge in Allah, surely, He is the Hearer, the Seer.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
Indeed, the creation of heavens and earth is greater than the creation of mankind, yet most people do not know.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
The blind and the seeing are not equal, nor are those who believe and do good works, and the wrongdoer yet you seldom reflect.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
There is no doubt that the Hour is coming, yet most people do not believe.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
Your Lord has said: 'Call on Me and I will answer you. Those who are too proud to worship Me shall enter Gehenna utterly abject'\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
It is Allah who made for you the night in which to rest and the day to see. Allah is bountiful to the people, yet most people do not give thanks.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
Such is Allah, your Lord, the Creator of all things. There is no god except He. How then can you turn away from Him?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
As such those who disbelieve the signs of Allah turn away.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
It is Allah who has given you the earth as a fixed place, and the heaven for a canopy. He has shaped you and made you fine images, and provided you with goodness. Such is Allah, your Lord. Blessed be Allah, Lord of all the Worlds.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Living; there is no god except He. Supplicate to Him and make the religion sincerely His. Praise belongs to Allah, Lord of the Worlds!\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say: 'I am forbidden to worship those whom you worship, other than Allah. Clear verses have come to me from my Lord and I am commanded to surrender to the Lord of the Worlds'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
It is He who created you from dust, then from a (sperm) drop, and then a (blood) clot. He then brings you forth as an infant, then you reach your strength, after which you come of age though some of you die before it and that you reach an appointed term, in order that you understand.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
It is He who gives life and makes to die, and when He decrees a thing, He says to it: 'Be' and it is!\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Do you not see how those who dispute about the verses of Allah how they are turned about?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who belie the Book and that with which We sent Our Messengers shall soon know.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When the fetters and chains are round their necks they shall be dragged\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
into boiling water, then, into the Fire they shall be poured.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
It will then be asked of them: 'Where are those whom you associated,\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
other than Allah' They will reply: 'They have gone astray from us. Indeed what we used to call upon before is nothing' Accordingly, Allah leads the unbelievers astray.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
(And it will be said): 'That is because you rejoiced on earth in things of which you had no right, and were very happy.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter the gates of Gehenna and live there for ever. Evil is the lodging of the proud.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
Therefore have patience, the Promise of Allah is true. Whether We show you something of that We promise them or call you to Us, to Us they shall all return.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
We sent other Messengers before you; of some, We have already told you, of others We have not told you. Yet it was not for any Messenger to bring a verse except by the permission of Allah. And when the command of Allah comes the matter will be justly decided; and the vaindoers will be lost.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
It is Allah who has provided you with cattle, some that you ride and some that you eat,\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
and for you there are other uses in them, and that upon them you may reach a need in your chests, and upon them and on ships you are carried.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
He shows you His signs. Now which of the signs of Allah do you disbelieve?\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Have they never journeyed through the land and seen what was the end of those who have gone before them? They were stronger than themselves in might and left firmer traces upon the earth; yet, whatsoever they earned did not help them.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
When their Messengers brought them clear verses they rejoiced in such knowledge as they had; but they were encompassed by that which they mocked.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
And when they saw Our Might, they said: 'We believe in Allah alone, and we disbelieve in that we used to associate with Him'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
But when they saw Our Might their belief did not benefit them! It is the way of Allah that has passed concerning His worshipers. There, the unbelievers shall be lost.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen HaMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
A sending down from the Merciful, the Most Merciful.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Book, the verses of which are distinguished, an Arabic Koran for a nation who know.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
It bears glad tidings and a warning, yet most of them turn away and do not listen.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
They say: 'Our hearts are veiled from that to which you call us, and in our ears there is heaviness. And between us and you is a veil. So work (as you will) and we are working'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say (Prophet Muhammad): 'I am only a human like you, to whom it is revealed that your God is One God. Therefore be straight with Him and ask Him to forgive you. Woe to the idolaters,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
who do not pay charity and disbelieve in the Everlasting Life.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
For those who believe and do good works is an enduring wage'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say: 'Do you disbelieve in Him who created the earth in two days? And do you set up equals with Him? He is the Lord of the Worlds'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
He set firm mountains on top (of the earth) and He blessed it. And in four days He ordained in it many provisions, equal to those who ask.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Then He willed to the heaven when it was smoke, and to it and the earth He said: 'Come willingly, or unwillingly' 'We come willingly' they answered.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
In two days He determined them seven heavens, and He revealed to each heaven its commands. We decorated the lowest heaven with lamps and preserve them. Such is the decree of the Almighty, the Knower.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
But if they turn away, say: 'I have given you warning of a thunderbolt similar to that which overtook Aad and Thamood'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
When their Messengers came to them from before them and behind them, (saying): 'Worship none except Allah' they answered: 'Had it been the will of our Lord, He would have sent down angels. So we disbelieve in the Message with which you were sent'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for Aad, they behaved proudly in the earth without right. 'Who is stronger than us' they would say. Could they not see that Allah, who created them, is stronger than they? But they disbelieved Our signs.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
Then, on the ominous days, We loosed against them a howling wind that We might let them taste the punishment of humiliation in this life; but more humiliating will be the punishment of the Everlasting Life and they will not be helped.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
As for Thamood, We (offered) them Our Guidance, but they preferred blindness to guidance. So a thunderbolt of the humiliating punishment seized them because of what they had earned;\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
and We saved those who believed and feared Allah.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
On the Day when the enemies of Allah will be rightfully gathered together before Fire,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
when they reach it, their hearing, eyes and skins will testify against them for what they were doing.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
'Why did you bear witness against us' they will ask their skins, and they will reply: 'Allah has given us speech, as He has given speech to everything. It was He who created you the first time, and to Him you shall return.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
It is not that you covered yourselves so that your hearing, eyes and skin could not bear witness against you but you thought that Allah did not know much of that which you do.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
Rather, it is the thoughts you thought about your Lord that have destroyed you, therefore, this morning you find yourselves among the losers'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
Even if they are patient the Fire shall still be their lodging, and if they seek pardon, they shall not be among those who are pardoned.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
We have assigned companions to them, who make what is before them and behind them seem fair to them. The statement has been realized against them in nations of people and jinn alike that passed away before them they were indeed the losers.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
The unbelievers say: 'Do not listen to this Koran, and talk idly about it so that you might be overcome'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
We will let the unbelievers taste a terrible punishment, and recompense them with the worst of what they were doing.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
The Fire that is the recompense of the enemies of Allah. There it is that they will be lodged for eternity, a recompense for their disbelief of Our verses.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
The unbelievers will say: 'Lord, show us the jinn and people who led us astray, to put them under our feet so that they are among the lowest'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
The angels will descend on those who said: 'Allah is Our Lord' and have then gone straight, (saying:) 'Be neither fearful, nor sad; rejoice in the Paradise you have been promised.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
We are your guides in this world and in the Everlasting Life. There, you shall have all that your souls desire, and all that you ask for\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
as hospitality from One, the Forgiving, the Most Merciful'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And, who is better in saying than he who invites to Allah, does what is right, and says: 'Surely, I am of those who surrender'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
Good and evil deeds are not equal. Repel with that which is most just, and see, the one whom there is enmity between you will be as if he were a loyal guide.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
But none will receive it except those who are patient and, none shall receive it, except he who has a great share.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
If a provocation from satan should provoke you, seek refuge in Allah. He is the Hearer, the Knower.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
Among His signs are the night and the day, and the sun and the moon. But do not prostrate yourselves before the sun or the moon; rather prostrate before Allah, who created them both, if it is He whom you worship.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
But if they become proud, those who are with your Lord exalt Him by day and night, and never grow weary.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And among His signs is that you see the earth humble; then when He sends down rain upon it, it quivers and swells. He who revives is He who revives the dead, surely, He is powerful over everything.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Those who disbelieve Our verses when it comes to them are not hidden from Us. Is he who is cast in the Fire better than he who comes in safety on the Day of Resurrection? Do as you will, surely, He sees the things you do.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Those who disbelieve in the Remembrance when it comes to them and indeed this is a Mighty Book\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
falsehood does not come to it from before it or from behind it. It is a sending down from the One, the Wise, the Praised.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Nothing that is said to you has not already been said to other Messengers before you. Indeed, your Lord is a Lord of forgiveness, but stern in retribution.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
Had We made the Koran in a nonArabic (language) they would have said: 'If only its verses were distinguished! Why in (a) nonArabic (language, when theProphet is) an Arab' Say: 'To the believers it is a guidance and a healing. But to those who do not believe, there is a heaviness in their ears, to them it is blindness. They are those called from afar'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
We gave the Book to Moses, but there were disputes about it, and had it not been for a Word that preceded from your Lord (their disputes) would have been decided between them. But they are in disquieting doubt about it.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
He who does good does it for himself; and he who does evil does so against it. Your Lord never wrongs His worshipers.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
To Him is referred the knowledge of the Hour. No fruit sprouts forth from its sheath, no female conceives or is delivered, except with His Knowledge. On the Day He will call to them: 'Where then are My associates' they will reply: 'We proclaim to You that none of us can bear witness'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
Those they used to call upon before will go away from them, and they shall think that they have no asylum.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Mankind never wearies of supplicating for goodness, but when evil befalls him he is downcast and (grows) desperate.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And if We give him a taste of mercy from Us after his affliction has befallen him, he is sure to say: 'This is my own. I do not think the Hour will ever come. And even if I am returned to my Lord, with Him there is for me the finest reward (Paradise)' Then, We shall tell the unbelievers what they did and let them taste a harsh punishment.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
When We favor a human, he swerves away and withdraws aside, but when evil befalls him he is full of unending prayer.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Say: 'Think, if this (Koran) is indeed from Allah, and you disbelieve in it, who is further astray than he who is in a wide schism'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
We will show them Our signs in all the horizons and in themselves, until it is clear to them that it is the truth. Is it not sufficient that your Lord is witness over everything'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Are they not in doubt concerning the Meeting with their Lord? Attention, He encompasses everything.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen HaMeem\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
'AeenSeenQaaf\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
As such Allah, the Almighty, the Wise reveals to you (Prophet Muhammad) and to those before you.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
To Him belongs whatsoever is in the heavens and the earth. He is the High, the Exalted.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
The heavens nearly break apart above them as the angels exalt with the praise of their Lord and ask forgiveness for those on earth. Indeed Allah is the Forgiving, the Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
As for those who take guardians for themselves, other than Him, Allah is the Warden over them. You are not a guardian over them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
As such We have revealed to you an Arabic Koran, so that you can warn the Mother of Villages (Mecca) and all who live about it, and that you also warn them of the Day of Gathering in which there is no doubt that a division will be in Paradise, and a division in the Blaze.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
Had it been the Will of Allah, He would have made them all one nation. But He admits into His Mercy whom He will the harmdoers shall have neither a guardian nor helper.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
Or have they taken to themselves guardians other than Him? But Allah, He is the Guardian. He revives the dead and has power over all things.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
Whatever you differ upon, its judgement belongs to Allah. Such is Allah, my Lord, in Him I have put my trust, and to Him I turn in repentance.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
The Originator of the heavens and the earth, He has given you from yourselves, pairs, and also pairs of cattle, thereby multiplying you. There is nothing like Him. He is the Hearer, the Seer.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
To Him belongs the keys of the heavens and the earth. He outspreads and withholds His provisions to whom He will, surely, He has knowledge of all things.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He has made plain for you the Religion with which He charged Noah and that which We have revealed to you, and that with which We charged (Prophets) Abraham, Moses and Jesus, (saying): 'Establish the Religion and do not be divided therein' That which you invite them to is too overwhelming for the idolaters. Allah brings close to Himself whom He will, and guides to Him those who turn in repentance.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
Yet they became divided only after knowledge had reached them from their own insolence. And had it not been for a Word that had preceded from yourLord, till an appointed term, it would have been determined between them. But those who inherited the Book after them are in disquieting doubt about it,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
so invite and go straight as you are ordered, and do not follow their desires and say: 'I believe in whatever Book Allah has sent down. I am ordered to be just among you. Allah is our Lord and your Lord. We have our deeds and you have yours; there is no argument between us and you, Allah will bring us all together, to Him is the arrival'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
As for those who argue concerning Allah after being answered, their arguments will be annulled before their Lord, and His Wrath will fall upon them, and for them there is a terrible punishment.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
It is Allah who has sent down the Book in truth and the Scale. And what will let you know? The Hour is near.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those who disbelieve in it seek to hasten it, but the believers are in fear of it, knowing it to be the truth. Indeed, those who doubt the Hour have strayed far away.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Allah is Subtle towards His worshipers, and provides for whosoever He will. He is the Strong, the Almighty.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whoever hopes for the tillage of the Everlasting Life, We will increase his tillage; and whoever hopes for the tillage of this world, We give him some of it, but in the Everlasting Life he shall have no share.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Or do they have associates who have made lawful to them in religion what Allah has not permitted? Had it not been for the Decisive Word, it would have been decided between them. For the evildoers there is a painful punishment.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
You shall see the harmdoers in fear of what they have earned as it is about to fall on them. But those who believe and do good deeds shall live in the meadows of the Gardens and from their Lord they will have all that they desire that is the great bounty.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
This is the glad tidings that Allah gives to His worshipers, who believe and do good works. Say: 'For this I ask of you no wage except the love of the (Prophet's) relatives. We will add good to whosoever gains a good deed. Allah is the Forgiving and the Thanker'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Or do they say: 'He has forged a lie about Allah? But if Allah wills He could set a seal upon your heart. Allah wipes out falsehood and verifies the truth by His Words. He knows the innermost of the chests.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
It is He who accepts the repentance of His worshipers and pardons their evil deeds. He has knowledge of what you do.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
He answers those who believe and do good deeds, and He increases them from His bounty. But for the unbelievers there is a terrible punishment.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
If Allah had expanded His provision to His worshipers, they would become tyrannical in the earth, but He sends down to them what He will in due measure; He is Aware and sees His worshipers.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
It is He who sends down rain for them after they despaired, and He unfolds His Mercy. He is the Guardian, the Praised.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
Among His signs is the creation of the heavens and the earth and the crawling things which He has dispersed in them. If He will, He is Able to gather all of them.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
If affliction befalls you, it is what your own hands have earned, but He pardons a lot.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
You are not able to frustrate Him in the earth, nor do you have a guardian and a helper other than Allah.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And among His signs are the ships that run on the sea like mountains and\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
if He will, He calms the wind so that they remain motionless upon its back, surely, there are signs in this for every thankful, patient (person).\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or, He wrecks them for what they have earned, but He pardons a lot.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
Those who dispute Our verses may know that they have no asylum.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
That which you have been given is but the enjoyment of the present life. Better and more enduring is that which Allah has for those who believe and put their trust in their Lord.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And those who avoid the major sins and indecencies and, when angered, forgive;\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
those who answer their Lord, establish the prayers, and their affairs are by consultation; who spend of that which We have given them,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
and when harmed they become victorious.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The recompense of a sin is a sin like it, but whosoever forgives and seeks to reform, his wage will be with Allah. Surely, He does not love the harmdoers.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
And whosoever harms after he has been harmed there is no blame upon them.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
The blame is only against those who wrong people, and are wrongfully insolent in the earth, for them there is a painful punishment.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
Surely, he who bears patiently and forgives indeed that is true constancy.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
He whom Allah leads astray has none to protect him thereafter. You will see the harmdoers when they see the punishment saying: 'Is there a way back'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
You shall see them exposed before it, humbled in shame and looking upon it with a furtive glance and the believers will say: 'Indeed, the losers are they who lose themselves and their families on the Day of Resurrection' The harmdoers shall suffer an everlasting punishment.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
They shall have none to protect or help them other than Allah. He whom Allah leads astray there is no way for him.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Answer your Lord before that Day arrives which cannot be turned back from Allah, for you on that Day there shall be neither shelter, nor denial.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
But if they turn away, We have not sent you (Prophet Muhammad) to be their (compulsory) guardian. It is only for you to deliver (the Message). When We give the human a taste of Our Mercy, he rejoices because of it; but when, because of what he has earned, evil befalls him, the human is ungrateful.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
To Allah belongs the Kingdom of the heavens and the earth. He creates what He will. He gives females to whom He will and males to whom He will.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or, He couples them, both males and females, and to others, if He will, He makes them barren. Surely, He is the Knower, the Powerful.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
It does not belong to any human that Allah should speak to him except by Revelation, or from behind a veil, or that He sent a Messenger to revealwhatsoever He will by His Permission. He is the High, the Wise.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
As such We have revealed to you (Prophet Muhammad) a spirit (the revelation of the Koran) from Our Ordinance. You did not know what the Book was, nor belief, but We made it a light whereby We guide those of Our worshipers whom We will. And you (Prophet Muhammad), you, surely guide to a Straight Path.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The Path of Allah, to whom belongs all that is in the heavens and all that is in the earth. Surely, to Allah all things return.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen HaMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the Clear Book\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
We have made it an Arabic Koran in order that you understand.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
It is in the Origin of the Book with Us, sublime and wise.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Shall We turn away the Remembrance from you because you are a sinful nation?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
How many a Prophet did We send to the ancients,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
no Prophet came to them except that they mocked him,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
so We destroyed those who were mightier in courage than they. And the example of the ancients has passed away.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
Yet, if you ask them who created the heavens and the earth, they will answer: 'The Almighty, the Knower created them'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
(It is) He who made the earth to be a cradle for you and made in it ways for you, in order that you are guided.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
And (it is He), who sends down water from the sky in its measure thereby We revive the land that was dead, as such you shall be brought forth.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
And, (it is He) who has created all the pairs and appointed for you ships and the cattle on which you ride,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
so that you can sit upon their backs and then remember the Favors of your Lord and say: 'Exaltations to Him who has subjected these to us otherwise, we ourselves were not capable of it,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
indeed, to our Lord we are turning'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
Yet they assign to Him some of His own (created) worshipers! Clearly, the human is unthankful.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Or, has He taken daughters from those He has created for Himself and favored sons for you?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
Yet when one of them is given glad news of (a daughter) that which he likened to the Merciful his face darkens and he chokes inwardly (with gloom).\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
(As such they attribute to Allah) who is brought up among ornaments but when disputes arise are powerless.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
They claim that the angels, who are themselves the worshipers of the Merciful, are females. Did they witness their creation! Their witness shall be written down and they shall be questioned.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
They say: 'Had it been the will of the Merciful, we would never have worshipped them' Of this they have no knowledge, they are but guessing.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or have We given them a Book before this which they hold fast to?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
No, but they say: 'We found our fathers following a creed, and by following in their footsteps we are guided.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
As such, We never sent a warner before you to a village, except those living in luxury said: 'We found our fathers following a creed, and by following in their footsteps we are guided'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
Say: 'What then if I bring you a better guidance than that you found your fathers following' But they reply: 'We disbelieve in that you have been sent with.'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So We took vengeance upon them, and see how the end was of those who lied.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
(Remember) when Abraham, said to his father and his nation: 'I am quit from what you worship,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
except Him who originated me, for He will guide me'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
He made this an abiding word among his descendants, in order that they would return.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
I gave them and their fathers days of enjoyment until the truth and a clear Messenger came to them.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
But when the truth came to them, they said: 'This is sorcery, we disbelieve in it'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
They also said: 'Why was this Koran not sent down to a great man from the two Villages'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
What, is it they who divide the Mercy of your Lord! (It is) We who divided between them their livelihoods in this life, raising some in rank above others, sothat some may take the other into his service. Your Lord's Mercy is better than all they gather.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
If it were not that mankind would be one nation We would have made for whosoever disbelieves in the Merciful silver roofs upon their houses, and stairs toclimb,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
with doors to their houses and couches on which to recline;\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
and gold, surely, all this is but the enjoyment of this present life. The Everlasting Life with your Lord is for those who fear (Him).\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
To whosoever blinds himself from the Remembrance of the Merciful, We shall assign him a satan so he is his companion,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
and they bar them from the Way, though they themselves think that they are guided.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
And when he comes before Us, he shall say: 'Would that there had been between me and you, the distance of the two Easts' Evil is the companion.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
Because of the harm you did, it would be of no benefit to you today, you are partners in the punishment.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
What, will you make the deaf hear, or guide the blind and he who is in clear error?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
Even if We take you away, We shall take vengeance upon them,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
or We show you a part of that which We have promised them, for indeed We have power over them.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
Therefore, hold fast to that which is revealed to you, indeed, you are on the Straight Path.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
It is indeed a Reminder to you and to your nation, and without doubt you shall be questioned.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
Ask Our Messengers whom We sent before you if We have ever made gods, other than the Merciful, to be worshipped.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
We sent Moses with Our signs to Pharaoh and his Council, and he said: 'I am the Messenger of the Lord of the Worlds'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
But when he showed them Our signs they laughed at them,\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
yet there was not a sign that We showed them that was not greater than its sister, and We seized them with the punishment so that they might return.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
'Sorcerer' they said, 'pray to your Lord for us in accordance to the covenant He has made with you, and surely we shall be rightly guided'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But when We had relieved them of their punishment they broke their promise.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
Then Pharaoh made a proclamation to his people: 'My people, is the kingdom of Egypt not mine and these rivers which flow beneath me? What, can you not see?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
Am I not better than this contemptible (man), who can scarcely make things clear (because of the impediment of his speech)?\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
Why have no armlets of gold been given him, or angels sent down successively with him'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
He (Pharaoh) intimidated his nation, so they obeyed him, for they were a sinning nation.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
And when they angered Us, We took vengeance on them and drowned all of them,\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
and We made them a thing of the past, and We made them an example to later people.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
When the son of Mary is mentioned as an example, your people turn away from it\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
and say: 'What are our gods better, or is he' They do not mention him to you except to dispute, truly, they are a contentious nation.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He (Prophet Jesus) was only a worshiper whom We favored and We made him an example to the Children of Israel.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
Had it been Our Will We would have made angels among you as successors in the earth.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
It is the knowledge of the Hour. Have no doubt concerning it, and follow me. This is a Straight Path,\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
and do let satan prevent you, for he is your clear enemy.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
And when (Prophet) Jesus came with clear signs, he said: 'I have come to you with wisdom and to clarify to you some of the matters about which you differ. Fear Allah and obey me.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
Indeed, Allah is my Lord and your Lord, therefore worship Him. That is the Straight Path'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
Yet the parties differed among themselves. So woe to those who did evil among the punishment of a Painful Day.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Are they looking for anything except the Hour (to overtake them). It will come upon them suddenly when they are unaware!\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
On that Day close friends shall become enemies of each other, except those who fear (Allah).\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
O My worshipers, there is no fear for you on this Day, nor will you grieve\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
to those who believed in Our verses and were Muslims,\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
(it will be said) 'You and your spouses, enter, walking with joy into Paradise'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
To them will be passed large platters and cups of gold. There will be all that souls desire and all that eyes delight in. (And it will be said:) 'There you shall live for ever.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
Such is the Paradise you shall inherit, for the things you did.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
You shall have therein abundant fruit to eat'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
But the evildoers shall live for ever in the punishment of Gehenna (Hell),\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
which will not be lightened for them, and therein they shall be silent.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
We did not wrong them, but they were harmdoers.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
'O Malik' (the angel of Hell) they will call out, 'let your Lord put an end to us' But he will answer: 'Here you shall stay'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
We brought you the truth, but most of you were averse to the truth.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Or have they devised a matter! We are devising.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Do they think We do not hear their secret and that which they conspire! Yes, indeed Our angels, who are present with them write it down.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say (Prophet Muhammad): 'If the Merciful had a son, I would be the first of the worshipers.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Exaltations be to the Lord of the heavens and the earth, the Lord of the Throne, above that which they describe'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
Let them alone to plunge and play, until they encounter that Day of theirs which they are promised.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
He who is God in the heavens is also God in the earth; He is the Wise, the Knower.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
Exaltations to Him to whom belong the Kingdom of the heavens and the earth, and all that is between them! With Him is the knowledge of the Hour and toHim you shall be returned.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
Those whom they call upon, other than Him, have no power to intercede (for them), except those that have knowingly borne witness to the truth.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
Yet if you ask them: 'Who created you' they will say: 'Allah' How then can they turn away from Him?\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
And for his saying: 'My Lord, these are an unbelieving nation'\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
pardon them, and say: 'Peace', soon they will know.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen HaMeem\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the Clear Book\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
that We sent down during a Blessed Night. We are ever warning.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
In it every wise matter is determined\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
an order from Us. We are ever sending.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
A Mercy from your Lord, He is the Hearer, the Knower.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
Lord of the heavens and the earth and all that is between them, if you are certain (of your faith).\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no god except He. He revives and causes to die. (He is) your Lord and the Lord of your fathers, the ancients.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Yet they are in doubt, playing.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
Watch for the Day when the heaven will bring clear smoke,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
engulfing the people; this will be a painful punishment.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
'Our Lord, remove this punishment from us, we are believers'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
But how will they avail themselves of the Reminder, when a clear Messenger had already come to them\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
but then they turned away from him, saying: 'He is tutored, mad'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
We are removing the punishment a little, but you revert.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
But on that Day We will assault them most mightily, and then We shall revenge!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
We tried Pharaoh's nation before them. A noble Messenger came to them,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
(saying:) 'Be obedient to me O worshipers of Allah. I am your honest Messenger.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
Do not rise up against Allah, I come to you with clear authority.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
I take refuge with my Lord and your Lord lest you stone me.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
And if you do not believe me, then leave me'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
Then he supplicated to his Lord saying: 'These are sinful people'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
(His Lord answered): 'Set out with My worshipers in the night, for you will surely be followed.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
Then leave the sea calm they are an army that will be drowned.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How many gardens and fountains did they leave behind,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
and sown fields, fine sitting places,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
and good things in which they took delight.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
As such (it was). And We made other people inherit them.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
Neither heaven nor earth shed tears for them; nor were they respited,\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
and We saved the Children of Israel from a humiliating punishment\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
from Pharaoh, who ranked high in sin,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
and We chose them, out of a knowledge above the nations (of their time).\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And gave signs to them in which there was a clear trial.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
Yet these say:\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
'There is nothing except the first death, we shall never be revived.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
Bring us our fathers, if what you say is true'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better or the people of Tubba' and those who were before them whom We destroyed? Indeed they were sinners.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
It was not in play that We created the heavens and the earth and all that is between them.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We created them in nothing else except the truth. But most do not know.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
The Day of Decision is the appointed time for all.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
On that Day no cousin shall help his cousin and they shall not be helped\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
except those on whom Allah will have mercy. He is the Almighty, the Most Merciful.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
The food of the Zakkum tree\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
shall be the food of the guilty sinners.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like molten copper boiling in the belly\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
as the boiling of the hot water.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
'Seize him and drag him into the center of Hell.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
Then pour the punishment of boiling water over his head,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
(Saying): 'Taste, surely you are the mighty and noble!\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
This is that which you doubted'\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Indeed, for those who feared (Allah) is a secure place\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
amidst gardens and fountains,\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
dressed in silks and brocade, set face to face.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
As such, We shall wed them to wideeyed houris (the virgins of Paradise).\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
There in security, they will call for every kind of fruit.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
There they shall not taste death, except the first death, and He will shield them from the punishment of Hell,\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
as a bounty from your Lord. That will be the mighty triumph.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
We have now made it easy on your tongue, in order that they remember.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
So be watchful, they too are watching.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen HaMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The sending down of the Book is from Allah, the Almighty, the Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Indeed, there are signs in the heavens and earth for believers,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
and in your creation, and in the crawling things that He has scattered far and near, there are signs for a nation whose belief is certain,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
and in the alternation of the night and day, in the provision Allah sends down from heaven with which the earth is revived after its death, and in the changing about of the winds, there are signs for people who understand.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
Such are the verses of Allah. We recite them to you in truth. So in what speech, after Allah and His signs, will they believe?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe to all the guilty impostors!\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
He hears the verses of Allah recited to him and then, as though he never heard them, persists in insolence. Give to him the glad tidings of a painful punishment.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
As for he who knows something of Our verses and then mocks them for those there is a humiliating punishment.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
Gehenna (Hell) is behind them, all that they have earned shall not help them at all, nor shall those they took as guardians, other than Allah. For them there is a mighty punishment.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This is guidance; for those who disbelieve in the verses of their Lord the anger of the painful punishment awaits them.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
It is Allah who has subjected to you the sea so that ships run upon it at His command, and so that you may seek His bounty and be thankful.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
He has subjected to you whatsoever is in the heavens and the earth; all is from Him. Surely, there are signs in this for people who contemplate.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Tell the believers to forgive those who do not look for the Days of Allah, so that He recompenses the people for what they have earned.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
He who does what is right does it for his own gain, and he who does evil does so at his own loss, then to your Lord you shall all return.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
We gave to the Children of Israel the Book, judgment and prophethood. We provided them with good things and preferred them above the worlds (of theirtime).\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
We gave them clear signs of the Command; yet it was not until after knowledge had come to them that they differed among themselves, and were insolent to each other. On the Day of Resurrection your Lord will indeed decide their differences.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
And now, We have set you on the jurisprudence of the Command, therefore follow it and do not follow the desires of those who do not know.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Indeed, they will not help you at all against Allah. The harmdoers are guides of each other; but Allah is the Guide of the cautious.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
These are clear proofs for people, a guidance, and mercy for those who are certain (of the Resurrection) in belief.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Do those who commit evil deeds think that We will make them (equal) to the believers who do good works, so that in life and death they shall be alike? How evil they judge!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
Allah created the heavens and the earth in truth and that each soul shall be recompensed for what it earned, they shall not be wronged.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Have you seen he who took his desire for a god? With knowledge, Allah has led him astray, setting a seal upon his hearing and heart, and has made a veil over his eyes, who then shall guide him after Allah? Will you not then remember!\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
They say: 'There is nothing except this life, we die and we live, it is only time that destroys us' Surely, of this they have no knowledge, they are just guessing.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our verses are recited to them, their only argument is: 'Bring our fathers back to us, if what you say is true'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say: 'Allah revives you and causes you to die. Then, He shall gather you on the Day of Resurrection, and of this there is no doubt, yet most people do notknow'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmd{%
To Allah belongs the Kingdom in the heavens and the earth. On the Day when the Hour comes, those who disbelieved shall be the losers.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
You shall see every nation hobbling on their knees. Each nation shall be summoned to its Book. (And it will be said:) 'This Day, you shall be recompensedfor what you were doing.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This is Our Book that speaks with the truth over you. We have recorded all that you were doing'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
As for those who have believed and done good works, their Lord will admit them into His Mercy that is a mighty triumph!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
But, to the unbelievers (it will be said): 'Were My verses not recited to you, but you were proud and were you not a sinful nation'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
When it was said: 'The promise of Allah is true, and of the Hour there is no doubt' you replied: 'We do not know what the Hour is, we guess, assuming, and we are by no means certain'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
The evil of their deeds will appear to them, and they shall be encompassed by that they mocked,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
and it shall be said: 'Today, We will forget you as you yourselves forgot that you would encounter this Day. The Fire shall be your refuge, and none will help you.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
That is because you took the verses of Allah (the Koran) in mockery, and you were deluded by your worldly life' So that Day they will not be brought outof it; nor shall they be repentant.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
Praise, belongs to Allah, the Lord of the heavens and the earth, the Lord of the Worlds.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
His is the Pride in the heavens and earth. He is the Almighty, the Wise.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen HaMeem.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The sending down of the Book is from Allah, the Almighty, the Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
It was in truth that We created the heavens and the earth, and all that is between them, for an appointed term. Yet the unbelievers do not turn away from that which they were warned.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say: 'Have you seen those whom you call upon, other than Allah? Show me what they have created from the earth! Or, do they have a partnership in theheavens? Bring me a Book before this or some other remnant of knowledge, if what you say is true'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
Who is further astray than he who calls upon, other than Allah, those who will never answer him till the Day of Resurrection, who are indeed, heedless of their supplication?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And, when mankind are gathered, those will become their enemies and disown their worship.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
When Our clear verses are recited to them, the unbelievers say of the truth that came to them: 'This is clear sorcery'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Or, do they say: 'He has forged it' Say: 'If I have forged it, then you have no power to help me against Allah, He knows what you say. It is sufficient that Heis the Witness between me and you. He is the Forgiving, the Most Merciful'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say: 'I am not an innovation among the Messengers; nor know what will be done with me or you. I follow only what is revealed to me; I am only a clearwarner'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say: 'Consider, if this (Koran) is from Allah and you disbelieve in it, and a witness from the Children of Israel testifies to its like and believes, while you areproud! Indeed, Allah does not guide the harmdoers'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
The unbelievers say of the believers: 'Had it been any good they would not have believed in it before us' And because they are not guided by it they say: 'This is an ancient falsehood'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
Yet before it there was the Book of Moses which was an authority, and a mercy. This (Koran) is the Book confirming it (the other untampered Books) in theArabic tongue, to warn the harmdoers and to give glad tidings to those who do good.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Those who say: 'Our Lord is Allah' and follow the Straight Path shall have nothing to fear nor shall they sorrow.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
Those, they shall be for ever the inhabitants of Paradise, a recompense for what they did.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
We have charged the human to be kind to his parents. With much pain his mother bore him, and with much pain she gave birth to him; his bearing andweaning are thirty months. When he grows to manhood and attains his fortieth year, he says: 'Make me so disposed My Lord, so that I give thanks for the favorswith which You have blessed me, my father and mother, and that I will do good deeds that will please You. And, make me righteous and also my descendants. To You I repent, and I am among those who surrender'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
Such are those from whom We will accept the best of what they have done and whose evil deeds We shall overlook. Those, they are among the inhabitants of Paradise; true is the promise that has been promised them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
But he who says to his father and his mother, 'Fie on you! Do you promise me that I shall be brought forth, when entire generations have passed away before me' Yet they supplicate to Allah for help 'Woe to you! Believe, surely the promise of Allah is true' Then he says: 'This is nothing but fairytales of the ancients'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
Such are they against whom the statement is realized concerning the nations of humans and jinn alike that passed away before them; they were the losers.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
Each shall have their degrees, according to what they have done, so that He will recompense them for their works, and they shall not be wronged.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
Upon the Day when the unbelievers are brought before the Fire, (We shall say to them): 'You squandered your good things in your earthly life and took your fill of enjoyment in them, therefore today you shall be recompensed with a humiliating punishment, because you were unrightfully proud in the earth and for that you were debauchers'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
Remember Aad's brother who warned his nation in (the valley of) Al Ahqaf. Warners had already preceded and succeeded him saying: 'Worship noneexcept Allah! (he said) 'Indeed, I fear for you the punishment of a Dreadful Day'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
'Have you come to turn us away from our gods (they replied)? If what you say is true then bring down that which you promise us'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
'Allah alone has the knowledge' he said, 'I am sent to deliver to you the Message. But I can see that you are ignorant people'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
And when they saw it as a sudden cloud heading for their valley they said: 'This is a cloud that will bring us rain' 'Rather' (he replied): 'it is that which you have sought to hasten, a wind in which there is a painful punishment.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
It will destroy everything by the command of its Lord' And when morning came there was nothing to be seen except their dwellings. As such Werecompense sinful people.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And We had established them in that which We have not established you, and We made for them hearing, sight, and hearts, but their hearing, sight, andhearts did not help them a thing, because they disbelieved the signs of Allah. And what they mocked encompassed them.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
We destroyed the villages around you and We repeated Our signs so that they might return.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
Why did not those who they took, other than Allah, as mediating gods help them! Indeed, they went astray from them! Such were their lies and what they were forging.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
(Remember) how We sent to you (Prophet Muhammad) a company of jinn who, when they came and listened to the Koran, said to each other: 'Be silent' Then, when it was finished, they returned to their nation and warned them.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
'Our nation' they said: 'we have just been listening to a Book sent down after Moses confirming what came before it and guiding to the truth and to aStraight Path.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
Our nation, answer the Caller of Allah and believe in Him! He (Allah) will forgive you some of your sins and protect you from a painful punishment.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
Those who do not answer the Caller of Allah cannot frustrate Allah in the earth, nor shall any one protect them other than Him; those are in clear error'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Have they not seen that it is Allah who created the heavens and the earth and was not wearied by their creation, and that He is Able to restore the dead tolife? Yes, He has power over all things!\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
On the Day when the unbelievers are brought before the Fire they shall be asked: 'Is this not the truth' 'Yes, by our Lord' they will answer. He will say:'Then taste the punishment, for you were unbelievers'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
Be patient, as the Messengers of might were patient, and do not hasten it for them. On the Day when they see what they have been promised, it will be as if they did not stay except an hour of a day. (This Koran is) a Conveyance! Shall any be destroyed except the nation of evildoers?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who disbelieve and bar from the way of Allah, Allah will cause their deeds go astray.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
As for the believers who do good works and believe in what is sent down to Muhammad which is the truth from their Lord He will acquit them of their sinsand repair their condition.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
This is because the unbelievers follow falsehood while the believers follow the truth from their Lord. As such Allah sets forth for people their examples.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
Therefore, when you meet the unbelievers smite their necks, then, when you have killed many of them, tie the bonds. Then, either free them by grace orransom until war shall lay down its loads, in this way, it shall be. Had Allah willed, He would have been victorious over them; except that He might test you, the oneby the means of others. As for those who are killed in the Way of Allah, He will not let their works to go astray.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will guide them and repair their condition;\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
and He will admit them to the Paradise He has made known to them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
Believers, if you help Allah, He will help you and strengthen your feet.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
But the unbelievers shall be the destroyed losers. He will bring their deeds to nothing.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they hated what Allah has sent down, so He annulled their deeds.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Have they never journeyed through the land and seen what was the end of those who had gone before them? Allah destroyed them! Likewise it is for theunbelievers,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
that is because Allah is the Guardian of the believers, and the unbelievers have no guardian.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Allah will indeed admit those who believe and do good works into Gardens underneath which rivers flow. As for the unbelievers, they take their fill of pleasure and eat as the cattle eat, but the Fire shall be their lodging!\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
How many a village mightier than your own village, which has expelled you, We have destroyed there was none to help them!\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
Is he who has clear proof from his Lord to be compared to him whose evil deeds are made to seem fair to him, so that they followed their desires?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
The example of the Paradise which the cautious have been promised in it, there are rivers of unstaling water, and rivers of milk that never change in flavor, and rivers of wine, delectable to the drinkers, and rivers of pure, filtered honey. They shall have therein of every fruit and forgiveness from their Lord. Are they then like he who shall live in the Fire for ever and given boiling water to drink that tears his bowels apart!\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
Some of them listen to you, but no sooner do they leave you they ask those to whom knowledge has been given: 'What did he say just now' Such are those whom Allah has set a seal upon their hearts and who follow their own desires.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
As for those who were guided, He increases their guidance and gives them their protection.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Are they looking except for the Hour to overtake them suddenly? Its signs have come. But how will they be reminded when it has come to them?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
Therefore, know that there is no god except Allah and ask for forgiveness of your sins and for the believers, men and women. Allah knows your going to and fro, and your lodging.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
The believers ask: 'Has a chapter been sent down' But when a clear chapter is sent down and fighting is mentioned in it, you see those in whose hearts is sickness looking towards you as one who swoons at death.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
Yet obedience and honorable words (would be better for them). Then, when the matter is decided, if they were true to Allah it would be better for them.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
Could it be, that if you turn away, you might make corruption in the land and break the ties of kinship?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Such are those whom Allah has cursed, making them deaf and blinding their eyes.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Will they not then contemplate on the Koran? Or are there locks upon their hearts!\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
As for those who turn back in their footsteps after the guidance of Allah has become clear to them, it was satan who tempted them, and Allah has respited them.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
That is because they say to those averse to what Allah has sent down 'We shall obey you in some of the matters' Allah knows their secrets.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
How shall it be when the angels (of death) take them and beat them on their face and back?\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That is because they follow what angers Allah and hate His pleasure, therefore He has annulled their deeds.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Or, do those who have a disease in their hearts think that Allah will not reveal their hatred?\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
If We willed, We would show them to you and you would recognize them by their marks. But you will surely know them by their twisted speech. Allahknows your deeds.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
Without doubt We shall test you until We know those who struggle and are patient among you, and make clear your news.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Those who disbelieve and bar from the Path of Allah, and break with the Messenger after guidance has been made clear to them shall not hurt Allah a thing, and He will annul their deeds.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
Believers, obey Allah and His Messenger and never let your labors go in vain!\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
As for those who disbelieve and bar (others) from the Path of Allah and then die as unbelievers? Allah will not forgive them.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
Therefore, do not be weakened and call out for peace, you shall be the upper ones, and Allah is with you and will not deprive you of your labors.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The life of this world is but play and an amusement. If you believe and are cautious, He will give you your wage, and will not ask for your possessions.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He asked you for them, and presses you, you would be mean and He would expose your anger.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
There you are! You are called upon to spend in the Way of Allah. Some of you are mean; yet whoever is mean is mean only to his own soul. Allah is theRich and you are the poor. If you turn away, He will replace you with another nation, and they will not be like you.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen Indeed, We have opened for you (Prophet Muhammad) a clear opening,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
that Allah forgives your past and future sins, and completes His Favor to you, and guides you on a Straight Path,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
and that Allah helps you with a mighty help.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
It was He who sent down tranquility into the hearts of the believers so that they might add belief upon belief. To Allah belong the armies of the heavens and the earth. Allah is the Knower, the Wise.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
(From His Wisdom) He admits the believers, both men and women, into Gardens underneath which rivers flow, there to live for ever, and acquit them of their sins that with Allah is a mighty triumph\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
and that He might punish the hypocrites and the idolaters, both men and women, and those who think evil thoughts of Allah. An evil turn (of fortune) will befall them. The Wrath of Allah is on them, and He has cursed them and prepared for them Gehenna (Hell), an evil arrival!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
To Allah belong the armies of the heavens and the earth. Allah is the Almighty and the Wise.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
We have sent you (Prophet Muhammad) as a witness and as a bearer of glad tidings and warning,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
so that you believe in Allah and His Messenger and that you support him, revere him (Prophet Muhammad), and exalt Him (Allah), at the dawn and in theevening.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Those who swear allegiance to you swear allegiance to Allah. The Hand of Allah is above their hands. He who breaks his oath breaks it against his self, but for he that keeps his covenant made with Allah, Allah shall give him a mighty wage.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
The Bedouins who lagged behind will say to you: 'We were occupied with our possessions and families, so ask Allah to forgive us' But they say with theirtongues what they do not mean in their hearts. Say: 'Who can help you against Allah if it is that He wills harm for you or desires benefit for you? Allah is Aware ofwhat you do'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
No, you thought that the Messenger and the believers would never return to their families, and this was made to seem fair in your hearts so you harbored evil thoughts, and so you are a destroyed nation.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
But whosoever disbelieves in Allah and His Messenger; We have prepared a Blazing Fire for the unbelievers.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
To Allah belongs the Kingdom of the heavens and the earth. He forgives whom He will and punishes whom He will. Allah is Forgiving and Merciful.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
When you set forth to take the spoils, those Bedouins who lagged behind will say: 'Let us follow you' They hope to change the Words of Allah. Say: 'Youshall not follow us. Allah has said so before' They will reply: 'No, you are envious of us' Rather, they have only understood a little!\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say to the Arabs who lagged behind: 'You shall be called upon to fight a mighty nation, unless they embrace Islam. If you are obedient you shall receive agood wage from Allah. But, if you turn away, as you turned your backs before, He will punish you with a painful punishment'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
There is no fault in the blind, or the lame, or the sick. He who obeys Allah and His Messenger He shall admit him to Gardens underneath which rivers flow; but he who turns away shall be punished with a painful punishment.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Allah was pleased with the believers when they swore allegiance to you under the tree and He knew what was in their hearts. Therefore, He sent downtranquility upon them and rewarded them with a victory close by\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
and they took many spoils, and Allah is the Almighty, and the Wise.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah has promised that you take many spoils. He has hastened this to you, and restrained the hands of people from you so that He makes it a sign to the believers and to guide you on a Straight Path.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And there were (other spoils) which you were unable to take. Allah has encompassed it already, Allah is powerful over all things.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
If the unbelievers had fought you they would have been put to flight, and found none to protect or help them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
Such is the way of Allah in days gone by, and you shall find no change in the ways of Allah.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
It was He who restrained their hands from you and your hands from them in the hollow (Hudaibiah) of Mecca after He had given you victory over them. Allah sees the things you do.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
They are those who disbelieved and barred you from the Holy Mosque and the offering detained so as not to reach its place of sacrifice if it had not been for certain believing men and certain believing women whom you did not know, you might have trampled upon them, and so sin reached you because of (killing) them while you did not know. In order that Allah admits into His Mercy whom He will, had they (the believers) been easy to distinguish, We would have punished the unbelievers among them with a painful punishment.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
And when the unbelievers established in their hearts fierce bigotry, the fierce bigotry of ignorance, Allah sent down His tranquility on His Messenger and the believers and firmly fastened to them the Word of 'taqwa' (there is no god except Allah, and Muhammad is His Messenger, as it is the cause of righteousness) to which they have better right and are worthy of it. Allah has knowledge of all things.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Indeed, Allah, in truth, has realized His Messenger's vision. You shall enter the Sacred Mosque in security if Allah wills, with hair shaven or cut short and without fear. He knew what you did not know, and granted you a near victory.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
It is He who has sent His Messenger with guidance and the religion of truth, so that He exalts it above all other religions. Allah is the Sufficient Witness.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is the Messenger of Allah. Those who are with him are harsh against the unbelievers but merciful to one another. You see them bow andprostrate themselves seeking the bounty and pleasure of Allah. Their mark is on their faces from the trace of prostration. That is their likeness in the Torah and their likeness in the Gospel, as the seed which puts forth its shoot and strengthens it, so that it grows stout and rises straight upon its stalk, delighting the sowers, and through them He enrages the unbelievers. Allah has promised those of them who believe and do good deeds, forgiveness and a great wage.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen Believers do not advance before Allah and His Messenger. Fear Allah. Allah is the Hearer, the Knower.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
Believers, do not raise your voices above the voice of the Prophet, nor speak loudly to him as you do to one another lest your works should be annulledwithout your knowledge.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Those who lower their voice in the presence of the Messenger of Allah are those whose hearts Allah has tested for warding off (evil). They shall receiveforgiveness and a great wage.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Whereas those who call out to you from behind the apartments, most of them lack understanding.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
If they had patience until you went out to them, it would have been better for them. But Allah is the Forgiving and the Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
Believers, if an evildoer brings you a piece of news, inquire first, in case you should unwittingly wrong others and then repent of what you have done.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
Know that the Messenger of Allah is among you. If he were to obey you in many matters, you would surely suffer. But Allah has endeared the Belief to youand beautified it in your hearts, and has made detestable to you disbelief, wrongdoing, and disobedience. Such are those who are righteous\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
by the Favor and Blessing of Allah. Allah is the Knower and the Wise.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
If two parties of believers fight, reform between them. If either of them is insolent against the other, fight the insolent one till they revert to the order of Allah. If they revert, reform between them with justice, and weigh with justice. Allah loves those who weigh with justice.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
Believers are indeed brothers, therefore make things right among your two brothers and fear Allah, so that you will be subject to mercy.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
Believers, do not let people mock other people who may be better than themselves. Do not let women mock women, who may be better than themselves. Do not find fault with one another, nor abuse one another with nicknames. An evil name is disobedience after belief. Those who do not repent are the harmdoers.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
Believers, abstain from most suspicion, some suspicion is a sin. Neither spy nor backbite one another would any of you like to eat the flesh of his deadbrother? Surely, you would loathe it. Fear Allah, without doubt Allah turns (in mercy) and He is the Merciful.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
People, We have created you from a male and a female, and made you into nations and tribes that you might know one another. The noblest of you before Allah is the most righteous of you. Allah is the Knower, the Aware.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The Arabs declare: 'We believe' Say: 'You do not', rather, say: 'we submit' because belief has not yet found its way into your hearts. If you obey Allah and His Messenger, He will not reduce a thing from of your deeds. Allah is the Forgiving and the Most Merciful.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
The believers are those who believe in Allah and His Messenger and have not doubted, and who struggled in His Way with their possessions and themselves. Such are those who are truthful.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say: 'Would you teach Allah what your religion is, when Allah knows all that is in the heavens and the earth' Allah has knowledge of all things.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They regard it as a favor to you that they have submitted! Say: 'Do not regard your submission as a favor to me, rather, it is Allah who bestows upon you a favor by guiding you to belief, if you are truthful'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
Indeed, Allah knows the Unseen of the heavens and the earth, and Allah is the Seer of what you do'\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaaf. By the Glorious Koran!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
No, but they marvel that from among themselves a warner has come to them. The unbelievers say (in mockery): 'This is a marvelous thing!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
What, when we are dead and turned to dust? That indeed would be an unlikely return'\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We know all that the earth takes away of them, and a Book of Records is with Us.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
Rather, they belied the truth when it came to them, and now they are in a state of confusion.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
What, have they never observed the heaven above them, (and seen) how We built and adorned it, leaving no crack?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
We spread out the earth and set upon it firm mountains, and We cause every delightful thing to grow in it\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
as a lesson and a reminder to every penitent worshiper.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
We sent down blessed water from the sky with which We caused gardens and the grains of harvest to grow,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
and tall palmtrees with compact spathes\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
as a provision for the worshipers; thereby We revived a land that was dead. Such shall be the emerging.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
Before them, the nation of Noah, the nation of ArRass belied and so did Thamood\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
and Aad, Pharaoh and the brothers of Lot,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
the dwellers of the Thicket and the nation of Tubba', all belied their Messengers, therefore My threat was realized.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
What, were We wearied by the first creation? No, indeed; yet they are in doubt about a new creation.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
Indeed, We created the human. We know the whisperings of his soul, and are closer to him than the jugular vein.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
When both receivers (the angels) receive, one on his right, the other on his left,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
whatever phrase he utters, an observer is present.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And when the agony of death comes in truth (they will say): 'This is what you have been trying to avoid'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the Horn shall be blown; that is the Day of Threat!\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
Each soul shall come with a driver, and a witness.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
(It will be said): 'Of this you have been heedless. Therefore, we have now removed your covering. Today your sight is sharp'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And his companion will say: 'This is that which I have present'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
(It will be said): 'Indeed, cast into Gehenna (Hell) every deviating unbeliever,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
forbidder of good, transgressor and doubter,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
who has set up with Allah another god. Indeed, you two, cast him into the terrible punishment'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
And his companion shall say: 'Our Lord, I did not make him insolent, he was far astray'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
He (Allah) will say: 'Do not dispute before Me. I sent you a warning beforehand.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
The Word cannot be changed with Me; I do not wrong My worshipers'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
On that Day We shall ask Gehenna: 'Are you full' And it will answer: 'Are there any more'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And Paradise, which is not far away, shall be brought closer to those who were cautious.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
(It shall be said to them): 'This is that you were promised. It is for every heeding penitent.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
Whosoever fears the Merciful in the Unseen, and comes with a contrite heart.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
Enter it in peace. This is the Day of Eternity'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
There they have all that they desire, and with Us is much more.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
How many generations, stronger in might than they have We destroyed before them! They searched the land, could they find any asylum?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Surely, in this there is a Reminder for he who has a heart or listens attentively while witnessing.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
In six days We created the heavens and the earth and all that is between them and no weariness touched Us!\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
Bear then with patience what they say. Exalt with the praise of your Lord before sunrise and before sunset.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And exalt Him in the night, and at the ends of the prostrations.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
Listen for the Day when the Caller will call from a nearby place.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
On the Day when they will hear the Shout, in truth that Day they will emerge.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
It is We who give life and make to die. To Us is the arrival.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
Upon that Day the earth will be rent asunder from around them as they hurry forth that is an easy gathering for Us.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
Indeed, We know what they say. You (Prophet Muhammad) are not a tyrant over them. Therefore, remind by the Koran whosoever fears (My) threat.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By the scatterers (the wind) scattering,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
then the bearers of weight (the clouds),\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
then the easy runners (the ships);\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
then by the distributors (angels), ordered;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
indeed, that which you are promised is true,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
and the recompense shall surely happen.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the heaven with its passages,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
surely, you are in different sayings,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
and are turned away from him who is turned.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Woe to the liars\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
who are heedless in the immersion.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
'When will the Day of Judgement be' they ask.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
On that Day they shall be tried at the Fire,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
'Taste your trial. This is what you have sought to hasten'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
The righteous shall live among gardens and fountains,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
receiving what their Lord will give them because before this they were gooddoers.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
They slept but a little at night,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
and at dawn would ask forgiveness,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
and in their wealth was a share for whosoever asked and for whosoever was prevented.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
For those with sure belief there are signs in the earth,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
and also in yourselves. Can you not see?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
In the sky is your provision and that which you are promised.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
So by the Lord of heaven and earth, it is as true as your speech.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Have you heard the story of Abraham's honored guests?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
They entered to him and said: 'Peace' And he replied: 'Peace, you are people unknown to me'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
So he turned to his household and brought a fattened calf.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
He set it before them, saying: 'Will you not eat'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
Then he conceived a fear about them, and they said: 'Have no fear', and gave him the glad tidings that he was to have a knowledgeable son.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
(Sarah) his wife came with an exclamation and clasped her face, and said: 'Surely, I am a barren old woman'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
'Such, says your Lord' they replied: 'He is the Wise, the Knower'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
'Messengers' said he (Abraham), 'what is your errand'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They replied: 'We are sent to a sinful nation,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
so that we bring down stones of clay upon them\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
marked by your Lord for the sinful'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
So We brought the believers out of that they were in.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
But We found in it only one household of those who had surrendered themselves,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
and left therein a sign for those who fear the painful punishment.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
In Moses, too, (there were signs). We sent him to Pharaoh with clear authority,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
but he turned his back with his Assembly, saying: 'He is (either) a sorcerer or a mad man'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We seized him and his hosts and cast them into the sea. Indeed, he was blameworthy.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in Aad. We let loose on them a withering wind\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
that left nothing it came upon, except that it was ashes.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in Thamood it was said to them: 'Take your enjoyment for awhile'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
But in their pride they turn away from the commandment of their Lord and the thunderbolt struck them whilst they were looking;\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
they could neither stand up straight, nor were they helped.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
And before them the nation of Noah, indeed they were a debauched nation.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
We built the heaven with might, and We widely extended it.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
and We cradled the earth. And We are the Best of Cradlers.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
We created two kinds of all things, so that you will remember.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
Therefore, flee to Allah. I am a clear warner to you from Him.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
Do not set up with Allah another god. I am a clear warner to you from Him.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Similarly, no Messenger came to those before them but they said: 'Sorcerer, or mad'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Have they handed this down from one to another? No, rather, they are an insolent nation.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So turn away from them, you shall not be blamed,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
But remind, the Reminder will benefit the believers.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
I have not created mankind and jinn except to worship Me.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I do not desire provision from them, nor do I desire that they should feed Me.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Surely, Allah is the Provider, the Possessor of Power, the Mighty.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
The evildoers shall have for their portion, a portion like their companions (who were destroyed before them). Therefore, they should not ask Us to hasten!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
Woe then to the unbelievers for their Day which they were promised!\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the Mount\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
and by the Book in lines\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
in an exposed parchment\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
by the Visited House,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
and the uplifted roof\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
and the sea that is full\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
surely, the punishment of your Lord is about to come,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
there is none to prevent it.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
Upon the Day when the heaven spins dizzily\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
and the mountains move, moving.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
On that Day woe to those who belied\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
those who are in plunging, playing.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
On that Day when they shall be pitched into the Fire of Gehenna (Hell),\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
(it will be said to them): 'This is the Fire which you belied!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
Is this magic, or is it that you do you not see?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
Roast in it, bear it with or without patience, it is the same, you are only being recompensed for that which you used to do'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
But in the Gardens the righteous shall live in bliss,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
rejoicing in all their Lord has given them, and their Lord will guard them against the punishment of Hell.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
(It will be said): 'Eat and drink with a good appetite because of that which you did'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
(They shall be) reclining on couches ranged in rows and We shall wed them to houris (virgins of Paradise) with large wide eyes.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
Those who believe, and whose descendants follow in belief, We will join their descendants to them. And We will not reduce them of anything of their deeds. Every one is pledged for what he has earned.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
We shall give them fruits and meat as they desire.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
There they will pass a goblet to one another with neither idle talk nor sin,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
and youths, of their own, shall pass among them as if they were hidden pearls.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
They will go to one another asking each other questions:\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
'When we were among our people' they will say, 'we were ever fearful,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
but Allah has been gracious to us and has protected us from the punishment of the burning wind.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
Before, we were supplicating to Him. He is the Giving, the Most Merciful'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
Therefore, remind. By the Favor of Allah, you are neither a soothsayer, nor mad.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or do they say: 'He is a poet, we are waiting for some misfortune to befall him'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say: 'Wait if you will; I shall be waiting with you'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Or, do their intellects order them to do this? Or, are they an insolent people?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Do they say: 'He has invented it' No, they do not believe.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
Let them produce a phrase like it, if what they say is true!\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Or, were they created out of nothing? Or, were they their own creators?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or, did they create the heavens and the earth? No, their belief is not certain!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or, are the treasures of your Lord in their keeping? Or, are they the controllers?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or, do they have a ladder on which they listen? Then let any of them that has listened bring a clear authority.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or, has He daughters, and they sons?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or, do you ask them for a wage, so that they become weighed down in debt?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or, is the Unseen in their keeping, so they are writing it down?\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or, do they desire to outwit? The unbelievers are the outwitted.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or, do they have a god, other than Allah? Exaltations to Allah above that which they associate!\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
Even if they saw lumps falling from the sky they would say: 'A massed cloud'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
So leave them till they encounter their Day in which they shall be thunderstruck.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
The Day when their guile shall not relieve them a thing, and they shall not be helped.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
For the harmdoers there is indeed, a punishment before that, but most of them do not know.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
And be patient under the Judgement of your Lord, surely, you are before Our Eyes. And exalt with the praise of your Lord when you arise,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
and exalt Him in the night and at the declining of the stars.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the star when it plunges,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
your companion is neither astray, neither errs,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
nor does he speak out of desire.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
Indeed it is not except a Revelation which is revealed,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
taught by One who is Stern in power.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
Of might, he (Gabriel) stood firm\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
while he was in the highest horizon;\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
then he drew near, and became close\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
he was but two bows' length or even nearer,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
so (Allah) revealed to His worshiper (Gabriel) that which he revealed (to Prophet Muhammad).\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
His heart did not lie of what he saw.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
What, will you dispute with him about what he sees!\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
Indeed, he saw him in another descent\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
at the Lote Tree (Sidrat tree) of the ending\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
close to the Garden of Refuge.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
When there comes to the Lote Tree, that which comes\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
his eyes did not swerve, nor did they stray\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
for indeed he saw one of the greatest signs of his Lord.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
(Among the idols) have you considered allat and al'uzza,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
and, another, the third manat?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
What, have you males, and He females!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
That is indeed an unjust division.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
They are but names, named by you and your fathers. Allah has not sent down any authority for them. They follow conjecture and their soul's desire, eventhough the guidance of their Lord has come to them.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Is the human to have whatever he fancies?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
To Allah belongs the Eternal life and the first life.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
How many an angel is there in the heavens whose intercession shall not benefit until Allah gives permission to whom He will and is pleased.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Those who disbelieve in the Everlasting Life call the angels by female names.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
Yet of this they have no knowledge, they follow mere conjecture, and conjecture does not help against truth.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
So turn from those who turn away from Our Remembrance and only desire this present life.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
That is all they have of knowledge. Your Lord knows best who has strayed from His Path, and those who are guided.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
To Allah belongs whatsoever is in the heavens and whatsoever is in the earth. He will recompense the evildoers according to their deeds, and recompense those who have done good with the finest reward\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
those who avoid the major sin and indecencies except the small sins, indeed your Lord is of immense forgiveness and He is more knowledgeable of you when He created you from the earth and when you were still unborn in your mothers' wombs. Do not praise yourself. Allah knows the cautious.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Have you considered he who turns his back,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
and gives a little, grudgingly?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Or, does he possess knowledge of the Unseen, and can therefore see?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Or, has he not been told of that which is in the Scrolls of Moses\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
and Abraham, who paid his debt in full?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
That no soul shall bear another's burden,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
and that everyone shall have in his account only that which he worked for,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
and that his work is surely seen\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
then, he shall be recompensed for it in full repayment\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
and that the final return is to your Lord,\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
that it is He who causes to laugh and causes to weep.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
and that it is He who causes to die, and causes to live\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
and that it is He who created pairs, the male and the female,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
from an ejaculated drop (of sperm),\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
and that upon Him is the second creation\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
and that it is He who gives riches and causes to hoard,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
and that He is the Lord of (the star) Sirius,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
that it was He that destroyed ancient Aad\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
and Thamood, sparing no one,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
and before them the nation of Noah, they exceeded in evil and were insolent.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
He plunged the villages\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
so that there came upon them that which came.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
So which then of your Lord's favors do you dispute?\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This is a warner from the warners of ancient times.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The Imminent is near at hand;\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
none except Allah can disclose it.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Do you marvel then at this discourse (the Koran)?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
Or do you laugh, and do you not weep\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
while you are thoughtless?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
Rather, prostrate to Allah and worship Him.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour is drawing near, and the moon is split (in two).\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
Yet if they see a sign (the unbelievers) turn their backs and say: 'This is but a continuation of sorcery'\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
They have belied, and follow their own fancies. But, every issue will be settled!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
Tidings containing a deterrent have come to them\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
which are full of wisdom; but the warnings do not help.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
Therefore, turn away from them. On the Day when the Caller summons them to a terrible thing,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
their eyes will be humbled as they come out from their graves as if they were scattered locusts,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
running (with their necks extended) to the Caller. The unbelievers will say: 'This is indeed a harsh Day'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
(Long) before them the nation of Noah belied. They belied Our worshiper saying: 'Mad' and he was reprimanded.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
Then he supplicated to his Lord, (saying): 'I am overcome, help me'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
We opened the Gates of Heaven with torrential water\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
and caused the earth to gush with springs, so that the waters met for a predestined matter.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
We carried him in a well built, watertight vessel made from planks (of wood)\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
that ran on under Our Eyes, a recompense for him because he had been disbelieved.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
We have left it as a sign. Is there any that will remember?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
How then were My punishment and My warnings!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
We have made the Koran easy to remember, is there any that will remember!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
Aad too belied. How then were My punishment and My warnings!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
And We sent against them a howling wind in a Day of continuous of ill fortune\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
and snatched people up as though they were stumps of uprooted palmtrees.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
How then were My punishment and My warnings!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
We have made the Koran easy to remember, is there any that will remember?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
Thamood, too, belied Our warnings.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
They said: 'Are we to follow a mortal who is one of us? Then indeed, we would surely be in error and insane.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
Out of all of us has the Reminder been given to him alone? Rather, he is indeed an arrogant liar'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
(To him We said): 'Tomorrow they shall know who is the arrogant liar.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
We are sending to them as a trial, a shecamel, so watch them and have patience.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
Tell them that the water is to be divided between them, a drink each for them in turn'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
But they called their companion who took hold of her and hamstrung her.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
How then were My punishment and My warnings!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
Then We sent against them one Shout and they became like the trampled twigs of the (sheep) penbuilder.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
We have made the Koran an easy Remembrance, is there any that will remember!\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The nation of Lot belied Our warnings.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
We let loose on all of them a squall of claystones, except for the house of Lot whom We saved at dawn\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
through Our Mercy. So it is that We recompense the thankful.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
He had warned them of Our assault but they disputed the warnings.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
They even solicited of him his guests, but We obliterated their eyes: 'Now, taste My punishment and My warnings'\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
And at daybreak a determined punishment came upon them.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
'Now, taste My punishment and My warnings'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
We have made the Koran an easy Remembrance, is there any that will remember!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
The warnings also came to Pharaoh's people,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
but they belied all Our signs so We seized them with the seizing of the Mighty, Powerful.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
What then, are your unbelievers better than those? Or do you have an immunity (written) in the Scrolls?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or do they say: 'We are a gathering that will be victorious'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
Most certainly their gatherings shall be routed, and they will turn their backs.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
Rather, the Hour is their encounter. And that Hour will be most calamitous and bitter.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Indeed the wrongdoers are in error and a raging fire.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
On the Day when they are dragged on their faces into the Fire, (it will be said to them): 'Taste the touch of the Scorching'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Indeed, We have created all things according to a measure.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our Order is but one word like the flashing of an eye.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
And We destroyed those like you, is there any that will remember!\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
All their deeds are in the Scrolls,\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
everything, be it great or small, is recorded.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Indeed, the cautious shall live amid gardens and a river,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
in a secure abode, in the presence of the Powerful King.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen The Merciful\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
has taught the Koran.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
He created the human\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
and taught him its pronunciation.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon to a reckoning.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
The stars and the trees prostrate themselves.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
He raised the heaven on high and set the scale.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
Do not transgress the scales.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
Give just weight and do not skimp the scales.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
He set down the earth for the creation.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
Therein are fruits and palm trees with sheaths,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
the grain in the blade; and aromatic herbs.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
Which favors of your Lord will you both (humans and jinn) belie?\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created the human from clay, like earthenware\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
and He created the jinn from smokeless fire.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
Which favors of your Lord will you both belie?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
The Lord of the Two Easts, the Lord of the Two Wests.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
Which favors of your Lord will you both belie?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He has let forth the two seas, they meet together,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
and between them is a barrier which they do not overpass.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
Which favors of your Lord will you both belie?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
Pearls and corals come from both.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
Which favors of your Lord will you both belie?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
Also, His are the ships that run, raised up like mountains upon the sea.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
Which favors of your Lord will you both belie?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
All that live on it will perish.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
Yet the Face of your Lord will abide forever, Majestic and Splendid.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
Which favors of your Lord will you both belie?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
Whosoever is in the heaven and earth ask Him. Every day He is upon an affair (He reveals according to His Eternal determination).\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
Which favors of your Lord will you both belie?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
We shall surely aim, O both burdened.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
Which favors of your Lord will you both belie?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
Tribe of jinn and of human, if you are able to penetrate the provinces of heaven and earth, pass through them! But you shall not pass through except with a power!\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
Which favors of your Lord will you both belie?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
Flames of fire and molten copper shall be loosed against you, and you shall not be helped.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
Which favors of your Lord will you both belie?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
When the heaven splits asunder and turns crimson, like red leather.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
Which favors of your Lord will you both belie?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
On that Day, neither human nor jinn shall be asked about his sin.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
Which favors of your Lord will you both belie?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The sinners shall be known by their mark, they shall be seized by their forelocks and their feet.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
Which favors of your Lord will you both belie?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is Gehenna (Hell) which the sinners belied,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
they shall go round between it, and between a hot, boiling water.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
Which favors of your Lord will you both belie?\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
And for he who fears the standing (before) his Lord there are two Gardens.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
Which favors of your Lord will you both belie?\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
(Gardens) with many branches.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
Which favors of your Lord will you both belie?\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
Therein are two running fountains.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
Which favors of your Lord will you both belie?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
Therein are two kinds of every fruit.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
Which favors of your Lord will you both belie?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
(They shall) recline on couches lined with brocade, and the fruits of the Gardens will be near at hand.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
Which favors of your Lord will you both belie?\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
Therein are maidens who restrain their glances, whom neither human nor jinn have touched before.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
Which favors of your Lord will you both belie?\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
As (lovely as) rubies and as (beautiful as) coral.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
Which favors of your Lord will you both belie?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Shall the recompense of goodness be anything other than goodness?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
Which favors of your Lord will you both belie?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And beside these there shall be two Gardens.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
Which favors of your Lord will you both belie?\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
The greenest of green pastures.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
Which favors of your Lord will you both belie?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
Therein are two gushing fountains of water.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
Which favors of your Lord will you both belie?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
In them are fruits, palm trees and pomegranates.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
Which favors of your Lord will you both belie?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
In them shall be good and pleasing.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
Which favors of your Lord will you both belie?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
Maidens (of Paradise, Houris) in cloistered cool pavilions.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
Which favors of your Lord will you both belie?\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
Neither human nor jinn will have touched them before.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
Which favors of your Lord will you both belie?\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining on green cushions and fine carpets.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
Which favors of your Lord will you both belie?\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed be the Name of your Lord, Majestic, Splendid.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the Event (the resurrection) comes\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
there is no denying its coming\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
(it will) abase (some) and exalt (others).\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
When the earth is shaken\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
and the mountains fragmented\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
becoming scattered dust,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
you shall be divided into three parties,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
Companions of the Right, what are the Companions of the Right?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
Companions of the Left, what are the Companions of the Left?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And the Outstrippers, the Outstrippers\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
those are they brought near (to their Lord)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
in the Gardens of Delight,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
a host of the ancients\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
but only a few from the later generations.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
on lavish couches\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
they shall recline, facing each other,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
(and there) shall wait on them immortal youths\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
with goblets and ewers, and a cup from a spring\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
that will neither make the head throb, nor intoxicate,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
with fruits of their own choice\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmm{%
and any flesh of fowl that they desire.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And wideeyed houris\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
like hidden pearls,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
a recompense for all that they did.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
There they shall hear no idle talk, no cause of sin,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
but only the saying: 'Peace, Peace'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
The Companions of the Right\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
(will be) among thornless Lote trees.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
Bananatrees, piled\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
and continuous shade,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
and flowing water\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
and an abundance of fruits,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
unfailing and not forbidden.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And couches raised up.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
Indeed We formed them (the houris and all believing women),\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
and made them virgins,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
chaste, loving companions of the same age\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
for the Companions of the Right\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
a multitude of the ancients,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
and a multitude of the later people.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
As for the Companions of the Left\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
(they shall live) amid burning winds and boiling water,\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
in the shadow of a smoking blaze,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
neither cool nor good.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
Before they lived at ease,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
and persisted in the great sin\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
and constantly said: 'What, when we are dead and become dust and bones, shall we then be restored to life?\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
What, and our fathers, the ancients'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say: 'Those of ancient times and those of later times\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
shall be gathered together to the appointed time on a known Day'\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
Then you went astray, you that belied,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
you shall eat (the fruit) of the Tree of Zakkum.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
You shall fill your bellies with it,\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
and drink boiling water on top of that,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
and you will drink as the lapping of thirsty camels.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
Such shall be your hospitality on the Day of Recompense.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We created you, why will you not believe!\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Have you thought about what (sperm) you ejaculate?\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Did you create it, or are We the Creator?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
It was We who decreed death among you. We will not be surpassed\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
that We will change you and cause you to grow again in a way you do not know.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
You have surely known of the first creation. Why then, will you not remember!\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
Ponder upon the soil you till,\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
is it you that sow it, or are We the Sower?\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
If We will, We would make it broken stubble and you would remain wondering,\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
(Saying:) 'We are laden with debts!\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
Rather, we have been prevented'\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
Have you thought about the water you drink?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Is it you that send it down from the clouds or We?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We will, We would make it bitter, why then do you not give thanks?\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmml{%
Have you thought about the fire you kindle?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Is it you that originated its tree, or are We the Originator?\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We have made it a reminder, and a blessing to the traveler.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Then, exalt the Name of your Lord, the Great.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
I swear by the fallings of the stars\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
and that is a mighty oath, if you but knew\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
it is indeed a Glorious Koran,\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
in a Book protected (from tampering)\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
which none shall touch except the purified;\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
a sending down from the Lord of all the Worlds.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
What, do you hold this discourse in disdain,\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
do you make it your provision to belie it?\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Why, then, when the soul leaps up to the throat of the dying\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
and you are watching at that time\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
We are nearer to him than you, but you do not see\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
why then, if you are not revived,\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
do you not restore his soul, if you are truthful?\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
If he is among the near\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
there shall be calmness and ease, a Garden of Delight.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
If he is a Companion of the Right\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
(he will be greeted with): 'Peace be upon you, Companion of the Right'\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
But, if he is of those who belied, and went astray,\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
there shall be a hospitality of boiling water,\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
and a roasting in Hell.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
Indeed, this is the certain truth.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
So exalt the Name of your Lord, the Great.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen All that is in the heavens and earth exalt Allah. He is the Almighty, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
To Him belongs the Kingdom in the heavens and earth. It is He who revives and causes to die, and He has power over all things.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First and the Last, the Clear and the Hidden. He has knowledge of all things.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
He created the heavens and the earth in six days, and willed to the Throne. He knows what penetrates the earth and all that emerges from it; all that descends from heaven and all that ascends to it. He is with you wherever you are. Allah sees the things you do.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
To Him belongs the Kingdom of the heavens and the earth. To Him all matters shall return.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He causes the night to enter into the day and the day to enter into the night. He has knowledge of the thoughts of the innermost of the chests.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in Allah and His Messenger and spend (in charity) of that which He has made you successors. Whosoever of you believes and spends shall have amighty wage.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
Why is it that you do not believe in Allah, when the Messenger calls on you to believe in your Lord, and He has made a covenant with you if you arebelievers?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
It is He who sends down clear verses to His worshiper, so that He brings you out of the darkness into the light. Indeed, Allah is the Gentle, the Most Merciful to you.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And why is it that you do not spend in the Way of Allah, when the inheritance of the heavens and earth belong to Allah alone? Those who spent before the victory and took part in the fighting are mightier in rank and are not equal to those who spent and fought thereafter. Yet, Allah has promised each a fine reward, and Allah is Aware of what you do.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who will lend a generous loan to Allah? He will multiply it for him and he shall receive a generous wage.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
The Day (will surely come) when you shall see believing men and women with their light running before them on their right hands, (it will be said to them):'Glad tidings for you this Day. You shall live for ever in Gardens underneath which rivers flow! That is indeed the mighty triumph.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
On that Day the hypocrites, both men and women, will say to the believers: 'Wait for us so that we can take from your light' But they will be answered: 'Go back and seek a light' And a wall with a door shall be between them. Inside it there is mercy, and outside will be the punishment.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
They will call out to them, saying: 'Were we not with you' 'Yes' they will reply, 'but you tempted yourselves, you waited (for problems to befall thebelievers), and you doubted, and were deluded by your own fancies until the Command of Allah came, and the deluder (satan) deluded you concerning Allah.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
Today no ransom shall be accepted from you or from the unbelievers. Your shelter is the Fire, that is your sponsor, the worst arrival'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Is it not time that the hearts of the believers be humbled to the Remembrance of Allah and the truth which He has sent down? They should not be like those who were given the Book before this, whose time became very long so that their hearts became hardened. Many of them were impious.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that Allah revives the earth after it was dead. We have made plain to you the signs in order that you understand.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Indeed, those who give in charity, be they men or women, and those who lend a good loan to Allah, shall be repaid in multiples. They shall receive agenerous wage.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
Those who believe in Allah and His Messengers are the sincere and the martyrs before their Lord, they shall have their reward and their light. But those that disbelieve and belied Our verses are the inhabitants of Gehenna (Hell).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the life of this world is but play and an amusement, and adornment, and a cause for boasting among you, a rivalry for greater riches and children. It is like rain whose vegetation pleases the unbelievers, but then it withers and turns yellow, becoming broken stubble. In the Everlasting Life is a terrible punishment, forgiveness, and great pleasure from Allah. The life of this world is nothing except the joy of delusion.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Therefore, race for forgiveness from your Lord, and for a Garden as wide as heaven and earth, prepared for those who believe in Allah and His Messengers. Such is the Favor of Allah; He gives it to whom He will. Allah is the Owner of great favor.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
No affliction can befall either the earth, or yourself, except that it is (written) in a Book before We created it. That is easy for Allah;\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
so that you will not be saddened for whatever does not come to you, nor be overjoyed in what has come to you. Allah does not love those who are proudand boastful\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
nor those who are mean, and encourage others to be mean. And he that turns away, (know) that Allah is Rich and Praised.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
We have sent Our Messengers with proofs, and sent them with the Book and the Scales, so that people might establish the Scale (of justice). We have sent down iron in which there is great might and diverse benefit for people, so that Allah knows those who help Him and His Messengers in the Unseen. Indeed, Allah is the Strong, the Almighty.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
We sent forth Noah and Abraham, and appointed the Prophethood and the Book to be given to their descendants. Some were guided, but many wereimpious.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Following them We sent Our (other) Messengers, and We sent following in their footsteps, (Prophet) Jesus, the son of Mary and gave him the Gospel, and put tenderness and mercy in the hearts of his followers. As for monasticism, they invented it thereby seeking the pleasure of Allah. We did not write it for them, and they did not observe it as it should be observed. We gave to those of them who believed their wage, but many of them are impious.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
Believers, fear Allah and believe in His Messenger (Prophet Muhammad), He will give you a double portion of His Mercy and He will make for you a light inwhich to walk, and forgive you; Allah is the Forgiver and the Most Merciful.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
So that the People of the Book may know that they have no power over any of the favors of Allah; that the favors are in the Hand of Allah; He gives it towhom He will. The Favor of Allah is the Great.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Allah has heard the words of her that reasons with you (Prophet Muhammad) concerning her husband and made her complaint to Allah. Allah has heard both of you discussing with one another. Indeed, Allah is the Hearer, the Seer.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Those of you who say to their wives, 'Be as my mother's back' indeed, they are not their mothers. Their mothers are only those who gave birth to them. Indeed they speak dishonorably and falsely. But Allah is the Pardoning, the Forgiving.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
Those who say to their wives, 'Be as my mother's back' then retract their words thereafter shall set a person free before they touch each other again. By that you are admonished. Allah is Aware of all that you do.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
He who is unable shall fast for two successive months before they touch one another. If he is unable to do this, let him feed sixty needy people that, so that you believe in Allah and His Messenger. Such are the bounds of Allah. There is a painful punishment awaiting the unbelievers.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Those who oppose Allah and His Messenger shall be frustrated just as those before them were frustrated. We have sent down proofs and clear verses, and for the unbelievers, there is a humiliating punishment.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
On the Day when Allah will raise them up all together He will inform them of what they did. Allah has taken count of it, although they have forgotten. Allah is Witness to all things.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Have you not seen that Allah knows that which is in the heavens and the earth? There is no secret talk between three but He is the fourth of them; nor between five but He is the sixth of them; nor between fewer or more but He is with them wherever they are. Then, on the Day of Resurrection, He will inform them of what they have done. Surely, Allah has knowledge of all things.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Have you not seen those who were forbidden to talk in secrecy together? They return to that which they are forbidden and talk secretly together in sin andhatred, and in disobedience to the Messenger. Then, when they come to you they greet you with greetings with which Allah does not greet you, and they say within themselves: 'Why does Allah not punish us for what we say' Gehenna (Hell) suffices them, they shall be roasted, an evil arrival!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
Believers, when you talk in secret do not talk together in sin and hatred, and disobedience towards the Messenger, but talk of piety and caution. Fear Allah before whom you shall be gathered.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Talking together maliciously in secret is from satan, so that believers should sorrow, yet he can not harm them at all, except by the permission of Allah. In Allah let the believers put their trust.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
Believers, make room in your sitting places when it is asked of you, and Allah will make room for you. When you are asked to move, so move, and Allahwill raise up in ranks those who believed among you and those who have been given knowledge. Allah is Aware of what you do.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
Believers, when you consult with the Messenger, present before your consultation a free will offering. That is best and purest for you. But if you lack themeans, Allah is the Forgiver and the Most Merciful.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Are you afraid to offer a freewill offering before your consultation? But if you do not, Allah will turn to you again, then establish the prayer and pay theobligatory charity, and be obedient to Allah and His Messenger. Allah is Aware of what you do.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Do you see those who have been guided by a nation that incurred the Wrath of Allah? They belong neither to you, nor to them, and knowingly they swear to lies.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah has prepared for them a grievous punishment. Evil indeed is that which they have done.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They have taken their oaths as a disguise and bar from the Way of Allah, so a humiliating punishment awaits them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Neither their wealth nor their children shall help them a thing against Allah. They are the inhabitants of the Fire, and there they shall live for ever.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
On the Day when Allah shall raise them all up, they will swear to Him as they now swear to you thinking that they are upon something. Indeed, they are the liars!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
satan has mastered them and caused them to forget the Remembrance of Allah. Those are satan's party; and satan's party shall assuredly be the losers.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Those who oppose Allah and His Messenger shall be among the humiliated.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah has written: 'I will surely be the Victor, I and My Messengers' Surely, Allah is the Strong, the Almighty.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
You shall find no nation believing in Allah and the Last Day loving anyone that opposes Allah and His Messenger, even though they be their fathers, theirsons, their brothers, or their tribe. Those, He has written upon their hearts faith and strengthened them with a spirit from Him. He will admit them to the Gardensunderneath which rivers flow, where they shall live for ever. Allah is pleased with them and they are pleased with Him. They are the Party of Allah; and the Party ofAllah are the winners.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen All that is in heavens and earth exalt Allah. He is the Almighty, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
It was He who expelled the unbelievers among the People of the Book from their homes into the first exile. You did not think that they would go out, and they thought their fortresses would protect them from Allah. But Allah came upon them from where they did not expect, casting terror into their hearts that their homes were destroyed by their own hands as well as by the hands of the believers. Therefore, take heed you that have eyes.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
Had it been that Allah had not decreed that they should be dispersed, He would have surely punished them in this world. And in the Everlasting Life thepunishment of the Fire awaits them,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
because they broke their promise with Allah and His Messenger; and whosoever breaks their promise with Allah Allah is Stern in retribution.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
Whatever palmtree you cut down or left standing upon its roots, it is by the permission of Allah, so that He might humiliate the impious.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
And whatever spoils of war Allah has given to His Messenger from them, you hastened on neither horse nor camel against them, but Allah gives HisMessengers authority over whom He will. Allah is Powerful over all things.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
The spoils of war taken from the villagers and given by Allah to His Messenger belong to Allah, His Messenger and the near kinsmen, the orphans, the needy and the destitute traveler, so that it is not something taken in turns by the rich among you. Whatever the Messenger gives you, accept it; and whatever he forbids you, abstain. And fear Allah; surely, Allah is Stern in retribution.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
(A share of the spoils shall also be given) to the poor emigrants who were expelled from their homes and their possessions, who seek the Favor and Pleasure of Allah, and help Allah and His Messenger. These are they that are truthful.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
And those before them who had made their dwelling in the abode (the City of Madinah), and because of their belief love those who have emigrated to them; they do not find any (envy) in their chests for what they have been given and prefer them above themselves, even though they themselves have a need. Whosoever is saved from the greed of his own soul, they are the ones who win.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
Those who came after them say: 'Forgive us our Lord, and forgive our brothers who were believers before us. Do not put in our hearts any spite towards those who believe. Lord, You are the Gentle, the Most Merciful'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Have you not seen the hypocrites? They say to their brothers among the People of the Book who disbelieve, 'If they expel you, we will go with you. We willnever obey anyone against you. If they fight against you we will certainly help you' But Allah bears witness that they are, without doubt, liars.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
If they are expelled or fought against, they will not go with them, nor will they will help them. Indeed, if they helped them, they would turn their backs andthen they would not be helped.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Their fear of you in their hearts is greater than their fear of Allah; that is because they are a people who do not understand.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They will never fight against you all together except from fortified villages or from behind walls. Their courage is great among themselves; you think them to be united, yet their hearts are not united. That is because they are a people who have no sense.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
Just as those who, not long before, tasted the mischief of their actions, there awaits for them a painful punishment.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
Like satan when he said to the human, 'Disbelieve'; then as soon as he disbelieved, he said, 'Indeed, I am innocent of you, surely, I fear Allah, the Lord of all the Worlds'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
Their end shall be that they live for ever in the Fire. That is the recompense of the harmdoers.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
Believers, fear Allah. Let every soul look to what it has forwarded for the future, and fear Allah, for Allah is Aware of the things you do.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
Do not be like those who have forgotten Allah so that He has caused them to forget their souls. Those, they are the evildoers.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
The inhabitants of the Fire and the inhabitants of Paradise are not equal. The inhabitants of Paradise shall be triumphant.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
Had We sent down this Koran upon a mountain, you would have seen it humble itself and split asunder for fear of Allah. Such are the parables we strike for people so that they will reflect.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is Allah, there is no god except He. He knows the Unseen and the Visible. He is the Merciful, the Most Merciful.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is Allah, there is no god except He. He is the King, the Pure, the Peace, the Confirmer, the Watchful, the Almighty, the Compeller, the Sublime. Exalted is Allah, above all that they associate!\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is Allah, the Creator, the Originator, the Shaper. To Him belong the Most Beautiful Names. All that is in the heavens and earth exalt Him. He is theAlmighty, the Wise.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen Believers, do not take My enemy and your enemy for your guides, offering them love when they have disbelieved the truth that has come to you, who expelthe Messenger and yourselves because you believe in Allah, your Lord! If you go out to struggle in My way seeking My pleasure, but secretly love them, I know well what you conceal and what you reveal; whosoever of you does this will have gone astray from the Right Path.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
If they come upon you, they will be your enemies, and stretch out their hands and tongues to do evil to you. They wish that you would disbelieve.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
On the Day of Resurrection neither your blood relatives nor your children shall be of benefit to you. Allah will differentiate between you, and Allah sees thethings you do.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
You have a good example in Abraham and those with him. They said to their nation: 'We are quit of you, and that which you worship, other than Allah. We disbelieve you, enmity and hatred has shown itself between us for ever until you believe in Allah alone' Except that Abraham said to his father: 'Surely, I shall supplicate to ask for forgiveness for you although I have no power to do anything for you with Allah' ' Our Lord, in You we have put our trust; to You we turn, and to You is the arrival,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
Our Lord, do not make us a temptation for the unbelievers and forgive us. Our Lord, You are the Almighty, the Wise'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
In those there is a good example for whosoever hopes for Allah and the Last Day. Whosoever turns away, indeed, Allah is the Rich and the Praised.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
It may be that Allah establishes love between you and those with whom you are at enmity. Allah is the Powerful, Allah is the Forgiving and the Most Merciful.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah does not forbid you to be kind and to act justly to those who have neither made war on your Religion nor expelled you from your homes. Allah loves the just.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
But Allah only forbids you to be guided by those who have fought against you in your religion's cause and expelled you from your homes or have supportedothers in your expulsion. Whosoever takes them as guides are harmdoers.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
Believers, when believing women come to you as emigrants, test them. Allah best knows their belief. If you find them to be believers do not return them to the unbelievers; they are not permitted to the unbelievers, nor are the unbelievers permitted to them. But give back to the unbelievers what they have spent, and there is no fault in you to marry such women, provided you give them their dowries. Do not hold on to the ties with unbelieving women, ask what you have spent and let them ask what they have spent. Such is the Judgement of Allah; He judges between you; and Allah is the Knower, and the Wise.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
If any of your wives desert you to be with the unbelievers and you retaliate, give those whose wives who have deserted the equivalent of what they have spent. And fear Allah in whom you believe.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet, when believing women come to you and swear loyalty to you upon the condition that they will not associate anything with Allah, and will notsteal, nor commit adultery, nor slay their children, nor fabricate slander between their hands and their feet, nor disobey you in any honorable thing, supplicate to Allah for forgiveness for them, Allah is the Forgiving and the Most Merciful.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
Believers, do not take as guides those who have incurred the Wrath of Allah and who despair of the Everlasting Life (to come), like the unbelieversdespaired of the inhabitants of the tombs (that they shall be resurrected).\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen All that is in the heavens and earth exalt Allah. He is the Almighty, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
Believers, why do you say what you never do?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
It is most hateful to Allah that you should say that which you do not do.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Allah loves those who fight in His Way lining up as if they were a stacked building.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And when Moses, said to his nation: 'Why do you harm me, when you know that I am the Messenger of Allah sent to you' But when they swerved away Allah caused their hearts to swerve. Allah never guides impious people.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And when (Prophet) Jesus, the son of Mary said: 'Children of Israel, I am sent to you by Allah to confirm the Torah that was before me, and to give news of a Messenger (Prophet Muhammad) who will come after me whose name shall be Ahmad' Yet when he came to them with clear proofs, they said: 'This is clearsorcery'\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who does greater evil than he who forges a lie against Allah, when he is being called to Islam? Allah does not guide the harmdoing people.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
They seek to extinguish the Light of Allah with their mouths; but Allah will complete His Light, much as the unbelievers dislike it.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
It is He who has sent His Messenger with guidance and the Religion of Truth, so that He raises it above all religions, much as the unbelievers dislike it.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
Believers! Shall I direct you to a commerce that will save you from a painful punishment?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
You shall believe in Allah and His Messenger and struggle for His Way with your possessions and yourselves. That is better for you, if you but knew.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive you your sins and admit you to Gardens underneath which rivers flow, and to fine dwelling places in the Gardens of Eden. That is the mightytriumph.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And other things that you love, victory from Allah and an opening that is near. (O Prophet Muhammad) give glad tidings to the believers.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
Believers, be the helpers of Allah. When (Prophet) Jesus, the son of Mary said to the disciples: 'Who will be my helpers unto Allah' The disciples replied:'We will be the helpers of Allah' A party of the Children of Israel believed, and a party disbelieved. So, We supported those who believed against their enemy, and they overcame.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen All that is in heavens and earth exalt Allah, the King, the Pure, the Almighty, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
It is He who has raised among the illiterate (Arabs), a Messenger from themselves, to recite to them His verses, to purify them, and to teach them the Book and the Wisdom, though before that they were in clear error,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
together with others who have not as yet joined them. He is the Almighty, the Wise.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
Such is the Favor of Allah; He gives it to whom He will, and Allah is of abounding favors.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The likeness of those who were loaded with the Torah, but did not carry it, is like that of a donkey carrying books. Evil is the example of the people who have belied the verses of Allah. Allah does not guide the evildoers.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say: 'O you who are Jews, if you claim that of all people, you alone are the guided by Allah, then long for death if you are truthful'\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But, because of what their hands forwarded they will never long for it. Allah knows the harmdoers.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say: 'Death from which you flee is sure to reach you. Then you shall be returned to the Knower of the Unseen and the Visible, and He will tell you all that you have done'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
Believers, when you are called to prayer on the Day of the Congregation (Friday), hasten to the Remembrance of Allah and put your trading to oneside. That is the best for you, if you but knew.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
Then, when the prayer has ended, disperse in the land and seek the favor of Allah, and, remember Allah often, so that you prosper.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
Yet when they see some commerce or amusement they flock to it, leaving you standing. Say: 'That which is with Allah is better than the amusement and commerce. Allah is the Best of Providers'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come to you they say: 'We bear witness that you are the Messenger of Allah' Allah knows that you (Prophet Muhammad) are indeedHis Messenger, and Allah bears witness that the hypocrites are truly liars!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They have taken their oaths as a cover and barred others from the Path of Allah. Evil is what they have done.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they believed, then disbelieved, because of this a seal has been set upon their hearts so they are unable to understand.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
When you see them their bodies please you, but when they speak and you listen to their sayings, they are like proppedup timber. Every shout (they hear) they take it to be against them. They are the enemy be wary of them. Allah kills them! How perverse they are!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
When it is said to them: 'Come, the Messenger of Allah will ask forgiveness for you' they turn their heads in pride and you see them go away.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
It is equal for them whether you ask for their forgiveness or you do not ask for their forgiveness, Allah will not forgive them. Allah does not guide the evildoers.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
It is they that say: 'Spend nothing on those who follow the Messenger of Allah until they disperse' Yet to Allah belong the treasuries of heavens and the earth, but the hypocrites do not understand.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say: 'If we return to the City, the strong will expel the humiliated' But the might belongs to Allah, and His Messenger and the believers, but thehypocrites do not know.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
Believers, do not let either your possessions or your children divert you from the Remembrance of Allah. Those who do that shall be the losers.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
So spend of that with which We have provided you before death comes upon any of you and he then says: 'O my Lord, if only You would defer me to anear term, so that I could give in charity and be among the good doers'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
But Allah will never defer any soul when its term comes. Allah is Aware of what you do.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen All that is in heavens and earth exalt Allah. His is the Kingdom, and His the Praise. He is powerful over all things.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
It is He who created you. Amongst you is an unbeliever and amongst you is a believer. Allah sees the things you do.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He created the heavens and the earth in truth and He shaped you and gave you good shapes. To Him is the arrival.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows whatever is in the heavens and the earth and He knows all what you conceal and what you reveal. Allah knows the innermost of the chests.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Have you not heard the news of those before you who disbelieved? They tasted the mischief of their action, and for them is a painful punishment.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That is because, when their Messengers came to them with clear proofs they said: 'Shall humans be our guides' They disbelieved and turned away, but Allah was not in need (of them). Allah is the Rich and the Praised.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
The unbelievers think that they will never be raised up. Say: 'By my Lord, yes indeed, you shall assuredly be raised up! Then you shall be told of all that you have done. That is easy for Allah'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
Believe in Allah, and His Messenger, and in the Light which We have sent down. Allah is Aware of all that you do.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
The Day on which He will gather you for the Day of Gathering; that is the Day of Loss and Gain. He who believes in Allah and does good deeds, Allah willacquit him of his evil deeds and admit him to Gardens underneath which rivers flow, where he shall live for ever. That is the mighty triumph.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
As for those who disbelieved and belied Our verses, they shall be the inhabitants of the Fire and shall live therein for ever. Evil shall be their arrival.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No affliction falls except by the permission of Allah. For those who believe in Allah, Allah will guide his heart. Allah has knowledge of all things.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
Obey Allah and obey the Messenger. But, if you turn away, Our Messenger's duty is only to deliver the Clear Message.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah, there is no god except He. In Allah let the believers put their trust.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
Believers, some of your wives and children are enemies; so beware of them. But if you pardon, overlook and forgive them, then Allah is the Forgiving, the Most Merciful.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your wealth and children are but a trial, and with Allah is a mighty wage.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
Therefore fear Allah as much as you can, and listen, obey, and spend well for yourselves. And whosoever is saved from the greed of his own soul; those are the winners.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If you lend a good loan to Allah He will multiply it for you and will forgive you. Allah is the Thankful, the Clement.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
He is the Knower of the Unseen and the Visible, the Almighty, the Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O (nation of the) Prophet, if you divorce your wives, divorce them after (the end of their) menstrual cycle. Count their waiting period and fear Allah your Lord. Do not drive them from their homes or let them go away unless they commit a proven immorality. Such are the bounds set by Allah, he that exceeds the bounds of Allah wrongs himself. You do not know, perhaps after that Allah will bring a new event.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
When they have reached their term, either keep them honorably or part from them honorably. Call two honest men among you to witness and give yourwitnessing before Allah. Whoever believes in Allah and the Last Day is warned to do this. Whosoever fears Allah, He will appoint for him a way out,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
and provide for him from where he does not expect, Allah is Sufficient for whosoever puts his trust in Him. Indeed, Allah brings about whatever He decrees. Allah has set a measure for all things.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
As for your women who have despaired of further menstruating, if you are in doubt, then their waiting period is three months as well as those who have not yet menstruated. As for those who are pregnant, their term shall be the time they deliver their burden. Allah will ease (matters) by His order for whosoever fears Him.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
Such is the command of Allah that He has sent down to you. Whosoever fears Allah shall be relieved of his sins and given a mighty wage.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Lodge them in your home according to your means. Do not harass them so as to (make life) difficult for them. If they are with child, spend upon them until they deliver their burden; and if they suckle give them their wage and consult together honorably. But if you both make difficulties, let another woman suckle for him.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Let the rich spend according to his wealth and for he whose provision is little, let him spend from what Allah has given him. Allah does not charge a soulexcept with that He has given him. Surely, Allah will bring ease after difficulty.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
How many a village has turned in its pride against the Order of their Lord and His Messengers! We made it a stern reckoning, and punished it with a horrible punishment.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
So it tasted the mischief of its action, and the end of its matter was loss.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah has prepared a severe punishment for them. So those possessing understanding fear Allah. Believers, Allah has sent this down for you as a Reminder,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
a Messenger reciting to you the verses, clear verses of Allah, so that he may bring forth those who believe and do good deeds from the darkness into thelight. Whosoever believes in Allah and does good deeds He will admit to Gardens underneath which rivers flow where they shall live for ever and ever. For those, Allah has made a goodly provision.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
It is Allah who has created the seven heavens, and of the earth their like, and the Command descends between them so that you know Allah is powerful over all things, and that Allah encompasses everything in knowledge.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O Prophet, why do you forbid that which Allah has made lawful to you. Do you seek to please your wives' Allah is the Forgiving, the Most Merciful.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Allah has absolved you from your oaths. Allah is your Guardian, the Knowing, the Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
The Prophet confided a certain matter to one of his wives but thereafter she disclosed it, then Allah revealed what she had done to him. He made part of it known and another part not. And when he acquainted her with it, she said: 'Who has told you this' He replied: 'I was told of it by the Knower, the Aware'\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If both of you (wives) turn to Allah in repentance, even though your hearts inclined; but if you support one another against him, (know that) Allah is hisGuardian, and Gabriel, and the righteous among the believers; and thereafter the angels are his reinforcers.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
It may be that if he divorces you his Lord will give him in your place better wives than yourselves, women who have surrendered, believing, obedient, penitent worshippers and given to fasting; who were (previously) married, and virgins too.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
Believers, guard yourselves and your families against the Fire the fuel of which is people and stones, over which there are harsh, and stern angels who never disobey Allah in that which He orders and do what they are ordered.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
Unbelievers, make no excuse for yourselves this Day. You shall be recompensed only according to your deeds.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
Believers, turn to Allah in sincere repentance. Your Lord may acquit you of your sins, and admit you to Gardens underneath which rivers flow on a Day whenAllah will not degrade the Prophet and those who believe with him. Their light will run before them and on their right hands, and they will say: 'Our Lord, completeour light for us and forgive us. Surely, You have power over all things'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet, struggle with the unbelievers and the hypocrites and deal harshly with them. Gehenna (Hell) shall be their refuge, an evil arrival!\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah has given as an example for the unbelievers, the wife of Noah and the wife of Lot. They were married to two of Our righteous worshipers, but theybetrayed them. It was not for (Noah and Lot) to avail them a thing. It was said to them both: 'Enter the Fire with those who shall enter'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
But to those who believe Allah has given as an example Pharaoh's wife, who said: 'My Lord, build me a house before You in Paradise and save me fromPharaoh and his work, and save me from a harmdoing nation'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And, Mary, 'Imran's daughter, who guarded her chastity so We breathed into her of Our Spirit (Gabriel); and she put her trust in the Words of her Lord andHis Books, and was among the devout.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed be He in whose Hand is the Kingdom, He is powerful over all things,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
who created death and life that He might examine which of you is best in deeds, and He is the Almighty, the Forgiving,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
who created the seven heavens, one above the other. You cannot see any inconsistency in the creation of the Merciful. Return your gaze, do you see anycrack!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then return your gaze once more and yet again, your gaze comes back to you dazzled, and tired.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
We have adorned the lower heaven with lamps, and We made them a stoning for the satans, We have prepared the punishment of the Blaze for them.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
And for those who disbelieve in their Lord there awaits the punishment of Gehenna (Hell) an evil arrival!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they are cast into it they shall hear it sighing, while it boils\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
nearly bursting apart out of rage. Every time a host is cast therein, its keepers will ask them: 'Did no one come to warn you'\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
'Yes, indeed' they will reply, 'but we belied the Warner (Messenger) saying: 'Allah has not sent down anything, you are but in great error'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
And they will then say: 'If only we had listened and understood we should not now be among the inhabitants of the Blaze'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
So it is that they confess their sins. Curse the inhabitants of the Blaze!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
But those who fear their Lord in the Unseen, for them there is forgiveness and a great wage.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
(Whether you) speak in secret or aloud, He knows the innermost of the chests.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Shall He who has created (all things) not know? He is the Subtle, the Aware.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
It is He who has made the earth submissive to you. Walk about in its land and eat of His provision. To Him is the Resurrection.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Do you feel secure that He who is in the heaven will not cause the earth to swallow you up while it shakes?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Do you feel secure that He who is in the heaven will not loose against you a squall of pebbles then you shall know how was My warning.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
Those who have gone before you also belied (their Messengers) then how was My disapproval!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Do they not observe the birds above them, spreading their wings and folding them? None, except the Merciful holds them. Surely, He sees all things.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Or, who is it that shall be your host to help you, other than the Merciful? Indeed, the unbelievers are only deluded.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Or, who is it that shall provide for you if He withholds His provision? Yet they persist in arrogance and aversion.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
What, is he who walks, falling upon his face, more guided than he who walks upright on a Straight Path!\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say: 'It is He who has created you and given to you hearing, sight and hearts but little is it that you thank'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say: 'It was He who created you, dispersing you in the earth, and to Him you shall be gathered'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
They ask: 'When will this promise come, if you speak truthfully'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say: 'The knowledge (of that) is with Allah; I am only a clear warner'\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
Then, when they see it drawing near, the faces of the unbelievers will be blackened, and it is said: 'This is what you were promised'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say: 'What do you think, if Allah destroys me and those with me, or has mercy upon us, who then will protect the unbelievers from the painful punishment'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say: 'He is the Merciful. In Him we believe and in Him we put all our trust. Indeed, you shall soon know who is in clear error'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say: 'What do you think. If your water should sink into the earth in the morning, who then would bring you running water'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Noon. By the Pen and that (the angels) write,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
you are not, because of the favor of your Lord, mad.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
Indeed, there is an unfailing wage for you.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
Surely, you (Prophet Muhammad) are of a great morality.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
You shall see and they will see\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
which of you is the demented.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Indeed, your Lord knows very well those who strayed from His Path, and those who are guided.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
Therefore, do not obey those who belie,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
they wish you would compromise, then, they would compromise.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
And do not obey every mean swearer,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
the backbiter who goes about slandering,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
those who hinder good, the guilty aggressor,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
the crude of low character\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
because he has wealth and sons.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When Our verses are recited to him, he says: 'They are but fairytales of the ancients'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
We shall mark him upon his nose!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
We have tried them as We tried the owners of the garden who had sworn that in the morning they would reap it,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
without adding to their swearing, (Allah willing, InshaAllah).\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
Then, a visitation from your Lord came down upon it while they slept,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
and in the morning it was if the garden had been reaped.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
(Then) in the morning they called out to one another, saying:\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
'Come out to your tillage if you want to reap'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
And so they departed, whispering to one another:\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
'No needy person shall set foot in it today'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And they went out early, determined in their resolve.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But when they saw it they said: 'We have surely gone astray.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
No, rather, we have been prevented'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
(Whereupon) the best among them said: 'Did I not say to you to exalt (Allah)'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
'Exaltations to Allah, our Lord' they said, 'We were truly harmdoers'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
And they came blaming one another.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said 'Woe to us, truly we were insolent'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
It may be that our Lord will give us better than it in exchange. To our Lord we humbly turn'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such was their punishment. But the punishment of the Everlasting Life is much greater, if they but knew.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Surely, the cautious shall have Gardens of Bliss with their Lord.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
What, shall We make those who are submissive like the wrongdoers?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What is the matter with you then, how do you judge?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or, have you a Book from which you study\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
surely in it you shall have whatever you choose!\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or, have you an oath from Us that stretches to the Day of Resurrection (if so) you shall surely have what you judge!\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them, which of them will guarantee that!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or, do they have associates? Then let them bring their associates, if what they say is true!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
On the Day when the leg shall be bared, and they are ordered to prostrate themselves, they will be unable.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
Their eyes will be humbled, and humiliation shall spread over them for they were already ordered to prostrate themselves when they were undiminished.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
Therefore, leave Me with he who belied this discourse. We will draw them on little by little from where they do not know.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
I shall respite them, My stratagem is firm.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or, do you ask them for a wage, so that they are burdened withdebt?\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or, is the Unseen with them, and they are writing it down!\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
So be patient with the judgement of your Lord and do not be like the Companion of the Whale (Jonah), when he called out choking inwardly.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Had the favor of his Lord not come upon him, he would have been blamed, cast upon the shore.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
But his Lord had chosen him and He placed him among the righteous.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
When the unbelievers hear the Reminder, they nearly strike you down with their glances, and say: 'Surely, he is mad'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
But it is nothing other than a Reminder for all the worlds.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The Resurrection Verifier;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
and what is the Resurrection Verifier?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
What makes you to know what the Resurrection Verifier is?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
Thamood and Aad belied the Clatterer.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
Thamood, they were destroyed by the violent shout (of Gabriel),\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
as for Aad, they were destroyed by a howling, violent wind\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
that He subjected upon them for seven nights and eight days consecutively and you might have seen them struck down as if they were the stumps of palm trees that had fallen down.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Can you see any remnant of them now?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
Similarly, Pharaoh, and those before him, and the ruined villages, sinned\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
and rebelled against their Lord's Messenger. So He took them with a stern taking.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
And when the waters rose (high) We carried you in the sailing (Ark),\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
making it a Reminder for you, for all attentive ears to retain.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
When a single blow is blown on the Horn,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
when the earth with all its mountains is lifted up and crushed with a single blow,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
on that Day, the Event occurs.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
The heaven will be split; because on that Day it will be frail.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
The angels will stand on all its sides. And on that Day, eight (of them) will carry the Throne of your Lord above them.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
On that Day you shall be exposed, and no secret of yours will remain hidden.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
Then, he who is given his book in his right hand will say: 'Here, take and read my book!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
Indeed, I knew that I should come to my reckoning'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
His shall be a pleasing life\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
in a high Garden,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
its fruits are near.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
(It will be said): 'Eat and drink with a good appetite because of what you did in days long passed'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
But, he who is given his book in his left hand will say: 'Woe to me, would that my book had not been given to me!\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
Nor that I knew my reckoning!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
Would that it (my death) had ended it all!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
My wealth has not helped me a thing\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
and my authority has been destroyed'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
(It will be said): 'Take him and bind him.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
Roast him in Hell,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
then in a chain seventy arm's lengths long insert him.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
He did not believe in Allah, the Great,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
nor did he urge the feeding of the needy.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
Today he shall have no loyal friend here,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
nor any food except foul pus\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
that none but sinners eat'\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
I swear by all that you can see,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
and all that you do not see,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
that this is the speech of a noble Messenger.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
It is not the speech of a poet little do you believe\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
nor is it the speech of a soothsayer little do you remember.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
(It is) a sending down from the Lord of all the Worlds.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
Had he invented sayings against Us,\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We would have seized him by the right hand\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
then, We would surely have cut from him the aorta (vein)\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
not one of you could have prevented it from him.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
Indeed, it is a Reminder to those who fear Allah,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
We know that there are some among you who will belie.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
Indeed, it is a sorrow to the unbelievers\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
yet it is a certain truth.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
Exalt the Name of your Lord, the Great.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A caller supplicated about a punishment to fall on\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
the unbelievers which none can prevent.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
(A punishment) from Allah, the Owner of the Elevated Passages.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
To Him the angels and the Spirit (Gabriel) ascend in a day, the measure of which is fifty thousand years.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
Therefore be patient, with a beautiful patience;\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
they see it as being far off;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
but We see it near.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
On that Day the heaven shall become like molten copper,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
and the mountains shall be like puffs of wool.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
No loyal friend will ask another loyal friend\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
though they are in sight of each other. To ransom himself from the punishment of that Day, the sinner will wish that he might even ransom himself by his sons,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
his companion (wife), his brother,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
the kinsmen who gave him shelter,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
and whosoever is in the earth, altogether, so that it might save him.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
No, in truth, it is a Furnace!\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
It snatches away by the scalps,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
and it shall call him who withdrew and turned his back\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
and amassed (riches) and hoarded.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Indeed, the human was created grudging and impatient.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
When evil comes upon him he is impatient;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
but when good comes upon him, he is grudging\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
except those that pray\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
who are constant in prayer;\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
who, from their wealth is a known right\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
for the impoverished nonrequester and the requester,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
who confirm the Day of Reckoning\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
and go in fear of the punishment of their Lord,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
for none is secure from the punishment of their Lord,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
who guard their privates\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
except from their wives and what their right hands own, for these they are not blameworthy.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
But whosoever seeks beyond that, they are the transgressors.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
(Those) who keep their trusts and their covenant,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
and standby their witnessing,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
and who are constant in their prayers.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
Those are highly honored in the Gardens.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
But what is the matter with the unbelievers, that they strain their glances continuously towards them,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
on the right and on the left in groups?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
What, is every one of them eager to be admitted to the Garden of Bliss?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
Not at all, for We have created them of what they know.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
No, I swear by the Lord of the Easts and the Wests that We have the ability\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
to exchange them with others better than they; nothing can outstrip Us!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
So leave them alone to plunge and play, until they encounter the Day which they are promised;\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
the Day when they shall rush from their graves, as if they were hurrying to a raised flag,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
their eyes are humbled and they are covered with humiliation. Such is the Day that they were promised.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen We sent Noah to his nation, saying: 'Give warning to your nation before a painful punishment overtakes them'\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said: 'My nation, I am a clear warner for you.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
Worship Allah, fear Him, and obey me.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
He will forgive you your sins and respite you till an appointed term. When the term of Allah arrives it cannot be deferred; if you but knew'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
'My Lord' said he, 'night and day I have called my nation,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
but my call has only increased them in running away.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
Each time I called them so that You might forgive them, they thrust their fingers in their ears and wrapped themselves in their garments, and persisted becomingvery proud.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
I called to them clearly,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
and indeed, I spoke to them both publicly and in secret:\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
``Ask for forgiveness of your Lord," I said. ``Surely, He is the Forgiver.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
He will let loose the sky upon you in abundance\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
and give to you wealth and sons, and provide you with gardens and rivers.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What is the matter with you that you do not want the Greatness of Allah,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
He has created you by stages!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
Have you not seen how Allah created the seven heavens one above the other,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
setting in them the moon as a light and the sun as a lantern?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
Allah has caused you to grow out of the earth,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
and to it He will return you. Then, He will bring you forth.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
Allah has made the earth spread out for you\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
so that you walk in its spacious paths.'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Noah said: 'My Lord, they have rebelled against me and followed he whose wealth and offspring increase him only in loss,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
they have devised a mighty plot,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
and said: 'Do not renounce your gods, do not leave waddan or suwa'an or yaghutha, or ya'uqa, or nasra'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
And they have led many astray. (Noah supplicated saying): 'Allah, do not increase the harmdoers except in error'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
So because of their sins they were drowned and admitted into the Fire. They found none to help them other than Allah.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And Noah (supplicated) saying: 'My Lord, do not leave a single unbeliever upon the earth.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
Surely, if You leave them they will mislead Your worshipers and father none but the immoral, and unbelievers.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
Forgive me, My Lord, and my parents, and whosoever seeks refuge in my house as a believer, and the believers men and women alike, and do not increase the harmdoers except in ruin'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say: 'It is revealed to me that a party of jinn listened then said: ``We have indeed heard a wonderful Koran,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
that guides to the Right Path. We believe in it and we will not associate anyone with our Lord.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
He exalted be the Majesty of our Lord, who has neither taken to Himself a wife, nor a son!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
The ignorant fool among us has spoken outrageously against Allah,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
we never thought that either human or jinn would ever tell a lie against Allah!'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
But there were certain men from mankind who would take refuge with certain males from the jinn and they increased them in tyranny.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
Like you, they thought that Allah would never raise the dead.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
(The jinn continued saying): ``We made our way towards heaven, but we found it filled with stern guards and a flame.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
There, we would sit to eavesdrop, but now an eavesdropper finds a flame in wait for him.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
And so we do not know whether evil is intended for those on earth, or whether their Lord intends to guide them.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
Some of us are righteous, but some are otherwise, we are sects that differ.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
We know that we cannot frustrate Allah in the earth, nor can we frustrate Him by flight.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
When we heard the Guidance, we believed in it, and whosoever believes in his Lord shall fear neither shortage nor injustice.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
Some of us have surrendered (Muslims) and some of us have deviated. Those who surrendered sought the Right Path,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
but those who have deviated shall become the fuel of Gehenna (Hell).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
If they had followed the Path We would give to them abundant water to drink,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
and tested them with it. And whosoever turns away from his Lord's Remembrance, He will hurl him into a stern punishment.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
Mosques belong to Allah, so do not call to anyone else, other than Allah.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
When the worshiper of Allah stood supplicating to Him, they swarmed around him (Prophet Muhammad).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say: 'I supplicate only to my Lord and I do not associate any with Him'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say: 'Indeed, I possess no power over you, either for harm or for guidance'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say: 'None shall protect me from Allah, and other than Him, I will find no refuge,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
except a deliverance from Allah and His Messages. He who disobeys Allah and His Messenger, for him is the Fire of Gehenna, which he will be in for ever.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
When they see that which they were promised they shall know who is weaker in helpers and fewer in numbers.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say: 'I do not know whether that which you are promised is near, or whether my Lord will set for it a time.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
He is the Knower of the Unseen and does not disclose His Unseen to anyone,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
except only to a Messenger that He has chosen, and He sends guardians before him and behind him,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
so that He may know that they have delivered the Messages of their Lord and He encompasses all that is with them, and He has counted everything innumbers'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O you (Prophet Muhammad) wrapped,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
rise (to pray) the night except a little;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
half the night, or a little less\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
or a little more; and with recitation, recite the Koran.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
We are about to cast upon you a weighty Word.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Indeed, the first part of night is heavier in tread, and more upright in speech.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
You have by day prolonged occupations.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
Remember the Name of your Lord and dedicate yourself devoutly to Him.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
He is the Lord of the East and the West; there is no god except Him. Take Him for your Guardian.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
Bear patiently with what they say and with a fine abandonment forsake them.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
Leave to Me those who belie, those who lead a life of pleasure, and bear with them yet a little while.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
We have fetters (for them) and a blazing fire,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
choking food and a painful punishment.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
On the Day when the earth with all its mountains quake and the mountains become heaps of shifting sand.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
Indeed, We have sent to you a Messenger as a witness over you, just as We sent a Messenger to Pharaoh.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
Pharaoh disobeyed Our Messenger, so We seized him remorselessly.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
If you disbelieve, how will you guard yourself against the Day that will make children gray haired,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
on which the heaven will split apart, and His promise is done.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
This is indeed a Reminder. Let whosoever will take the Path to his Lord.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Your Lord knows that you keep vigil nearly two thirds of the night and sometimes half or onethird of it, and a party of those with you. Allah measures thenight and the day. He knows that you cannot count it, and turns to you. Therefore, recite from the Koran as much as is easy (for you); He knows that among youthere are the sick and others traveling the road seeking the bounty of Allah; and others fighting in the Way of Allah. So then, recite from it as much as is easy. Establish your prayers, pay the obligatory charity, and lend Allah a generous loan. Whatever good you shall forward to your souls' account, you surely will find it better with Allah, and a mightier wage. And supplicate for the forgiveness of Allah. Allah is the Forgiving, the Merciful.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O you (Prophet Muhamad), the cloaked,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
arise and warn,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
and exalt your Lord,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
and purify your clothing,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
and flee from the statues!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
Do not give, thinking to gain greater\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
be patient unto your Lord.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
When the Horn is blown,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
that shall be a Harsh Day\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
and it will not be easy for the unbelievers.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me alone with he whom I created\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
and designated for him ample wealth,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
and sons that stand in witness.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
I made things smooth and easy for him,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
yet he is eager that I increase him.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
Not at all! Surely, he has been disobedient to Our verses.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
I will constrain him to a hard ascent.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
He reflected, and then determined\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
death seized him, how was his determining!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
Again, death seized him, how was his determining!\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then he looked,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
frowned and scowled;\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
then he retreated and grew proud\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
and said: 'This is no more than traced sorcery;\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
It is nothing but the word of a mortal'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
I will surely roast him in the Scorching.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
What will let you know what the Scorching is like!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It neither spares, nor releases,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
and it burns the flesh.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Over it are nineteen (angels guarding).\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
We have appointed none but angels to guard the Fire, and made their number only as a trial for the unbelievers, so that those to whom the Book was given are certain and those who believe increase in belief. And that those who were given the Book, and those who believe will not be in doubt. And that those in whose hearts there is a sickness, together with the unbelievers, may say: 'What did Allah intend by this as an example' As such, Allah leaves in error whom He will and He guides whomsoever He will. None knows the hosts of your Lord except He. This is no more than a Reminder to humans.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
No, by the moon!\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
By the receding night\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
and the morning when it appears,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
it is one of the greatest trials,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
a warning to humans,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
to whoever among you desires to go forward, or lag behind.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Each soul is held in pledge for what it earns,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
except the Companions of the Right.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
In Gardens they will question\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
concerning the sinners,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
'What caused you to be thrust into the Scorching (Fire)'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will reply: 'We were not among those who prayed\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
and we did not feed the needy.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
We plunged in with the plungers\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
and belied the Day of Recompense\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
till the certainty (death) overtook us'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
The intercession of their intercessors shall not benefit them.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
What is the matter with them that they turn away from this Reminder,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
like startled wild donkeys\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
fleeing before a lion?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Indeed, each one of them desires to be given unrolled scrolls.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
No, indeed they have no fear of the Everlasting Life.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
No, indeed, surely, this is a Reminder.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
So, whoever wills, will remember it.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
But none will remember, unless Allah wills, He is the Owner of fear, the Owner of forgiveness.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen No! I swear by the Day of Resurrection,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
No! I swear by the reproachful soul!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
What, does the human think We shall never gather his bones?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Indeed yes, We are able to shape his fingerstips yet again!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
Rather, the human desires to continue in his immorality,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
'When will the Day of Resurrection be' he asks,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
but when the sight is dazed\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
and the moon eclipsed,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
when the sun and moon are gathered together\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
on that Day the human will ask: 'To (which place) shall I flee'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
No, there shall be no (place of) refuge.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
For on that Day the refuge shall be to your Lord.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
On that Day the human shall be informed of his former and latter deeds.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
He shall be a clear proof against himself,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
even though he offers his excuses.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Do not move your tongue with it (the Revelation) to hasten it.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
It's gathering and reciting is upon Us.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
When We recite it, follow its recitation.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
It's explanation is upon Us.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
Yet you love this hasty world\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
and are heedless of the Everlasting Life.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
On that Day there shall be radiant faces,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
gazing towards their Lord.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And on that Day there shall be scowling faces,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
so they might think the Calamity had been inflicted upon them.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
But, when (the soul) reaches the collar bone\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
and it is said: 'Who is a healing chanter'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
and when he thinks it is the time of departure\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
and when leg is intertwined with leg,\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
upon that Day the driving shall be to your Lord.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
Because, he neither believed nor prayed;\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
he belied the truth and turned away;\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
then went arrogantly to his household.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Near to you and nearer,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
then nearer to you and nearer!\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Does the human think he will be left to roam at will?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
What, was he not an ejaculated drop (of sperm)?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then he was a clot of blood, then He created and formed him\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
and made from him two kinds, male and female.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
What, is He then unable to revive the dead?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Indeed, there came upon the human a period of time when he was an unremembered thing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
We have created the human from a (sperm) drop, a mixture, testing him; We made him to hear and see.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
Indeed, We have guided him to the path, he is either grateful or ungrateful.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
Indeed, for the unbelievers We have prepared chains, fetters and a Blazing (Fire).\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
But the righteous shall drink of a goblet mixed with camphor;\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
a fountain at which the worshipers of Allah drink and make it gush forth abundantly;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
they who keep their vows and fear a Day whose evil is spread;\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
who give food, for the love of Him to the needy, the orphan, and the captive,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
(saying): 'We feed you only desirous of the Face of Allah; we seek of you neither recompense nor thanks,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
for we fear from our Lord a stern, frownful Day'\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
So Allah will save them from the evil of that Day and has secured for them radiance and joyfulness,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
and recompense them for their patience with a Garden, and robes of silk.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
Reclining there upon couches, they shall see neither the sun nor the moon.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
Near them shall be its shades with its clusters hung gently down,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
and passed around them shall be silver vessels, and crystal goblets,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
goblets of silver that they have precisely measured.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
And they shall be given to drink from a cup whose mixture is ginger,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
from a fountain called Salsabila.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
Immortal youths will go about them, when you see them, you would suppose them to be scattered pearls.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
When you see them, you see bliss, and a great Kingdom.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Upon them there will be garments of green silk, rich brocade, and they will be adorned with bracelets of silver. Their Lord will give them a pure beverage to drink.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
'See, this is your recompense, your striving is thanked'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
We have indeed, sent down to you the Koran, a (clear) sending,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
therefore be patient under the Judgement of your Lord, and do not obey either the sinner or the unbeliever.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And, remember the Name of your Lord at the dawn and in the evening;\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
and in the night prostrate to Him; and exalt Him for a long night.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Indeed, these love the hasty life, and are heedless and leave behind them a heavy Day.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
We created them, and We strengthened their joints, but, when We will, We shall indeed exchange their likes.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
This is indeed a Reminder, so that he who will, takes a path to his Lord.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
Yet you will not unless Allah wills; surely, Allah is the Knower, the Wise.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He is Merciful to whom He will; but, for the harmdoers He has prepared for them a painful punishment.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By (the wind) those sent (as horses') mane (in succession),\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
storming tempestuously\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
and by the scatterers scattering (rain)\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
then the criterion (the verses of Koran), separating\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
and those (angels) dropping, reminding\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
excusing or warning,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
surely, that which you have been promised is about to fall!\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
When the stars are extinguished,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
and when the sky is rent asunder\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
and the mountains scattered,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
and when the Messengers' time is set\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
to what day shall they be deferred?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
Upon the Day of Decision!\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
Would that you knew what the Day of Decision is!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe on that Day to those who belied it!\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy the ancients\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
and let the latter follow them?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
As such shall We deal with the sinners.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe on that Day to those who belied it!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you from a weak water,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
which We placed within a sure lodging\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
for an appointed term?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
We determined, how excellent a Determiner are We!\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe on that Day to those who belied it!\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Have We not made the earth a housing\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
for both the living and the dead?\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
Have We not placed high mountains upon it and filled you with sweet water?\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe on that Day to those who belied it!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
Depart to that which you belied!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
Depart into the shadow of three masses,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
wherein there is neither shade, nor freeing from the blazing flames\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
it throws spits as (high as a huge) palace,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
as black camels.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe on that Day to those who belied it!\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
This is the Day they shall not speak,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
nor shall they be given permission, so that they can apologize.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe on that Day to those who belied it!\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
Such is the Day of Decision. We will gather you with the ancients.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
If you are cunning, then try your cunning against Me!\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe on that Day to those who belied it!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Indeed, the cautious, shall live amid shades and fountains\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
and have such fruits as they desire.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
(It shall be said to them): 'Eat and drink, with a good appetite, for all that you did'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
As such We recompense those who did good.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe on that Day to those who belied it!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
'Eat and enjoy yourselves a little, for you are sinners'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe on that Day to those who belied it!\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
When it is said to them: 'Bow yourselves' they do not bow.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe on that Day to those who belied it!\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
After this, in what discourse will they believe?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen What do they question each other about!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
About the Great News\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
whereupon they are at variance?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
Indeed, they shall know!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Again, indeed, they shall know!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not made the earth as a cradle\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
and the mountains as pegs?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And We created you in pairs,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
and We made your sleep a rest,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
and We made the night a mantle,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
and We made the day for a livelihood.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And We built above you seven strong ones,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
and placed in them a blazing lamp\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
and have sent down from the clouds, pouring rain\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
that We may bring forth with it grain, plants\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
and luxuriant gardens.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Indeed, the Day of Decision is an appointed time,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
the Day that the Horn is blown, and you shall come in crowds\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
and heaven is opened, having gates,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
and the mountains move, and vaporize.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Indeed, Gehenna (Hell) has become an ambush,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
a return for the insolent,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
there, they shall live for ages,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
tasting neither coolness nor any drink\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
except boiling water and pus\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
for a suitable recompense.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
Indeed, they did not hope for a Reckoning,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
and they absolutely belied Our verses,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
and everything We have numbered in a Book.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
'Taste! We shall not increase you except in punishment'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
But, for the cautious a place of prosperity,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
and gardens and vineyards,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
curvaceous (virgins), of equal age\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
and an overflowing cup.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
There, they shall neither hear idle talk, nor yet any falsehood,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
a recompense from your Lord, a gift, a reckoning,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
the Lord of the heavens and earth, and all that is between them, the Merciful, of whom they are unable to speak.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
On that Day, when the Spirit (Gabriel) and the angels stand in ranks they shall not speak, except he to whom the Merciful has given permission, and sayswhat is right.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is the Day, the truth, so whosoever wills takes a way to his Lord.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Indeed, We have forewarned you of an imminent punishment, the Day when the person will look upon his works and the unbelievers will say: 'Would that I were dust'\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By the pluckers (the angels of death), violently plucking (the souls of the unbelievers),\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
by the drawers (the angels of death), gently drawing (the souls of the believers),\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
by the swimmers (angels) swimming gently\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
and the outstrippers (angels), outstripping,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
by the managers (angels) affair.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
On the Day, the shiverer shivers\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
followed by the succeeding,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
hearts will throb on that Day\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
and their eyes will be humbled.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They say: 'What, are we being restored as we were before,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
even after we are fragmented bones'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They will say: 'Then we are returned lost'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
But it will be only a single blow,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
and they will be upon the surface of the earth (alive).\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Have you received the story of Moses?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
His Lord called to him in the Sacred Valley of Towa,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
saying 'Go to Pharaoh, he has become exceedingly insolent,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
and say: ``Will you purify yourself,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
that I might guide you to your Lord, so that you fear (Him)."\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
He showed him the mighty sign,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
but he belied and disobeyed,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
and hastily turned away,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
then, he gathered, proclaimed, then said:\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
'I am your lord, the most high'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
So Allah seized him with the punishment of the Everlasting Life, and of this world.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Surely, in this there is a lesson for he that fears!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
What, are you harder to create than the heaven which He has built?\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He raised it high and leveled it,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
and darkened its night and brought forth its morning.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And the earth He extended after that;\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
and then brought from it its water and pastures.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And the mountains He set firm\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
an enjoyment for you and your herds.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
But when the Great Catastrophe comes,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
the Day when the human will remember what he has worked for,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
and when Hell is advanced for whoever sees,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
then as for whosoever was insolent\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
preferring the present life,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
surely, Hell will be their refuge.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
But, whosoever feared the standing before his Lord and prevented the self from desires,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
indeed, their refuge shall be Paradise.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They will question you about the Hour: 'When shall it be'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
But how are you to know?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
Its final end is for your Lord.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
You are but a warner for those who fear it.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
On the Day when they behold it, it will be as if they had lingered but an evening, or, a morning.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen He frowned and turned away\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
when the blind came to him.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
And what could let you know? Perhaps he (comes to hear you) to be purified.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
(He might) remember, and the Reminder might profit him.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
As for he who is sufficed\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
you attended to him,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
although it is not for you to be concerned if he remained unpurified.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
And to him who came to you eagerly\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
and fearfully,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
of him you were unmindful.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
No indeed, this is a Reminder;\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
and whosoever wills, shall remember it.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
upon highly honored pages,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
exalted, purified,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
by the hands of scribes\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
noble and pious.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Perish the human! How unthankful he is!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
From what did He create him?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
From a (sperm) drop He created him and then determined him,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
then eased his path for him,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
then causes him to die and buries him,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
then, He will raise him when He wills.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
Indeed, he has not fulfilled that which He has ordered him.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Let the human reflect on the food he eats,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
how We pour down rain in abundance,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
and split the earth, splitting,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
how We made the grain to grow,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
grapes, and fresh fodder,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
and the olive, and the palm,\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
the densely tree'd gardens,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
and fruit and pastures,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
for you and for your herds to delight in.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
But, when the Blast comes,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
on that Day each person will flee from his brother,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
his mother and his father,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
his wife and his children.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
Everyone on that Day will have affairs to keep him occupied.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Some faces will shine,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
laughing and joyful,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
whereas some faces will be covered with dust\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
and veiled with darkness.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
Those, they are the unbelievers, the immoral.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun is woundup;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
when the stars are thrown down,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
and the mountains have been taken,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
when the pregnant camels are neglected,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
when the savage beasts are gathered\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
when the seas are set boiling,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
when the souls are coupled (to their body),\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
when the buried female infant is asked\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
for what crime she was slain,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
when the scrolls are unrolled,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
when heaven is stripped,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
when Hell is set ablaze,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
when Paradise is brought near,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
then, each soul shall know what it has produced.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
Rather, I swear by the returning\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
orbiting, disappearing;\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
by the night when it approaches\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
and the morning when it extends,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
it is indeed the word of an Honorable Messenger,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
of power, given a rank by the Owner of the Throne\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
obeyed, and honest.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
Your Companion is not mad,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
in truth he saw him (Gabriel) on the clear horizon,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
he is not grudging of the Unseen.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
Nor is this the word of a stoned satan.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
Where then are you going?\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
This is nothing but a Reminder to the worlds,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
for whosoever of you would go straight,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
but you shall not, unless Allah wills, the Lord of all the Worlds.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the sky is split,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
when the planets are scattered,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
when the oceans are gushed forth,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
when the graves are overturned,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
the soul shall know what it has done, the former and the latter.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O human! What has deceived you concerning your Generous Lord\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
who created you, formed you and proportioned you?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
In whatever shape He will He could surely have fashioned you.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
Rather, you belied the Recompense.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
Yet over you there are watchers,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
noble scribes\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
who know of all that you do.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Indeed, the righteous shall (live) in bliss.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
But the wicked, indeed they shall be in the Fiery Furnace,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
roasting in it on the Day of Recompense\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
and from it they shall never be absent.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
What could let you know what the Day of Recompense is!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what could let you know what the Day of Recompense is!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
It is the Day when no soul can do a thing for another soul. That Day, the command belongs to Allah.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe to the diminishers,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
who, when people measure for them, take full measure,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
but when they measure or weigh for others, they reduce!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Do they not think that they will be resurrected\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
for a great Day,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
the Day when people will stand before the Lord of the Worlds?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
No indeed, the Book of the immoral is in Sijjeen.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
What could let you know what the Sijjeen is!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
(It is) a marked Book.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe on that Day to those who belied it,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
who belied the Day of Recompense!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
None belies it except every guilty sinner.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
When Our verses are recited to him, he says: 'Fictitious tales of the ancients'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
No indeed! Their own deeds have cast a veil over their hearts.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
No indeed, on that Day they shall be veiled from their Lord.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Then they shall roast in Hell,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
and it will be said to them: 'This is that which you belied'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
But, the Book of the righteous is in the 'Illiyoon.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
What could let you know what the 'Illiyoon is!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
(It is) a marked Book,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
witnessed by those who are near (to Allah).\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
The righteous shall indeed be blissful,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
(reclining) upon couches they will gaze,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
and in their faces you shall know the radiance of bliss.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They shall be given to drink of a wine that is sealed,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
its seal is musk, for this let the competitors compete;\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
and its mixture is Tasneem,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
a fountain at which those brought near (to their Lord) drink.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
The sinners laughed at the believers\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
and winked at one another as they passed them by.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
When they returned to their people they returned jesting;\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
and when they saw them said: 'These are they who are astray'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
Yet they were not sent to be their guardians.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
But on this Day the believers will laugh at the unbelievers\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
as they (recline) upon their couches and gaze (around them).\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Have the unbelievers been rewarded for what they did?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the sky is torn apart,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
hearing and obeying its Lord, as it must do;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
when the earth is stretched out\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
and casts out all that is within and voids itself,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
obeying its Lord, as it must do!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O human, you are working hard towards your Lord and you will meet Him.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Then, he who is given his Book in his right hand\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
shall have an easy reckoning\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
and will return rejoicing to his family.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But he who is given his Book from behind his back\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
shall call for destruction\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
and roast at the Blaze.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
Once, he lived joyfully among his family\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
and surely thought he would never return (to his Lord).\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
Yes indeed, his Lord was ever watching him.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
I swear by the twilight;\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
by the night and all that it envelops;\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
by the moon, in its fullness\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
that you shall surely ride from stage to stage.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
What is the matter with them, that they do not believe\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
and when the Koran is recited to them that they do not prostrate!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
No, the unbelievers only belie,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
and Allah knows very well what they gather.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
Therefore give to them glad tidings of a painful punishment,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
except to those who believe, and do righteous deeds, for theirs is an unfailing recompense.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the heaven of the constellations!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
By the Promised Day!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
By the witness and the witnessed!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
The companions of the pit were killed\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
the fire with its fuel,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
when they were seated around it\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
and they were witnesses of what they did to the believers\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
and their revenge on them was only because they believed in Allah, the Almighty, the Praised,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
to whom belongs the Kingdom of the heavens and earth. And Allah is the Witness of all things.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Those who persecuted the believing men and women and never repented, there is for them the punishment of Gehenna (Hell), and for them the punishment of the burning.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
(But) for those who believe and do good works, for them there are Gardens underneath which rivers flow that is the Great Victory!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Indeed, the seizing of your Lord is severe.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
It is He who originates and repeats.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He is the Forgiving, and the Loving.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Owner of the Throne, the Exalted.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
The Doer of whatever He wants.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Has it come to you the story of the hosts\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
of Pharaoh and of Thamood?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
Yet the unbelievers still belie,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
Allah encompasses them all from behind.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
Indeed, this is a Glorious Koran,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
in a Guarded Tablet.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the sky, and by the nightly comer!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
What could let you know what the nightly comer is!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
(It is) the piercing star.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
For every soul there is a watcher.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
Let the human reflect of what he is created.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He was created from ejaculated water\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
that issues from between the loins and the ribs.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Surely, He is Able to bring him back,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
on the Day when consciences are examined,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
when he will be helpless, with no supporter.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the sky with its returning rain,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
and by the earth bursting with vegetation;\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
this is indeed a Decisive Word,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
it is not a jest.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
They are cunningly devising,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
and I am cunningly devising.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
Therefore respite the unbelievers, and delay them for a while.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Exalt the Name of your Lord, the Highest,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
who has created and shaped,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
who has ordained and guided,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
who brings forth the pastures,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
then made it dry dark, flaky stubble,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We shall make you recite so that you will not forget,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
except what Allah wills, surely, He knows all that is (spoken) aloud and what is hidden.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
We shall ease you to the easy.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
Therefore remind, if the Reminder benefits,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
and he who fears shall remember,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
but the most wretched shall avoid it,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
who will roast in the Great Fire,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
in which he will neither die nor live therein.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
Prosperous is he who purifies himself,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
and remembers the Name of his Lord, so he prays.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
But you prefer the present life,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
but the Everlasting Life is better, and more enduring.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
Surely, this is in the ancient Scrolls,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
the Scrolls of Abraham and Moses.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Have you received the news of the Enveloper?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
On that Day faces shall be humbled,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
laboring, wornout,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
roasting at a scorching Fire\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
that is fueled from a tremendously hot fountain,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
no food for them except thorny plants\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
which neither sustains, nor satisfy hunger.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
(Whereas other) faces on that Day will be joyful,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
well pleased with their striving,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
in a Garden on high,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
where they will hear no idle talk.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
A gushing fountain shall be there\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
and raised couches,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
and prepared goblets,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
and arranged cushions\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
and outspread carpets.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
What, do they not reflect upon how the camel was created?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And how the heaven was raised up,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
and how the mountains were firmly fixed?\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And how the earth was outstretched?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
Therefore remind, you are only a Reminder.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
You are not charged to oversee them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
As for those who turn their back and disbelieve,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
Allah will punish them with the greatest punishment.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Indeed, to Us they shall return,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
then upon Us shall rest their reckoning.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the dawn\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
and ten nights (of pilgrimage or the last ten days of Ramadan),\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
by the even, and the odd,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
by the night when it journeys on!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Is there in that an oath for the mindful?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Have you not heard how your Lord dealt with Aad?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
of the columned (city) of Iram,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
the like of which was never created in the countries?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And Thamood, who hewed out the rocks of the valley?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And Pharaoh, of the pegs (impaling his victims)?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
They were tyrants in the land\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
and exceeded in corruption therein.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
(Therefore) your Lord let loose upon them a scourge of punishment;\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
indeed, your Lord is ever watchful.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
As for man, when his Lord tests him by honoring him and favoring him, he says: 'My Lord, has honored me'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But when He tests him by restricting his provision, he says: 'My Lord has humiliated me'\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
No! But you show no good to the orphan,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
nor do you urge one another to feed the needy.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
and you devour the inheritance with greed,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
and you ardently love wealth.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
No! But when the earth quakes and is pounded,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
and your Lord comes with the angels, rank upon rank,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
and Gehenna (Hell) is brought near on that Day the human will remember, and how shall the Reminder be for him?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say: 'Would that I had forwarded (good works) for my life!'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
But on that Day none will punish as He (Allah) will punish,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
nor will any bind as He binds.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
O satisfied soul,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
return to your Lord wellpleased, wellpleasing.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
Join My worshipers and\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
enter My Paradise!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen No, I swear by this country (Mecca),\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
and you are a lodger in this country.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And by the giver of birth, and whom he fathered,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
We created the human in fatigue.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Does he think that none has power over him!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He will say: 'I have destroyed a vast wealth'\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Does he think that none has observed him?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Have We not given him two eyes,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
a tongue, and two lips,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
and guided him on the two paths (of good and evil)?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
Yet he has not scaled the height.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
What could let you know what the height is!\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
(It is) the freeing of a slave,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
the giving of food upon the day of hunger\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
to an orphaned relative\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
or to a needy person in distress;\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
so that he becomes one of those who believe, charge each other to be patient, and charge each other to be merciful.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
Those are the Companions of the Right.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
But those who disbelieve in Our verses, they are the Companions of the Left,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
with the Fire closed above them.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the sun and its midmorning,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
by the moon, which follows it,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
by the day, when it displays it,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
by the night, when it envelops it!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
By the heaven and Who built it,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
by the earth and Who spread it,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
by the soul and Who shaped it\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
and inspired it with its sin and its piety,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
prosperous is he who purified it,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
and failed is he who buried it!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
Thamood belied in their pride\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
when the most wicked of them broke forth,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
the Messenger of Allah said to them: '(This is) the shecamel of Allah, let her drink'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
But they belied him, and hamstrung her. So their Lord crushed them for their sin and leveled it (their village).\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
He does not fear the result (of their destruction).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night, when it envelops,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
and by the day when it unveils.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
And by Who created the male and female,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
your striving is indeed to different ends!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
For him that gives and fears (Allah)\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
and believes in the finest,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
We shall surely ease him to the Path of Easing;\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
but for him that is a miser, and sufficed,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
and he belied the finest\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
We shall surely ease for him the Path of Hardship (the Fire).\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
When he falls (into Hell), his wealth will not help him.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Indeed, Guidance is Ours,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
and to Us belong the Last and the First.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
I have now warned you of the Blazing Fire,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
in which none shall be roasted except the most wretched sinner,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
who belied and turned away,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
and from which the cautious shall be distanced.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
He who gives his wealth to be purified,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
and confers no favor upon anyone for recompense\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
seeking only the Face of his Lord, the Most High,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
surely, he shall be satisfied.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the midmorning,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
and by the night when it covers,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
your Lord has not forsaken you (Prophet Muhammad), nor does He hate you.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
The Last shall be better for you than the First.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
Your Lord will give you, and you will be satisfied.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find you an orphan and give you shelter?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
Did He not find you a wanderer so He guided you?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
Did He not find you poor and suffice you?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Do not oppress the orphan,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
nor drive away the one who asks.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
But tell of the favors of your Lord!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Have We not expanded your chest for you (Prophet Muhammad),\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
and relieved you of your burden\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
that weighed down your back?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
Have We not raised your remembrance?\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
Indeed, hardship is followed by ease,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
indeed, hardship is followed by ease!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
So, when you have finished (your prayer), labor (in supplication),\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
and let your longing be for your Lord (in humility).\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the fig and the olive!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
and the Mount, Sinai,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
and this safe country (Mecca)!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
Indeed, We created the human with the fairest stature\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
and We shall return him to the lowest of the low,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
except the believers who do good works, for theirs shall be an unfailing recompense.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
So, what then shall belie you concerning the Recompense?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is Allah not the Most Just of judges!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Read (Prophet Muhammad) in the Name of your Lord who created,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
created the human from a (blood) clot.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Read! Your Lord is the Most Generous,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
who taught by the pen,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
taught the human what he did not know.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
Indeed, surely the human is very insolent\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
that he sees himself sufficed.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Indeed, to your Lord is the returning.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
What do you think? Have you seen he who forbids\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
a worshiper when he prays.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Have you seen if he was upon guidance\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
or orders piety?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
What do you think? Have you seen if he belies and turns away,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
does he not know that Allah sees?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
Indeed, if he does not desist, We will seize him by the forelock,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
a lying, sinful forelock.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
So, let him call upon his way!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We, will call the Zabania (the harsh angels of Hell).\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
No, indeed; do not obey him! Prostrate and come nearer (to Allah).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen We sent this (the Holy Koran) down on the Night of Honor.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
What could let you know what the Night of Honor is!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Honor is better than a thousand months,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
in it the angels and the Spirit (Gabriel) descend by the permission of their Lord upon every command.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
Peace it is, till the break of dawn.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen The unbelievers among the People of the Book and the idolaters would never desist until the Clear Proof came to them.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
A Messenger from Allah reciting Purified Pages\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
in which there are valuable Books.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
Those to whom the Book was given did not divide themselves until the Clear Proof came to them.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
Yet they were ordered to worship Allah alone, making the Religion His sincerely, upright, and to establish their prayers and to pay the obligatory charity. That is indeed the Religion of Straightness.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
The unbelievers among the People of the Book and the idolaters shall be for ever in the Fire of Gehenna (Hell). They are the worst of all creatures.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
But those who believe and do good deeds are the best of all creatures.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their recompense is with their Lord; Gardens of Eden, underneath which rivers flow, where they shall live for ever. Allah is wellpleased with them, and theyare wellpleased with Him. That is for he who fears his Lord!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth is shaken with its mighty shaking,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
and when the earth brings forth its burdens\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
and the human asks: ``What is the matter with it?"\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
On that Day it shall proclaim its news,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
for your Lord will have revealed to it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
On that Day mankind shall issue in scatterings to see their deeds.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
Whosoever has done an atom's weight of good shall see it,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
and whosoever has done an atom's weight of evil shall see it.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the snorting runners (the horses),\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
by the strikers of fire,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
by the dawnraiders,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
raising a trail of dust,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
dividing the gathering.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Indeed, the human is ungrateful to his Lord.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
To this he himself shall bear witness.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And indeed he is ardent for the love of good (wealth, becoming greedy).\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Does he not know that when that which is in the graves is overthrown,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
and that which is in the chest is brought out,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
indeed, on that Day their Lord will be aware of them!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The Clatterer (the Day of Judgement)!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the Clatterer.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
What shall let you know what the Clatterer is!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
On that Day people shall become like scattered moths\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
and the mountains like tufts of carded wool.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then he whose deeds weigh heavy in the Scale\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
shall live in a life which is pleasing,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
but he whose weight is light in the Scale,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
his head will be in the Plunging\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
What shall let you know what the Plunging is?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
(It is) a Fire which is extremely hot.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen The excessive gathering (of increase and boasting) occupied you (from worshipping and obeying)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
until you visit the graves.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
But no, indeed, you shall soon know.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Again, no indeed, you shall soon know.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
Indeed, did you know with certain knowledge\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
that you shall surely see Hell?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
Again, you shall surely see it with the sight of certainty.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
On that Day, you shall be questioned about the pleasures.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By the time of the afternoon!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Surely, the human is in a (state of) loss,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
except those who believe and do good works and charge one another with the truth and charge one another with patience.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe to every backbiter, slanderer\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
who amasses wealth and counts it,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
thinking his wealth will render him immortal!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
On the contrary! He shall be flung to the Crusher.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
What shall let you know what the Crusher is?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
(It is) the kindled Fire of Allah,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
which shall oversee the hearts,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
closed around them\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
in extended columns.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Have you not seen how Allah dealt with the companions of the Elephant?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not cause their schemes to go astray?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And He sent against them flights of birds\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
pelting them with stones of baked clay,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
so that He made them like straw eaten (by cattle).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen For the custom of the Koraysh,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
their custom of the winter and summer journey.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
Therefore let them worship the Lord of this House\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
who fed them from hunger and secured them from fear.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Have you seen he who belied the Recompense?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
It is he who turns away the orphan\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
and does not urge others to feed the needy.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
Woe to those who pray,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
who are heedless of their prayers (delaying them from their prescribed times),\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
who show off,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
and prevent the utensils of assistance.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen Indeed, We have given you (Prophet Muhammad) the abundance (Al Kawthar: river, its pool and springs).\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
So pray to your Lord and sacrifice.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
Surely, he who hates you, he is the most severed.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say: 'O unbelievers,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
I do not worship what you worship,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
nor do you worship what I worship.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
Nor am I worshiping what you have worshipped,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
neither will you worship what I worship.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
To you your religion, and to me my Religion'\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When the victory of Allah and the opening comes,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
and you see people embracing the Religion of Allah in throngs,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
exalt with the praise of your Lord and ask forgiveness from Him. For indeed, He is the Turner (for the penitent).\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen Perish the hands of AbiLahab, and perish he!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth will not suffice him, neither what he has gained;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
he shall roast at a Flaming Fire,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
and his wife, laden with firewood\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
shall have a rope of palmfiber around her neck!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say: 'He is Allah, the One,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
the called upon.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
Who has not given birth, and has not been born,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
and there is none equal to Him'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say: 'I take refuge with the Lord of Daybreak\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
from the evil of what He has created,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
from the evil of the darkness when it gathers\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
from the evil of the blowers on knots;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
from the evil of the envier when he envies'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say: 'I take refuge with the Lord of people,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
the King of people,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
the God of people,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
from the evil of the slinking whisperer.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
who whispers in the chests of people,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
both jinn and people.'\qt@no{(6)}}%
%% End of file `qurantext-enxi.translation.def'
