\qt@newcmd\qurantrans@en@i{%
Allah - beginning with the name of - the Most Gracious, the Most Merciful.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ii{%
All praise is to Allah, the Lord Of The Creation.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@iii{%
The Most Gracious, the Most Merciful\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@iv{%
Owner of the Day of Recompense\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@v{%
You alone we worship and from You alone we seek help (and may we always).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@vi{%
Guide us on the Straight Path.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@vii{%
The path of those whom You have favoured – Not the path of those who earned Your anger – nor of those who are astray.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif-Laam-Meem. (Alphabets of the Arabic language; Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ix{%
This is the exalted Book (the Qur’an), in which there is no place for doubt; a guidance for the pious.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@x{%
Those who believe without seeing (the hidden), and keep the (obligatory) prayer established, and spend in Our cause from what We have bestowed upon them.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@xi{%
And who believe in this (Qur’an) which has been sent down upon you, O beloved Prophet, (Mohammed – peace and blessings be upon him) and what was sent down before you; and are certain of the Hereafter.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@xii{%
It is they who are on guidance from their Lord; and they are the successful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@xiii{%
As for those whose fate is disbelief, whether you warn them or do not warn them – it is all one for them; they will not believe. (Because their hearts are sealed – see next verse).\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah has sealed their hearts and their ears, and on their eyes is a covering; and for them is a terrible punishment.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@xv{%
And among the people are some* that say, “We believe in Allah and the Last Day**” whereas they are not believers! (* The hypocrites ** the Day of Resurrection)\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@xvi{%
They wish to deceive Allah and the believers; and in fact they deceive none except themselves and they do not have any understanding.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is a disease, so Allah has increased their disease; and for them is a painful punishment, because of their lies.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@xviii{%
And when it is said to them, “Do not cause turmoil in the earth”, they say, “We are only peacemakers!”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@xix{%
Pay heed! It is they who are mischievous, but they do not have sense.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@xx{%
And when it is said to them, “Believe as the others believe”, they say, “Shall we believe as the foolish believe?” It is they who are the fools, but they do not know.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@xxi{%
And when they meet with the believers, they say, “We believe”; and when they are alone with their devils, they say, “We are undoubtedly with you, we were just mocking!”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@xxii{%
Allah (befitting His Majesty) mocks them, leaving them to wander blindly in their rebellion.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@xxiii{%
These are the people who purchased error in exchange of guidance – so their bargain did not profit them, and they did not know how to trade.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their example is like that of one who kindled a fire; and when it lit up all that was around it, Allah took away their light and left them in darkness, unable to see anything.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@xxv{%
Deaf, dumb and blind; and they are not to return.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or like a rainstorm from the sky, in which are darkness, thunder and lightning; they thrust their fingers in their ears due to the thunderclaps, fearing death; and Allah has the disbelievers encompassed.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@xxvii{%
It seems the lightning may snatch away their sight from them; whenever it flashes they walk in it, and when it darkens they stand still; if Allah willed, He could take away their hearing and their sight; indeed Allah is Able to do all things.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@xxviii{%
O mankind! Worship your Lord, Who has created you and those before you, in the hope of attaining piety.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@xxix{%
The One Who has appointed the earth a base for you, and the sky a canopy – and caused water to pour down from the sky, thereby producing fruits as food for you; and do not knowingly set up rivals to Allah!\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@xxx{%
And if you are in any doubt concerning what We have sent down upon Our distinguished bondman (Prophet Mohammed – peace and blessings be upon him), bring forth a single surah (chapter) equal to it; and call upon all your supporters, other than Allah, if you are truthful.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@xxxi{%
And if you are unable to bring forth (one chapter) – and We declare that you can never bring one – then fear the fire (of hell), the fuel of which is men and stones; kept ready for the disbelievers.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@xxxii{%
And give glad tidings to those who believe and do good deeds; that for them are Gardens beneath which rivers flow; when they are provided with a fruit of the Gardens, they will say, “This is the same food as what was given to us before” whereas it is in resemblance; and in the Gardens are pure spouses for them; and they shall abide in it forever.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Indeed Allah does not, for the sake of explanation, shy to illustrate an example of anything, whether it is of a gnat or something further (inferior) than it; so the believers know it is the Truth from their Lord; as for the disbelievers, they say, “What does Allah intend by such an example?” He misleads many thereby, and He guides many thereby; and with it He misleads only those who are rebellious.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@xxxiv{%
Those who break the covenant of Allah after ratifying it – and sever what Allah has ordered to join, and who cause turmoil (evil / religious chaos) in the earth; it is they who are the losers.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@xxxv{%
What has made you disbelieve in Allah? Whereas you were dead and He gave you life; then He will give you death, then bring you to life again, and then it is to Him you will return!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@xxxvi{%
It is He Who created for you all that is in the earth; then He inclined towards the heaven, therefore fashioning it as proper seven heavens; and He knows everything.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@xxxvii{%
And (remember) when your Lord said to the angels, “I am about to place My Caliph in the earth”; they said, “Will You place (as a caliph) one who will spread turmoil in it and shed blood? Whereas we glorify You with praise and proclaim Your Sanctity”; He said, “I know what you do not.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And Allah the Supreme taught Adam all the names (of things), then presented them to the angels, saying, “Tell Me the names of these, if you are truthful.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@xxxix{%
They said, “Purity is to You! We do not have any knowledge except what You have taught us! Indeed You only are the All Knowing, the Wise.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@xl{%
He said “O Adam! Inform them the names”; and when Adam had informed them their names, He said, “Did I not tell you that I know all the secrets of the heavens and the earth? And I know all what you disclose and all what you hide?”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@xli{%
And (remember) when We ordered the angels to prostrate before Adam, so they all prostrated, except Iblis (Satan – devil); he refused and was proud – and became a disbeliever.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@xlii{%
And We said, “O Adam! You and your wife dwell in this Garden, and eat freely from it wherever you please – but do not approach this tree for you will become of those who transgress.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@xliii{%
So the devil destabilised them in it and removed them from where they were – and We said, “Go down, one of you is an enemy to the other; and for a fixed time you shall stay on earth and feed in it.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@xliv{%
Then Adam learnt from his Lord certain words (of revelation), therefore Allah accepted his repentance; indeed He only is the Most Acceptor of Repentance, the Most Merciful. (See Verse 7:23)\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@xlv{%
We said, “Go down from Paradise, all of you; then if some guidance comes to you from Me – so whoever follows My guidance, for such is neither fear nor any grief.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@xlvi{%
And those who disbelieve and deny Our signs, are the people of fire (hell); they will remain in it forever.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@xlvii{%
O Descendants of Israel (Jacob)! Remember My favour which I bestowed upon you, and fulfil your covenant towards Me, I shall fulfil My covenant towards you; and fear Me alone.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@xlviii{%
And accept faith in what I have sent down (the Qur’an), which confirms what is with you (the Torah / Bible), and do not be the first to disbelieve in it – and do not exchange My verses for an abject – and fear Me alone.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@xlix{%
And do not mix the truth with falsehood, nor purposely conceal the truth.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@l{%
And keep the (obligatory) prayer established, and pay the charity, and bow your heads with those who bow (in prayer).\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@li{%
What! You enjoin righteousness upon people while you forget (to practise it) yourselves, whereas you read the Book? Do you not have sense?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@lii{%
And seek help in patience and prayer; and truly it is hard except for those who prostrate before Me with sincerity.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@liii{%
Who know that they have to meet their Lord, and that it is to Him they are to return.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@liv{%
O Descendants of Israel! Remember the favour of Mine, which I bestowed upon you and gave you superiority over others of your time. (by sending the Noble Messengers to your nation)\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@lv{%
And fear the Day (of Resurrection) when no soul will be exchanged for another, nor will any intercession be accepted for the disbelievers, nor will they be set free in lieu of compensation nor will they be helped.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@lvi{%
(And remember) When We rescued you from Firaun’s people, for they were inflicting you with a dreadful torment, slaying your sons and sparing your daughters; that was a tremendous trial from your Lord (or a great reward).\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@lvii{%
And when We split the sea for you thereby rescuing you, and drowned the Firaun's people in front of your eyes.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@lviii{%
And when We made a commitment with Moosa (Moses) for forty nights – then behind him you started worshipping the calf, and you were unjust.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@lix{%
Then after that We pardoned you so that you may be grateful.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@lx{%
And when We gave Moosa the Book (Taurat / Torah) and the criterion to judge right from wrong, so that you may attain guidance.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@lxi{%
And when Moosa said to his people, “O my people! You have wronged yourselves by taking the calf,* therefore turn in repentance to your Creator, therefore kill each other; this is better for you before your Creator”; He therefore accepted your repentance; indeed He only is the Most Acceptor of Repentance, the Most Merciful. (* as your deity for worship)\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@lxii{%
And when you said “O Moosa! We will not believe you till we clearly see Allah”; so the thunder seized you while you were watching.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We brought you back to life after your death, so that you may be grateful.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We made the clouds a canopy for you and sent down Manna and Salwa (birds) on you; “Eat of the pure things We have provided you”; they did not wrong Us in the least, but indeed they wronged themselves.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@lxv{%
And when We said, “Enter this town and eat freely from what is in it, and enter the gate whilst prostrating, and say, ‘May our sins be forgiven’ – We will forgive you your sins; and We will soon increase the reward for the righteous.”\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@lxvi{%
But the unjust changed the word that had been ordered for another one, so We sent down a punishment on them from the skies, the recompense of their disobedience.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@lxvii{%
And when Moosa asked for water for his people, We said, “Strike this rock with your staff”; thereupon twelve springs gushed forth from it; each group recognised its drinking-place; “Eat and drink from what Allah has provided, and do not roam about the earth making turmoil in it.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@lxviii{%
And when you said, “O Moosa! We shall never put up with only one kind of food, so call upon your Lord to produce for us what the earth grows – some herbs, cucumbers, corn, lentils and onions”; he said, “What! You wish to exchange the better for something inferior? Therefore settle down in Egypt or any city, where you will get what you demand”; and disgrace and misery were destined for them; and they returned towards Allah’s wrath; that was because they disbelieved in Allah’s signs and wrongfully martyred the Prophets; that was for their disobedience and transgression.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@lxix{%
Indeed the believers (the Muslims) and those among the Jews, the Christians, and the Sabeans who sincerely accept faith in Allah and the Last Day* and do good deeds – their reward is with their Lord; and there shall be no fear upon them nor shall they grieve. (* i.e. convert to Islam)\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@lxx{%
And when We made a covenant with you and raised the Mount above you; “Accept and hold fast to what We give you, and remember what is in it, so that you may attain piety.”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@lxxi{%
Then after that, you turned away; and were it not for the munificence of Allah and His mercy, you would be among the losers.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@lxxii{%
And you certainly know of those amongst you who transgressed in the matter of Sabth (Sabbath – Saturday) – We therefore said to them, “Become apes, despised!”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@lxxiii{%
So We made this incident (of that town) a warning to the surrounding towns (others of their time) and to succeeding generations, and a lesson for the pious.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And (remember) when Moosa said to his people, “Allah commands you to sacrifice a cow”; they said, “Are you making fun of us?” He answered, “Allah forbid that I should be of the ignorant!”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said, “Pray to your Lord that He may describe the cow”; said Moosa, “He says that it is a cow neither old nor very young but between the two conditions; so do what you are commanded.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said, “Pray to your Lord that He may reveal its colour to us”; answered Moosa, “Indeed He says it is a yellow cow, of bright colour, pleasing to the beholders.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said, “Pray to your Lord that He may clearly describe the cow to us, we are really in a doubt as to which cow it is; and if Allah wills, we will attain guidance.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@lxxviii{%
Said Moosa, “He says, ‘She is a cow not made to work, neither ploughing the soil nor watering the fields; flawless and spotless’; they said, “You have now conveyed the proper fact”; so they sacrificed it, but seemed not to be sacrificing it (with sincerity).\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@lxxix{%
And (remember) when you slew a man and were therefore accusing each other concerning it; and Allah wanted to expose what you were hiding.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@lxxx{%
We therefore said, “Strike the dead man with a part of the sacrificed cow”; this is how Allah will bring the dead to life, and shows you His signs so that you may understand!\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Then after it, your hearts hardened – so they are like rocks, or even harder; for there are some rocks that rivers gush forth from them; and some that water flows from them when they split asunder; and there are rocks that fall down for the fear of Allah; and Allah is not unaware of your deeds.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@lxxxii{%
So O Muslims, do you wish for the Jews to accept faith in you whereas a group of them used to listen to the Words of Allah, and then after having understood it, purposely changed it?\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
And when they meet the believers, they say, “We believe”; but when they are in isolation with one another they say, “You clarify to the believers from what Allah has disclosed to you, so that they may evidence it against you before your Lord? So have you no sense?”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Do they not know that Allah knows all whatever they hide and whatever they disclose?\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And among them are the unlearned that do not know anything of the Book except to recite something therefrom or parts of their own fabrications; they are in absolute illusion.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
Therefore woe is to those who write the Book with their hands; and they then claim, “This is from Allah” in order to gain an abject (worldly) price for it; therefore woe to them for what their hands have written, and woe to them for what they earn with it.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they said, “The fire will not touch us except for a certain number of days”; say, “Have you taken a covenant from Allah – then Allah will certainly not break His covenant – or do you say something concerning Allah what you do not know?”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Yes, why not?* The one who earns evil and his sin surrounds him; he is from the people of fire (hell); they will remain in it forever. (You will remain in the fire forever).\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@lxxxix{%
And those who believe and do good deeds – they are the People of Paradise; they will abide in it forever.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@xc{%
And (remember) when We took a covenant from the Descendants of Israel that, “Do not worship anyone except Allah; and be good to parents, relatives, orphans and the needy, and speak kindly to people and keep the prayer established and pay the charity”; thereafter you retracted, except some of you; and you are those who turn away.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@xci{%
And when We took a covenant from you that, “Do not shed the blood of your own people nor turn out your own people from your colonies”; you then acknowledged it and you are witnesses.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@xcii{%
Then it is you who began slaying each other and you drive out a group of your people from their homeland – providing support against them (to their opponents) through sin and injustice; and if they come to you as captives you redeem them, whereas their expulsion itself is forbidden to you; so do you believe in some of Allah’s commands and disbelieve in some? So what is the reward of those who do so, except disgrace in this world? And on the Day of Resurrection they will be assigned to the most grievous punishment; and Allah is not unaware of your deeds.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@xciii{%
These are the people who bought the worldly life in exchange of the Hereafter – so their punishment will not be lightened, nor will they be helped.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@xciv{%
And indeed We gave Moosa (Moses) the Book and subsequent to him, sent Noble Messengers one after another – and We gave Eisa (Jesus), the son of Maryam (Mary), clear proofs and supported him with the Holy Spirit; so when a Noble Messenger from Allah comes to you bringing what you yourselves do not desire, you grow arrogant; so you disbelieve in a group of the Prophets and another group of Prophets you slay!\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@xcv{%
And the Jews said, “Our hearts are covered”; in fact Allah has cursed them because of their disbelief, so only a few of them accept faith.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when the Book from Allah (the Holy Qu’ran) came to them, which confirms the Book in their possession (the Taurat / Torah) – and before that they used to seek victory through the medium of this very Prophet (Mohammed – peace and blessings be upon him) over the disbelievers; so when the one whom they fully recognised (the Holy Prophet) came to them, they turned disbelievers – therefore Allah’s curse is upon the disbelievers.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@xcvii{%
How abject is the price for which they exchange their lives that they should disbelieve in what Allah has sent down, jealous that Allah should reveal of His grace to whomever He wills of His bondmen! So they deserved wrath upon wrath; and for the disbelievers is a disgraceful punishment.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@xcviii{%
And when it is said to them, “Believe in what Allah has sent down", they say, “We believe in what was sent down to us, and disbelieve in the rest” – whereas it is the Truth confirming what they possess! Say (to them, O dear Prophet Mohammed – peace and blessings be upon him), “Why did you then martyr the earlier Prophets, if you believed in your Book?”\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@xcix{%
And indeed Moosa came to you with clear signs, and after it you worshipped the calf – and you were unjust.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@c{%
And remember when We made a covenant with you and raised the Mount Tur (Sinai) above you; “Accept and hold fast to what We give you, and listen”; they said, “We hear and we disobey”; and the calf was still embedded in their hearts because of their disbelief; say (O dear Prophet Mohammed – peace and blessings be upon him), “What an evil command is what your faith orders you, if you are believers!”\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@ci{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “If the abode of the Hereafter in the sight of Allah is for you alone and none else, then long for death if you are truthful!”\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@cii{%
And they will never long for it, because of the evil deeds they have done in the past; and Allah knows the unjust, very well.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ciii{%
And you will surely find them the greediest among mankind for life; and (likewise) among the polytheists (idolaters); each one of them yearns to live a thousand years; and the grant of such age will not distance him from the punishment; and Allah is seeing their misdeeds.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@civ{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “Whoever is an enemy to Jibreel (Gabriel)” – for it is he who has brought down this Qu’ran to your heart by Allah’s command, confirming the Books before it, and a guidance and glad tidings to Muslims. –\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@cv{%
“Whoever is an enemy to Allah, and His angels and His Noble Messengers, and Jibreel and Mikaeel (Michael) -, then (know that), Allah is an enemy of the disbelievers.”\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@cvi{%
We have indeed sent down to you clear signs; and none will disbelieve in them except the sinners.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@cvii{%
And is it that whenever they make a covenant, only a group of them throws it aside? In fact, most of them do not have faith.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@cviii{%
And when a Noble Messenger from Allah came to them, confirming the Book(s) which they possessed, a group of those who have received the Book(s) flung the Book of Allah behind their backs as if they were totally unaware!\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@cix{%
And they followed what the devils used to read during the rule of Sulaiman (Solomon – peace and blessings be upon him); and Sulaiman did not disbelieve, but the devils disbelieved – they teach people magic; and that which was sent down to the two angels, Harut and Marut in Babylon; and the two (angels) never taught a thing to anyone until they used to say, “We are only a trial, therefore do not lose your faith” and they used to learn from them that by which they cause division between man and his wife; and they cannot harm anyone by it except by Allah’s command; and they learn what will harm them, not benefit them; and surely they know that whoever bargains for this will not have a share in the Hereafter; and for what an abject thing they have sold themselves; if only they knew!\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@cx{%
And had they believed and been pious, then the recompense from Allah is extremely good; if only they knew!\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@cxi{%
O People who Believe, do not say (to the Prophet Mohammed- peace and blessings be upon him), “Raena (Be considerate towards us)” but say, “Unzurna (Look mercifully upon us)", and listen attentively from the start; and for the disbelievers is a painful punishment. (To disrespect the Holy Prophet – peace and blessings be upon him – is blasphemy.)\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@cxii{%
Those who disbelieve – the People given the Book(s) or the polytheists – do not wish that any good be sent down upon you from your Lord; and Allah chooses whomever He wills by His Mercy; and Allah is the Most Munificent.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@cxiii{%
When We abrogate a verse or cause it to be forgotten, We will bring one better than it or one similar; do you not know that Allah is Able to do all things?\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@cxiv{%
Do you not know that for Allah only is the kingship of the heavens and the earth? And except Allah, you have neither a protector nor any supporter?\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@cxv{%
Do you wish to ask your Noble Messenger a question similar to what Moosa was asked before? And whoever chooses disbelief instead of faith has gone astray from the Right Path.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many among People given the Book(s) wished to turn you to disbelief after you had accepted faith; out of hearts’ envy, after the truth has become very clear to them; so leave them and be tolerant, until Allah brings His command; indeed Allah is Able to do all things.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@cxvii{%
And keep the prayer established, and pay the charity; and whatever good you send ahead for yourselves, you will find it with Allah; indeed Allah is seeing your deeds.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cxviii{%
And the People given the Book(s) said, “None will enter Paradise unless he is a Jew or a Christian”; these are their own imaginations; say (O dear Prophet Mohammed – peace and blessings be upon him), “Bring your proof, if you are truthful.”\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cxix{%
Yes, why not? Whoever submits his face for the sake of Allah, and is virtuous, his reward is with his Lord; and there shall be no fear upon them nor shall they grieve.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cxx{%
And the Jews said, “The Christians are nothing” – and the Christians said, “The Jews are nothing” whereas they both read the Book; and the ignorant spoke similarly; so Allah will judge between them on the Day of Resurrection, concerning the matter in which they dispute.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who is more unjust than one who prevents the name of Allah being mentioned in the mosques, and strives for their ruin? It did not befit them to enter the mosques except in fear; for them is disgrace in this world, and a terrible punishment in the Hereafter.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cxxii{%
And the East and the West, all belong to Allah – so whichever direction you face, there is Allah’s Entity (Allah’s Mercy is directed towards you); indeed Allah is the All Capable, (His powers and reach are limitless), the All Knowing.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cxxiii{%
And they said, “Allah has taken an offspring for Himself” – Purity is to Him! In fact, all that is in the heavens and the earth, is His dominion; all are submissive to Him.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cxxiv{%
The Originator of the heavens and the earth – and when He commands a thing, He only says to it, “Be", and it thereupon happens.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cxxv{%
And the ignorant people said, “Why does not Allah speak to us, or some sign come to us?” Those before them had also spoken in the same way as they speak; their hearts (and of those before them) are all alike; undoubtedly, We have made the signs clear for the people who have faith.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cxxvi{%
Undoubtedly, We have sent you (O dear Prophet Mohammed – peace and blessings be upon him) with the truth, giving glad tidings and conveying warning, and you will not be questioned about the people of hell.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cxxvii{%
And never will the Jews or the Christians be pleased with you, until you follow their religion; say, “The guidance of Allah only is the (true) guidance”; and were you (the followers of this Prophet) to follow their desires after the knowledge has come to you, you would then not have a protector or aide against Allah.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those to whom We have given the Book, read it in the manner it should be read; it is they who believe in it; and those who deny it – it is they who are the losers.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cxxix{%
O Descendants of Israel! Remember the favour of Mine which I bestowed upon you and made you superior to all others of your time. (By sending Noble Messengers among you).\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cxxx{%
And fear the day when no soul will be exchanged for another, nor will they be set free in lieu of compensation, nor will any intercession benefit the disbelievers, nor will they be helped.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And (remember) when Ibrahim’s (Abraham’s) Lord tested him in some matters and he fulfilled them; He said, “I am going to appoint you as a leader for mankind”; invoked Ibrahim, “And of my offspring”; He said, “My covenant does not include the unjust (wrong-doers).”\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And remember when We made this House (at Mecca) a recourse for mankind and a sanctuary; and take the place where Ibrahim stood, as your place of prayer; and We imposed a duty upon Ibrahim and Ismail (Ishmael), to fully purify My house for those who go around it, and those who stay in it (for worship), and those who bow down and prostrate themselves.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And (remember) when Ibrahim prayed, “My Lord! Make this city a place of security and bestow upon its people various fruits as providence – for those among them who believe in Allah and the Last Day (of Resurrection)”; He answered, “And whoever disbelieves, I shall provide him also some subsistence and then compel him towards the punishment of fire (hell); and that is a wretched place to return.”\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And (remember) when Ibrahim was raising the foundations of the House, along with Ismail; (saying), “Our Lord! Accept it from us; indeed You only are the All Hearing, the All Knowing.”\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cxxxv{%
“Our Lord! And make us submissive towards you and from our offspring a nation obedient to You – and show us the ways of our worship, and incline towards us with Your mercy; indeed You only are the Most Acceptor of Repentance, the Most Merciful.”\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
“Our Lord! And send towards them a Noble Messenger, from amongst them, to recite to them Your verses, and to instruct them in Your Book and sound wisdom*, and to fully purify them; indeed You only are the Almighty, the Wise.” (The traditions of the Holy Prophet – sunnah and hadith – are called wisdom.)\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
And who will renounce the religion of Ibrahim except him who is a fool at heart? We indeed chose him (Ibrahim) in this world; and indeed in the Hereafter he is among those worthy of being closest to Us.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said to him, “Submit”, he said, “I have submitted to the Lord Of The Creation.”\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cxxxix{%
And Ibrahim willed the same religion upon his sons, and also did Yaqub (Jacob); (saying), “O my sons – indeed Allah has chosen this religion for you; therefore do not die except as Muslims (those who submit to Him).”\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cxl{%
In fact, some of you yourselves were present when death approached Yaqub and when he said to his sons, “What will you worship after me?” They said, “We shall worship Him Who is your God, and is the God of your fathers, Ibrahim and Ismail and Ishaq (Isaac) – the One God; and to Him we have submitted ourselves.”\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cxli{%
This was a nation that has passed away; for them is what they earned, and yours is what you earn; and you will not be questioned about their deeds.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cxlii{%
And the People given the Book(s) said, “Become Jews or Christians – you will attain the right path”; say (O dear Prophet Mohammed – peace and blessings be upon him), “No – rather we take the religion of Ibrahim, who was far removed from all falsehood; and was not of the polytheists.”\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say, “We believe in Allah and what is sent down to us and what was sent down to Ibrahim, and Ismael, and Ishaq, and Yaqub, and to their offspring, and what was bestowed upon Moosa and Eisa (Jesus), and what was bestowed upon other Prophets – from their Lord; we do not make any distinction, in belief, between any of them; and to Allah we have submitted ourselves.”\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cxliv{%
And if they believe in the same way you have believed, they have attained guidance; and if they turn away, they are clearly being stubborn; so Allah will soon suffice you (O dear Prophet Mohammed – peace and blessings be upon him) against them; and He only is the All Hearing, the All Knowing.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cxlv{%
“We have taken the colour (religion) of Allah; and whose colour (religion) is better than that of Allah? And only Him do we worship.”\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “What! You dispute with us concerning Allah, whereas He is our Lord and also yours? Our deeds are with us and with you are your deeds; and only to Him do we sincerely belong.”\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cxlvii{%
“In fact you claim that Ibrahim, and Ismail, and Ishaq, and Yaqub, and their offspring were Jews or Christians”; say, “Do you know better, or does Allah?”; and who is more unjust than one who has the testimony from Allah and he hides it? And Allah is not unaware of your deeds.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cxlviii{%
They were a group that has passed away; for them is what they earned, and for you is what you earn; and you will not be questioned about their deeds.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cxlix{%
So now the foolish people will say, “What has turned the Muslims away from the qiblah (prayer direction) which they formerly observed?”; proclaim, “To Allah only belong the East and the West; He guides whomever He wills upon the Straight Path.”\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cl{%
And so it is that We have made you the best nation* for you are witnesses** against mankind, and the Noble Messenger is your guardian and your witness; and (O dear Prophet Mohammed – peace and blessings be upon him) We had appointed the qiblah which you formerly observed only to see (test) who follows the Noble Messenger, and who turns away; and it was indeed hard except for those whom Allah guided; and it does not befit Allah’s Majesty to waste your faith! Indeed Allah is Most Compassionate, Most Merciful towards mankind. (* The best Ummah is that of Prophet Mohammed – peace and blessings be upon him. ** The Holy Prophet is a witness from Allah.)\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cli{%
We observe you turning your face, several times towards heaven (O dear Prophet Mohammed – peace and blessings be upon him); so We will definitely make you turn (for prayer) towards a qiblah which pleases you; therefore now turn your face towards the Sacred Mosque (in Mecca); and O Muslims, wherever you may be, turn your faces (for prayer) towards it only; and those who have received the Book surely know that this is the truth from their Lord; and Allah is not unaware of their deeds. (Allah seeks to please the Holy Prophet – peace and blessings be upon him.)\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@clii{%
And even if you were to bring all the signs to the People given the Book(s), they would not follow your qiblah; nor should you follow their qiblah; nor do they follow each others qiblah; and were you (the followers of this Prophet) to follow their desires after having received knowledge, you would then surely be unjust.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cliii{%
Those to whom We gave the Book(s) recognise the Prophet (Mohammed – peace and blessings be upon him) as men (or they) recognise their own sons; and undoubtedly a group among them purposely conceals the truth.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cliv{%
This is the Truth from your Lord, therefore (O those who listen) beware – do not be in doubt.\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@clv{%
And each one has a direction towards which he inclines, therefore strive to surpass others in good deeds; Allah will bring you all together, wherever you may be; indeed Allah may do as He wills.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@clvi{%
And wherever you come from, turn your face towards the Sacred Mosque; and indeed it is the truth from your Lord; and Allah is not unaware of your deeds.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@clvii{%
And O dear Prophet (Mohammed – peace and blessings be upon him) wherever you come from, turn your face towards the Sacred Mosque; and wherever you may be, O Muslims, turn your faces towards it only, so that people may not have an argument against you – except those among them who do injustice; therefore do not fear them, and fear Me; and this is in order that I complete My favour upon you and that you may attain guidance. –\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@clviii{%
The way We have sent to you a Noble Messenger from among you, who recites to you Our verses and purifies you, and teaches you the Book and sound wisdom*, and teaches you what you did not know. (The traditions / sayings of the Holy Prophet – peace and blessings be upon him).\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@clix{%
Therefore remember Me, I will cause you to be spoken of and acknowledge My rights, and do not be ungrateful.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@clx{%
O People who Believe! Seek help from patience and prayer; indeed Allah is with those who patiently endure.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@clxi{%
And do not utter regarding those who are slain in Allah's cause as “dead”; in fact they are alive, but it is you who are unaware.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@clxii{%
And We will surely test you with some fear and hunger, and with paucity of wealth and lives and crops; and give glad tidings to those who patiently endure. –\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@clxiii{%
Those who say when calamity befalls them, “Indeed we belong to Allah and indeed it is to Him we are to return.”\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@clxiv{%
These are the people upon whom are the blessings from their Lord, and mercy; and it is they who are on guidance.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@clxv{%
Undoubtedly Safa and Marwah* are among the symbols of Allah; so there is no sin on him, for whoever performs the Hajj (pilgrimage) of this House (of Allah) or the Umrah (lesser pilgrimage), to go back and forth between them; and whoever does good of his own accord, then (know that) indeed Allah is Most Appreciative (rewards virtue), the All Knowing. (These are 2 hillocks near the Holy Ka’aba)\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@clxvi{%
Indeed those who hide the clear proofs and the guidance which We sent down, after We made it clear to mankind in the Book – upon them is the curse of Allah and the curse of those who curse.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@clxvii{%
Except those who repent and do reform and disclose (the truth) – so I will accept their repentance; and I only am the Most Acceptor of Repentance, the Most Merciful.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@clxviii{%
Indeed upon those who disbelieved, and died as disbelievers, is the curse of Allah and of the angels and of men combined.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@clxix{%
They will remain in it forever; neither will the punishment be lightened for them, nor will they be given respite.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@clxx{%
Your God is One God; there is no God except Him – the Most Gracious, the Most Merciful.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@clxxi{%
Indeed in the creation of the heavens and the earth, and in the continuous alternation of night and day, and the ships which sail the seas carrying what is of use to men, and the water which Allah sends down from the sky thereby reviving the dead earth and dispersing all kinds of beasts in it, and the movement of the winds, and the obedient clouds between heaven and earth – certainly in all these are signs for the intelligent.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@clxxii{%
And some people create for themselves Gods (objects of worship) other than Allah, with devotion (love) equal to the devotion of Allah; and the believers do not love anybody with love equal to the love of Allah; and what will be their state, when the punishment will be before the eyes of the unjust (disbelievers)? For all power belongs wholly to Allah, and because Allah’s punishment is very severe.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@clxxiii{%
(The day) when the leaders will be disgusted with their followers – and they shall see their punishment, and all their links will be cut off.\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@clxxiv{%
And the followers will say, “If we were to return (to earth), we would break off from them like they have broken off from us”; this is how Allah will show them their deeds as despair for them; and they will never come out from the fire (hell).\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@clxxv{%
O mankind! Eat from what is lawful and clean in the earth; and do not follow the footsteps of the devil; undoubtedly he is your open enemy.\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@clxxvi{%
For he will only instruct you towards the evil and the shameful, and that you fabricate matters concerning Allah, what you do not know.\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@clxxvii{%
And when it is said to them, “Follow what Allah has sent down”, they say, “On the contrary, we shall follow what we found our forefathers upon”; What! Even if their forefathers had no intelligence, or guidance?!\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@clxxviii{%
And the example of the disbelievers is similar to one who calls upon one that hears nothing except screaming and yelling; deaf, dumb, blind – so they do not have sense.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@clxxix{%
O People who Believe! Eat of the good things We have provided you, and be grateful to Allah if it is only Him you worship.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@clxxx{%
He has forbidden for you only the carrion, and blood, and flesh of swine, and the animal that has been slaughtered while proclaiming the name of anyone other than Allah; so there is no sin on him who is compelled and does not eat out of desire, nor eats more than what is necessary; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Those who hide the Book sent down by Allah and exchange it for an abject price – they only fill their bellies with fire and Allah will not speak to them on the Day of Resurrection nor will He purify them; and for them is a painful punishment.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@clxxxii{%
They are the people who purchased error in exchange of guidance, and torment in exchange of pardon; so how much can they bear the fire?\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
This is because Allah has sent down the Book with the truth; and indeed those who caused disagreement in the Book are, surely, disputants in the extreme.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
Basic virtue is not just to turn faces to the East and the West, but true righteousness is that one must believe in Allah and the Last Day and the angels and the Book and the Prophets; and out of love for Allah, to give treasured wealth to relatives and to the orphans and the needy and the traveller, and to those who ask, and to set slaves free; and to keep the prayer established and to pay the charity; and those who fulfil their obligations when they make an agreement; and the patient during times of calamity, in hardships and during holy war; it is they who have proved true to their word; it is they who are the pious.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O People who Believe! Retribution is made obligatory for you in the matter of those killed unjustly; a freeman for a freeman, and a slave for a slave, and a female for a female; and for him who is partly forgiven by his brother, seek compensation with courtesy and make payment in proper manner; this is a relief and a mercy upon you, from your Lord; so after this, a painful punishment is for whoever exceeds the limits.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
And there is life for you in retribution, O men of understanding, so that you may avoid.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
It is ordained for you that when death approaches one of you, and he leaves behind wealth, he must bequeath it to parents and near relatives in accordance with tradition; this is a duty upon the pious.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
So whoever changes the will after he has heard it – its sin is only upon those who change it; indeed Allah is the All Hearing, the All Knowing.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@clxxxix{%
Then if one fears that the will maker (the deceased) has done injustice or sin, and he makes a reconciliation between the parties, there shall be no sin upon him; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@cxc{%
O People who Believe! Fasting is made compulsory for you, like it was ordained for those before you, so that you may attain piety.\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@cxci{%
For a certain number of days only; so whoever is sick among you, or on a journey, the same number in other days; and those who do not have the strength for it must give a redemption by feeding a needy person; so whoever increases the good of his own accord, it is better for him; and fasting is better for you, if only you realise.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@cxcii{%
The month of Ramadan in which was sent down the Qur’an – the guidance for mankind, the direction and the clear criteria (to judge between right and wrong); so whoever among you witnesses this month, must fast for the (whole) month; and whoever is sick or on a journey, may fast the same number in other days; Allah desires ease for you and does not desire hardship for you – so that you complete the count (of fasts), and glorify Allah’s greatness for having guided you, and so that you may be grateful.\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@cxciii{%
And O dear Prophet (Mohammed – peace and blessings be upon him), when My bondmen question you concerning Me, then surely I am close; I answer the prayer of the supplicant when he calls on Me, so they must obey Me and believe in Me, so that they may attain guidance.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@cxciv{%
Going to your wives during the nights of the fast is made lawful for you; they are coverings for you and you are coverings for them; Allah knows that you were deceiving yourselves (in this respect), so He accepted your penance and forgave you; so cohabit with them and seek what Allah has destined for you – and eat and drink until the white thread becomes distinct to you from the black thread at dawn – then complete the fast till nightfall; and do not touch women while staying in seclusion for worship in the mosques; these are the limits imposed by Allah, so do not go near them; this is how Allah explains His verses to mankind so that they may attain piety.\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@cxcv{%
And do not unjustly devour the property of each other, nor take their cases to judges in order that you may wrongfully devour a portion of other peoples’ property on purpose.\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask you, (O dear Prophet Mohammed – peace and blessings be upon him), regarding the crescents; say, “They are indicators of time for mankind and for Hajj (the pilgrimage)”; and it is not a virtue at all that you enter the houses by demolishing their back portions, but in reality virtue is piety; and enter the houses using their gates – and keep fearing Allah, hoping that you achieve success.\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@cxcvii{%
And fight in Allah's cause against those who fight you and do not exceed the limits; and Allah does not like the transgressors.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And slay the disbelievers wherever you find them, and drive them out from where they drove you out, and the turmoil they cause is worse than slaying; and do not fight them near the Sacred Mosque until they fight you there; so if they fight you, slay them; this is the punishment of the disbelievers.\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@cxcix{%
Then if they desist, then indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@cc{%
And fight them until no mischief remains, and only Allah is worshipped; then if they desist, do not harm them, except the unjust.\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@cci{%
The sacred month for the sacred month, and respect in lieu of respect; harm the one who harms you, to the extent as he did – and keep fearing Allah, and know well that Allah is with the pious.\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@ccii{%
And spend your wealth in Allah's cause, and do not fall into ruin with your own hands; and be virtuous; undoubtedly the righteous are the beloved of Allah.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@cciii{%
And perform Hajj (greater pilgrimage) and Umrah (lesser pilgrimage) for Allah; and if you are prevented, send sacrifice whatever is available; and do not shave your heads until the sacrifice reaches its destination; so whoever among you is sick or has an ailment in the head, must pay a compensation by fasting or charity or sacrifice; then when you are in peace – and whoever takes the advantage of combining the Hajj and Umrah, it is compulsory for him to sacrifice whatever is available; and whoever cannot afford it, must fast for three days while on the pilgrimage, and seven when you have returned to your homes; these are ten in all; this decree is for him who is not a resident of Mecca; and keep fearing Allah and know well that Allah’s punishment is severe.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@cciv{%
The Hajj is during the well-known months; and for one who intends to perform the Hajj in it – neither is there to be mention of cohabitation in the presence of women, nor any sin, nor a fight with anyone till the completion of Hajj; and whatever good you do, Allah knows it; and take provision along with you for the best provision is piety; and keep fearing Me, O men of understanding!\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@ccv{%
It is no sin for you that you seek the bounty of your Lord; so when you return from Arafat, remember Allah near the Sacred Symbol (Mash’ar al Haram) – and remember Him in the manner He has guided you; and indeed, before this, you were of the astray.\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then, O people of Quraish, you too must return from the place where the people return from, and ask forgiveness from Allah; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@ccvii{%
So when you have completed your Hajj rites, remember Allah as you used to remember your forefathers, in fact more than that; and among the people are some that say, “Our Lord! Give us in this world” – and he does not have a portion in the Hereafter.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@ccviii{%
And among them are some that say, “Our Lord! Give us good in the world and good in the Hereafter, and save us from the punishment of fire!”\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@ccix{%
For such is a portion from what they have earned; and Allah is Swift At Taking Account.\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@ccx{%
And remember Allah in the counted days; so whoever hastens by departing in two days, there is no sin on him; and whoever stays on, there is no sin for him – for the pious; and keep fearing Allah, and know well that it is to Him you will be raised.\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@ccxi{%
And among men is one whose conversation may please you in the life of this world, and he brings Allah as witness to what is in his heart, whereas he is the biggest quarreller!\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@ccxii{%
And when he turns away, he creates turmoil in the earth and destroys crops and lives; and Allah is not pleased with turmoil.\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@ccxiii{%
And when it is said to him, “Fear Allah”, he becomes more resolute in committing sin – therefore hell is sufficient for such; and that is indeed, a very wretched resting place.\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@ccxiv{%
And among men is one who sells himself to seek the pleasure of Allah; and Allah is Most Compassionate towards the bondmen.\qt@no{(207)}}%
\qt@newcmd\qurantrans@en@ccxv{%
O People who Believe! Enter Islam in full – and do not follow the footsteps of the devil; indeed he is your open enemy.\qt@no{(208)}}%
\qt@newcmd\qurantrans@en@ccxvi{%
And if you renege, even after the clear commands have come to you, then know well that Allah is Almighty, Wise.\qt@no{(209)}}%
\qt@newcmd\qurantrans@en@ccxvii{%
What are they waiting for, except that Allah’s punishment should come through stretched clouds and the angels descend and the matter be finished? And all matters are directed only towards Allah.\qt@no{(210)}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the Descendants of Israel how many clear signs We gave them; and whoever alters Allah’s favour which came to him, then indeed Allah’s punishment is severe.\qt@no{(211)}}%
\qt@newcmd\qurantrans@en@ccxix{%
The life of this world is made to appear beautiful in the sight of the disbelievers, and they make fun of the believers; and the pious will be above them on the Day of Resurrection; and Allah may give to whomever He wills, without account.\qt@no{(212)}}%
\qt@newcmd\qurantrans@en@ccxx{%
Mankind was on one religion; so Allah sent Prophets giving glad tidings and warnings – and with them sent down the true Book to judge between mankind on their differences; and only those to whom it was given created disputes regarding the Book, after clear commands had come to them, due to hostility of one another; so Allah, by His command, made the truth clear to the believers, concerning their disputes; and Allah may guide whomever He wills to the Straight Path.\qt@no{(213)}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Are you under the illusion that you will enter Paradise whereas the suffering, which came to those before you, has not yet come to you? Hardship and adversity befell them and they were shaken, to the extent that the Noble Messenger and the believers along with him said, “When will the help of Allah come?”; pay heed! Allah’s help is surely near.\qt@no{(214)}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They ask you what they should spend; say, “Whatever you spend for good, is for parents and near relatives and orphans and the needy and the traveller”; and whatever good you do, indeed Allah knows it.\qt@no{(215)}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Fighting in Allah's cause is ordained for you, whereas it is disliked by you; and it is possible that you hate a thing which is better for you; and it is possible that you like a thing which is bad for you; and Allah knows, and you do not know.\qt@no{(216)}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask you the decree regarding fighting in the sacred month; say (O dear Prophet Mohammed – peace and blessings be upon him), “Fighting in it is a great sin; and to prevent from the way of Allah, and not to believe in Him and to prevent (people) from the Sacred Mosque and to expel its residents – these are greater sins before Allah"; and the turmoil they cause is worse than killing; and they will keep fighting you till they turn you away from your religion, if they can; and whoever among you turns renegade and dies as a disbeliever, then their deeds are wasted in this world and in the Hereafter; and they are the people of hell; they will remain in it forever.\qt@no{(217)}}%
\qt@newcmd\qurantrans@en@ccxxv{%
Those who believed, and those who migrated for the sake of Allah, and fought in Allah's cause – they are hopeful of gaining Allah’s mercy; and Allah is Oft Forgiving, Most Merciful.\qt@no{(218)}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask you the decree regarding wine (intoxicants) and gambling; say (O dear Prophet Mohammed – peace and blessings be upon him), “In both is great sin, and some worldly benefit for men – but their sin is greater than their benefit”; and they ask you what they should spend; say, “That which remains spare (surplus)”; this is how Allah explains His verses to you, so that you may think.\qt@no{(219)}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
Before you execute your deeds of this world and of the Hereafter; and they ask you the decree regarding orphans; say, “To do good towards them is better; and if you combine your expenses with theirs, they are your brothers”; and Allah knows very well the one who spoils from him who improves; and if Allah willed, He could have put you in hardship; and Allah is Almighty, Wise.\qt@no{(220)}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
And do not marry polytheist women until they become Muslims; for undoubtedly a Muslim bondwoman is better than a polytheist woman, although you may like her; and do not give your women in marriage to polytheist men until they accept faith; for undoubtedly a Muslim slave is better than a polytheist, although you may like him; they invite you towards the fire; and Allah invites towards Paradise and forgiveness by His command; and explains His verses to mankind so that they may accept guidance.\qt@no{(221)}}%
\qt@newcmd\qurantrans@en@ccxxix{%
And they ask you the decree concerning menstruation; say, “It is an impurity, so stay away from women at such times, and do not cohabit with them until they have cleansed themselves; so when they have cleansed themselves, cohabit with them the way Allah has determined for you”; indeed Allah loves those who repent profusely, and loves those who keep clean.\qt@no{(222)}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your women are a tillage for you; so come into your tillage as you will; and first perform the deeds that benefit you; and keep fearing Allah, and know well that you have to meet Him; and (O dear Prophet Mohammed – peace and blessings be upon him) give glad tidings to the Muslims.\qt@no{(223)}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
And do not make Allah a target of your oaths, by pledging against being virtuous and pious, and against making peace among mankind; and Allah is All Hearing, All Knowing.\qt@no{(224)}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah does not take you to task for oaths which are made unintentionally but He does take you to task for deeds which your hearts have done; and Allah is Oft Forgiving, Most Forbearing.\qt@no{(225)}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
Those who swear not to touch their wives have four months’ time; so if they turn back during this period, indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(226)}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
And if they firmly decide to divorce them, Allah is All Hearing, All Knowing.\qt@no{(227)}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
And divorced women shall restrain themselves for three menstrual periods; and it is not lawful for them to conceal what Allah has created in their wombs if they believe in Allah and the Last Day; and their husbands have the right to take them back, during this time, if they desire reconciliation; and the women also have rights similar to those of men over them, in accordance with Islamic law – and men have superiority over them; and Allah is Almighty, Wise.\qt@no{(228)}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
This type of divorce is up to twice; the woman must then be retained on good terms or released with kindness; and it is not lawful for you to take back from women a part of what you have given them except when both fear that they may not be able to stay within the limits established by Allah; so if you fear that they may not be able to observe the limits of Allah, then it is no sin on them if the woman pays to get her release; these are the limits set by Allah, so do not exceed them; and those who transgress Allah’s limits are the unjust.\qt@no{(229)}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
Then if he divorces her the third time, she will not be lawful to him until she has stayed with another husband; then if the other husband divorces her, it is no sin for these two to reunite if they consider that they can keep the limits of Allah established; these are the limits set by Allah which He explains for people of intellect.\qt@no{(230)}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
And when you have divorced women, and their term reaches its end, either retain them on good terms within this period or release them with kindness; and do not retain them in order to hurt them, hence transgressing the limits; and he who does so harms only himself; and do not make the signs of Allah the objects of ridicule; and remember Allah’s favour that is bestowed upon you and that He has sent down to you the Book and wisdom, for your guidance; keep fearing Allah and know well that Allah knows everything. (The traditions of the Holy Prophet – sunnah and hadith – are called wisdom.)\qt@no{(231)}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
And when you have divorced women and they complete their waiting period – then O guardians of such women, do not prevent them from marrying their husbands if they agree between themselves in accordance with Islamic law; this lesson is for those among People who Believe in Allah and the Last Day; this is purer for you, and cleaner; and Allah knows and you do not know.\qt@no{(232)}}%
\qt@newcmd\qurantrans@en@ccxl{%
And mothers shall breast-feed their children for two full years – for those who wish to complete the term of milk feeding; and the father of the child must provide for food and clothing of the mother in accordance with custom; no one will be burdened except with what he can bear; a mother should not be harmed because of her child, nor he to whom the child is born be harmed because of his child (or a mother should not harm the child nor he to whom the child is born should harm the child); and the same is incumbent on the guardian in place of the father; then if the parents desire to wean the child by mutual consent and consultation, it is no sin for them; and if you wish to give your children out to a (milk feeding) nurse, it is no sin for you, provided you pay to them what is agreed, with kindness; and keep fearing Allah, and know well that Allah is seeing what you do.\qt@no{(233)}}%
\qt@newcmd\qurantrans@en@ccxli{%
And those among you who die leaving wives behind them, then such widows shall restrain themselves for four months and ten days; so when their term is completed, O guardians of such women, there is no sin on you in what the women may decide for themselves in accordance with Islamic law; and Allah is Well Aware of what you do.\qt@no{(234)}}%
\qt@newcmd\qurantrans@en@ccxlii{%
And there is no sin on you if you propose marriage to women while they are hidden from your view, or hide it in your hearts; Allah knows that you will now remember them, but do not make secret pacts with women except by decent words recognised by Islamic law; and do not consummate the marriage until the written command reaches its completion; know well that Allah knows what is in your hearts, therefore fear Him; and know well that Allah is Oft Forgiving, Most Forbearing.\qt@no{(235)}}%
\qt@newcmd\qurantrans@en@ccxliii{%
There is no sin upon you if you divorce women while you have not touched them or appointed their bridal money; and give them some provision; the rich according to their means, and the poor according to their means; a fair provision according to custom; this is a duty upon the virtuous.\qt@no{(236)}}%
\qt@newcmd\qurantrans@en@ccxliv{%
If you divorce them before you have touched them and have appointed the bridal money, then payment of half of what is agreed is ordained unless the women forgo some of it, or he in whose hand is the marriage tie, pays more; and O men, your paying more is closer to piety; and do not forget the favours to each other; indeed Allah is seeing what you do.\qt@no{(237)}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Guard all your prayers, and the middle prayer; and stand with reverence before Allah.\qt@no{(238)}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
And if you are in fear, pray while on foot or while riding, as you can; when you are in peace remember Allah the way He has taught you, which you did not know.\qt@no{(239)}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
And those among you who die leaving wives behind them – they should bequeath for their wives a complete provision for one full year without turning them out; so if they go out themselves, there is no sin on you regarding what they do of themselves in a reasonable manner; and Allah is Almighty, Wise.\qt@no{(240)}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
And for divorced women also, is a complete provision in reasonable manner; this is a duty upon the pious.\qt@no{(241)}}%
\qt@newcmd\qurantrans@en@ccxlix{%
This is how Allah explains His verses to you so that you may understand.\qt@no{(242)}}%
\qt@newcmd\qurantrans@en@ccl{%
Did you (O dear Prophet Mohammed – peace and blessings be upon him) not see those who left their homes, whereas they numbered in thousands, fearing death? So Allah said to them, “Die”; He then brought them back to life; indeed Allah is Most Munificent towards mankind, but most men are ungrateful.\qt@no{(243)}}%
\qt@newcmd\qurantrans@en@ccli{%
And fight in Allah's cause and know well that Allah is All Hearing, All Knowing.\qt@no{(244)}}%
\qt@newcmd\qurantrans@en@cclii{%
Is there someone who will lend an excellent loan to Allah, so that He may increase it for him several times over? And Allah restricts and eases (the sustenance) – and it is to Him that you will return.\qt@no{(245)}}%
\qt@newcmd\qurantrans@en@ccliii{%
Did you (O dear Prophet Mohammed – peace and blessings be upon him) not see a group of the Descendants of Israel, after Moosa? When they said to one of their Prophets (Shamueel – Samuel), “Appoint a king for us so that we may fight in Allah’s way”? He said, “Do you think you would refrain from fighting if it is made obligatory for you?” They said, “What is the matter with us that we should not fight in Allah’s cause, whereas we have been driven away from our homeland and our children?” So when fighting was ordained for them, they all turned away, except a few; and Allah is Well Aware of the unjust.\qt@no{(246)}}%
\qt@newcmd\qurantrans@en@ccliv{%
And their Prophet said to them, “Indeed Allah has sent Talut (Saul) as your king”; they said, “Why should he have kingship over us whereas we deserve the kingship more than he, and nor has he been given enough wealth?” He said, “Indeed Allah has chosen him above you, and has bestowed him with vast knowledge and physique”; and Allah may bestow His kingdom on whomever He wills; and Allah is Most Capable, All Knowing.\qt@no{(247)}}%
\qt@newcmd\qurantrans@en@cclv{%
And their Prophet said to them, “Indeed the sign of his kingdom will be the coming of a (wooden) box to you, in which from your Lord is the contentment of hearts and containing some souvenirs (remnants) left behind by the honourable Moosa and the honourable Haroon (Aaron), borne by the angels; indeed in it is a great sign* for you if you are believers.” (The remnants of pious persons are blessed by Allah.)\qt@no{(248)}}%
\qt@newcmd\qurantrans@en@cclvi{%
So when Talut left the city along with the armies, he said, “Allah will surely test you with a river; so whoever drinks its water is not mine – and whoever does not drink is mine – except him who takes it in the hollow of his hand”; so they all drank it, except a few of them; thereafter when Talut and the believers with him had crossed the river, they said, “We do not have power this day to face Jalut (Goliath) and his armies”; those who were certain of meeting Allah said, “Many a times has a smaller group overcome a bigger group by Allah’s command; and Allah is with the steadfast.”\qt@no{(249)}}%
\qt@newcmd\qurantrans@en@cclvii{%
And when they confronted Jalut and his armies they invoked, “Our Lord! Pour (bestow abundantly) on us patience (fortitude), and keep our feet steady, and help us against the disbelieving people.”\qt@no{(250)}}%
\qt@newcmd\qurantrans@en@cclviii{%
So they routed them by the command of Allah; and Dawud (David) slew Jalut, and Allah gave him the kingdom and wisdom, and taught him all whatever He willed; and if Allah does not ward off some men by others, the earth will be destroyed, but Allah is Most Munificent towards the entire creation.\qt@no{(251)}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the verses of Allah, which We recite to you (O dear Prophet Mohammed – peace and blessings be upon him) with truth; and undoubtedly you are one of the Noble Messengers.\qt@no{(252)}}%
\qt@newcmd\qurantrans@en@cclx{%
These are the Noble Messengers, to whom We gave excellence over each other; of them are some with whom Allah spoke, and some whom He exalted high above all others; and We gave Eisa (Jesus), the son of Maryam, clear signs and We aided him with the Holy Spirit; and if Allah willed, those after them would not have fought each other after the clear evidences had come to them, but they differed – some remained on faith and some turned disbelievers; and had Allah willed, they would not have fought each other; but Allah may do as He wills.\qt@no{(253)}}%
\qt@newcmd\qurantrans@en@cclxi{%
O People who Believe! Spend in Allah's cause, from what We have provided you, before the advent of a day in which there is no trade, and for the disbelievers neither any friendship nor intercession; and the disbelievers themselves are the unjust.\qt@no{(254)}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah – there is no God except Him; He is Alive (eternally, on His own) and the Upholder (keeps others established); He never feels drowsy nor does He sleep; to Him only belongs all whatever is in the heavens and all whatever is in the earth; who is he that can intercede* with Him except by His command? He knows what is in front of them and what is behind them; and they do not achieve anything of His knowledge except what He wills; His Throne (of Sovereignty) encompasses the heavens and the earth; and it is not difficult for Him to guard them; and He is the Supreme, the Greatest. (This Verse is popularly known as Ayat Al-Kursi. It has a special status and reciting it carries great reward. *Prophet Mohammed – peace and blessings be upon him – will be the first one to be granted the permission to intercede, others will follow.)\qt@no{(255)}}%
\qt@newcmd\qurantrans@en@cclxiii{%
There is no compulsion at all in religion; undoubtedly the right path has become very distinct from error; and whoever rejects faith in the devil (false deities) and believes in Allah has grasped a very firm handhold; it will never loosen; and Allah is All Hearing, All Knowing.\qt@no{(256)}}%
\qt@newcmd\qurantrans@en@cclxiv{%
Allah is the Guardian of the Muslims – He removes them from realms of darkness towards light; and the supporters of disbelievers are the devils – they remove them from light towards the realms of darkness; it is they who are the people of fire; they will remain in it forever.\qt@no{(257)}}%
\qt@newcmd\qurantrans@en@cclxv{%
Did you (O dear Prophet Mohammed – peace and blessings be upon him) not see him who argued with Ibrahim (Abraham) concerning his Lord, as Allah had given him the kingdom? When Ibrahim said, “My Lord is He Who gives life and causes death”, he answered, “I give life and cause death”; Ibrahim said, “So indeed it is Allah Who brings the sun from the East – you bring it from the West!” – the disbeliever was therefore baffled; and Allah does not guide the unjust.\qt@no{(258)}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or like him* who passed by a dwelling and it had fallen flat on its roofs; he said, “How will Allah bring it to life, after its death?”; so Allah kept him dead for a hundred years, then brought him back to life; He said, “How long have you stayed here?”; he replied, “I may have stayed for a day or little less”; He said, “In fact, you have spent a hundred years – so look at your food and drink which do not even smell stale; and look at your donkey whose bones even are not intact – in order that We may make you a sign for mankind – and look at the bones how We assemble them and then cover them with flesh”; so when the matter became clear to him, he said, “I know well that Allah is Able to do all things.” (Prophet Uzair – peace be upon him.)\qt@no{(259)}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And when Ibrahim said, “My Lord! Show me how You will give life to the dead”; He said, “Are you not certain (of it)?” Ibrahim said, “Surely yes, why not? But because I wish to put my heart at ease”; He said, “Therefore take four birds (as pets) and cause them to become familiar to you, then place a part of each of them on separate hills, then call them – they will come running towards you; and know well that Allah is Almighty, Wise.” (Prophet Ibrahim called the dead birds and they did come running towards him.)\qt@no{(260)}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The example of those who spend their wealth in Allah’s way is similar to that of a grain which has sprouted seven stalks and in each stalk are a hundred grains; and Allah may increase it still more than this, for whomever He wills; and Allah is Most Capable, All Knowing.\qt@no{(261)}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who spend their wealth in Allah’s way and thereafter do not express favour nor cause injury (hurt the recipient’s feelings), their reward is with their Lord; there shall be no fear upon them nor shall they grieve.\qt@no{(262)}}%
\qt@newcmd\qurantrans@en@cclxx{%
Speaking kind words and pardoning are better than charity followed by injury; and Allah is the Independent, Most Forbearing.\qt@no{(263)}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O People who Believe! Do not invalidate your charity by expressing favour and causing injury – like one who spends his wealth for people to see, and does not believe in Allah and the Last Day; his example is similar to that of a rock covered with dust and hard rain fell on it, leaving it as a bare rock; they shall get no control over (or benefit from) anything they have earned; and Allah does not guide the disbelievers.\qt@no{(264)}}%
\qt@newcmd\qurantrans@en@cclxxii{%
And the example of those who spend their wealth in order to seek Allah’s pleasure and to make their hearts steadfast, is similar to that of a garden on a height – hard rain fell on it, so bringing forth its fruit twofold; so if hard rain does not reach it, the dew is enough; and Allah is seeing your deeds.\qt@no{(265)}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would any of you like that he may own a garden of dates and grapes, with rivers flowing beneath it – in it are all kinds of fruits for him – and he reaches old age and has young children; therefore a windstorm containing fire came to the garden, burning it? This is how Allah explains His verses to you, so that you may give thought.\qt@no{(266)}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O People who Believe! Spend a part of your lawful earnings, and part of what We have produced from the earth for you – and do not (purposely) choose upon the flawed to give from it (in charity) whereas you would not accept it yourselves except with your eyes closed towards it; and know well that Allah is Independent, Most Praised.\qt@no{(267)}}%
\qt@newcmd\qurantrans@en@cclxxv{%
The devil scares you of poverty and bids you to the shameful; and Allah promises you forgiveness from Him, and munificence; and Allah is Most Capable, All Knowing.\qt@no{(268)}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
Allah bestows wisdom on whomever He wills; and whoever receives wisdom has received abundant goodness; but none heed advice except men of understanding.\qt@no{(269)}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
And whatever you spend or pledge to do, Allah is aware of it; and the unjust do not have supporters.\qt@no{(270)}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If you give charity openly, what an excellent deed it is! And if you secretly give it to the poor, it is the best for you; and it will redeem some of your sins; and Allah is Aware of your deeds.\qt@no{(271)}}%
\qt@newcmd\qurantrans@en@cclxxix{%
It is not your duty (O dear Prophet Mohammed – peace and blessings be upon him) to make them accept guidance – but Allah guides whomever He wills; and whatever good thing you spend is beneficial for yourselves; and it is not right for you to spend except to seek Allah’s pleasure; and whatever you spend will be repaid to you in full, and you will not be wronged. –\qt@no{(272)}}%
\qt@newcmd\qurantrans@en@cclxxx{%
(Spend) For the poor who are restricted while in Allah's cause, who cannot travel in the land (for earning) – the unwise think they are wealthy because of their restraint; you will recognise them by their faces; they do not seek from people in order to avoid grovelling; and Allah knows whatever you spend in charity.\qt@no{(273)}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who spend their wealth by night and day, secretly and openly – their reward is with their Lord; and there shall be no fear upon them nor shall they grieve.\qt@no{(274)}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who devour usury will not stand up on the Day of Judgement, except like the one whom an evil jinn has deranged by his touch; that is because they said, “Trade is also like usury!”; whereas Allah has made trading lawful and forbidden usury; for one to whom the guidance has come from his Lord, and he refrained therefrom, is lawful what he has taken in the past; and his affair is with Allah; and whoever continues earning it henceforth, is of the people of fire; they will remain in it for ages.\qt@no{(275)}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah destroys usury and increases charity; and Allah does not like any ungrateful, excessive sinner.\qt@no{(276)}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Indeed those who believed and did good deeds and kept the prayer established and paid the charity – their reward is with their Lord; and there shall be no fear upon them nor shall they grieve.\qt@no{(277)}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O People who Believe! Fear Allah and forego the remaining usury, if you are Muslims.\qt@no{(278)}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
And if you do not, then be certain of a war with Allah and His Noble Messenger; and if you repent, take back your principal amount; neither you cause harm to someone, nor you be harmed.\qt@no{(279)}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
And if the debtor is in difficulty, give him respite till the time of ease; and your foregoing the entire debt from him is still better for you, if only you realise.\qt@no{(280)}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And fear the day in which you will be returned to Allah; and every soul will be paid back in full what it had earned, and they will not be wronged.\qt@no{(281)}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O People who Believe! If you make an agreement for debt for a specified time, write it down; and appoint a scribe to write it for you with accuracy; and the scribe must not refuse to write in the manner Allah has taught him, so he must write; and the liable person (debtor) should dictate it to him and fear Allah, Who is his Lord, and not hide anything of the truth; but if the debtor is of poor reasoning, or weak, or unable to dictate, then his guardian must dictate with justice; and appoint two witnesses from your men; then if two men are not available, one man and two women from those you would prefer to be witnesses, so that if one of them forgets, the other can remind her; and the witnesses must not refuse when called upon to testify; do not feel burdened to write it, whether the transaction is small or big – write it for up to its term’s end; this is closer to justice before Allah and will be a strong evidence and more convenient to dispel doubts amongst yourselves – except when it is an instant trade in which exchange is carried out immediately, there is no sin on you if it is not written down; and take witnesses whenever you perform trade; and neither the scribe nor the witnesses be caused any harm (or they cause any harm); and if you do, it would be an offence on your part; and fear Allah; and Allah teaches you; and Allah knows everything.\qt@no{(282)}}%
\qt@newcmd\qurantrans@en@ccxc{%
And if you are on a journey and cannot find a scribe, then a mortgage (deposit) must be handed over; and if one of you trusts the other, the one who is trusted may return the mortgage entrusted to him and fear Allah, his Lord; and do not hide testimony; and if one hides it, his heart is sinful from within; and Allah knows what you do.\qt@no{(283)}}%
\qt@newcmd\qurantrans@en@ccxci{%
To Allah only belongs all whatever is in the heavens and all whatever is in the earth; and whether you disclose what is in your hearts or hide it, Allah will take account of it from you; so He will forgive whomever He wills and punish whomever He wills; and Allah is Able to do all things.\qt@no{(284)}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Noble Messenger believes in what has been sent down to him by his Lord, and so do the believers; all have accepted faith in Allah and His angels and His Books and His Noble Messengers; saying, “We do not make any distinction, in believing, between any of His Noble Messengers”; and they said, “We hear, and we obey; Your forgiveness be granted, O our Lord, and towards You is our return.”\qt@no{(285)}}%
\qt@newcmd\qurantrans@en@ccxciii{%
Allah does not burden anyone, except with something within its capacity; beneficial for it is the virtue it earned, and harmful for it is the evil it earned; “Our Lord! Do not seize us if we forget or are mistaken; our Lord! And do not place on us a heavy burden (responsibility) as You did on those before us; our Lord! And do not impose on us a burden, for which we do not have the strength; and pardon us – and forgive us – and have mercy on us – You are our Master, therefore help us against the disbelievers.”\qt@no{(286)}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alif-Laam-Meem. (Alphabets of the Arabic language; Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah – none is worthy of worship, except Him, He is Alive (eternally, on His own) and the Upholder (keeps others established).\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
He has sent down to you (O dear Prophet Mohammed – peace and blessings be upon him) this true Book (the Holy Qur’an), confirming the Books before it, and He sent down the Taurat (Torah) and the Injeel (Bible). –\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
Before this, a guidance to mankind; and sent down the Judgement (Criterion to judge between right and wrong); indeed for those who disbelieved in the verses of Allah, is a severe punishment; and Allah is the Almighty, the Avenger (of the wrong).\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Indeed nothing is hidden from Allah, neither in the earth nor in the heavens.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@ccxcix{%
It is He Who fashions (moulds) you in your mothers’ wombs as He wills; none is worthy of worship except Him, the Almighty (the Most Honourable), the Wise.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@ccc{%
It is He Who has sent down to you (O dear Prophet Mohammed – peace and blessings be upon him) this Book (the Qur’an) containing the verses that have a clear meaning – they are the core of the Book – and other verses the meanings of which are indistinct; those in whose hearts is deviation pursue the verses having indistinct meanings, in order to cause turmoil and seeking its (wrongful) interpretation; and only Allah knows its proper interpretation; and those having sound knowledge say, “We believe in it, all of it is from our Lord”; and none accept guidance except the men of understanding.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@ccci{%
“Our Lord! Do not deviate our hearts after You have guided us, and bestow mercy on us from Yourself; indeed You only are the Great Bestower.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@cccii{%
“Our Lord! Indeed You will gather all mankind for a Day about which there is no doubt"; indeed Allah’s promise does not change.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@ccciii{%
Indeed for those who disbelieve, neither their wealth nor their offspring will help to save them in the least from Allah; and it is they who are fuel for the fire.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@ccciv{%
Like the way of Firaun’s people, and those before them; they denied Our signs; so Allah seized them because of their sins; and Allah’s punishment is severe.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@cccv{%
Say (O dear Prophet Mohammed – peace and blessings be upon him) to the disbelievers, “Very soon you shall be overcome and driven towards hell; and that is a wretched resting-place.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@cccvi{%
Indeed there was a sign for you in the two groups that clashed; one army fighting in Allah's cause, against the other of disbelievers, whom they (the Muslims) saw with their eyes, as twice their own number; and Allah strengthens with His help whomever He wills; indeed in this is a lesson for the intelligent, to be learnt by observing.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@cccvii{%
Beautified is for mankind the love of these desires – women, and sons, and heaps of gold and piled up silver, and branded horses, and cattle and fields; this is the wealth of the life of this world; and it is Allah, with Whom is the excellent abode.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “Shall I inform you of something better than that? For the pious, with their Lord, are Gardens beneath which rivers flow – they will abide in it forever – and pure wives, and Allah’s pleasure”; and Allah sees the bondmen.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@cccix{%
Those who say, “Our Lord! we have accepted faith, so forgive us our sins and save us from the punishment of fire.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@cccx{%
The steadfast, and the truthful, and the reverent, and who spend in Allah's cause, and who seek forgiveness in the last hours of the night (before dawn).\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@cccxi{%
Allah has given witness that there is none worthy of worship (God) except Him – and the angels and the scholars also give witness, established with justice (with truth) – there is no God except Him, the Almighty, the Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@cccxii{%
Indeed the only true religion in the sight of Allah is Islam; those who had received the Books differed only after the knowledge came to them, due to their hearts’ envy; and whoever disbelieves in the signs of Allah, then Allah is Swift At Taking Account.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@cccxiii{%
Then if they argue with you, (O dear Prophet Mohammed – peace and blessings be upon him) say, “I have submitted my face (self) to Allah and likewise have my followers”; and say to the People given the Book(s) and the illiterate, “Have you submitted (accepted Islam)?” If they submit, they have attained the right path – and if they turn away (reject), then your duty is only to convey this command; and Allah is seeing the bondmen.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Those who disbelieve in the signs of Allah, and wrongfully martyr the Prophets, and slay people who enjoin justice – so give them the glad tidings of a painful punishment.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@cccxv{%
They are those whose deeds are wasted in this world and in the Hereafter; and they do not have any aides.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Did you not see them who have received a part of the Book – when called towards the Book of Allah for judging between them, a group of them opposes it and turns away?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@cccxvii{%
They dared to do this because they say, “The fire will definitely not touch us except for a certain number of days”; and they are deceived in their religion by the lies they fabricated.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@cccxviii{%
So what will be (their state) when We bring all of them together for the Day (of Resurrection) about which there is no doubt; and every soul will be paid back in full for what it has earned, and they will not be wronged.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@cccxix{%
Invoke (O dear Prophet Mohammed – peace and blessings be upon him), “O Allah! Owner Of The Kingdom – You bestow the kingdom on whomever You will, and You take back the kingdom from whomever You will; and You give honour to whomever You will, and You humiliate whomever You will; only in Your Hand (control) lies all goodness; indeed, You are Able to do all things.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@cccxx{%
“You cause part of the night to pass into the day, and You cause part of the day to pass into the night; and You bring forth the living from the dead, and You bring forth the dead from the living; and You give to whomever You will, without account.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@cccxxi{%
The Muslims must not befriend the disbelievers, in preference over the Muslims; whoever does that has no connection whatsoever with Allah, except if you fear them; Allah warns you of His wrath; and towards Allah only is the return.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say, (O dear Prophet Mohammed – peace and blessings be upon him), “Whether you hide or reveal whatever is in your hearts, Allah knows it all; and He knows all whatever is in the heavens and all whatever is in the earth; and Allah has control over all things.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
On the Day when every soul will be confronted with all the good that it has done; and all the evil that it has done – it will wish that perhaps there would have been a great distance between itself and the punishment; and Allah warns you of His punishment; and Allah is Most Compassionate towards His bondmen.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Proclaim, (O dear Prophet Mohammed – peace and blessings be upon him), “O mankind! If you love Allah, follow me – Allah will love you and forgive you your sins”; and Allah is Oft Forgiving, Most Merciful.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Proclaim, “Obey Allah and the Noble Messenger”; so if they turn away – then Allah is not pleased with the disbelievers.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Indeed Allah chose Adam, and Nooh, and the Family of Ibrahim, and the Family of Imran over the creation.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
They are the descendants one of another; and Allah is the All Hearing, the All Knowing.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
(Remember) When the wife of Imran said, “My Lord! I pledge to you what is in my womb – that it shall be dedicated purely in Your service, so accept it from me; indeed You only are the All Hearing, the All Knowing.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@cccxxix{%
So when she gave birth to it, she said, “My Lord! I have indeed given birth to a girl!” And Allah well knows what she gave birth to; and the boy she had prayed for is not like this girl; “And I have named her Maryam and I give her and her offspring in Your protection, against Satan the outcast.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@cccxxx{%
So her Lord fully accepted her (Maryam), and gave her an excellent development; and gave her in Zakaria’s guardianship; whenever Zakaria visited her at her place of prayer, he found new food with her; he said, “O Maryam! From where did this come to you?” She answered, “It is from Allah; indeed Allah gives to whomever He wills, without limit account.” (Miracles occur through the friends of Allah.)\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
It is here that Zakaria prayed to his Lord; he said, “My Lord! Give me from Yourself a righteous child; indeed You only are the Listener Of Prayer.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
And the angels called out to him while he was standing, offering prayer at his place of worship, “Indeed Allah gives you glad tidings of Yahya (John), who will confirm a Word (or sign) from Allah, – a leader, always refraining from women, a Prophet from one of Our devoted ones.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said, “My Lord! How can I have a son when old age has reached me and my wife is barren?” He said, “This is how Allah brings about, whatever He wills.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said, “My Lord! Determine a sign for me”; He said, “The sign is that you shall not be able to speak to mankind for three days except by signs; and remember your Lord profusely, and proclaim His Purity before sunset and at dawn.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
And when the angels said, “O Maryam! Indeed Allah has chosen you and purified you, and has this day, chosen you among all the women of the world.”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
“O Maryam! Stand in reverence before your Lord, prostrate yourself and bow along with those who bow.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
These are tidings of the hidden, which We secretly reveal to you (O dear Prophet Mohammed – peace and blessings be upon him); and you were not present with them when they threw their pens to draw lots, to know who should be the guardian of Maryam; nor were you present with them when they were quarrelling. (Yet you know of these things – this is a proof of your being a Prophet.)\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
And remember when the angels said, “O Maryam! Allah gives you glad tidings of a Word from Him, whose name is the Messiah, Eisa the son of Maryam – he will be honourable in this world and in the Hereafter, and among the close ones (to Allah).”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
“He will speak to people while he is in the cradle and in his adulthood, and will be of the devoted ones.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said, “My Lord! How can I bear a child when no man has ever touched me?” He said, “This is how Allah creates whatever He wills; when He wills a thing, He only says to it, ‘Be’ – and it happens immediately.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@cccxli{%
“And Allah will teach him the Book and wisdom, and the Taurat (Torah) and the Injeel (Bible).”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@cccxlii{%
“And he will be a Noble Messenger towards the Descendants of Israel saying, ‘I have come to you with a sign from your Lord, for I mould a birdlike sculpture from clay for you, and I blow into it and it instantly becomes a (living) bird, by Allah’s command; and I heal him who was born blind, and the leper, and I revive the dead, by Allah’s command; and I tell you what you eat and what you store in your houses; undoubtedly in these (miracles) is a great sign for you, if you are believers.’ (Several miracles bestowed to Prophet Eisa are mentioned here.)\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@cccxliii{%
‘And I come confirming the Taurat (Torah) – the Book before me – and to make lawful for you some of the things which were forbidden to you, and I have come to you with a sign from your Lord – therefore fear Allah and obey me.’\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@cccxliv{%
‘Undoubtedly Allah is the Lord of all – mine and yours – so worship Him only; this is the Straight Path.’”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@cccxlv{%
So when Eisa sensed their disbelief he said, “Who will be my aides towards (in the cause of) Allah?” The disciples said, “We are the aides of Allah’s religion; we believe in Allah, and you bear witness that we are Muslims.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
“Our Lord! We have believed in what You have sent down and we follow the Noble Messenger, therefore record us among the witnesses of the truth.”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
And the disbelievers conspired (to kill Eisa), and Allah covertly planned to destroy them; and Allah is the best of secret planners.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
Remember when Allah said, “O Eisa! I will keep you alive till your full age, and raise you towards Me, and cleanse you of the disbelievers and give your followers dominance over the disbelievers until the Day of Resurrection; then you will all return to Me, so I shall judge between you concerning the matter in which you dispute.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@cccxlix{%
“So I shall mete a severe punishment to those who disbelieve, in this world and in the Hereafter; and they will not have any supporters.”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@cccl{%
“And for those who believed and did good deeds, Allah will give them their full reward; and Allah does not like the unjust.”\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@cccli{%
These are some verses that We recite to you, and advice full of wisdom.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@ccclii{%
The example of Eisa with Allah is like that of Adam; He created him (Adam) from clay and then said to him, “Be” – and it thereupon happens!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@cccliii{%
O listener! (followers of this Prophet) This is the Truth from your Lord, so never be of those who doubt.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@cccliv{%
Therefore say to those who dispute with you (O dear Prophet Mohammed – peace and blessings be upon him) concerning Eisa after the knowledge has come to you, “Come! Let us summon our sons and your sons, and our women and your women, and ourselves and yourselves – then pray humbly, thereby casting the curse of Allah upon the liars!” (The Christians did not accept this challenge.)\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@ccclv{%
This undoubtedly is the true narrative; there is none worthy of worship except Allah; and Allah is the Almighty, the Wise.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@ccclvi{%
So if they turn away, then indeed Allah knows those who cause turmoil.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “O People given the Book(s)! Come towards a word which is common between us and you, that we shall worship no one except Allah, and that we shall not ascribe any partner to Him, and that none of us shall take one another as lords besides Allah”; then if they do not accept say, “Be witness that (only) we are Muslims.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@ccclviii{%
O People given the Book(s)! Why do you argue about Ibrahim, whereas the Taurat (Torah) and the Injeel (Bible) were not sent down until after him? So do you not have sense?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@ccclix{%
Listen! This was what you argued about – of which you have some knowledge – why do you then argue about the matter you do not have any knowledge of? And Allah knows whereas you do not know.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@ccclx{%
Ibrahim was neither a Jew nor a Christian; but he was a Muslim, free from all falsehood; and was not of the polytheists.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Undoubtedly among all mankind who have the best claim to Ibrahim are those who followed him, and this Prophet (Mohammed – peace and blessings be upon him) and the believers; and Allah is the Guardian of the believers.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@ccclxii{%
A group among the People given the Book(s) desire that if only they could lead you astray; and they only make themselves astray, and they do not have sense.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
O People given the Book(s)! Why do you disbelieve in the signs of Allah, whereas you yourselves are witnesses?\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
O People given the Book(s)! Why do you mix the truth with falsehood and conceal the truth, whereas you know?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@ccclxv{%
And a group among the People given the Book(s) said, “Believe in what has been sent down to the believers in the morning and deny it by evening – perhaps they (the Muslims) may turn back (disbelieve).”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
“And do not believe in anyone except him who follows your religion”; say (O dear Prophet Mohammed – peace and blessings be upon him), “Only Allah’s guidance is the true guidance” – (so why not believe in it) if someone has been given similar to what was given to you, or if someone may be able to evidence it against you before your Lord; say (O dear Prophet Mohammed – peace and blessings be upon him), “Undoubtedly the munificence lies only in Allah’s Hand (control); He may bestow upon whomever He wills; and Allah is Most Capable, All Knowing.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
“He chooses by His mercy, whomever He wills; and Allah is the Owner of Great Munificence.”\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
Among the People given the Book(s) is one who, if you trust him with a heap of treasure, will return it to you; and among them is one who, if you trust him with (just) one coin, will not return it to you unless you constantly stand over him (keep demanding); that is because they say, “We are not obliged in any way, in the case of illiterates”; and they purposely fabricate lies against Allah.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Yes, why not? Whoever fulfilled his pledge and practised piety – and indeed Allah loves the pious.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Those who accept abject prices in exchange of Allah’s covenant and their oaths, do not have a portion in the Hereafter – Allah will neither speak to them nor look towards them on the Day of Resurrection, nor will He purify them; and for them is a painful punishment.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And amongst them are some who distort (change words of) the Book with their tongues, so that you may think that this also is in the Book whereas it is not in the Book; and they say, “This is from Allah” whereas it is not from Allah; and they fabricate lies against Allah, whereas they know.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It is not for any human to whom Allah has given the Book and wisdom and Prophethood, that he should afterwards say to the people, “Leave (the worship of) Allah and be my worshippers” – but he will surely say, “Be sincere worshippers of Allah, because you teach the Book and you preach from it.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
And nor will he command you to appoint the angels and the Prophets as Gods; would he (a Prophet) command you to disbelieve after you have become Muslims?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
And remember when Allah took a covenant from the Prophets; “If I give you the Book and knowledge and the (promised) Noble Messenger (Prophet Mohammed – peace and blessings be upon him) comes to you, confirming the Books you possess, you shall positively, definitely believe in him and you shall positively, definitely help him”; He said, “Do you agree, and accept My binding responsibility in this matter?” They all answered, “We agree”; He said, “Then bear witness amongst yourselves, and I Myself am a witness with you.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
So those who turn away after this – it is they who are the sinners.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
So do they desire a religion other than the religion of Allah, whereas to Him has submitted whoever is in the heavens and the earth, willingly or grudgingly, and it is to Him they will return?\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say, “We believe in Allah and what is sent down to us and what was sent down to Ibrahim, and Ismael, and Ishaq, and Yaqub (Jacob) and their sons, and that which came to Moosa and Eisa and the Prophets, from their Lord; we do not make any distinction, in belief, between any of them, and to Him we have submitted ourselves.”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
And if one seeks a religion other than Islam, it will never be accepted from him; and he is among the losers in the Hereafter.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
Why should Allah will guidance for the people who disbelieved, after their having accepted faith and bearing witness that the Noble Messenger is a true one, and after clear signs had come to them? And Allah does not guide the unjust.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
The recompense of such is that on them is the curse of Allah and of the angels and of men combined.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
Remaining in it forever; their punishment will not be lightened, nor will they get any respite.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Except those who repented thereafter and reformed themselves; then indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Indeed those who disbelieve after having accepted faith, and advance further in their disbelief – their repentance will never be accepted; and it is they who are the astray.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
Those who disbelieved and died as disbelievers – an earth full of gold will never be accepted from any one of them, even if he offers it, for his freedom; for them is a painful punishment and they do not have any aides.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
You can never attain virtue until you spend in Allah's cause the things you love; and Allah is Aware of whatever you spend.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was lawful for the Descendants of Israel (Jacob), except what Israel forbade for himself, before the Taurat (Torah) was sent down; say, “Bring the Taurat and read it, if you are truthful.”\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
So henceforth whoever fabricates lies against Allah – it is they who are the unjust.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “Allah is truthful; so follow the religion of Ibrahim, who was free from all falsehood; and he was not of the polytheists.”\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
Indeed the first house that was appointed as a place of worship for mankind, is the one at Mecca (the Holy Ka’aba), blessed and a guidance to the whole world;\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@cccxc{%
In it are clear signs – the place where Ibrahim stood (is one of them); and whoever enters it shall be safe; and performing the Hajj (pilgrimage) of this house, for the sake of Allah, is a duty upon mankind, for those who can reach it; and whoever disbelieves – then Allah is Independent (Unwanting) of the entire creation!\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “O People given the Book(s)! Why do you not believe in the verses (or signs) of Allah, whereas your deeds are being witnessed by Allah?”\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “O People given the Book(s)! Why do you prevent those who have accepted faith from the way of Allah, seeking to cause deviation in it, whereas you yourselves are witnesses to it? And Allah is not unaware of your deeds!”\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O People who Believe! If you obey some of People given the Book(s), they will definitely turn you into disbelievers after your having accepted faith.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@cccxciv{%
And how can you disbelieve, whereas Allah’s verses are recited to you and His Noble Messenger is present amongst you?! And whoever takes the support of Allah is indeed guided to the right path.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O People who Believe! Fear Allah in the manner He should rightfully be feared, and do not die except as Muslims.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold fast to the rope of Allah, all of you together, and do not be divided; and remember Allah’s favour on you, that when there was enmity between you, He created affection between your hearts, so due to His grace you became like brothers to each other; and you were on the edge of a pit of fire (hell), so He saved you from it; this is how Allah explains His verses to you, so that you may be guided.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
And there should be a group among you that invites to goodness, and enjoins good deeds and forbids immorality; it is they who are the successful.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
And do not be like those who became divided and disputed after the clear signs had come to them; and for them is a terrible punishment.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On the Day (of Resurrection) when some faces will be shining and some faces black; so, (to) those whose faces are blackened, “What! You disbelieved after you had accepted faith! Therefore now taste the punishment, the result of your disbelief.”\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@cd{%
And those whose faces will be shining, are in the mercy of Allah; they will abide in it forever.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@cdi{%
These are the verses of Allah, which We recite to you (O dear Prophet Mohammed – peace and blessings be upon him), with truth; and Allah does not wish any injustice to the creation.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@cdii{%
And to Allah only belongs all whatever is in the heavens and all whatever is in the earth; and towards Allah only is the return of all matters.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@cdiii{%
You are the best among all the nations that were raised among mankind – you enjoin good deeds and forbid immorality and you believe in Allah; and if the People given the Book(s) believed it would be better for them; some of them are believers (Muslims) and most of them are disbelievers. (The best Ummah is that of Prophet Mohammed – peace and blessings be upon him.)\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cdiv{%
They cannot harm you except cause some trouble; and if they fight against you, they will turn their backs on you; then they will not be helped.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cdv{%
Disgrace has been destined for them – wherever they are they shall not find peace, except by a rope from Allah and a rope from men – and they have deserved the wrath of Allah, and misery is destined for them; that is because they used to disbelieve in the signs of Allah, and unjustly martyr the Prophets; that was for their disobedience and transgression.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cdvi{%
All of them are not alike; among the People given the Book(s) are some who are firm on the truth – they recite the verses of Allah in the night hours and prostrate (before Him).\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cdvii{%
They accept faith in Allah and the Last Day, and enjoin good deeds and forbid immorality, and hasten to perform good deeds; and they are the righteous.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cdviii{%
And they will not be denied the reward of whatever good they do; and Allah knows the pious.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cdix{%
Indeed those who disbelieve – neither their wealth nor their offspring will help save them in the least, from Allah; and they are the people of fire; remaining in it forever.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cdx{%
The example of what they spend in this worldly life is similar to the freezing cold wind which struck the fields of a nation who wronged themselves, and destroyed it completely; and Allah did not oppress them, but it is they who wronged themselves.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cdxi{%
O People who Believe! Do not share your secrets with others – they do all they can to ruin you; they desire the maximum harm for you; enmity has been revealed from their speech, and what they hide in their breasts is greater; we have explained the signs clearly to you, if you have intelligence.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cdxii{%
Listen! It is you who love them and they do not love you, whereas the fact is that you believe in all the Books; when they meet you they say, “We believe”; and when they are alone they chew their fingers at you with rage; say, “Die in your frenzy!” Allah knows well what lies within the hearts.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If some good reaches you, they feel unhappy; and if misfortune befalls you, they will rejoice; and if you remain steadfast and pious, their evil scheme will not harm you in the least; undoubtedly all what they do is encompassed by Allah.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cdxiv{%
And remember O dear Prophet (Mohammed – peace and blessings be upon him) when you came forth from your house in the morning, appointing the believers on positions of battle; and Allah is All Hearing, All Knowing.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cdxv{%
When two groups among you almost decided to show cowardice – and Allah is their Protector; and in Allah only should the believers trust.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cdxvi{%
Allah indeed aided you at Badr when you had no means; so fear Allah – so that you may be thankful.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cdxvii{%
When you O dear Prophet (Mohammed – peace and blessings be upon him) said to the believers, “Is it not sufficient for you that your Lord may support you by sending down three thousand angels?”\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cdxviii{%
Yes, why not? If you patiently endure and remain pious, and the disbelievers attack you suddenly, your Lord will send down five thousand marked angels to help you.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cdxix{%
And Allah did not bestow this victory except for your happiness, and only that your hearts may attain peace with it; and there is no help except from Allah, the Almighty, the Wise.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cdxx{%
So He may cut off a part of the disbelievers, or disgrace them so that they return unsuccessful.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cdxxi{%
This matter is not for you to decide – whether He guides them to repent or punishes them, for they are the unjust.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cdxxii{%
And to Allah only belongs all whatever is in the heavens and all whatever is in the earth; He may forgive whomever He wills, and punish whomever He wills; and Allah is Oft Forgiving, Most Merciful.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O People who Believe! Do not devour usury doubling and quadrupling it; and fear Allah, hoping that you achieve success.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And save yourselves from the fire which is prepared for disbelievers.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey Allah and the Noble Messenger, hoping that you gain mercy. (Obeying the Prophet is in fact obeying Allah.)\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And rush towards forgiveness from your Lord, and towards a Paradise that can hold all the heavens and the earth in its width – prepared for the pious.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
Those who spend in Allah’s cause, in happiness and in grief, and who control their anger and are forgiving towards mankind; and the righteous are the beloved of Allah.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
And those who, when they commit an immoral act or wrong themselves, remember Allah and seek forgiveness of their sins – and who forgives sins except Allah? And those who do not purposely become stubborn regarding what they did.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cdxxix{%
For such the reward is forgiveness from their Lord, and Gardens beneath which rivers flow – abiding in it forever; what an excellent reward for the performers (of good deeds)!\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Some traditions have been tried before you – therefore travel in the land and see what sort of fate befell those who denied.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This is an explanation for mankind, a guidance and an advice to the pious.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
And do not be negligent nor grieve – it is you who will be victorious if you are believers.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If you have been struck by some misfortune, so they (the disbelievers) too have been struck earlier with the same misfortune; these are the days in which We have allotted turns to people; and so that Allah may make known the believers and may bestow martyrdom to some of you; and Allah does not befriend the unjust.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
And so that Allah may purify* the believers, and destroy the disbelievers. (* Forgive them their sins, if any.)\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
What! You assume that you will enter Paradise while Allah has not yet tested your warriors, nor yet tested the steadfast?\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
And you used to wish for death before you met it; so now you see it before your eyes.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
And Mohammed (peace and blessings be upon him) is purely* a Noble Messenger; there have been Noble Messengers before him; so if he departs or is martyred, will you turn back on your heels? So whoever turns back on his heels does not cause any harm to Allah; and Allah will soon reward the thankful. (* Neither God nor an angel, but a human being with the highest spiritual status.)\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
And no soul can die except by Allah’s command – a time has been appointed for each; whoever desires the rewards of this world, We bestow upon him from it; and whoever desires the reward of the Hereafter, We bestow upon him from it; and We shall soon reward the thankful.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
And many Prophets have fought in Allah’s cause – and many devoted men were with them; so neither did they lose heart due to the calamities that befell them in Allah's cause, nor did they weaken and nor were they subdued; and the steadfast are the beloved of Allah.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cdxl{%
And they never said anything except that they invoked, “Our Lord! Forgive us our sins and the excesses committed during our efforts, and keep our feet steady, and bestow us help over the disbelievers.”\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@cdxli{%
So Allah gave them the reward of this world and the best of rewards in the Hereafter; and Allah loves the righteous.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O People who Believe! If you obey the disbelievers, they will make you turn back on your heels, so you will then turn back as losers.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@cdxliii{%
In fact, Allah is your Master; and He is the Best Supporter.\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@cdxliv{%
Soon We shall cast awe in the hearts of disbelievers because they have appointed partners to Allah, for which He has not sent any proof; their destination is hell; and what a wretched abode for the unjust!\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@cdxlv{%
And indeed Allah has proved true His promise to you, when you used to slay the disbelievers by His command; until the time you people lost courage and disputed about the order and disobeyed after Allah had shown you what pleases you; some of you desired the world, and some of you desired the Hereafter; thereafter He turned you away from them in order to test you; and undoubtedly He has forgiven you; and Allah is Most Munificent towards the Muslims.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
When you were leaving, unconcerned without turning to look back at anyone, and from another group Our Noble Messenger was calling you (to fight); so He gave you sorrow in lieu of sorrow, and then forgave you so that you do not grieve over what has been lost or over the calamity that befell you; and Allah is Well Aware of what you do.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then after grief, He sent down a peaceful slumber (calm), which engulfed a group among you – and another party kept fearing for their own lives, thinking wrongfully of Allah – like the thoughts of ignorance; they say, “Do we have any authority in this matter?” Say (O dear Prophet Mohammed – peace and blessings be upon him), “All authority lies only with Allah”; they hide in their hearts what they do not reveal to you; they say, “Had we any control, we would not have been slain here”; say, “Even if you had been in your houses, those destined to be slain would have come forth to their places of slaying; and in order that Allah may test what is in your breasts and reveal whatever is in your hearts”; and Allah knows well what lies within the hearts.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Indeed those of you who turned back on the day when the two armies met – for it was the devil who caused them to waver, because of some of their deeds; and undoubtedly Allah has forgiven them; indeed Allah is Oft Forgiving, Most Forbearing.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O People who Believe! Do not be like the disbelievers who said regarding their brothers who went on a journey or on holy war, “If they had been here with us they would not have died or been killed” – so that Allah may make it as despair in their hearts; and Allah gives life and causes death; and Allah is seeing your deeds.\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@cdl{%
And if you are killed in Allah’s way or die, then the pardon from Allah and mercy are better than all what they hoard.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@cdli{%
And whether you are killed or you die, towards Allah you will be gathered.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@cdlii{%
So what a great mercy it is from Allah that you (O dear Prophet Mohammed – peace and blessings be upon him), are lenient towards them; and if you had been stern and hardhearted (unsympathetic) they would have certainly been uneasy in your company; so forgive them and intercede for them and consult with them in the conduct of affairs; and when you decide upon something, rely upon Allah; indeed Allah loves those who trust (Him).\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah supports you, no one can overcome you; and if He forsakes you, who is there who can then help you? And in Allah only should the Muslims trust.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@cdliv{%
And it is unimaginable that any Prophet would hide something; and whoever hides it, will bring what he hid with him on the Day of Resurrection; then every soul will be paid in full for whatever they earned; and they will not be wronged.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@cdlv{%
So is one who follows the will of Allah equal to one who has incurred the wrath from Allah and whose home is the fire? And what a wretched place to return!\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They are in different ranks before Allah; and Allah sees their deeds.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Allah has indeed bestowed a great favour upon the Muslims, in that He sent to them a Noble Messenger (Prophet Mohammed – peace and blessings be upon him) from among them, who recites to them His verses, and purifies them, and teaches them the Book and wisdom; and before it, they were definitely in open error. (The Holy Prophet Mohammed – peace and blessings be upon him – is one of Allah’s greatest favours to mankind.)\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@cdlviii{%
So will you say when disaster strikes you, though you had struck them with twice as much, “Where has this come from?” Say (to them, O dear Prophet Mohammed – peace and blessings be upon him), “It has come from yourselves”; indeed Allah is Able to do all things.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@cdlix{%
And the calamity that struck you on the day the two armies met, was by Allah’s command – and in order that He may make known the believers.\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@cdlx{%
And in order to expose them who turned hypocrites; and it was said to them, “Come, fight in Allah's cause, or repel the enemy”; they answered, “If we knew how to fight, we would certainly have been with you”; and on that day they were nearer to open disbelief than to professed faith; they utter with their mouths what is not in their hearts; and Allah knows well what they hide. –\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@cdlxi{%
Those who spoke regarding their brothers while they themselves stayed back at home, “Had they listened to us, they would not have been slain”; say (to them, O dear Prophet Mohammed – peace and blessings be upon him), “Then avert your own death, if you are truthful!”\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@cdlxii{%
And do not ever assume that those who are slain in Allah's cause, are dead; in fact they are alive with their Lord, receiving sustenance. (Death does not mean extinction, it is the passing of the soul from this world to another. In case of virtuous believers, their bodies do not rot after death and they remain “alive”, in the manner Allah has ordained for them.)\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
Happy over what Allah has bestowed upon them from His grace, and rejoicing for those who will succeed them, and have not yet joined them; for on them is no fear nor any grief.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They rejoice because of the favours from Allah and (His) munificence, and because Allah does not waste the reward of the believers.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@cdlxv{%
Those who responded to the call of Allah and His Noble Messenger after they had been grieved; for the virtuous and the pious among them is a great reward.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Those to whom the people said, “The people have gathered against you, therefore fear them”, so their faith was further increased; and they said, “Allah is Sufficient for us – and what an excellent (reliable) Trustee (of affairs) is He!”\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So they returned with the favour and munificence from Allah, in that no harm reached them; they followed what pleased Allah; and Allah is Extremely Munificent.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
It is the devil who threatens with his friends; so do not fear them and fear Me, if you have faith.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@cdlxix{%
And O dear Prophet (Mohammed – peace and blessings be upon him) do not grieve for those who rush towards disbelief; they cannot cause any harm to Allah; and Allah does not will to assign them any portion in the Hereafter; and for them is a terrible punishment.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Those who have purchased disbelief in exchange of faith cannot cause any harm to Allah; and for them is a painful punishment.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
And never must the disbelievers be under the illusion that the respite We give them is any good for them; We give them respite only for them to further advance in their sins; and for them is a disgraceful punishment.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
Allah will not leave you, O People who Believe (the Muslims) in your present state, till He separates the evil from the good; and it does not befit Allah’s Majesty to give you, the common men, knowledge of the hidden, but Allah does chose from His Noble Messengers whomever He wills; so believe in Allah and His Noble Messengers; and if you believe and practice piety, for you is a great reward. (Allah gave the knowledge of the hidden to the Holy Prophet – peace and blessings be upon him.)\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
And never must those who act miserly upon what Allah has bestowed upon them of His grace, think that it is good for them; in fact it is harmful for them; soon what they had withheld will be collars round their necks on the Day of Resurrection; and Allah only is the Inheritor (Owner) of the heavens and the earth; and Allah is Well Aware of what you do.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Undoubtedly Allah heard them who said, “Allah is needy, and we are the wealthy”; We shall keep recorded their saying and their wrongfully martyring of the Prophets; and We shall say, “Taste the punishment of the fire!”\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
“This is the recompense of what your hands have sent ahead and Allah does not oppress the bondmen.”\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
Those who say, “Allah has agreed with us that we should not believe in any Noble Messenger until he comes with the command to offer a sacrifice, which a fire (from heaven) shall devour”; say (O dear Prophet Mohammed – peace and blessings be upon him), “Many Noble Messengers did come to you before me, with clear signs and with this command which you state – why did you then martyr them, if you are truthful?”\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
So O dear Prophet (Mohammed – peace and blessings be upon him) if they are denying you, Noble Messengers who came before you had also been denied, who had come with clear signs and Scriptures and the clear Book.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Every soul must taste death; and only on the Day of Resurrection will you be fully recompensed; so the one who is saved from the fire and is admitted into Paradise – he is undoubtedly successful; and the life of this world is just counterfeit wealth.\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
You will surely be tried in respect of your property and lives, and you will surely hear much wrong from those who were given the Book before you, and from the polytheists; and if you remain steadfast and remain pious, it is then an act of great courage.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
And remember when Allah took a covenant from the People given the Book(s) that, “You shall definitely preach it to the people and not hide it”; so they flung it behind their backs and gained an abject price for it; so what a wretched bargain it is!\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Do not ever think of those who rejoice for their deeds and wish to be praised without doing (good deeds) – do not ever think that they are safe from the punishment; and for them is a painful punishment.\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
And for Allah only is the kingship of the heavens and the earth; and Allah is Able to do all things.\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Undoubtedly in the creation of the heavens and the earth and the alternation of night and day are signs for the intelligent.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Those who remember Allah while standing, and sitting, and reclining on their sides, and ponder about the creation of the heavens and the earth; “O our Lord! You have not created this without purpose; Purity is to You, therefore save us from the punishment of fire.”\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
“O our Lord! You have indeed given disgrace to whomever You put in the fire (of hell); and the unjust do not have any supporters.”\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
“O our Lord! We have heard a proclaimer calling towards faith, (saying) ‘Believe in your Lord’ so we have accepted faith; Our Lord! Therefore forgive us our sins, and wipe out our evil deeds, and make us die among the virtuous.”\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
“O our Lord! And give us what You have promised us through Your Noble Messengers, and do not humiliate us on the Day of Resurrection; indeed You do not break the promise.”\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
So their Lord accepted their prayer, for I do not waste the efforts of any (righteous) worker, male or female; you are all one among yourselves; so those who migrated and were driven out from their homes and were harassed in My cause, and fought, and were slain – I will certainly wipe out all their sins and will certainly admit them into Gardens beneath which rivers flow; a reward from Allah; and only with Allah is the best reward.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
O listener (followers of this Prophet)! Do not ever be deceived by the disbelievers’ free movements in the cities.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@cdxc{%
It is a brief usage; their home is hell; and what an evil resting-place!\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@cdxci{%
But for those who fear their Lord are Gardens beneath which rivers flow – abiding in it for ever – the hospitality from their Lord; and that which is with Allah, is the best for the righteous.\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And undoubtedly there are some among the People given the Book(s), who accept faith in Allah and what is sent down to you and what was sent down to them – their hearts are submitted humbly before Allah – they do not exchange the verses of Allah for an abject price; they are those whose reward is with their Lord; indeed Allah is Swift At Taking Account.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O People who Believe! Endure and surpass your enemies in endurance, and guard the frontiers of the Islamic nation; and keep fearing Allah, hoping that you may succeed.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O mankind! Fear your Lord Who created you from a single soul and from it created its spouse and from them both has spread the multitude of men and women; fear Allah in Whose name you claim (your rights from one another) and be mindful of your blood relations; indeed Allah is always seeing you.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@cdxcv{%
And give the orphans their wealth and do not exchange the pure for the foul; and do not devour (or use up) their wealth, mixing it with your own; this is indeed a great sin.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
And if you fear that you will not be just towards orphan girls, marry the women whom you like – two at a time, or three or four; then if you fear that you cannot keep two women equally then marry only one or the bondwomen you own; this is closer to your not doing injustice.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
And give the women their bridal money willingly; then if they willingly give you a part of it, eat (use) it with joy and fruition.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
And do not give the foolish their wealth which is in your custody – those for whom Allah has put you in charge to maintain (look after) – and feed and clothe them from it, and speak kindly to them.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@cdxcix{%
And test the orphans till they are fit to get married (reach full age); then if you find them of proper judgement, hand over their wealth to them; and do not devour it by spending excessively and hastily, fearing that they will grow up; and whoever is not in need must abstain; and whoever is needy may use from it in a reasonable measure; and when you hand over their wealth to them, get witnesses over them; and Allah is Sufficient to take account.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@d{%
For men is a share from what the parents and near relatives leave behind, and for women is a share from what the parents and near relatives leave behind, whether the wealth (inheritance) is small or large; the share is a fixed one.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@di{%
And if relatives and orphans and the needy are present at the time of disbursement, give them something from it and speak to them with kindness.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dii{%
And those people must fear, who if they die leaving behind them young children would be afraid for them; so they must fear Allah and speak with fairness.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@diii{%
Indeed those who unjustly devour the wealth of orphans only fill their bellies with fire; and soon they will go into a blazing pit.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@div{%
Allah commands you concerning your children; the son’s share is equal to that of two daughters; and if there are only daughters, for them is two-thirds of the inheritance, even if they are more than two; and if there is only one daughter, for her is half; and to each of the deceased’s parents a sixth of the inheritance, if he has children; and if the deceased has no children but leaves behind parents, then one third for the mother; and if he has several brothers and sisters, a sixth for the mother, after any will he may have made and payment of debt; your fathers and your sons – you do not know which of them will be more useful to you; this is the share fixed by Allah; indeed Allah is All Knowing, Wise.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dv{%
And from what your wives leave, half is for you if they do not have any child; or if they have a child for you is a fourth of what they leave, after any will they may have made or debt to be paid; and to the women is a fourth of what you leave behind, if you do not have any child; or if you have a child then an eighth of what you leave behind, after any will you may have made, or debt to be paid; and if a deceased does not leave behind a mother, father or children but has a brother or a sister through a common mother, then to each of them a sixth; and if they (brothers and sisters) are more than two, then they shall all share in a third, after any will that may have been made or debt to be paid, in which the deceased has not caused a loss (to the heirs); this is the decree of Allah; and Allah is All Knowing, Most Forbearing.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dvi{%
These are the limits of Allah; and whoever obeys Allah and His Noble Messenger – Allah will admit him into Gardens beneath which rivers flow – abiding in it forever; and this is the great success.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dvii{%
And whoever disobeys Allah and His Noble Messenger and crosses all His limits – Allah will put him in the fire (of hell), in which he will remain forever; and for him is a disgraceful punishment.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dviii{%
And take testimony from four chosen men amongst you, against the women among you who commit adultery; and if they testify, confine those women in the houses until death takes them away or Allah creates a solution for them.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dix{%
And punish them both, the man and the woman, whoever are guilty of it (adultery); then if they repent and become pious, leave them; indeed Allah is the Most Acceptor Of Repentance, Most Merciful.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dx{%
Undoubtedly the repentance which Allah has by His grace made obligatory upon Himself to accept, is only the repentance of those who commit sin in folly and then soon repent – towards them does Allah incline in mercy; and Allah is the All Knowing, the Wise.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dxi{%
And that repentance is not of those who constantly commit sins, and when death approaches one of them, he says, “I repent now”, nor of those who die as disbelievers; for them, We have kept prepared a painful punishment.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dxii{%
O People who Believe! It is not lawful for you to forcibly become the women’s heirs; and do not restrain women with the intention of taking away a part of bridal money you gave them, unless they openly commit the shameful; and deal kindly with them; and if you do not like them, so it is possible that you dislike a thing in which Allah has placed abundant good.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dxiii{%
And if you wish to change one wife for another and you have given her heaps of treasure, do not take back anything from it; will you take it back by slander and open sin?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dxiv{%
And how will you take it back whereas you have become unveiled before each other, and they have taken a strong pledge from you?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dxv{%
And do not marry the women who were wedded to your fathers (and grand fathers), except what has already passed; that is indeed an act of shame and great wrong; and an evil way.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden for you are your mothers, and your daughters, and your sisters, and your father’s sisters, and your mother’s sisters, and your brothers’ daughters and your sisters’ daughters, and your foster-mothers (who breast-fed you), and their daughters (your foster-sisters), and your wives’ mothers (mothers-in-law), and your wives’ daughters who are under your protection – born of the women with whom you have cohabited; and if you have not cohabited with them, then it is no sin for you to marry their daughters; and (forbidden are) the wives of your own sons (and foster-sons and grandsons) and the keeping of two sisters together in marriage, except what has already passed; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dxvii{%
And all married women are forbidden for you except the wives of disbelievers who come into your possession as bondwomen; this is Allah’s decree for you; and other than these, all women are lawful for you so that you seek them in exchange of your wealth in proper wedlock, not adultery; therefore give the women you wish to marry, their appointed bridal money; and after the appointment (of bridal money) there is no sin on you if you come to a mutual agreement; indeed Allah is All Knowing, Wise.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dxviii{%
And whoever among you does not have in marriage free, believing women due to poverty, should marry from the believing bondwomen you own; and Allah knows well your faith; you are from one another; therefore marry them with the permission of their masters, and give them their bridal money according to custom, they becoming (faithful) wives, not committing mischief or secretly making friends; so when they are married and commit the shameful, for them is half the punishment prescribed for free women; this is for one among you who fears falling into adultery; and to practice patience is better for you; and Allah is Oft Forgiving, Most Merciful.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah wills to explain His commands to you and show you the ways of those before you, and to incline towards you with His mercy; and Allah is All Knowing, Wise.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dxx{%
And Allah wills to incline towards you with His mercy; and those who pursue their own pleasures wish that you be far separated from the Straight Path.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dxxi{%
Allah wills to lessen your burden; and man was created weak.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dxxii{%
O People who Believe! Do not unjustly devour the property of each other, except through trade by mutual agreement; and do not kill one another; indeed Allah is Most Merciful upon you.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dxxiii{%
And whoever does that through injustice and oppression, We shall soon put him in the fire; and this is easy for Allah.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If you keep avoiding the cardinal sins that are forbidden to you, We will forgive you your other (lesser) sins and admit you into a noble place.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dxxv{%
And do not long for things by which Allah has given superiority to some of you over others; for men is the share of what they earn; and for women the share from what they earn; and seek from Allah His munificence; indeed Allah knows everything.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dxxvi{%
And for all, We have appointed heirs – from whatever the parents and near relatives leave behind; and to those with whom you have made an agreement, give them their dues; indeed all things are present before Allah.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are in charge of women, as Allah has made one of them superior to the other, and because men spend their wealth for the women; so virtuous women are the reverent ones, guarding behind their husbands the way Allah has decreed guarding; and the women from whom you fear disobedience, (at first) advise them and (then) do not cohabit with them, and (lastly) beat them; then if they obey you, do not seek to do injustice to them; indeed Allah is Supreme, Great.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dxxviii{%
And if you fear a dispute between husband and wife, send an arbitrator from the man’s family and an arbitrator from the woman’s family; if these two wish conciliation, Allah will unite them; indeed Allah is All Knowing, Well Aware.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dxxix{%
And worship Allah and do not ascribe any partner to Him, and be good to parents, and to relatives, and orphans, and the needy, and the related neighbour and the unrelated neighbour, and the close companion and the traveller; and your bondwomen; indeed Allah does not like any boastful, proud person. –\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dxxx{%
Those who are misers and preach miserliness to others, and hide what Allah has bestowed upon them from His munificence; and We have kept ready a disgraceful punishment for the disbelievers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dxxxi{%
And those who spend their wealth in order for people to see, and do not accept faith in Allah nor the Last Day; and whoever has Satan (the devil) as a companion – so what an evil companion is he!\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dxxxii{%
And what would they lose, if they had believed in Allah and the Last Day and spent from what Allah has bestowed upon them? And Allah knows them very well.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Allah does not commit even the least injustice; and if there is a good deed, He doubles it and gives from Himself a great reward.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
So how will it be when We bring a witness from each nation (religion), and We bring you (O dear Prophet Mohammed – peace and blessings be upon him) as a witness and a watcher over them? (The Holy Prophet is a witness from Allah.)\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dxxxv{%
On that day, those who disbelieved and disobeyed the Noble Messenger will wish that they be buried and the ground levelled above them; and they will not be able to hide anything from Allah.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O People who Believe! Do not approach the prayer when you are intoxicated until you have the sense to understand what you say, nor in the state of impurity until you have bathed except while travelling; and if you are ill or on a journey or one of you returns from answering the call of nature or you have cohabited with women, and you do not find water, then cleanse (yourself) with clean soil – therefore stroke your faces and your hands with it; indeed Allah is Most Pardoning, Oft Forgiving.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Did you not see those who received a portion of the Book, that they purchase error and wish that you too go astray from the right path?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
Allah well knows your enemies; Allah is Sufficient as a Guardian, and Allah is Sufficient as a Supporter.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Some of the Jews interchange the words from their places and say, “We hear and disobey” – and they say “Hear- may you not be able to hear” – and they say “Raena (Be considerate towards us)” distorting it with their tongues and in order to slander religion; had they said, “We hear and we obey” and “Kindly listen to us, O dear Prophet,” and “Look mercifully upon us, O dear Prophet”, it would have been much better for them and more just – but Allah has cursed them for their disbelief; so they do not believe except a little.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dxl{%
O People given the Book(s)! Believe in what We have sent down confirming the Book which you possess, before We transform some faces so turning them towards their backs, or curse them like We had cursed the people of Sabth; and (know that) the Allah’s command is always carried out!\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dxli{%
Undoubtedly Allah does not forgive (the sin of) disbelieving in Him and forgives anything lower than it to whomever He wills; and whoever ascribes partners to Allah has invented a tremendous sin.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dxlii{%
Did you not see those who proclaim their piety (cleanliness of deeds)? In fact Allah purifies whomever He wills, and no injustice, even equal to the hair upon a date seed will be done to them.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dxliii{%
See how they fabricate lies against Allah! And this is a sufficient manifest sin.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dxliv{%
Did you not see those who received a portion of the Book, that they believe in idols and the devil, and say regarding the disbelievers that they are more rightly guided than the Muslims?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dxlv{%
It is they whom Allah has cursed; and for those whom Allah has cursed, you (Prophet Mohammed – peace and blessings be upon him) will never find any supporter.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Do they have some share in the kingship?- if it were, they would not give to mankind even a single sesame.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or do they envy people due to what Allah has given them from His grace? In that case, We bestowed the Book and the wisdom upon the family of Ibrahim (Abraham), and We gave them a great kingdom.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dxlviii{%
So some of them believed in it and some of them turned away from it; and sufficient is hell, a blazing fire!\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dxlix{%
We shall soon put those who disbelieve in Our signs into the fire; whenever their skins are cooked (fully burnt) We shall change them for new skins so they may taste the punishment (again and again); indeed Allah is Almighty, Wise.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dl{%
And those who believed and did good deeds, We shall soon admit them into Gardens beneath which rivers flow – abiding in it forever; in it for them are pure wives – and We shall admit them into places of plentiful shade.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dli{%
Indeed Allah commands you to hand over whatever you hold in trust, to their owners – and that whenever you judge between people, judge with fairness; undoubtedly Allah gives you an excellent advice; indeed Allah is All Hearing, All Seeing.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dlii{%
O People who Believe! Obey Allah and the Noble Messenger and those amongst you who are in authority; so if there is a dispute amongst you concerning any matter, refer it to Allah and the Noble Messenger (for judgement) if you believe in Allah and the Last Day; this is better and has the best outcome.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dliii{%
Did you not see those whose claim is that they believe in what has been sent down on you and what was sent down before you, and they then wish to make the devil their judge, whereas they were ordered to completely reject him? And the devil wishes to mislead them far astray.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dliv{%
And when they are told, “Come towards the Book sent down by Allah and to the Noble Messenger,” you will see that the hypocrites turn their faces away from you.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dlv{%
What will be their state, if some calamity befalls them as a result of what their own hands have sent before them – and then they come to you (O dear Prophet Mohammed – peace and blessings be upon him), swearing by Allah that, “Our goal was only to do good and create harmony"?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dlvi{%
The secrets of their hearts are well known to Allah; so avoid them and explain to them, and speak to them clearly in their affairs.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dlvii{%
And We did not send any Noble Messenger except that he be obeyed by Allah’s command; and if they, when they have wronged their own souls, come humbly to you (O dear Prophet Mohammed – peace and blessings be upon him) and seek forgiveness from Allah, and the Noble Messenger intercedes for them, they will certainly find Allah as the Most Acceptor Of Repentance, the Most Merciful.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dlviii{%
So O dear Prophet (Mohammed – peace and blessings be upon him), by oath of your Lord, they will not be Muslims until they appoint you a judge for the disputes between them – and then whatever you have decided, they should not find opposition to it within their hearts, and they must accept it wholeheartedly.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dlix{%
And had We decreed for them to slay themselves or to leave their homes and families, only a few of them would have done it; and if they did what they are advised to, it would be good for them, and would have strengthened faith.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dlx{%
And were it so, We would bestow upon them a great reward from Ourselves.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dlxi{%
And would certainly guide them to the Straight Path.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dlxii{%
And whoever obeys Allah and His Noble Messenger, will be with those upon whom Allah has bestowed grace – that is, the Prophets and the truthful and the martyrs and the virtuous; and what excellent companions they are!\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dlxiii{%
This is Allah’s munificence; and Allah is Sufficient, the All Knowing.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O People who Believe! Be cautious, then advance towards the enemy in small numbers or all together.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dlxv{%
Indeed among you is one who will certainly loiter behind; then if some disaster were to befall you, he would say, “It was Allah’s grace upon me that I was not present with them!”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dlxvi{%
And were you to receive Allah’s munificence (a bounty), he would surely say – as if there had been no friendship between you and him – “Alas – if only I had been with them, I would have achieved a great success!”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dlxvii{%
So those who sell the life of this world for the Hereafter, must fight in Allah's cause; and We shall bestow a great reward upon whoever fights in Allah's cause, whether he is martyred or is victorious.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dlxviii{%
And what is the matter with you, that you should not fight in Allah’s cause and for the feeble men, and women, and children, who invoke, “Our Lord! Liberate us from this town, the people of which are unjust; and give us a protector from Yourself; and give us a supporter from Yourself.” (Allah has created many supporters for the believers.)\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dlxix{%
The believers fight for Allah’s cause; and the disbelievers fight for the devil’s cause – so fight against the friends of the devil; undoubtedly the devil’s conspiracy is weak.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dlxx{%
Did you not see those to whom it was said, “Restrain your hands, keep the prayer established and pay the charity”; but when fighting was ordained for them, some of them started fearing people, the way they feared Allah – or even greater! And they said, “Our Lord! Why have You ordained fighting for us? If only You would have let us live some more!” Say (O dear Prophet Mohammed – peace and blessings be upon him), “The usage of this world is meagre; and the Hereafter is better for the pious; and you will not be wronged even (the weight of) a single thread.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dlxxi{%
Death will come to you wherever you may be, even if you were in strong fortresses; if some good reaches them they say, “This is from Allah”; and if any misfortune reaches them, they say, “This is from you”; say, “Everything is from Allah”; what is wrong with these people, that they do not seem to understand anything?\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever good reaches you, O listeners, is from Allah, and whatever ill reaches you is from yourselves; and We have sent you (O dear Prophet Mohammed – peace and blessings be upon him) as a Noble Messenger towards all mankind; and Allah is Sufficient, as a Witness.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
Whoever obeys the Noble Messenger has indeed obeyed Allah; and for those who turn away – We have not sent you as their saviour.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
And they say, “We have obeyed”; and when they go away from you, a group of them spend the night conspiring against what they had said; and Allah records what they conspired by night; therefore O dear Prophet (Mohammed – peace and blessings be upon him) avoid them and rely upon Allah; and Allah is Sufficient as a Trustee (of affairs).\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dlxxv{%
So do they not ponder about the Qur’an? And had it been from anyone besides Allah, they would certainly find much contradiction in it.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
And when any news of safety or fear comes to them, they speak of it publicly; and had they referred it to the Noble Messenger and to those among them having authority, those among them who are able to infer would certainly learn the truth of the matter from them; and were it not for Allah’s munificence upon you, and His mercy, all of you would have certainly followed Satan – except a few.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
Therefore O dear Prophet, fight in Allah's cause; you will not be burdened except for yourself, and urge the believers (to fight); it is likely that Allah will curb the strength of the disbelievers; and Allah's strike is most stinging and His punishment the most severe.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whoever makes a noble intercession will have a share of it, and whoever makes an evil intercession will have a share of it; and Allah is Able to do all things.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dlxxix{%
And when you are greeted with some words, greet back with words better than it or with the same; indeed Allah will take account of everything.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dlxxx{%
Allah! There is none worthy of worship except Him; He will surely gather you all on the Day of Resurrection in which there is no doubt; and whose Words are more true than those of Allah? (Allah does not lie.)\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
So what is the matter with you that you got divided into two groups concerning the hypocrites, whereas Allah has inverted them because of their misdeeds? Do you wish to guide one whom Allah has sent astray? And for one whom Allah sends astray, you will not find a way.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They wish that you too should turn disbelievers the way they did, so that you all may become equal – so do not befriend any of them until they forsake their homes and families in Allah’s cause; then if they turn back, seize them and kill them wherever you find them; and do not take any of them as a friend nor as a supporter.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
Except those who are related to the people between whom and you is a treaty, or who come to you with their hearts no longer having the will to fight you or to fight their own people; had Allah willed, He would certainly have given them power over you so that they would have surely fought you; then if they avoid you and do not wage war against you and make an offer of peace – then Allah has not kept for you a way against them.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
You will now find others who desire that they should be safe from you and also safe from their own people; whenever their people turn them towards war, they fall headlong into it; so if they do not avoid (confronting) you nor submit an offer of peace nor restrain their hands, seize them and kill them wherever you find them; and they are the ones against whom We have given you clear authority.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
It is not rightful for a Muslim to kill another Muslim, unless it occurs by mistake; and the one who mistakenly kills a Muslim must set free a Muslim slave and pay blood-money to the family of the slain, except if they forego it; and if the victim is of a people who are hostile to you, and the killer is a Muslim, then only the setting free of a Muslim slave (is obligatory); and if the victim is from a people between whom and you there is a treaty, then blood-money must be paid to his family and the setting free of a Muslim slave; therefore one who has no means must fast for two consecutive months; this is his penance before Allah; and Allah is All Knowing, Wise.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
And whoever slays a Muslim on purpose, his reward will be hell – to remain in it for ages – and Allah has wreaked wrath upon him and has cursed him and kept prepared a terrible punishment for him.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O People who Believe! When you go forth to fight in holy war, make a proper study, and do not say to the one who greets you, “You are not a Muslim,” – you seek the means of this worldly life; so with Allah are the bounties in plenty; you too were like this before, then Allah bestowed His favour on you, therefore you must make a proper study; indeed Allah knows whatever you do.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
The Muslims who stay back from holy war without proper excuse, are not equal to the Muslims who fight in Allah's cause with their wealth and lives; Allah has bestowed higher ranks to the warriors who strive with their wealth and lives, than those who stay back; and Allah has promised good to all; and Allah has favoured the warriors upon those who stay back, with a great reward.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Ranks (of honour) from Him, and forgiveness, and mercy; and Allah is Oft Forgiving, Most Merciful.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dxc{%
The angels ask the people whose souls they remove while they were wronging themselves, “What were you engaged in?” They reply, “We were powerless in the land”; the angels say, “Was Allah’s earth not spacious enough for you to have migrated in it?” The destination for such is hell; and a very wretched place to return.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dxci{%
Except those who were forcibly subdued among men, and the women and children, unable to devise a plan and unaware of the way.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dxcii{%
So for such, it is likely that Allah will pardon them; and Allah is Most Pardoning, Oft Forgiving.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dxciii{%
Whoever migrates for Allah's cause will find much shelter and abundant capacity in the earth; and whoever leaves his home, migrating towards Allah and His Noble Messenger, and death seizes him, his reward then lies entrusted with Allah; and Allah is Oft Forgiving, Most Merciful.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dxciv{%
And when you travel in the land, it is no sin for you to curtail some of your obligatory prayers; if you fear that disbelievers may cause you harm; undoubtedly the disbelievers are open enemies to you.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dxcv{%
And when you (O dear Prophet Mohammed – peace and blessings be upon him) are among them and lead them in prayer, only a group of them should be with you, and they must keep their weapons with them; so when they have performed their prostrations they should move away behind you; and the other group that had not prayed, must come and offer prayers in your leadership, keeping their guard and weapons with them; the disbelievers wish that you neglect your arms and your means so they may overpower you with a single attack; it is no sin for you to lay aside your arms due to rain or if you are sick; and keep your guard; undoubtedly Allah has kept prepared a disgraceful punishment for the disbelievers.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dxcvi{%
So when you have offered your prayers remember Allah while standing, sitting and reclining; and when you feel secure, offer prayers in the usual manner; indeed prayers are a time bound obligatory duty upon the Muslims.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dxcvii{%
Do not relax in pursuit of the disbelievers; if you are suffering, they also suffer as you do; and you expect from Allah what they do not; and Allah is All Knowing, Wise.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dxcviii{%
We have indeed sent down the true Book towards you (O dear Prophet Mohammed – peace and blessings be upon him), so that you may judge between men, in the way Allah may show you; and do not plead on behalf of the treacherous.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dxcix{%
And seek forgiveness from Allah; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dc{%
And do not plead on behalf of those who deceive themselves; indeed Allah does not like any treacherous, excessive sinner.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dci{%
They hide from men and do not hide from Allah, whereas Allah is with them when they plan in their hearts that which displeases Him; and Allah has their deeds encompassed.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcii{%
Pay heed! It is you people who argued on their behalf in the life of this world; so who will fight on their behalf with Allah on the Day of Resurrection, or who will be their pleader?\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dciii{%
And whoever does evil or wrongs his own soul and then seeks forgiveness from Allah, will find Allah Oft Forgiving, Most Merciful.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@dciv{%
And whoever earns sin, his earnings will only be against himself; and Allah is the Knowing, Wise.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@dcv{%
And whoever commits a mistake or a sin, then blames it on someone innocent has indeed burdened himself with infamy and a manifest crime.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@dcvi{%
And O dear Prophet, were it not for Allah’s munificence and His mercy upon you, a group among them would have wished to deceive you; and they only mislead themselves and will not harm you at all; and Allah has sent down upon you the Book and wisdom, and taught you all what you did not know*; and upon you is Allah’s great munificence. (Allah gave the knowledge of the hidden to the Holy Prophet – peace and blessings be upon him.)\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@dcvii{%
Most of their discussions do not contain any good, except of the one who enjoins charity or goodness or peace-making among people; whoever does that to seek the pleasure of Allah – We shall soon give him a great reward.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@dcviii{%
And whoever opposes the Noble Messenger after the right path has been made clear to him, and follows a way other than that of the Muslims, We shall leave him as he is, and put him in hell; and what a wretched place to return!\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@dcix{%
Allah does not forgive (the greatest sin) that partners be ascribed with Him – and He forgives all that is below (lesser sins) it, to whomever He wills; and whoever ascribes partners with Allah has indeed wandered far astray.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@dcx{%
The polytheists do not worship Allah, except some females; and they do not worship anyone except the rebellious Satan.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@dcxi{%
The one whom Allah has cursed; and the devil said, “I swear, I will certainly take an appointed portion of Your bondmen,” –\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@dcxii{%
“And I will surely lead them astray, and I will certainly arouse desires in them, and I will definitely order them so they will pierce animals’ ears, and I will definitely order them so they will alter Allah’s creation”; and whoever chooses the devil for a friend instead of Allah, has indeed suffered a manifest loss.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@dcxiii{%
The devil promises them and arouses desires in them; and the devil does not give them promises except of deceit.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@dcxiv{%
The destination for such is hell; they will not find any refuge from it.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@dcxv{%
And those who believed and did good deeds – We shall soon admit them into Gardens beneath which rivers flow, abiding in them for ever and ever; a true promise from Allah; and whose Words are more true than those of Allah? (Allah does not lie.)\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@dcxvi{%
The affair does not rest on your thoughts, nor the cravings of the People given the Book(s); whoever does wrong will get the recompense of it – and will not find, other than Allah, any friend or any supporter.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@dcxvii{%
And whoever does some good deeds, be it a man or woman, and is a Muslim, will be admitted to Paradise and they will not be wronged even to the extent of one sesame.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And whose religion is better than one who submits his self to Allah and is virtuous and follows the religion of Ibrahim, who was far removed from all falsehood? And Allah made Ibrahim His close friend.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@dcxix{%
And to Allah only belongs all whatever is in the heavens and all whatever is in the earth; and Allah has control over all things.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@dcxx{%
And they ask you the decree concerning women; say, “Allah gives you a decree concerning them – and what is recited to you from the Qur’an concerning orphan girls, that you are not giving them which is ordained for them, and you are avoiding marrying them – and concerning the weak children, and that you must firmly establish justice in dealing with the orphans’ rights; and whatever good deeds you do, then Allah is Well Aware of it.”\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@dcxxi{%
And if a woman fears ill treatment from her husband or disinterest, so it is no sin for them if they reach an agreement of peace between themselves; and peace is better; and the heart is trapped in greed; and if you do good and practice piety, then Allah is Well Aware of it.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@dcxxii{%
And you will never be able to deal equally between women however much you may desire – therefore do not be totally inclined towards one leaving the other in uncertainty; and if you do good and practice piety, then (know that) Allah is Oft Forgiving, Most Merciful.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
And if the two separate, Allah will make each one independent of the other, with His Capability; and Allah is Most Capable, Wise.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
And to Allah only belongs all whatever is in the heavens and all whatever is in the earth; and indeed We have commanded those who received the Books before you, and commanded you, that keep fearing Allah; and if you disbelieve, undoubtedly to Allah only belongs all whatever is in the heavens and all whatever is in the earth; and Allah is Independent, Worthy Of All Praise.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@dcxxv{%
And to Allah only belongs all whatever is in the heavens and all whatever is in the earth; and Allah is Sufficient as a Trustee (of affairs).\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
O people! He can remove you and bring others, if He wills; and Allah is Able to do that.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whoever desires the reward of this world, then with Allah only lie both – the rewards of this world and of the Hereafter; and Allah is All Hearing, All Seeing.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O People who Believe! Be firm in establishing justice, giving witness for Allah, even if it is harmful to yourselves or parents or relatives; whether the one you testify against is wealthy or poor, for in any case Allah has the greater right over it; then do not follow your wishes for you may stray from the truth; and if you distort testimony or turn away, then Allah is Well Aware of your deeds.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O People who Believe! Have faith in Allah and His Noble Messenger and the Book He has sent down upon this Noble Messenger of His, and the Book He sent down before; and whoever does not accept faith in Allah and His angels and His Books and His Noble Messengers and the Last Day, has undoubtedly wandered far astray.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Indeed those who believe, then disbelieve and then again believe, then again disbelieve, and go further in their disbelief – Allah will never forgive them, nor ever guide them to the path.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Give glad tidings to the hypocrites, that for them is a painful punishment.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who leave the Muslims to befriend the disbelievers; do they seek honour from them? Then (know that) undoubtedly all honour is for Allah.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
And indeed Allah has sent down to you in the Book that whenever you hear the signs of Allah being rejected or being made fun of, do not sit with those people, until they engage in some other conversation; or else you too are like them; undoubtedly Allah will gather the hypocrites and the disbelievers, all together, into hell.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
Those who keep watching your circumstances; so if a victory comes to you from Allah, they say, “Were we not with you?”; and if victory is for disbelievers, they say, “Did we not have control over you, and protect you from the Muslims?” Allah will judge between you all on the Day of Resurrection; and Allah will not provide the disbelievers any way over the Muslims.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
Undoubtedly the hypocrites, in their fancy, seek to deceive Allah whereas He will extinguish them while making them oblivious; and when they stand up for prayer, they do it unwillingly and for others to see, and they do not remember Allah except a little.\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
Fluctuating in the middle; neither here (in faith) nor there (in disbelief); and for one whom Allah sends astray, you will not find a way.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O People who Believe! Do not befriend disbelievers in place of Muslims; do you wish to give Allah a clear proof against you?\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
Undoubtedly the hypocrites are in the deepest segment of hell; and you will never find any supporter for them.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
Except those who repented and reformed themselves and held fast to Allah’s rope and made their religion sincerely only for Allah – so they are with the Muslims; and Allah will soon bestow upon the believers a great reward.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@dcxl{%
And what will Allah gain by punishing you, if you acknowledge the truth and accept faith? And Allah is Most Appreciative, All Knowing.\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah does not like disclosure of evil matters except by the oppressed; and Allah is All Hearing, All Knowing.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@dcxlii{%
If you do any good openly or in secret, or pardon someone’s evil – then indeed Allah is Oft Forgiving, Able.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Those who disbelieve in Allah and His Noble Messengers, and seek to cause division between Allah and His Noble Messengers, and say, “We believe in some and disbelieve in others,” and wish to choose a way between faith and disbelief; –\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@dcxliv{%
These are the real disbelievers; and for the disbelievers We have kept prepared a disgraceful punishment.\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@dcxlv{%
And those who believe in Allah and all His Noble Messengers and do not make any distinction in belief between any of them – to them Allah will soon give them their reward; and Allah is Oft Forgiving, Most Merciful.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
O dear Prophet (Mohammed – peace and blessings be upon him) the People given the Book(s) ask you, to cause a Book to be sent down on them from heaven – so they had asked something even greater from Moosa, for they said, “Show Allah to us, clearly” – so the thunder seized them on account of their sins; then they chose the calf (for worship) after clear signs had come to them, then We forgave this; and We bestowed Moosa with a clear dominance.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
We then raised the mount (Sinai) above them to take a covenant from them and decreed them that, “Enter the gate while prostrating” and decreed them that, “Do not cross the limits of the Sabbath,” and We took from them a firm covenant.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
So Allah cursed them because of their constantly breaking their covenant – and they disbelieved in the signs of Allah, and they used to wrongfully martyr the Prophets, and because they said, “Our hearts are covered”; in fact Allah has set a seal upon their hearts due to their disbelief, so that they do not accept faith, except a few.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@dcxlix{%
And because they disbelieved and slandered Maryam with a tremendous accusation.\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@dcl{%
And because they said, “We have killed the Messiah, Eisa the son of Maryam, the Messenger of Allah”; they did not slay him nor did they crucify him, but a look-alike was created for them; and those who disagree concerning it are in doubt about it; they know nothing of it, except the following of assumptions; and without doubt, they did not kill him.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@dcli{%
In fact Allah raised him towards Himself; and Allah is Almighty, Wise.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@dclii{%
There is not one of the People given the Book(s), who will not believe in him (Eisa) before his death; and on the Day of Resurrection he will be a witness against them.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@dcliii{%
So due to the great injustices committed by the Jews, We forbade them some of the good things which were earlier lawful for them, and because they prevented many people from Allah’s way.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@dcliv{%
And because they used to take usury whereas they were forbidden from it, and they used to wrongfully devour people’s wealth; and for the disbelievers among them, We have kept prepared a painful punishment.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@dclv{%
But those among them who are firm in knowledge and who have faith, believe in what is sent down upon you (O dear Prophet Mohammed – peace and blessings be upon him), and what was sent down before you, and those who keep the prayer established and those who pay the charity, and those who believe in Allah and the Last Day; to such, We shall soon bestow a great reward.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@dclvi{%
Indeed We sent a divine revelation to you (Prophet Mohammed – peace and blessing be upon him) as We did send divine revelations to Nooh (Noah) and the Prophets after him; and We sent divine revelations to Ibrahim (Abraham) and Ismael (Ishmael) and Ishaq (Isaac) and Yaqub (Jacob) and their offspring, and Eisa (Jesus) and Ayyub (Job) and Yunus (Jonah) and Haroon (Aaron) and Sulaiman (Solomon), and We bestowed the Zaboor (the Holy Book) upon Dawud (David).\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@dclvii{%
And to the Noble Messengers whom We have mentioned to you before, and to the Noble Messengers We have not mentioned to you; and Allah really did speak to Moosa.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@dclviii{%
Noble Messengers giving glad tidings and declaring warnings, in order that people may not have any argument against Allah, after the (advent of) Noble Messengers; and Allah is Almighty, Wise.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@dclix{%
But Allah is the Witness of what He has sent down upon you – He has sent it down by His knowledge; and the angels are witnesses; and sufficient is Allah’s testimony.\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@dclx{%
Indeed those who disbelieved and prevented (others) from the way of Allah, have undoubtedly wandered far astray.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@dclxi{%
Indeed those who disbelieved and crossed the limits – Allah will never forgive them, nor guide them to a way.\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@dclxii{%
Except the path of hell, in which they will remain for ever and ever; and that is easy for Allah.\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O mankind! This Noble Messenger (Prophet Mohammed – peace and blessings be upon him) has come to you with the truth from your Lord, so accept faith for your own good; and if you disbelieve, then undoubtedly to Allah only belongs all whatever is in the heavens and in the earth; and Allah is All Knowing, Wise.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@dclxiv{%
O People given the Book(s)! Do not exaggerate in your religion nor say anything concerning Allah, but the truth; the Messiah, Eisa the son of Maryam, is purely a Noble Messenger of Allah, and His Word; which He sent towards Maryam, and a Spirit from Him; so believe in Allah and His Noble Messengers; and do not say “Three”; desist, for your own good; undoubtedly Allah is the only One God; Purity is to Him from begetting a child; to Him only belongs all whatever is in the heavens and all whatever is in the earth; and Allah is a Sufficient Trustee (of affairs).\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@dclxv{%
The Messiah does not at all hate being a bondman of Allah, and nor do the close angels; and whoever hates worshipping Him and is conceited – so very soon He will gather them all towards Him.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@dclxvi{%
Then to those who believed and did good deeds, He will pay their wages in full and by His munificence, give them more; and to those who hated (worshipping Him) and were proud, He will inflict a painful punishment; and they will not find for themselves, other than Allah, any supporter nor any aide.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O mankind! Indeed the clear proof from your Lord has come to you, and We have sent down to you a bright light. (The Holy Prophet is a Clear Proof from Allah.)\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@dclxviii{%
So those who believed in Allah and held fast to His rope – He will admit them into His mercy and munificence, and will guide them on the Straight Path towards Himself.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@dclxix{%
O dear Prophet (Mohammed – peace and blessings be upon him), they ask you for a decree; say, “Allah decrees you concerning the solitary person (without parents or children); if a man dies childless and has a sister, for her is half the inheritance; and the man is his sister’s heir if the sister dies childless; and if there are two sisters, for them is two-thirds of the inheritance; so if there are brothers and sisters, both men and women, the male’s share is equal to that of two females; and Allah explains clearly to you, so that you do not go astray; and Allah knows all things.”\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O People who Believe! Fulfil your words (agreements); the mute animals are made lawful for you (to eat) except what will be declared to you after this, but do not assume hunting as lawful when you are on the pilgrimage; indeed Allah commands whatever He wills.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O People who Believe! Do not make lawful the symbols of Allah nor the sacred months nor the sacrificial animals sent to Sacred Territory (around Mecca) nor the animals marked with garlands, nor the lives and wealth of those travelling towards the Sacred House (Kaa’bah) seeking the munificence and pleasure of their Lord; and when you have completed the pilgrimage, you may hunt; and let not the enmity of the people who had stopped you from going to the Sacred Mosque tempt you to do injustice; and help one another in righteousness and piety – and do not help one another in sin and injustice – and keep fearing Allah; indeed Allah’s punishment is severe.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Forbidden for you are carrion, and blood, and flesh of swine, and that which has been slaughtered while proclaiming the name of any other than Allah, and one killed by strangling, and one killed with blunt weapons, and one which died by falling, and that which was gored by the horns of some animal, and one eaten by a wild beast, except those whom you slaughter; and (also forbidden is) that which is slaughtered at the altar (of idols) and that which is distributed by the throwing of arrows (as an omen); this is an act of sin; this day, the disbelievers are in despair concerning your religion, so do not fear them and fear Me; this day have I perfected your religion for you* and completed My favour upon you, and have chosen Islam as your religion; so whoever is forced by intense hunger and thirst and does not incline towards sin, then indeed Allah is Oft Forgiving, Most Merciful. (*Prophet Mohammed – peace and blessings be upon him – is the Last Prophet.)\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask you (O dear Prophet Mohammed – peace and blessings be upon him) what is made lawful for them; say, “Pure things are made lawful for you, and the beasts (and birds) of prey which you have trained and use for hunting, (and) you teach them what Allah has taught you; so eat what they kill and leave for you, and mention Allah’s name upon it – and keep fearing Allah; indeed Allah is Swift At Taking Account.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
This day the pure things are made lawful for you; and the food of the People given the Book(s) is lawful for you – and your food is lawful for them – and likewise are the virtuous Muslim women and the virtuous women from the people who received the Book(s) before you when you give them their bridal money – marrying them, not committing adultery nor as mistresses; and whoever turns a disbeliever after being a Muslim, all his deeds are wasted and he will be among the losers in the Hereafter.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O People who Believe! When you wish to stand up for prayer, wash your faces, and your hands up to the elbows, and pass wet palms over your heads and wash your feet up to the ankles; and if you need a bath, clean yourselves thoroughly; and if you are sick or on a journey, or one of you returns from answering the call of nature, or you have cohabited with women, and you do not find water, then cleanse (yourself) with clean soil – therefore stroke your soiled palms over your faces and your hands with it; Allah does not will to place you in hardship, but He wills to fully purify you and complete His favour upon you, so that you may be grateful.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
And remember Allah’s favour upon you and the covenant He took from you when you said, “We hear and we obey” – and fear Allah; indeed Allah knows what lies within the hearts.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O People who Believe! Firmly establish the commands of Allah, giving testimony with justice – and do not let the enmity of anyone tempt you not to do justice; be just; that is nearer to piety – and fear Allah; indeed Allah is Well Aware of your deeds.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
It is Allah’s promise to those who believe and are righteous, that for them will be forgiveness and a great reward.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@dclxxix{%
And those who disbelieve and deny Our signs – it is they who are the people of hell.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O People who Believe! Remember Allah’s favour upon you, when a people wished to extend their hands against you, so He restrained their hands from you; and keep fearing Allah; and Muslims must rely only upon Allah.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
Undoubtedly Allah made a covenant with the Descendants of Israel, and We appointed twelve chiefs among them; and Allah said, “Indeed I am with you; surely, if you establish the prayer and pay the charity, and believe in My Noble Messengers and respect* them, and lend an excellent loan to Allah, I will surely forgive your sins, and I will surely admit you into Gardens beneath which rivers flow; then after this, if any of you disbelieves, he has certainly gone astray from the Straight Path." (To honour the Holy Prophet – peace and blessings be upon him – is part of faith. To disrespect him is blasphemy.)\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
So We cursed them because of them constantly breaking their covenant, and hardened their hearts; they shift the Words of Allah from their places, and have forgotten a large portion of the advices that were given to them; and you will constantly learn of deceits from them, except a few; so forgive them and excuse them; indeed Allah loves the virtuous.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
And We made a covenant with those who proclaimed, “We are Christians” – they then forgot a large portion of the advices given to them; We have therefore instilled enmity and hatred between them till the Day of Resurrection; and Allah will soon inform them of what they were doing.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
O People given the Book(s)! Indeed this Noble Messenger (Prophet Mohammed – peace and blessings be upon him) of Ours has come to you, revealing to you a lot of the things which you had hidden in the Book, and forgiving a lot of them; indeed towards you has come a light* from Allah, and a clear Book. (* The Holy Prophet is a light from Allah).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
With it, Allah guides whoever obeys the will of Allah to the paths of peace, and takes them out of darkness towards light by His command, and guides them to the Straight Path.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
They have indeed become disbelievers who say, “Messiah, the son of Maryam is certainly Allah”; say, “Who can then do anything against Allah, if He wills to destroy the Messiah, the son of Maryam, and his mother and everyone on earth?” And for Allah only is the kingship of the heavens and the earth and all that is between them; He creates whatever He wills; and Allah is Able to do all things.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
The Jews and the Christians said, “We are the sons of Allah and His beloved ones”; say, “Why does He then punish you for your sins? In fact you are human beings, part of His creation; He forgives whomever He wills, and punishes whomever He wills; and for Allah only is the kingship of the heavens and the earth and all that is between them – and towards Him is the return.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
O People given the Book(s)! Indeed this Noble Messenger (Prophet Mohammed – peace and blessings be upon him) of Ours has come to you, revealing to you Our commands, after the Noble Messengers had stopped arriving for ages, for you might claim, “Never did any Harbinger of Glad Tidings or Herald of Warning come to us” – so this Harbinger of Glad Tidings and Herald of Warning has come to you; and Allah is Able to do all things.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
And when Moosa said to his people, “O my people! Remember Allah’s favour upon you, that He created Prophets among you, and made you kings, and has now given you what He has not given to any one else in this world.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dcxc{%
“O my people! Enter the holy land which Allah has decreed for you and do not turn back, for you will turn back as losers.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said, “O Moosa! In it lives a very strong nation – and we shall never enter it, until they have gone away from there; so when they have gone away from there, we will enter it.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dcxcii{%
So two men who were among those who feared Allah and whom Allah had favoured said, “Enter upon them by force, through the gate; if you enter the gate, victory will be yours; and depend only upon Allah, if you have faith.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said, “O Moosa! We will never enter it whilst they are there, so you and your Lord go and fight – we shall remain seated here.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dcxciv{%
Said Moosa, “My Lord! I have no control except over myself and my brother, so keep us separated from the disobedient nation.” (Do not count us among them).\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dcxcv{%
Said Allah, “The (holy) land is therefore forbidden for them for forty years; they will wander in the earth; so do not grieve for these disobedient people.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
And recite to them the true tale of the two sons of Adam; when both of them offered a sacrifice each – hence the sacrifice of one was accepted and not accepted from the other; he (the other) said, “I swear I will kill you”; he answered, “Allah accepts only from the pious.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
“Indeed, if you do extend your hand against me to kill me, I will not extend my hand against you to kill you; I fear Allah, the Lord Of The Creation.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
“I only desire that you alone should bear my sin and your own sin – hence you become of the people of hell; and that is the proper punishment of the unjust.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dcxcix{%
So his soul incited him to kill his brother – he therefore killed him, and was therefore ruined.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dcc{%
So Allah sent a crow scratching the ground, to show him how to hide his brother’s corpse; he said, “Woe to me! I was not even capable enough to be like this crow, so I would hide my brother’s corpse”; and he turned remorseful.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dcci{%
For this reason; We decreed for the Descendants of Israel that whoever kills a human being except in lieu of killing or causing turmoil in the earth, so it shall be as if he had killed all mankind; and whoever saves the life of one person, is as if he had saved the life of all mankind; and undoubtedly Our Noble Messengers came to them with clear proofs – then after this indeed many of them are oppressors in the earth.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dccii{%
The only reward of those who make war upon Allah and His Noble Messenger and cause turmoil in the land is that they be all be killed or crucified, or their hands and feet cut off from alternate sides, or they be banished far away from the land; this is their degradation in the world, and for them in the Hereafter is a great punishment.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dcciii{%
Except those who repent before you apprehend them; so know well that Allah is Oft Forgiving, Most Merciful.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dcciv{%
O People who Believe! Fear Allah, and seek the means towards Him, and strive in His cause, in the hope of attaining success.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dccv{%
Indeed if the disbelievers owned all that is in the earth and a similar one in addition to it, and they offered it as a ransom to save themselves from the punishment of the Day of Resurrection, it would not be accepted from them; and for them is a painful punishment.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will wish to come out of hell, and will not come out of it – and for them is an unending punishment.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dccvii{%
And cut off the hands of those men or women who are thieves – a recompense of their deeds, a punishment from Allah; and Allah is Almighty, Wise.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dccviii{%
So if one repents after his wrongdoing and reforms himself, Allah will incline towards him with His mercy; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dccix{%
Do you not know that to Allah only belongs the kingship of the heavens and the earth? He punishes whomever He wills, and forgives whomever He wills; and Allah is Able to do all things.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dccx{%
O Noble Messenger (Prophet Mohammed – peace and blessings be upon him)! Do not let yourself be aggrieved by the people who rush towards disbelief – those who say with their mouths, “We believe” but whose hearts are not Muslims; and some Jews; they listen a great deal to falsehood, and to other people who do not come to you; shifting Allah’s Words from their correct places; and say, “If this command is given to you, obey it, but if this is not given to you, then refrain”; and the one whom Allah wills to send astray, you will never be able to help him in the least against Allah; they are those whose hearts Allah did not will to cleanse; for them is disgrace in this world, and for them is a great punishment in the Hereafter.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dccxi{%
The excessively eager listeners of falsehood, extreme devourers of the forbidden; so if they come humbly to you (Prophet Mohammed – peace and blessings be upon him), judge between them or shun them; and if you turn away from them they cannot harm you at all; and if you do judge between them, judge with fairness; indeed Allah loves the equitable.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dccxii{%
And why should they wish to be judged by you, when they have the Taurat with them, in which exist the commands of Allah and yet they turn away from it? And they will not accept faith.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dccxiii{%
Undoubtedly We sent down the Taurat, in which is guidance and light; the Jews were commanded according to it by Our obedient Prophets, and the rabbis and the religious jurists for they were commanded to protect Allah’s Book, and were witnesses to it; so do not fear men, and fear Me, and do not exchange My verses for an abject price; and whoever does not judge according to what is sent down by Allah – it is they who are disbelievers.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And in the Taurat, We made it obligatory upon them that, “A life (is the retribution) for a life, and an eye for an eye, and a nose for a nose, and an ear for an ear, and a tooth for a tooth, and for wounds is a retribution”; then whoever willingly agrees to retribution, it shall redeem him of his sin; and whoever does not judge according to what is sent down by Allah – it is they who are the unjust.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dccxv{%
And We brought Eisa the son of Maryam, following the footsteps of those Prophets, confirming the Taurat which preceded him – and We bestowed upon him the Injeel (Bible) in which is guidance and light, and confirms the Taurat which preceded it, and a guidance and an advice to the pious.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dccxvi{%
And the People of Injeel must judge by what Allah has sent down in it; and whoever does not judge according to what is sent down by Allah – it is they who are the sinners.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And O dear Prophet (Mohammed – peace and blessings be upon him) We have sent down the true Book upon you, confirming the Books preceding it, and a protector and witness over them – therefore judge between them according to what is sent down by Allah, and O listener, do not follow their desires, abandoning the truth which has come to you; We have appointed for you all, a separate (religious) law and a way; and had Allah willed He could have made you one nation, but the purpose (His will) is to test you by what He has given you, therefore seek to surpass one another in good deeds; towards Allah only you will all return, so He will inform you concerning the matter in which you disputed.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And therefore, O Muslims, judge between them according to what is sent down by Allah, and do not follow their desires, and be cautious of them so that they may not divert you from some commands which have been sent down to you; then if they turn away, know that Allah’s will is to punish them for some of their sins; and indeed many men are disobedient.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dccxix{%
So do they wish a judgement of ignorance? And whose judgement is better than that of Allah, for the people who are certain?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dccxx{%
O People who Believe! Do not make the Jews and the Christians your friends; they are friends of one another; and whoever among you befriends them, is one of them; indeed Allah does not guide the unjust.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dccxxi{%
You will now see those in whose hearts is a disease, that they rush towards the Jews and the Christians, saying, “We fear that a misfortune will possibly befall us”; so it is likely that Allah may soon bring victory, or a command from Himself, so they will remain regretting what they had hidden in their hearts.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dccxxii{%
And the believers say, “Are these the ones who swore by Allah most vehemently in their oaths, that they are with you?” All their deeds are destroyed, so they are ruined.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O People who Believe! Whoever among you reneges from his religion, so Allah will soon bring a people who are His beloved ones and Allah is their beloved, lenient with the Muslims and stern towards disbelievers – they will strive in Allah’s cause, and not fear the criticism of any accuser; this is Allah’s munificence, He may give to whomever He wills; and Allah is the Most Capable, the All Knowing.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
You do not have any friends except Allah and His Noble Messenger and the believers who establish the prayer and pay the charity, and are bowed down before Allah.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dccxxv{%
And whoever takes Allah and His Noble Messenger and the Muslims as friends – so undoubtedly only the party of Allah is victorious.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O People who Believe! Those who have made your religion a mockery and a sport, and those who received the Book before you, and the disbelievers – do not befriend any of them; and keep fearing Allah, if you have faith.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
And when you call to prayer, they mock and make fun of it; this is because they are people without any sense.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say, “O People given the Book(s)! What do you dislike in us – except that we believe in Allah and what is sent down to us and what was sent down before, and because most of you are disobedient?”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say, “Shall I tell you of those who are in a worse position than this, in Allah’s sight? It is those whom Allah has cursed and has wreaked His wrath upon and turned some of them into apes and swine, and worshippers of the devil; theirs is a worse destination and they have wandered further astray from the Straight Path.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dccxxx{%
And when they come to you, they say, “We are Muslims” whereas they were disbelievers when they came in, and disbelievers when they went out; and Allah knows very well, what they hide.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
And you will see many of them rushing towards sin and oppression, and to devour the forbidden; undoubtedly what they do is extremely evil.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why do not their priests and monks forbid them from speaking evil and devouring the forbidden? Undoubtedly what they do is extremely evil.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
And the Jews said, “Allah’s hand is tied"; may their hands be tied – and they are accursed for saying so! In fact, both His hands* are free, He bestows upon whomever He wills; and O dear Prophet, this Book which has been sent down upon you from your Lord will cause many of them to advance in their rebellion and disbelief; and We have instilled enmity and hatred between them till the Day of Resurrection; whenever they ignite the flame of war, Allah extinguishes it, and they strive to create chaos in the land; and Allah does not love the mischievous. (* This is a metaphor used to express Allah’s power).\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
If the People given the Book(s) had accepted faith and been pious, We would have certainly redeemed them of their sins and would have certainly taken them into serene Gardens.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
And had they kept the Taurat and the Injeel established, and what was sent down towards them from their Lord, they would have received sustenance from above and from beneath their feet; among them is a group who is fair; but most of them commit extremely evil deeds.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Noble Messenger (Prophet Mohammed – peace and blessings be upon him)! Convey all what has been sent down upon you from your Lord; and if you do not, then you have not conveyed any of His messages; and Allah will protect you from the people; indeed Allah does not guide the disbelievers.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say, “O People given the Book(s)! You are nothing until you establish the Taurat and the Injeel, and what was sent down towards you from your Lord”; and this Book which has been sent down upon you from your Lord will cause many of them to advance in their rebellion and disbelief; so do not at all grieve for the disbelievers.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Indeed those who call themselves Muslims – and similarly among the Jews, and the Sabeans, and the Christians* – whoever sincerely accepts faith in Allah and the Last Day, and does good deeds – so there shall be no fear upon them nor shall they grieve. (Whoever among them converts to Islam).\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
We made a covenant with the Descendants of Israel and sent Noble Messengers towards them; whenever a Noble Messenger came to them with whatever was not according to their own desires, they denied some of them and some they slew.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dccxl{%
And they assumed that there will be no punishment, so they turned blind and deaf – then Allah accepted their penance, then again many of them turned blind and deaf; and Allah is seeing their deeds.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dccxli{%
They are certainly disbelievers who say, “Allah is actually the Messiah, the son of Maryam”; whereas the Messiah had said, “O Descendants of Israel, worship Allah Who is my Lord and (also) your Lord”; undoubtedly whoever ascribes partners with Allah, then Allah has forbidden Paradise for him; his destination is hell; and the unjust do not have any supporters.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dccxlii{%
They are certainly disbelievers who say, “Indeed Allah is the third of the three Gods”; whereas there is no God except the One God; and if they do not desist from their speech, undoubtedly a painful punishment will reach those among them who die as disbelievers.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dccxliii{%
So why do they not incline towards Allah and seek His forgiveness? And Allah is Oft Forgiving, Most Merciful.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah, the son of Maryam, is purely a Noble Messenger; many Noble Messengers have passed before him; and his mother is a truthful woman; they both used to eat food; see how We make the signs clear for them, and see how they turn away!\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “What! You worship, other than Allah, that which is neither the controller of your losses nor of your benefits? And Allah only is the All Hearing, the All Knowing.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say, “O People given the Book(s)! Do not wrongfully commit injustice in your religion, and do not follow the people who earlier went astray, and led many others astray, and wandered away from the Straight Path.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Those among the Descendants of Israel who turned disbelievers were cursed by the tongue of Dawud, and of Eisa the son of Maryam; it was because of their disobedience and their rebellion.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They did not restrain one another from the evil they used to do; undoubtedly they used to commit extremely evil deeds.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dccxlix{%
You will see that many of them make friends with the disbelievers; what an evil thing they had sent ahead for themselves, for Allah’s wrath came upon them and they will remain in the punishment, forever.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dccl{%
Had they believed in Allah and this Prophet (Mohammed – peace and blessings be upon him) and what is sent down upon him, they would not befriend the disbelievers, but most of them are disobedient.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dccli{%
You will certainly find the Jews and the polytheists as the greatest enemies of the Muslims; and you will find the closest in friendship to the Muslims those who said, “We are Christians”; that is because scholars and monks are among them, and they are not proud.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dcclii{%
And when they listen to what has been sent down to the Noble Messenger (Prophet Mohammed – peace and blessings be upon him), you observe their eyes overflowing with tears because they have recognised the truth; they say, “Our Lord, we have accepted faith – therefore record us among the witnesses of the truth.”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dccliii{%
“And what is the matter with us, that we should not believe in Allah and this truth which has come to us? And we hope that our Lord will admit us along with the righteous.”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dccliv{%
So because of their saying, Allah bestowed them with Gardens beneath which rivers flow, in which they will abide forever; and this is the reward of the virtuous.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dcclv{%
And those who disbelieved and denied Our signs, are the people of hell.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O People who Believe! Do not forbid the pure things, which Allah has made lawful for you, and do not cross the limits; indeed Allah dislikes the transgressors.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dcclvii{%
Eat of the sustenance which Allah has given you, the lawful and the pure – and fear Allah in Whom you believe.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah does not take you to task for oaths which are made unintentionally but He does take you to task for oaths which you ratify; so the redemption of such oaths is to provide food to ten needy persons equal to the average of what you feed your family, or to clothe them, or to free one slave; and for one who has no means, is the fasting for three days; this is the redemption of your oaths when you have sworn; and fulfil your oaths; this is how Allah explains His verses to you, so that you may be thankful.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dcclix{%
O People who Believe! Wine (all intoxicants), and gambling, and idols, and the darts are impure – the works of Satan, therefore keep avoiding them so that you may succeed.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dcclx{%
The devil only seeks to instil hatred and enmity between you with wine and gambling, and to prevent you from the remembrance of Allah and from prayer; so have you desisted?\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dcclxi{%
And obey Allah and obey the Noble Messenger, and be cautious; then if you turn away, so know that the duty of Our Noble Messenger is only to plainly convey the message.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dcclxii{%
Upon those who accepted faith and did good deeds, there shall be no sin for whatever they have consumed in the past, provided they fear and continue to believe and do good deeds, then again fear and continue to believe, and then again fear and remain virtuous; and Allah loves the virtuous.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O People who Believe! Allah will surely test you with some prey that is within reach of your hands and your spears, so that Allah may make known those who fear Him without seeing; so henceforth, a painful punishment is for anyone who transgresses.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O People who Believe! Do not kill prey while you are on the pilgrimage; and whoever among you kills it intentionally, so its recompense is that he shall give a similar domestic animal (for sacrifice), two honest men among you rendering the command, the sacrifice being brought to the Kaa’bah – or he gives as redemption, food for some needy persons, or fasts for the same number of days, so that he may taste the consequences of his deed; Allah has forgiven what has passed; and henceforth whoever does it, Allah will take recompense from him; and Allah is Almighty, Avenger.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dcclxv{%
It is lawful for you to hunt from the sea and to eat from it, for your benefit and that of the travellers; and hunting on land is forbidden for you while you are on the pilgrimage; and fear Allah, towards Whom you will arise.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah has made the Kaa’bah, the respected house, a cause for peoples survival, and the Sacred Month, and the sacrifices in the holy land, and the garlanded animals; this is so that you may be convinced that Allah knows all whatever is in the heavens and all whatever is in the earth, and that Allah is the All Knowing.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know well that Allah’s punishment is severe, and that Allah is Oft Forgiving, Most Merciful.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
There is no duty upon the Noble Messenger except to convey the command; and Allah knows all what you disclose and all what you hide.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say, “The impure (evil) and the pure (good) are not equal, even though the abundance of the impure may attract you; therefore keep fearing Allah, O men of intellect, so that you may succeed.”\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O People who Believe! Do not ask about matters which, if disclosed to you, would be disliked by you; and if you ask about them while the Qur’an is being sent down, they will be disclosed to you; Allah has forgiven these; and Allah is Oft Forgiving, Most Forbearing.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
A nation before you asked about such matters and then disbelieved in them.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
Allah has not appointed (commanded to sacrifice) the camel with ears sliced (Bahira) or the she-camel (Saibah) or the she-goat (Wasilah) or the breeding camel (Hami), but the disbelievers fabricate lies against Allah; and most of them do not have any sense at all.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
And when it is said to them, “Come towards what Allah has sent down and towards the Noble Messenger”, they say, “Sufficient for us is what we found our forefathers upon”; even if their forefathers did not have knowledge nor had guidance?\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O People who Believe! Fear for your own souls; he who has strayed cannot harm you in the least if you are on guidance; towards Allah only you will all return – He will then inform you of what you used to do.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O People who Believe! The witnesses between you when death approaches any one of you, at the time of making a will, should be two reliable men from among you, or two from another tribe in case you are travelling in the land and the event of death approaches you; engage them after the prayers, and if you doubt, they must swear by Allah that, “We shall not exchange our oaths for any price even if he is a near relative, nor will we hide the testimony of Allah – if we do, then surely we are of the sinners.”\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
Then if it is later known that both of them committed sin, two others may take their place, from those who were caused the most harm by the false testimony, and they must swear by Allah that, “Our testimony is more accurate than the testimony of these two, and we have not exceeded the limits – if we do, then surely we shall be of the unjust.”\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
This is more suitable than their bearing testimony as they wish or fear that some oaths may be made void, after their taking oath; so fear Allah and heed the commands; and Allah does not guide the disobedient.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
On the day when Allah will gather all the Noble Messengers, and then say, “What response did you get?” They will submit, “We do not have any knowledge; indeed it is only You, Who knows all the hidden.”\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
When Allah will say, “O Eisa, the son of Maryam! Remember My favour upon you and your mother; when I supported you with the Holy Spirit; you were speaking to people from the cradle and in maturity; and when I taught you the Book and wisdom and the Taurat and the Injeel; and when you used to mould a birdlike sculpture from clay, by My command, and blow into it – so it (the living bird) used to fly by My command, and you used to cure him who was born blind and cure the leper, by My command; and when you used to raise up the dead, by My command; and when I restrained the Descendants of Israel against you when you came to them with clear proofs, and the disbelievers among them said, ‘This is nothing but clear magic’.”\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
“And when I inspired into the hearts of the disciples that, ‘Believe in Me and in My Noble Messenger’; they said, ‘We accept faith, and be witness that we are Muslims.’”\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
When the disciples said, “O Eisa, the son of Maryam! Will your Lord send down a table spread (with food) for us from heaven?” He said, “Fear Allah, if you are believers.”\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said, “We wish to eat from it and so that our hearts be convinced and to see that you have spoken the truth to us, and that we may be witnesses upon it.”\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
Eisa, the son of Maryam, said, “O Allah, O our Lord! Send down to us a table spread from heaven, so that it may become a day of celebration for us – for our former and latter people – and a sign from You; and give us sustenance – and You are the Best Provider Of Sustenance.”\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Said Allah, “Indeed I shall send it down to you; so thereafter whoever disbelieves amongst you – I will surely mete out to him a punishment with which I shall not punish anyone else in the whole world.”\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And when Allah will say, “O Eisa, the son of Maryam! Did you say to the people, ‘Appoint me and my mother as two Gods, besides Allah’?” He will submit, “Purity is to You! It is not proper for me to say something for which I do not have a right; if I have said it, then surely You know it; You know what lies in my heart, and I do not know what is in Your knowledge; indeed You only know all the hidden.”\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
“I have not told them except what You commanded me, that ‘Worship Allah, Who is my Lord and is also your Lord’; I was aware of them till I was among them; and when You raised me, only You watched over them; and all things are present before You.”\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
“If you punish them, then indeed they are Your slaves; and if you forgive them, then indeed You only are the Almighty, the Wise.”\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Proclaimed Allah, “This is a day on which the truthful will benefit from their truthfulness; for them are Gardens beneath which rivers flow, in which they will abide for ever and ever; Allah is pleased with them and they are pleased with Allah; this is the greatest success.”\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To Allah only belongs the kingship of the heavens and the earth and all that is in them: and He is Able to do all things.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen All praise is to Allah, Who has created the heavens and the earth, and has created darkness and light; yet the disbelievers appoint equals (false deities) to their Lord!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@dccxci{%
It is He Who has created you from clay, and then decreed a term for you; and it is a fixed promise before Him, yet you still doubt!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@dccxcii{%
And He is Allah (the God) of the heavens and in the earth; He knows all, your secrets and your disclosures, and He knows your deeds.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@dccxciii{%
And never does a sign come to them from among the signs of Allah, except that they* turn away from it. (* The disbelievers)\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@dccxciv{%
So indeed they denied the truth* when it came to them; so now the tidings of the thing they used to mock at, will come to them. (Prophet Mohammed -peace and blessings be upon him, or the Holy Qur’an).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Do they not see how many civilisations We destroyed before them, whom We had established more firmly in the earth than We have established you, and We sent on them abundant rain from the sky, and made the rivers flow beneath them? So we destroyed them because of their sins, and created another civilisation after them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
And had We sent down to you (O dear Prophet Mohammed – peace and blessings be upon him) something written on paper so that they could feel it with their hands, even then the disbelievers would have said, “This is nothing but clear magic.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
And they said, “Why has not an angel been sent down to him?” And had We sent down an angel, then the matter would have been finished, and they would not get any respite.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
And had we appointed an angel as a Prophet, We would still have made him as a man and would keep them in the same doubt, as they are now in.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@dccxcix{%
And certainly, O dear Prophet (Mohammed – peace and blessings be upon him) the Noble Messengers before you have also been mocked at, so those who laughed at them were themselves ruined by their own mocking.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@dccc{%
Proclaim, “Travel in the land, and see what sort of fate befell those who denied.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dccci{%
Say, “To Whom does all whatever is in the heavens and the earth, belong?” Proclaim, “To Allah”; He has made mercy obligatory upon His grace; undoubtedly, He will surely gather you all together on the Day of Resurrection in which there is no doubt; those who put their souls to ruin, do not accept faith.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dcccii{%
And to Him only belongs all whatever exists in the night and in the day; and He only is the All Hearing, the All Knowing.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say, “Shall I choose as a supporter someone other than Allah, Who is the Originator of the heavens and the earth and Who feeds and does not need to eat?” Say, “I have been ordered to be the first to submit myself (to Him), and O people, do not be of the polytheists.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say, “If I disobey my Lord, I then fear the punishment of the Great Day (of Resurrection).”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dcccv{%
Indeed Allah’s mercy has been upon him, from whom the punishment has been averted on that Day; and this is the clear success.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dcccvi{%
And if Allah afflicts you with some misfortune, then there is none who can remove it, except Him; and if He sends you some good fortune, then (know that) He is Able to do all things.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dcccvii{%
He is the Omnipotent over His bondmen; and He is the Wise, the Aware.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Whose testimony is the greatest?” Say, “Allah is the Witness between me and you; and this Qur’an has been sent down upon me, so I may warn you with it and whomever it may reach; so do you bear witness that there are other Gods along with Allah?” Say, “I do not bear witness to it”; Say, “He is the only One God and I do not have any relation with whatever you ascribe as partners (to Him).”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dcccix{%
The people to whom We gave the Book(s) recognise this Prophet (Mohammed – peace and blessings be upon him) as they recognise their own sons; those who put their own souls to ruin, do not accept faith.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dcccx{%
And who is more unjust than one who fabricates lies against Allah or denies His signs? Undoubtedly, the unjust will never succeed.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dcccxi{%
And on the day when We will resurrect everyone together, then say to the polytheists, “Where are those partners (your false deities) whom you professed?”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dcccxii{%
Then they had no fabrication except that they said, “By Allah, our Lord, we were never polytheists!”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Observe how they lied against themselves, and how they lost the things they fabricated!\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
And among them is one who listens to you; and We have put covers upon their hearts so they may not understand it, and deafness in their ears; and (even) if they see all the signs, they will not believe in them; to the extent that when they come to you to debate with you, the disbelievers say, “This is nothing but stories of former people.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dcccxv{%
And they stop (others) from it and run away from it; and they ruin none except themselves, and they do not have sense.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
And if you see them when they will be placed above hell, they will say, “Alas, if only we might be sent back and not deny the signs of our Lord, and become Muslims!”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
In fact it has become clear to them what they used to hide before; and were they to be sent back, they would commit the same which they were forbidden to, and undoubtedly they are liars.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they said, “There is no other life except our life of this world, and we are not to be raised.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dcccxix{%
And if you see when they are placed before their Lord, He will say, “Is this not real (the truth)? They will say, “Yes – why not, by our Lord!” He will say, “So now taste the punishment – the recompense of your disbelief.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dcccxx{%
Those who denied their meeting with Allah, have indeed failed; to the extent that when the Last Day suddenly came upon them they said, “Woe to us that we failed to believe in it” – and they carry their burdens on their backs; what an evil burden they carry!\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
The life of this world is nothing except a pastime and sport; and undoubtedly the abode of the Hereafter is better for the pious; so do you not have sense?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know well that their statement grieves you – so they do not deny you (Prophet Mohammed – peace and blessings be upon him) but in fact the unjust deny the signs of Allah.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
And indeed Noble Messengers have been denied before you, so they patiently bore the denial and torture till Our help reached them; and there is none to alter the decisions of Allah; and the news of the Noble Messengers have already reached you.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
And if their turning away has grieved you, then if you can, seek a tunnel into the earth or a ladder into the sky to bring a sign for them; and if Allah willed, He could have brought them all together upon guidance, so O listener (followers of this Prophet) do not ever be of the ignorant.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
It is only those who hear (with sincere hearts) that accept faith; and Allah will raise these people dead of heart, then towards Him they will be herded.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
And they said, “Why has no sign been sent down upon him from his Lord?” Say, “Indeed Allah is Able to send down a sign”, but most of them are totally ignorant.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
And there is not an animal moving in the earth nor a bird flying on its wings, but they are a nation like you; We have left out nothing in this Book – then towards their Lord they will be raised.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
And those who deny Our signs are deaf and dumb in realms of darkness; Allah may send astray whomever He wills; and may place on the Straight Path whomever He wills.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say, “What is your opinion – if the punishment of Allah comes upon you or the Hour arrives, will you call upon anyone (deity) besides Allah; if you are truthful?”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
“In fact you will only call upon Him, and if He wills, He may remove that because of which you prayed to Him, and you will forget the partners (you ascribe to Him).”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
And We have indeed sent Noble Messengers towards the nations that were before you – We therefore seized them with hardship and adversity so that, in some way, they may humbly plead.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
So why did they not humbly plead when Our punishment came to them? But their hearts were hardened and the devil made all their deeds appear good to them!\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
So when they forgot the advices made to them, We opened the gates of all things for them; to the extent that when they were rejoicing for what they had received, We seized them suddenly, hence they remained dejected.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
The origins of the unjust people were therefore cut off; and all praise is to Allah, Lord Of The Creation.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say, “What is your opinion – if Allah were to take away your hearing and your sight and seal your hearts, then is there a God besides Allah who could restore it for you?” Observe how We explain the verses to them, yet they turn away!\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say, “What is your opinion – if the punishment of Allah were to come upon you suddenly or openly (with forewarning), who would be destroyed except the disbelieving people?”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
And We did not send Noble Messengers except as Heralds of glad tidings and warnings; so upon those who accept faith and reform themselves, shall be no fear nor shall they grieve.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
And those who deny Our signs – the punishment will afflict them for their disobedience.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “I do not say to you that I possess the treasures of Allah, nor do I say that I gain knowledge of the hidden on my own, nor do I say to you that I am an angel; I only follow what is divinely revealed to me”; say, “Will the blind and the sighted ever be equal? So do you not think?”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And with this Qur’an warn those who fear, that they will be raised towards their Lord in a state when, except Allah, there will be no protector for them nor an intercessor, so that they may be pious.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dcccxli{%
And do not repel those who call upon their Lord in the morning and evening, seeking His pleasure; you are not responsible for their account nor are they responsible for your account – then your repelling them would be far from justice.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
And similarly We have made some as a trial for others – that the wealthy disbelievers upon seeing the needy Muslims say, “Are these whom Allah has favoured among us?” Does not Allah recognise those who are thankful?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
And when those who believe in Our signs come humbly in your presence, say to them, “Peace be upon you – your Lord has prescribed mercy for Himself by His grace – that whoever among you commits a sin by folly and thereafter repents and reforms (himself), then indeed Allah is Oft Forgiving, Most Merciful.”\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
And this is how We explain Our verses clearly and so that the way of the criminals become well exposed.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say, “I have been forbidden to worship those whom you worship other than Allah”; say, “I do not follow your desires – if it were, I would then go astray and not be on the right path.”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say, “I am on the clear proof from my Lord, whereas you deny Him; I do not have what you are impatient for; there is no command except that of Allah; He states the truth and He is the Best of Judges."\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say, “If I had the thing for which you are impatient, then the matter between me and you would have already been decided”; and Allah is Well Aware of the unjust.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
And it is He Who has the keys of the hidden – only He knows them; and He knows all that is in the land and the sea; and no leaf falls but He knows it – and there is not a grain in the darkness of the earth, nor anything wet or dry, which is not recorded in a clear Book.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
And it is He Who removes your souls at night (while asleep) and knows whatever you commit by day; then He raises you again during the day, to complete the term appointed (for you); then it is to Him that you are to return – He will then inform you of what you used to do.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dcccl{%
And He is Omnipotent over His bondmen and sends guardians over you; to the extent that when death comes to one of you, Our angels remove his soul, and they do not err.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dcccli{%
They (the souls) are then returned towards their True Lord – Allah; pay heed! Only His is the command; and He is the Swiftest At Taking Account.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say, “Who rescues you from the calamities of the land and the sea – Whom you call upon crying loudly and in whispers that, ‘If we are saved from this we will surely be grateful’?”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say, “Allah delivers you from these and from all distresses – yet you ascribe partners to Him!”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say, “He is Able to send punishment upon you from above you or from beneath your feet, or to cause you to fight each other by dividing you into different groups, and make you taste the harshness of one another”; observe how We explain the verses so that they may understand.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dccclv{%
And your people (O dear Prophet Mohammed – peace and blessings be upon him) denied it whereas this is undoubtedly the truth; say, “I am not responsible for you.”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dccclvi{%
All matters have a fixed time and soon you will come to know.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dccclvii{%
And O listener (followers of this Prophet) when you see those who argue in Our verses, turn away from them until they engage in another topic; and if the devil causes you to forget, then do not sit with the unjust after remembering.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dccclviii{%
And the pious are not accountable for them in the least, apart from the giving of advice so that they may avoid.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dccclix{%
And forsake those who have made their religion a mockery and play, and whom the worldly life has deceived – and advise them with this Qur’an so that a soul may not be seized for what it earns; other than Allah it will not have a protector nor an intercessor; and if it offers every recompense in exchange for itself, it will not be accepted from it; these are the ones who are seized for their own deeds; for them is boiling water to drink and a painful punishment, as a recompense of their disbelief. (The disbelievers will not have any intercessors.)\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say, “Shall we worship, other than Allah, that which neither benefits us nor harms us, and (therefore) be turned back after Allah has guided us, like one whom the devils have led astray in the earth – bewildered?; his companions call him to the path (saying), ‘Come here’”; say, “Indeed only the guidance of Allah is (the true) guidance; and we are commanded to submit to the Lord Of The Creation.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dccclxi{%
“And to keep the (obligatory) prayer established and to fear Him; and it is to Him that you are to be raised.”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dccclxii{%
And it is He Who perfectly created the heavens and the earth; and when He will say “Be” on the Day (of resurrection) to all the extinct things, it will happen immediately; His Word is true; and it will be His kingship on the day when the Trumpet is blown; All Knowing of all the hidden and the revealed; and He only is the Wise, the Aware.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
And remember when Ibrahim said to his father (paternal uncle) Azar, “What! You appoint idols as Gods? Indeed I find you and your people in open error.” (Prophet Ibrahim was rightly guided since birth).\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
And likewise We showed Ibrahim the entire kingdom of the heavens and the earth and so that he be of those who believe as eyewitnesses.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dccclxv{%
So when the night became dark upon him he saw a star; he said (to Azar / the people), “(You portray that) this is my Lord?”; then when it set he said, “I do not like the things that set.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
Then when he saw the moon shining, he said, “(You proclaim that) this is my Lord?”; then when it set, he said, “If my Lord had not guided me*, I too would be one of these astray people.” (* Prophet Ibrahim was rightly guided before this event).\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
Then when he saw the sun shining brightly, he said, “(You say that) this is my Lord? This is the biggest of them all!”; then when it set he said, “O people! I do not have any relation with the whatever you ascribe as partners (to Him).”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
“I have directed my attention towards Him Who has created the heavens and the earth, am devoted solely to Him, and am not of the polytheists.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dccclxix{%
And his people argued with him; he said, “What! You dispute with me concerning Allah? So He has guided me; and I do not have any fear of whatever you ascribe as partners, except what my Lord wills (to happen); my Lord’s knowledge encompasses all things; so will you not accept advice?”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dccclxx{%
“And how should I fear whatever you ascribe as partners, whilst you do not fear that you have ascribed partners to Allah – for which He has not sent down on you any proof? So which of the two groups has more right to refuge, if you know?”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
Those who believed and did not mix it with injustice (disbelief), the refuge is only for them, and only they are on guidance.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
And this is Our argument, which We gave Ibrahim against his people; We raise to high ranks whomever We will; indeed your Lord is Wise, All Knowing.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We bestowed upon him Ishaq (Isaac) and Yaqub (Jacob); We guided all of them; and We guided Nooh before them and of his descendants, Dawud and Sulaiman and Ayyub and Yusuf and Moosa and Haroon; and this is the way We reward the virtuous.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
And (We guided) Zakaria and Yahya (John) and Eisa and Elias; all these are worthy of Our proximity.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
And Ismael (Ishmael) and Yasa’a (Elisha) and Yunus (Jonah) and Lut (Lot); and to each one during their times, We gave excellence over all others.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
And some of their ancestors and their descendants and their brothers; and We chose them and guided them to the Straight Path.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
This is the guidance of Allah, which He may give to whomever He wills among His bondmen; and had they ascribed partners (to Allah), their deeds would have been wasted.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
These are the ones whom We gave the Book and the wisdom and the Prophethood; so if these people do not believe in it, We have then kept ready for it a nation who do not reject (the truth).\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
These are the ones whom Allah guided, so follow their guidance; say (O dear Prophet Mohammed – peace and blessings be upon him), “I do not ask from you any fee for the Qur’an; it is nothing but an advice to the entire world.”\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
And they (the Jews) did not realise (or appreciate) the importance of Allah as was required when they said, “Allah has not sent down anything upon any human being”; say, “Who has sent down the Book which Moosa brought, a light and guidance for mankind, which you have divided into different papers, some which you show and hide most of them? And (by which) you are taught what you did not know nor did your forefathers?” Say, “Allah” – then leave them playing in their indecency.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
And this is the blessed Book which We have sent down, confirming the Books preceding it, and in order that you may warn the leader of all villages and all those around it in the entire world; and those who believe in the Hereafter accept faith in this Book, and guard their prayers.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
Who is more unjust than one who fabricates lies against Allah or says, “I have received divine inspiration”, whereas he has not been inspired at all – and one who says, “I will now reveal something similar to what Allah has sent down”? And if you see when the unjust are in the throes of death and the angels are with their hands outstretched; (saying) “Surrender your souls; this day you shall be given a disgraceful punishment – the recompense of your fabricating lies against Allah, and your scorning His signs.”\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
“And indeed you (the disbelievers) have now come to Us alone as We had created you at first, and you have left behind you all the wealth and riches We had bestowed upon you; and We do not see your intercessors along with you, whom you claimed to possess a share in you; indeed the link between yourselves is cut off, and you have lost all what you contended.”\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
Indeed it is Allah Who splits the grain and the seed; it is He Who brings forth living from the dead, and it is He Who brings forth dead from the living; such is Allah; so where are you reverting?\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
It is He Who breaks dawn (by splitting the dark); and He has made the night a calmness, and the sun and the moon a count (for time); this is the command set by the Almighty, the All Knowing.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
And it is He Who has created the stars for you, so that you may find your way by them in the darkness of the land and the sea; indeed We have explained Our verses in detail for the people of knowledge.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
And it is He Who has created you from a single soul – then you have to stop over* in one place and stay entrusted** in another; indeed We have explained Our verses in detail for people of understanding. (* This earth. ** The grave.)\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
And it is He Who sends down water from the sky; so with it We produced all things that grow; hence We produce from it vegetation from which We bring forth grains in clusters; and from the pollen of dates, dense bunches – and gardens of grapes and olives and pomegranates, similar in some ways and unlike in some; look at its fruit when it bears yield, and its ripening; indeed in it are signs for the people who believe.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
And out of sheer ignorance they have ascribed jinns as partners of Allah, whereas it is He Who created them, and they have invented sons and daughters for Him! Purity and Supremacy is to Him, from all what they ascribe.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dcccxc{%
The Originator of the heavens and the earth; how can He possibly have a child when, in fact, He does not have a spouse? And He has created all things; and He knows everything.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dcccxci{%
Such is Allah, your Lord; and none is worthy of worship except Him; the Creator of all things – therefore worship Him; and He is the Trustee over all things.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
Eyes do not encompass Him – and all eyes are within His domain*; He is the Most Subtle, the Fully Aware. (* control / knowledge)\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
“Enlightening proofs came to you from your Lord; so whoever observes, it is for his own good; and whoever is blind, it is for his own harm; and I am not a guardian over you.”\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
And this is how We explain Our verses in different ways that they (the disbelievers) may say to you, (O dear Prophet Mohammed – peace and blessings be upon him), “You have studied” – and to make it clear for the people of knowledge.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow what is divinely revealed to you from your Lord; there is none worthy of worship except Him; and turn away from the polytheists.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
And if Allah willed, they would not ascribe (any partner to Him); We have not made you as a guardian over them; and you are not responsible for them.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
Do not abuse those whom they worship besides Allah lest they become disrespectful towards Allah’s Majesty, through injustice and ignorance; likewise, in the eyes of every nation, We have made their deeds appear good – then towards their Lord they have to return and He will inform them of what they used to do.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
And they swore by Allah vehemently in their oaths that if any sign came to them, they will certainly believe in it; say, “The signs are with Allah, and what do you people know that if they came to them, they will not believe.”\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
And We revert their hearts and their eyes – the way they had not believed the first time – and We leave them to keep wandering blindly in their rebellion.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cm{%
And had We sent down the angels towards them, and had the dead spoken to them, and had We raised all things in front of them, they would still not have believed unless Allah willed – but most of them are totally ignorant.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cmi{%
And similarly We have appointed enemies for every Prophet – devils from men and jinns – one inspires the other with fabrications to deceive; and had your Lord willed they would not do so, therefore leave them with their fabrications.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cmii{%
And in order that the hearts of those who do not believe in the Hereafter may lean towards it and that they may like it, and earn the sins which they are to earn.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cmiii{%
“So shall I seek the command other than that of Allah, whereas it is He Who has sent down the detailed Book towards you?” And those whom We gave the Book know that this is the truth sent down from your Lord, so O listener, (followers of this Prophet) do not ever be of those who doubt.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cmiv{%
And the Word of your Lord is complete in truth and justice; there is none to change His Words; He is the All Hearing, the All Knowing.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cmv{%
And O listener, (followers of the Prophet) most of the people on earth are such that were you to obey them, they would mislead you from Allah’s way; they follow only assumptions and they only make guesses.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cmvi{%
Your Lord well knows who has strayed from His way; and He well knows the people on guidance.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cmvii{%
So eat from that over which Allah’s name has been mentioned, if you believe in His signs.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cmviii{%
And what is the matter with you that you should not eat from that over which Allah’s name has been mentioned whereas He has explained in detail to you all what is forbidden to you except when you are forced (by circumstances) towards it? And indeed many lead astray by their own desires, out of ignorance; indeed your Lord well knows the transgressors.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cmix{%
And give up the open and hidden sins; those who earn sins will soon receive the punishment of their earnings.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cmx{%
And do not eat that on which Allah’s name has not been mentioned, and indeed that is disobedience; and undoubtedly the devils inspire in the hearts of their friends to fight with you; and if you obey them, you are then polytheists.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cmxi{%
And will the one who was dead and so We raised him to life and set for him a light with which he walks among the people, ever be like the one who is in realms of darkness never to emerge from them? Similarly, the deeds of disbelievers are made to appear good to them.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cmxii{%
And similarly, We have made in every town leaders among its criminals that they may conspire in it; and they do not conspire except against themselves and they do not have perception.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cmxiii{%
And when a sign comes to them, they say, “We will not believe until we are given the same which Allah’s Noble Messengers were given”; Allah knows best where to place His message (prophethood); soon the guilty will be afflicted with disgrace before Allah and a severe punishment due to their scheming.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cmxiv{%
And whomever Allah wills to guide, He opens his bosom for Islam; and whomever He wills to send astray, He makes his bosom narrow and firmly bound as if he were being forced by someone to climb the skies; this is how Allah places the punishment on those who do not believe.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cmxv{%
And this is the Straight Path of your Lord; We have explained in detail Our verses for the people who accept advice.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cmxvi{%
For them is the abode of peace with their Lord and He is their Master – the result of their deeds.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cmxvii{%
And the Day when He will raise them all and will proclaim, “O you group of jinns, you have enticed a lot of men”; and their human friends will submit, “Our Lord, some of us have benefited from one another and have reached the appointed term which You had set for us”; He will say, “Your home is hell – remain in it for ever, except whomever Allah wills”; O dear Prophet (Mohammed – peace and blessings be upon him), indeed your Lord is the Wise, the All Knowing.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cmxviii{%
And similarly We empower some of the oppressors over others – the recompense of their deeds.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cmxix{%
“O you groups of jinns and men! Did not the Noble Messengers amongst you come to you reciting My verses and warning you of confronting this day?” They will say, “We testify against ourselves” – and the worldly life deceived them and they will testify against themselves that they were disbelievers.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cmxx{%
This is because your Lord does not unjustly destroy townships for their people may be unaware.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cmxxi{%
And for everyone are ranks from what they do; and your Lord is not unaware of their deeds.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cmxxii{%
And O dear Prophet (Mohammed – peace and blessings be upon him), your Lord is the Perfect (Not needing anything), the Merciful; O people! If He wills, He can remove you and bring others in your stead – the way He created you from the descendants of others.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
Indeed the thing which you are promised will definitely come to pass, and you cannot escape.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “O my people! Keep on with your works* in your positions, I am doing mine; soon you will come to know for whom is the abode of the Hereafter; undoubtedly the unjust are never successful.” (* This is said as a challenge)\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cmxxv{%
And among the crops and animals that Allah has created, they assigned (only) a portion to Him and therefore said “This is for Allah” – in their opinion – “and this is for our partners (false deities)”; so the portion for their partners does not reach Allah; and the portion for Allah reaches their partners; what an evil judgement they impose!\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
And similarly, their partners (the devils) have made the killing of their children seem righteous in the sight of many of the polytheists, in order to ruin them and make their religion blurred to them; and if Allah willed they would not do so, therefore leave them alone with their fabrications.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
And they said, “These cattle and crops are forbidden; only those whom we wish can eat them” – in their opinion – and some cattle are those which they have forbidden riding upon, and some cattle over which they do not mention the name of Allah while slaughtering – all this is fabricating lies against Allah; He will soon repay them for their fabrications.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they said, “The animals in the bellies of such cattle are purely for our males and forbidden to our women; and if the animal is stillborn, they all have a share of it”; soon Allah will repay them for their utterances; indeed He is Wise, All Knowing.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Indeed ruined are those who slay their children out of senseless ignorance and forbid the sustenance which Allah has bestowed upon them, in order to fabricate lies against Allah; they have undoubtedly gone astray and not attained the path.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cmxxx{%
It is He Who produces gardens spread on the ground and above, and the date-palm, and crops of various flavours, and the olive and the pomegranate, similar in some respects and unlike in others; eat from its fruit when it bears yield, and pay the due (obligatory charity) from it on the day it is harvested; and do not be wasteful; indeed the wasteful are not liked by Allah.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And from the cattle, some for burdens, some spread on the earth; eat of the sustenance which Allah has bestowed upon you, and do not follow the footsteps of the devil; undoubtedly he is your open enemy.\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
“Eight males and females; one pair of sheep and one of goats”; say, “Has He forbidden the two males or the two females, or what the two females carry in their wombs? Answer with some knowledge, if you are truthful.”\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
“And a pair of camels and a pair of oxen”; say, “Has He forbidden the two males or the two females, or what the two females carry in their wombs? Were you present when Allah commanded this to you?” So who is more unjust than one who fabricates a lie against Allah in order to lead mankind astray with his ignorance? Indeed Allah does not guide the unjust.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “I do not find in what is sent down to me any eatable prohibited to a consumer, except if it is carrion, or blood flowing from blood vessels, or the flesh of swine – for that is indeed foul, or the sin causing animal over which the name of any other than Allah is taken at the time of slaughtering; so for one compelled by circumstances, neither himself desiring nor eating more than necessary, indeed your Lord is Oft Forgiving, Most Merciful.”\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
And for the Jews We forbade all animals with claws; and forbade them the fat of oxen and sheep except which is on their backs or joined to their intestines or to the bone; We awarded this to them for their rebellion; and indeed, surely, We are truthful.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
Then if they deny you (O dear Prophet Mohammed – peace and blessings be upon him) say, “Your Lord has boundless mercy; and His wrath is never withdrawn from the culprits.”\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
The polytheists will now say, “Had Allah willed, we would not have ascribed partners (to Him) nor would have our forefathers, nor would we have forbidden anything”; similarly those before them had denied, till the time they tasted Our punishment; say, “Do you have any knowledge so you can offer it to us? You follow only assumptions and only make guesses.”\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say, “Then only Allah’s argument is the complete one; so had He willed, He would have guided you all.”\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say, “Bring your witnesses who can testify that Allah has forbidden this”; then if they do testify, O listener (followers of this Prophet) do not bear witness along with them and do not follow the desires of those who deny Our signs, and of those who do not believe in the Hereafter and who ascribed equals to their Lord.\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say, “Come – so that I may recite to you what your Lord has forbidden for you that ‘Do not ascribe any partner to Him and be good to parents; and do not kill your children because of poverty; We shall provide sustenance for all – you and them; and do not approach lewd things, the open among them or concealed; and do not unjustly kill any life which Allah has made sacred; this is the command to you, so that you may have sense.’\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@cmxli{%
‘And do not approach the wealth of an orphan except in the best manner, till he reaches his adulthood; and measure and weigh in full, with justice; We do not burden any soul except within its capacity; and always speak fairly, although it may be concerning your relative; and be faithful only to Allah’s covenant; this is commanded to you, so that you may accept advice.’”\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@cmxlii{%
“And that, ‘This is My Straight Path, so follow it; and do not follow other ways for they will sever you from His way; this is commanded to you, so that you may attain piety.’”\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then We gave the Book to Moosa, to complete the favour on one who is virtuous, and an explanation of all things, a guidance and a mercy, so they may believe in meeting their Lord.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And this (the Qur’an) is the blessed Book which We have sent down; so follow it and be pious, so there may be mercy upon you.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@cmxlv{%
For you (the disbelievers) may say, “The Book was sent down only to two groups (Jews and Christians) before us; and we were totally unaware of what they read and taught.”\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or may say that, “If the Book had been sent down to us, we would have been more upon guidance than them”; so the clear proof and guidance and mercy has come to you, from your Lord; so who is more unjust than one who denies the signs of Allah, and turns away from them? We shall soon punish those who turn away from Our signs with a great punishment, the recompense of their turning away.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
What are they waiting for – except that the angels come to them, or the punishment from your Lord, or one of the signs of your Lord? On the day when the (foretold) sign of your Lord comes, not a single soul who had not earlier accepted faith nor earned any good from its faith, will benefit from accepting faith; say, “Wait – we too are waiting.”\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
You (O dear Prophet Mohammed – peace and blessings be upon him) have no concern with those who divided their religion and became several groups; their case is only with Allah – He will then inform them of what they used to do.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@cmxlix{%
For one who brings one good deed, are ten like it; and one who brings an ill-deed will not be repaid but with one like it, and they will not be wronged.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@cml{%
Say, “Indeed my Lord has guided me to the Straight Path; the right religion, (of) the community of Ibrahim who was free from all falsehood; and was not a polytheist.”\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@cmli{%
Say, “Undoubtedly my prayers and my sacrifices, and my living and my dying are all for Allah, the Lord Of The Creation.”\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@cmlii{%
“He has no partner; this is what I have been commanded, and I am the first Muslim.”\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say, “Shall I seek a Lord other than Allah, whereas He is Lord of all things?” And whatever a soul earns is itself responsible for it; and no load bearing soul will bear anyone else’s load; then towards your Lord you have to return and He will inform you about the matters you differed.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@cmliv{%
And it is He who made you caliphs (viceroys) in the earth and ranked some of you high above others, in order that He may test you with what He has bestowed upon you; indeed it does not take time for your Lord to mete out punishment; and indeed, surely, He is Oft Forgiving, Most Merciful.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif-Laam-Meem-Saad. (Alphabets of the Arabic language; Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@cmlvi{%
O dear Prophet (Mohammed – peace and blessings be upon him), a Book has been sent down upon you, therefore may not your heart be disinclined towards it, so that you may give warning with it, and as an advice for the Muslims.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@cmlvii{%
O mankind, follow what has been sent down to you from your Lord, and do not follow other administrators, abandoning this (the Holy Qur’an); very little do you understand.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@cmlviii{%
And many a township did We destroy – so Our punishment came to them at night or while they were sleeping at noon.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@cmlix{%
Therefore they uttered nothing when Our punishment came to them, except that they said, “Indeed we were the unjust.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@cmlx{%
So undoubtedly We shall question those to whom Our Noble Messengers went, and indeed We shall question the Noble Messengers.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@cmlxi{%
So indeed We shall inform them with Our knowledge and We were not absent.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@cmlxii{%
And on that Day, the weighing will truly be done; so those whose scales prove heavy are the successful.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
And those whose scales are light are the people who put themselves to ruin – the recompense of the injustice they used to do to Our signs.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
And indeed We established you in the earth and in it created for you the means of livelihood; very little thanks do you offer!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@cmlxv{%
And indeed We created you, then designed you and then ordered the angels, “Prostrate before Adam”; so they all prostrated, except Iblis (Satan); he did not become of those who prostrate.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
Said Allah, “What prevented you, that you did not prostrate when I commanded you?” Answered Iblis, “I am better than him; You created me from fire whereas You created him from clay.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
Said Allah, “Therefore go down from here – it does not befit you to stay here and be proud – exit, you are of the degraded.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
He said, “Give me respite till the day when people will be resurrected.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@cmlxix{%
Said Allah, “You are given respite.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@cmlxx{%
He said, “Hence I swear by the fact that You sent me astray, I will certainly lay in wait for them on Your Straight Path.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
“Then I will certainly approach them – from their front and from behind them and from their right and from their left; and You will find most of them not thankful.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
He said, “Exit from here, rejected, outcast; indeed whoever among them follows your bidding, I will fill hell with all of you.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
And said, “O Adam! You and your wife dwell in Paradise – therefore eat from it from wherever you wish, and do not approach this tree for you will become of those who transgress.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
Then Satan created apprehensions in their hearts in order to disclose to them matters of their shame which were hidden from them, and said, “Your Lord has forbidden you from this tree, for you may become angels or immortals.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he swore to them, “Indeed I am a well-wisher for both of you.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
So he brought them down with deception; and when they tasted from that tree, their shame became manifest to them and they began attaching the leaves of Paradise on themselves; and their Lord said to them, “Did I not forbid you from that tree, and tell you that Satan is an open enemy to you?”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
They both submitted, “Our Lord! We have wronged ourselves; so if You do not forgive us and have mercy on us, then surely, we are of the losers.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
He said, “Go down, one of you is a foe unto the other; and for a fixed time you shall stay on earth and feed in it.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He said, “You shall live there and there shall you die, and from there only you will be raised.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O Descendants of Adam! We have sent down to you a garment to conceal your shame, and another garment for your elegance; and the garment of piety – that is the best; this is among the signs of Allah, so that they may remember.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
O Descendants of Adam, beware! Do not let Satan put you in trial the way he removed your parents from Paradise and had their garments removed so that their shame become visible to them; indeed he and his tribe see you from where you do not see them; indeed We have made the devils the friends of those who do not believe.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And when they commit any shameful act they say, “We found our forefathers on it and Allah has commanded it to us”; say, “Indeed Allah does not ordain shamelessness; what! You attribute things to Allah, which you do not know?”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say, “My Lord has ordained justice; and set your attention straight every time you offer pray and worship Him, as only His devoted worshippers; the way He brought you into being, in the same manner will you return.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
He has guided one group, and one group’s error has been proved; instead of Allah, they have chosen the devil as their friend and they assume that they are on guidance!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
O Descendants of Adam! Adorn yourself when you go to the mosque, and eat and drink, and do not cross limits; indeed He does not like the transgressors.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say, “Who has forbidden the adornment of Allah which He has brought forth for His bondmen, and the good food?” Say, “That is for the believers in this world, and on the Day of Resurrection it will be for them only”; this is how We explain Our verses in detail for people of knowledge.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say, “My Lord has forbidden the indecencies, the apparent among them and the hidden, and sin and wrongful excesses, and forbidden that you ascribe partners with Allah for which He has not sent down any proof, and forbidden that you say things concerning Allah of which you do not have knowledge.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
And every group has a promise; so when its promise comes, it cannot be postponed for a moment or brought forward.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
O Descendants of Adam! If Noble Messengers from among you come to you narrating My verses – so whoever practices piety and reforms – upon him shall be no fear nor shall he grieve.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@cmxc{%
And those who denied Our signs and were conceited towards them, are the people of hell-fire; they will remain in it forever.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@cmxci{%
So who is more unjust than one who fabricated a lie against Allah or denied His signs? Their written fate will reach them; until when Our sent angels come to remove their souls, hence they say to them, “Where are they whom you used to worship besides Allah?” They say, “We have lost them” and they testify against themselves that they were disbelievers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@cmxcii{%
Allah says to them, “Join the groups of jinns and mankind who have entered hell before you”; when a group enters, it curses the other; until when they have all gone in, the latter groups will say regarding the former, “Our Lord! It is these who led us astray, so give them double the punishment of the fire”; He will say, “For each one is double – but you do not know.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@cmxciii{%
And the preceding groups will say to the latter, “So you too were no better than us, therefore taste the punishment for what you have done!”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Indeed those who denied Our signs and were conceited towards them – the gates of the heavens will not be opened for them nor will they enter Paradise until the camel goes through the needle’s eye*; and this is the sort of reward We give the guilty. (* Which will never happen.)\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@cmxcv{%
Their beds and their coverings – both are fire; and this is the sort of reward We give the unjust.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
And those who accepted faith and performed good deeds according to their capacity – We do not burden any one, except within its capacity – are the people of Paradise; they shall abide in it forever.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
And We have removed resentment from their hearts – rivers will flow beneath them; and (while entering Paradise) they will say, “All praise is to Allah, Who guided us to this; we would not have attained the right path if Allah had not guided us; indeed the Noble Messengers of our Lord brought the truth”; and it is proclaimed, “You have received this Paradise as an inheritance for what you used to do.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
And the people of Paradise said to the people of hell, “We have surely received what our Lord had truly promised us – so have you also received what your Lord had truly promised?” They said, “Yes”; and an announcer between them proclaimed, “The curse of Allah is upon the unjust.” –\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@cmxcix{%
“Those who prevent from the path of Allah and wish to distort it; and who disbelieve in the Hereafter.”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@m{%
Between Paradise and Hell is a veil; and on the Heights will be some men who will recognise them all by their foreheads; and they call to the people of Paradise, “Peace be upon you”; they have not entered Paradise and they yearn for it.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mi{%
And when their eyes turn towards the people of hell, they will say, “Our Lord! Do not put us along with the unjust.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mii{%
And the men on the Heights will call to some men whom they recognise by their foreheads, and say, “What benefit did your derive from your populace and from what you prided in?”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@miii{%
“Are these the people (Muslims) regarding whom you swore that Allah would not have mercy on them at all? Whereas to the Muslims it has been said ‘Enter Paradise; you shall have no fear nor any grief.’”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@miv{%
And the people of hell will cry out to the people of Paradise, “Provide us some benefit from your water or from the food Allah has provided you”; they will say, “Indeed Allah has forbidden both to the disbelievers.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mv{%
People who made their religion a sport and pastime, and whom the worldly life deceived; so this day We will disregard them, the way they had neglected their confronting of this day, and the way they used to deny Our signs.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mvi{%
And indeed We brought to them a Book, which We have explained in detail with a great knowledge – a guidance and a mercy for people who believe.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mvii{%
What do they await, except for the result foretold by that Book to appear? The day when the result foretold by it occurs, those who had previously forgotten it from the beginning (the disbelievers) will exclaim, “Indeed the Noble Messengers of our Lord had brought the truth! Do we have any intercessors who may intercede for us? Or can we be returned (to earth), so we may do contrary to what we have done before?” Indeed they have put themselves into ruin, and have lost the things they fabricated.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mviii{%
Indeed your Lord is Allah Who created the heavens and the earth in six days, then in the manner befitting His Majesty, ascended the Throne (of control); He covers the night with the day, which hastily follows it, and made the sun and the moon and the stars subservient to His command; pay heed! Only He has the power to create and command; Most Auspicious (Propitious) is Allah, the Lord Of The Creation.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mix{%
Pray to your Lord crying humbly, and softly; indeed He does not love the transgressors.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mx{%
And do not spread turmoil in the earth after its reform, and pray to Him with fear and hope; indeed Allah’s mercy is close to the virtuous.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mxi{%
And it is He Who sends the winds giving glad tidings, ahead of His mercy; until when they come bearing heavy clouds, We drove it towards a city devoid of vegetation, and then rained water upon it, then produced fruits of various kinds from it; this is how We will bring forth the dead, so that you may heed advice.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mxii{%
And from the good land comes forth its vegetation by the command of Allah; and from the infertile land, nothing comes forth except a little with difficulty; this is how We explain Our signs in different ways, for people who are thankful.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mxiii{%
Indeed We sent Nooh to his people – he therefore said, “O my people! Worship Allah – you do not have any God except Him; indeed I fear for you the punishment of the Great Day (of Resurrection).”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mxiv{%
The leaders of his people said, “Indeed we see you in open error.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mxv{%
He said, “O my people! There is no straying in me – I am in fact a Noble Messenger from the Lord Of The Creation.”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mxvi{%
“Conveying to you the messages of my Lord and wishing good for you, and I know from Allah what you do not know.”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mxvii{%
“And are you surprised that an advice came to you from your Lord through a man amongst you, so that he may warn you and that you may fear, and so that there be mercy upon you?”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mxviii{%
In response they denied him, so We rescued him and those with him in the ship, and We drowned those who denied Our signs; indeed they were a blind group.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mxix{%
And We sent Hud to the people of Aad from their own community; he said, “O my people! Worship Allah – you do not have any God except Him; so do you not fear?”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mxx{%
The disbelieving leaders of his people said, “Indeed we consider you foolish and think you are a liar.”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mxxi{%
He said, “O my people! I do not have any concern with foolishness and I am in fact a Noble Messenger from the Lord Of The Creation.”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mxxii{%
“I convey to you the messages of my Lord and am your trustworthy well-wisher.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mxxiii{%
“And are you surprised that an advice came to you from your Lord through a man amongst you, so that he may warn you? Remember when He made you the successors of Nooh’s people, and enlarged your bodies; therefore remember Allah’s favours, so that you may attain good.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said, “Have you come to us in order that we worship only Allah, and abandon those whom our ancestors worshipped?! So bring upon us what you promise us, if you are truthful.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mxxv{%
He said, “Indeed the punishment and the wrath of your Lord have fallen upon you; what! You needlessly dispute with me regarding the names you and your ancestors have fabricated? Allah has not sent down any proof concerning them; therefore wait – I too await with you.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mxxvi{%
We therefore rescued him and those with him by a great mercy from Us, and We cut off the lineage of those who denied Our signs – and they were not believers.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And We sent Saleh to the tribe of Thamud, from their own community; he said, “O my people! Worship Allah – you do not have any God except Him; indeed a clear proof has come to you from your Lord; this is Allah’s she-camel – a sign for you – so leave her free to feed in Allah’s earth, and do not touch her with evil intentions for a painful punishment will seize you.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mxxviii{%
“And remember when He made you successors of A’ad and gave you a region in the earth, so you now build palaces in the soft plains and carve houses in rocks; therefore remember Allah’s favours and do not roam the earth spreading turmoil.”\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mxxix{%
The proud leaders of his people (mockingly) said to the weak Muslims, “Do you know that Saleh is (really) the Noble Messenger of his Lord?” They said, “We believe in whatever he has been sent with.”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mxxx{%
The proud ones said, “We deny what you have believed in.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mxxxi{%
So they hamstrung the she-camel and rebelled against the command of their Lord and said, “O Saleh! Bring upon us what you promise us, if you are a Noble Messenger.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mxxxii{%
Therefore the earthquake seized them, so at morning they remained lying flattened in their homes.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
Saleh therefore turned away from them and said, “O my people! Indeed I did deliver my Lord’s message to you and wished you good, but you do not want well-wishers.” (The people in the graves can hear the speech of those who are on earth.)\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And We sent Lut – when he said to his people, “What! You commit the shameful acts which no one in the creation has ever done before you?”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mxxxv{%
“You lustfully go towards men, instead of women! In fact, you have transgressed the limits.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
And his people had no answer except to say, “Turn them out of your dwellings; these are people who wish purity!”\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
And We rescued him and his family, except his wife – she became of those who stayed behind.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And We rained a shower (of stones) upon them; therefore see what sort of fate befell the culprits!\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And We sent Shuaib to Madyan from their community; he said, “O my people! Worship Allah – you do not have any God except Him; indeed a clear proof has come to you from your Lord, so measure and weigh in full and do not give the people their goods diminished, and do not spread turmoil in the earth after it is organised; this is for your good, if you believe.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mxl{%
“And do not be seated on every road in order to scare the travellers, and to prevent from Allah’s path the people who believe in Him, wishing to distort it; and remember when you were few and He increased your numbers; and see what sort of fate befell the mischievous!”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mxli{%
“And if a group among you believes in what I have been sent with, and another group does not believe, then wait until Allah judges between us; and Allah’s judgement is the best of all.”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mxlii{%
The proud leaders of his people said, “O Shuaib, we swear we will banish you and the Muslims who are with you, from our town or you must return to our religion”; he said, “Even though we detest it?”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mxliii{%
“We shall then have fabricated a lie against Allah if we return to your religion after Allah has rescued us from it; and it is not for any of us Muslims to return to your religion except if Allah, Who is our Lord, wills; the knowledge of our Lord encompasses all things; in Allah only we have trusted; our Lord! Decide with justice between us and our people – and Yours is the best decision.”\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mxliv{%
And the disbelieving leaders of his people said, “If you obey Shuaib, you will indeed be in a loss.”\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mxlv{%
Therefore the earthquake seized them – so at morning they remained lying flattened in their homes.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mxlvi{%
As if those who denied Shoaib had never lived in those homes; those who denied Shoaib, were themselves ruined.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mxlvii{%
So Shoaib turned away from them saying, “O my people! Indeed I did deliver my Lord’s message to you and gave you sound advice; so why should I grieve for the disbelievers?” (The people in the graves can hear the speech of those who are on earth.)\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mxlviii{%
And never did We send any Prophet to a dwelling but We seized its people with hardship and adversity so that they may become humble.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then We changed the misfortune into prosperity to the extent that they became numerous and said, “Indeed grief and comfort did reach our ancestors” – so We seized them suddenly in their neglect.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ml{%
And had the people of the dwellings believed and been pious, We would have surely opened for them the blessings from the sky and from the earth, but in fact they denied, and We therefore seized them on account of their deeds.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mli{%
Do the people of the dwellings not fear that Our wrath may come upon them at night while they are asleep?\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mlii{%
Or do the people of the dwellings not fear that Our wrath may come upon them during the day, while they are playing?\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mliii{%
Are they oblivious to Allah’s secret plan? So none is unafraid of Allah’s secret plan except the people of ruin!\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mliv{%
Or did not those who inherited the land after its owners, get enough guidance that if We will, We can afflict them with calamity for their sins? And We set seals upon their hearts so they do not hear.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mlv{%
These are the dwellings – the affairs of which We relate to you (Prophet Mohammed – peace and blessings be upon him); and indeed their (respective) Noble Messengers came to them with clear proofs; so they were not able to believe in what they had denied before; this is how Allah sets seals upon the hearts of disbelievers.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mlvi{%
And We found most of them not true to their words; and indeed We found most of them disobedient.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then after them, We sent Moosa with our signs to Firaun and his court members, but they did injustice to those signs; therefore see what sort of fate befell the mischievous!\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mlviii{%
And Moosa said, “O Firaun! Indeed I am a Noble Messenger from the Lord Of The Creation.”\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mlix{%
“It is obligatory for me not to speak concerning Allah except the truth; I have come to you all with a clear sign from your Lord, therefore let the Descendants of Israel go with me.”\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mlx{%
Said Firaun, “If you have come with a sign, then present it if you are truthful!”\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mlxi{%
Therefore Moosa put down his staff – it immediately turned into a visible python.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mlxii{%
And putting his hand in his bosom, withdrew it – so it shone brightly before the beholders.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mlxiii{%
Said the chieftains of Firaun’s people, “He is really an expert magician.”\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mlxiv{%
“He wishes to expel you all from your kingdom; so what do you advise?”\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said, “Stop him and his brother, and send announcers to the cities to gather people.”\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mlxvi{%
“To bring all the expert magicians to you.”\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mlxvii{%
And the magicians came to Firaun, and said, “Will we get some reward if we are victorious?”\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He said, “Yes, and you will then become close to me.”\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said, “O Moosa! You may throw first – or shall we be the first to throw?”\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mlxx{%
He said, “You throw”; when they threw, they cast a magic spell upon the people’s eyes and terrified them, and they brought a great magic.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mlxxi{%
And We inspired Moosa that, “Put forth your staff”; it immediately began swallowing up their fabrications.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mlxxii{%
So the truth was proved and their works were disproved.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
They were therefore defeated here and they turned back humiliated.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
And the magicians were obliged to fall prostrate.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mlxxv{%
They said, “We have accepted faith in the Lord Of The Creation.”\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
“The Lord of Moosa and Haroon.”\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Said Firaun, “You have accepted faith in Him before I gave you permission! This is indeed a grand conspiracy you have plotted in the city, in order to expel its people from it; so now you will come to know!”\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
“I swear I will cut off your hands and your feet from alternate sides and then crucify you all.”\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said, “We shall return to our Lord.”\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mlxxx{%
“And what did you dislike in us, except that we believed in the signs of our Lord when they came to us? Our Lord! Pour (bestow abundantly) patience on us, and bestow us death as Muslims.”\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
The chieftains of Firaun’s people said, “Are you releasing Moosa and his people to cause turmoil in the land, and for Moosa to abandon you and your appointed deities?” He said, “We shall now slay their sons and spare their women; and indeed we have power over them.”\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Moosa said to his people, “Seek the help of Allah and patiently endure; indeed the Owner of the earth is Allah – He appoints as its successor whomever He wills; and the final triumph is for the pious.”\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said, “We have been oppressed before you came to us, and after you have come to us”; he said, “It is likely that your Lord may destroy your enemy and in his place make you the rulers of the earth, and then see what deeds you perform.”\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
And indeed We seized the people of Firaun with a famine of several years and with reduction of fruits, so that they may follow advice.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
So when good would reach them they would say, “This is for us”; and when misfortune reached them, they would infer it as ill omens of Moosa and his companions; pay heed! The misfortune of their ill luck lies with Allah, but most of them are unaware.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
And said, “You may come with any sign to us, in order to cast a magic spell on us – yet by no means are we going to believe in you.”\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
We therefore sent against them the flood and the locusts and the vermin (or insects) and the frogs and the blood – separate signs; in response they were proud and were a guilty people.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
And whenever the punishment came upon them they said, “O Moosa! Pray to your Lord for us, by means of His covenant which you have; indeed if you lift the punishment from us we will surely accept faith in you and let the Descendants of Israel go with you.”\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
Consequently whenever We lifted the punishment from them for a term which they must reach, they used to then turn away.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mxc{%
We therefore took revenge from them; so We drowned them in the sea for they used to deny Our signs and were ignoring them.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mxci{%
And We made the people who were oppressed, the inheritors of the eastern and western parts of the land in which We placed blessings; and the good promise of your Lord was fulfilled for the Descendants of Israel – the reward of their patience; and We destroyed whatever Firaun and his people built and whatever they had contrived.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We transported the Descendants of Israel across the sea – so they came across a people who used to squat in seclusion in front of their idols; they said, “O Moosa! Make a God for us, the way they have so many Gods!” He said, “You are indeed an ignorant people.”\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mxciii{%
“The condition they are in is, in fact, one of destruction – and all what they do is utter falsehood.”\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said, “Shall I seek for you a God other than Allah, whereas He has given you superiority above the entire world?” (By sending His message towards you).\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mxcv{%
And remember when We rescued you from Firaun’s people who were afflicting you with a dreadful torment; slaughtering your sons and sparing your daughters; and in it was a great favour from your Lord.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And We agreed with Moosa a covenant for thirty nights (of solitude) and completed it by adding ten to them, so the covenant of His Lord amounted to forty nights in full; and Moosa said to his brother Haroon, “Be my deputy over my people and make reform and do not allow the ways of the mischievous to enter.”\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Moosa presented himself upon Our promise, and his Lord spoke to him, he said, “My Lord! Show me Your Self, so that I may see You”; He said, “You will never be able to see Me, but look towards the mountain – if it stays in its place, then you shall soon see Me”; so when his Lord directed His light on the mountain, He blew it into bits and Moosa fell down unconscious; then upon regaining consciousness he said, “Purity is to You! I incline towards You, and I am the first Muslim.”\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mxcviii{%
Said Allah, “O Moosa! I have chosen you from mankind by (bestowing) My messages and by My speech; so accept what I have bestowed upon you and be among the thankful.”\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We wrote for him on the tablets, the advice for all things and the details of all things; and commanded “Accept it firmly and command your people to choose its good advices; soon I shall show you people the destination of the disobedient.”\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mc{%
“And I shall turn away from My signs the people who unjustly wish to be admired in the earth; and if they see all the signs, they would not believe them; and if they see the path of guidance, they would not prefer to tread it; and if they see the way of error, they would present themselves to tread it; that is because they denied Our signs and were ignoring them.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mci{%
And those who denied Our signs and the confronting of the Hereafter – all their deeds are wasted; what recompense will they get, except what they used to do?\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mcii{%
And behind Moosa, his people moulded a calf from their ornaments – a lifeless body making sounds like a cow; did they not see that it neither speaks to them nor guides them in any way? They chose it (for worship), and were unjust.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mciii{%
And when they repented and realised that they had gone astray, they said, “If our Lord does not have mercy on us and forgive us, we are ruined.”\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Moosa returned to his people, angry and upset, he said, “What an evil way you have handled affairs on my behalf, behind me; did you hasten upon the command of your Lord?” And he cast down the stone tablets, and catching hold of his brothers hair, began pulling him towards him; said Haroon said, “O the son of my mother! The people thought I was weak and would have probably killed me; so do not make my enemies laugh at me and do not identify me with the unjust.”\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mcv{%
He submitted, “My Lord! Forgive me and my brother and admit us into Your mercy; and You are the Most Merciful of all those who show mercy.”\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mcvi{%
Indeed those who took the calf – the punishment from their Lord, and humiliation will reach them in the life of this world; and this is the way We reward those who fabricate lies.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mcvii{%
And those who performed misdeeds and then repented and accepted faith – so after that, your Lord is Oft Forgiving, Most Merciful.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mcviii{%
And when the anger of Moosa abated, he picked up the stone tablets; and in their texts are guidance and mercy for those who fear their Lord.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mcix{%
And Moosa chose seventy men from his people for Our promise; therefore when the earthquake seized them, he submitted, “My Lord! If You had willed You could have destroyed them and me, even earlier! Will You destroy us for the deeds which the ignorant among us did? That is not but Your testing us; with it You send astray whomever You will and guide whomever You will; You are our Master, so forgive us and have mercy on us, and You are the Best of the Forgiving.”\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mcx{%
“And destine good for us in this world and in the Hereafter – We have indeed inclined towards You”; He said, “I give My punishment to whomever I will; and My mercy encompasses all things; so I shall soon destine favours for those who fear and pay the charity, and they believe in Our signs.”\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mcxi{%
“Those who will obey this Noble Messenger (Prophet Mohammed – peace and blessings be upon him), the Herald of the Hidden who is untutored* (except by Allah), whom they will find mentioned in the Taurat and the Injeel with them; he will command them to do good and forbid them from wrong, and he will make lawful for them the good clean things and prohibit the foul for them, and he will unburden the loads and the neck chains which were upon them; so those who believe in him, and revere** him, and help him, and follow the light which came down with him – it is they who have succeeded." (*The Holy Prophet was taught by Allah Himself – see Surah 55 Al-Rahman. **To honour the Holy Prophet – peace and blessings be upon him – is part of faith. To disrespect him is blasphemy.)\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “O people! Indeed I am, towards you all, the Noble Messenger of Allah – for Whom (Allah) only is the kingship of the heavens and the earth; there is none worthy of worship, except Him – giving life and giving death; therefore believe in Allah and His Noble Messenger, the Prophet who is untutored (except by Allah), who believes in Allah and His Words, and obey him (the Prophet) to attain guidance.” (Prophet Mohammed – peace and blessings be upon him – is the Prophet towards all mankind.)\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mcxiii{%
And among the people of Moosa is a group that shows the true path, and establishes justice with it.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mcxiv{%
And We divided them into twelve tribes, as separate groups; and when his people asked him for water, We revealed to Moosa, “Strike the rock with your staff”; so twelve springs gushed forth from it; each group recognised its drinking-place; and We made the clouds a canopy over them and sent down the Manna and the Salwa (birds) on them; “Eat of the good things we have provided you”; and they did not wrong Us in the least, but they used to wrong themselves.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mcxv{%
And remember when they were commanded, “Reside in this township and eat whatever you wish in it, and say ‘Sins are forgiven’ and enter the gate prostrating – We will forgive you your sins; We shall soon bestow more upon the virtuous.”\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mcxvi{%
So the unjust among them changed the words, contrary to what they had been commanded – consequently We sent down upon them a punishment from the sky – the recompense of their injustice.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mcxvii{%
And ask them (O dear Prophet Mohammed – peace and blessings be upon him) of the township that was by the sea; when they used to exceed in the matter of the Sabbath – when their fish used to come swimming atop the water in front of them on the day of Sabbath and not come on the days it was not Sabbath; this is how We used to test them, due to their disobedience.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And when a group among them said, “Why do you preach to a people whom Allah is going to destroy or mete out a severe punishment?” They said, “To have an excuse before your Lord, and that perhaps they may fear.”\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mcxix{%
And when they forgot the advices they had been given, We rescued those who forbade evil, and seized the unjust with a dreadful punishment – the recompense of their disobedience.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mcxx{%
Consequently when they rebelled against the command to refrain, We said to them, “Be apes, despised!”\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mcxxi{%
And remember when your Lord announced the command that till the Day of Resurrection I will certainly send such oppressors against them, who will inflict them with a dreadful punishment; indeed your Lord is swift in meting out punishment; and indeed He is Oft Forgiving, Most Merciful.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We divided them in the earth as separate groups; some of them are righteous and some are the other type; and We tested them with good (favours) and evil things (adversities) so that they may return.\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
And after them in their place, came those unworthy successors who inherited the Books – they accept the goods of this world (as bribes) and say, “We shall soon be forgiven”; and if similar goods come to them again, they would accept it; was not the covenant taken from them in the Book, that they must not relate anything to Allah except the truth, and they have studied it? And indeed the abode of the Hereafter is better for the pious; so do you not have sense?\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
And those who hold fast to the Book, and have kept the prayer established; and We do not waste the wages of the righteous.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And when We raised the Mount (Sinai) above them as if it were a canopy, and they thought that it would fall upon them; “Accept firmly what We have given you, and remember what is in it, so that you may become pious.”\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And remember when your Lord brought forth the generations from the backs of the Descendants of Adam, and made them their own witness; “Am I not your Lord?”; they all said, “Yes surely You are, why not? We testify”; for you may say on the Day of Resurrection that, “We were unaware of this.”\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Or you may say, “It is our ancestors who first ascribed partners (to Allah) and we were (their) children after them; so will You destroy us on account of the deeds of the followers of falsehood?”\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
And this is how We explain the verses in different ways, and so that they may return.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mcxxix{%
And O dear Prophet (Mohammed – peace and blessings be upon him) recite to them the case of the one to whom We gave Our revelations, and in response he departed from them completely – so Satan went after him – he therefore became of the astray.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mcxxx{%
And had We willed We could have raised him because of the revelations, but he clung to the earth and followed his own desires; his condition therefore is like that of a dog; if you attack him he hangs out his tongue and if you leave him he hangs out his tongue; this is the state of the people who denied Our signs; therefore preach, so that they may give thought.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
What an evil example is of those who denied Our signs and used to wrong only their own souls.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
Whomever Allah guides – only he is on the right path; and whomever He sends astray – it is they who are the losers.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
And indeed We have created many jinns and men for hell; they have hearts in which their is no understanding; and the eyes they do not see with; and the ears they do not hear with; they are like cattle – in fact more astray; it is they who are the neglectful.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
And for Allah only are the best names, so invoke Him by them; and abandon those who depart from the truth regarding His names; they will soon receive the reward of their deeds.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
And from Our creation is a group that shows the truth and establishes justice with it.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
And those who denied Our signs – We shall soon steadily lead them towards the punishment, from the place they will not know.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
And I will give them respite; indeed My secret plan is extremely solid.\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Do they not ponder that their companion is far removed from insanity? In fact he is clearly a Herald of Warning.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Have they not pondered deeply regarding the kingdom of the heavens and the earth, and whatever things Allah created? And that possibly their promise (of death) may have come near? So after this*, in what will they believe? (*Advent of the Last Prophet and the Holy Qur’an.)\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@mcxl{%
For one whom Allah sends astray, there is none to guide him; and He leaves them to wander in their rebellion.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask you about the Resurrection, as to when it is destined; say, “Indeed its knowledge is with my Lord; only He will manifest it at its time; it is proving cumbersome in the heavens and the earth; it will not come to you except suddenly”; they question you as if you have researched it deeply; say, “Indeed its knowledge is with Allah only but most people do not know.”\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say, “I have no autonomy to benefit or hurt myself, except what Allah wills; and were I to procure knowledge of the hidden on my own, it would be that I had accumulated a lot of good; and no misfortune would touch me; I am purely a Herald of Warning and Glad Tidings to the people who believe.”\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He Who created you from a single soul, and from him made its mate for him to gain comfort with her; so when the male covered her, she was burdened lightly in her womb, and she therefore moved easily carrying it; and when she felt the burden heavy, they both cried to their Lord Allah, “Indeed You may give to us a child as You will, so we will surely be thankful.”\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@mcxliv{%
So when He bestowed them a normal child, they ascribed partners (to Him) in respect of what He had bestowed upon them; therefore Supreme is Allah, above all that they ascribe as partners.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Do they (the disbelievers) ascribe (false deities) that which do not create anything, but are themselves created?\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
And cannot provide any help to them, nor do they help themselves?\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
And if you call the disbelievers to guidance, they do not follow you; it is the same for you, whether you invite them or remain silent.\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Indeed those whom you (the disbelievers) worship besides Allah are slaves like you – so call them and they may answer you, if you are truthful!\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Do they have feet to walk with? Or have they hands to hold with? Or have they eyes to see with? Or have they ears to hear with? Say, “Call upon your ascribed partners and conspire against me, and do not give me respite.”\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@mcl{%
“Indeed my Protector is Allah Who has sent down the Book; and He befriends the righteous.”\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@mcli{%
“And those whom you worship besides Him cannot help you nor do they help themselves.”\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@mclii{%
And if you call them to guidance they do not listen; and you (Prophet Mohammed – peace and blessings be upon him) observe them looking towards you, whereas they do not perceive anything.\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@mcliii{%
And O dear Prophet (Mohammed – peace and blessings be upon him) adopt forgiveness, and enjoin virtue, and turn away from the ignorant.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@mcliv{%
And O listener! If the devil provokes you, seek the refuge of Allah; indeed He is All Hearing, All Knowing.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@mclv{%
Indeed those who fear get alerted whenever a temptation from the devil troubles them, and they perceive immediately.\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@mclvi{%
And the devils pull those who their brothers into error, and then do not make any relaxation.\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@mclvii{%
And O dear Prophet (Mohammed – peace and blessings be upon him) when you do not bring to them a verse, they say, “Why did you not fabricate it?” Say, “I follow only what is divinely revealed to me from my Lord”; this (the Holy Qur’an) is an enlightenment from your Lord, and a guidance and a mercy for the Muslims.\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@mclviii{%
And when the Qur’an is recited, listen to it attentively and keep silent, so that you receive mercy.\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@mclix{%
And remember your Lord within your hearts humbly and with fear, and softly with your tongues, morning and evening, and do not be of the neglectful.\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@mclx{%
Indeed those who are with your Lord are not conceited towards worshipping Him, and they proclaim His Purity and it is to Him they prostrate. (Command of Prostration \# 1)\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask you O dear Prophet (Mohammed – peace and blessings be upon him) concerning the war booty; say, “Allah and the Noble Messenger are the owners of the war booty; so fear Allah and maintain friendship among yourselves; and obey Allah and His Noble Messenger, if you have faith."\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mclxii{%
Only they are the believers whose hearts fear when Allah is remembered, and their faith advances when His verses are recited to them, and who trust only in their Lord.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mclxiii{%
Those who keep the prayer established and spend in Our cause from what We have bestowed upon them.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mclxiv{%
These are the true Muslims; for them are ranks before their Lord, and forgiveness and an honourable sustenance.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mclxv{%
The way your Lord caused you, O dear Prophet to come forth from your home with the truth; and indeed a group of Muslims were unhappy about it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mclxvi{%
Disputing with you regarding the truth after it had been made clear, as if they were being herded towards a visible death.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mclxvii{%
And remember when Allah promised you that one of the two groups (of enemies) is for you, and you wished to get the one that posed no danger, and Allah willed to prove the truth with His Words, and to cut the origins of the disbelievers.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mclxviii{%
In order that He may prove the truth and disprove falsehood, even if the criminals get annoyed.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mclxix{%
When you (Prophet Mohammed – peace and blessings be upon him) were seeking the help of your Lord, so He answered your prayers that, “I will help you with a row of thousands of angels.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mclxx{%
And Allah did this just for your happiness and for your hearts to gain contentment; and help does not come except from Allah; indeed Allah is Almighty, Wise.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mclxxi{%
When He made the slumber overcome you, so it was as a peacefulness from Him, and sent down water from the sky upon you to purify you with it, and to remove the impurity of Satan from you, and to give your hearts fortitude and firmly establish your feet with it.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mclxxii{%
And when O dear Prophet, your Lord was inspiring the angels that, “I am with you – so make the believers stand firm; I will soon instil fear into the hearts of the disbelievers, so strike above the disbelievers’ necks and hit their each and every bone joint.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
This is because they opposed Allah and His Noble Messenger; and whoever opposes Allah and His Noble Messenger – then indeed Allah’s punishment is severe.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
Therefore taste this for now, and along with it for the disbelievers is the punishment of fire.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O People who Believe! When you confront a large army of disbelievers in battle, do not turn your backs to them.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
And on that day whoever turns his back to them, except for a battle strategy or to join one’s own company, has then turned towards Allah’s wrath, and his destination is hell; and what an evil place of return!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
So you did not slay them, but in fact Allah slew them; and O dear Prophet (Mohammed – peace and blessings be upon him) you did not throw (the sand) when you did throw, but in fact Allah threw; and in order to bestow an excellent reward upon the Muslims; indeed Allah is the All Hearing, the All Knowing.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
Therefore take this, and (know that) Allah will weaken the scheme of the disbelievers.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mclxxix{%
O disbelievers! If you seek a judgement, then this judgement has come to you; and if you desist, it is better for you; and if you return to mischief, We will punish you again; and your populace will not benefit you, however large it may be – and besides this, Allah is with the Muslims.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O People who Believe! Obey Allah and His Noble Messenger, and do not turn away from him after you have heard him speak.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
And do not be like those who said, “We have heard”, whereas they do not hear.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
Indeed the worst beasts in the sight of Allah are those (people) who are deaf, dumb – who do not have any sense.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
And had Allah found any goodness in them, He would have made them hear; and had He made them hear they would, in the end, have turned away and gone back.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O People who Believe! Present yourselves upon the command of Allah and His Noble Messenger, when the Noble Messenger calls you towards the matter that will bestow you life; and know that the command of Allah becomes a barrier between a man and his heart’s intentions, and that you will all be raised towards Him.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And fear the turmoil which will certainly not fall only upon a few selected unjust people among you; and know that Allah’s punishment is severe.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember when you were only a few and meek in the land, and feared that men may snatch you away – He therefore gave you refuge and strengthened you with His help, and gave you good things as sustenance, so that you may be thankful.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O People who Believe! Do not betray Allah and His Noble Messenger, nor purposely defraud your trusts.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
And know that your wealth and your children are a test, and that with Allah is an immense reward.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O People who Believe! If you fear Allah, He will bestow upon you (the criterion) that with which you will separate the truth from falsehood, and He will unburden your misdeeds and forgive you; and Allah is the Extremely Munificent.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcxc{%
And remember O dear Prophet when the disbelievers were scheming against you to either imprison you, or to kill you or to banish you; and they were scheming, and Allah was making His secret plan; and Allah’s secret plan is the best.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcxci{%
And when Our verses are recited to them they say, “Yes, we have heard – if we wanted we could also say something like this – these are nothing but stories of former people!”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And when they said, “O Allah! If this (the Qur’an) is really the truth from You, then shower upon us a rain of stones from the sky, or bring upon us some painful punishment.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcxciii{%
And it is not for Allah to punish them while you O dear Prophet (Mohammed – peace and blessings be upon him) are amongst them; and Allah will not punish them as long as they are seeking forgiveness. (Prophet Mohammed – peace and blessings be upon him – is a mercy unto mankind.)\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcxciv{%
And what is with them that Allah should not punish them, whereas in fact they prevent from the Sacred Mosque and they are not worthy (of being the custodians) of it; only the pious are its befitting custodians, but most of them do not have knowledge.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcxcv{%
And their prayer near the Kaa’bah is nothing except whistling and clapping; “So now taste the punishment – the result of your disbelief.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Indeed the disbelievers spend their wealth in order to prevent people from the way of Allah; so they will spend it now, and then regret over it, then they will be defeated; and the disbelievers will be gathered towards hell.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
In order that Allah may separate the filthy from the pure, and placing the filthy atop one another, make a heap and throw them into hell; it is they who are the losers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Say to the disbelievers that if they desist, what has passed will be forgiven to them; and if they do the same, the tradition of former people has already passed.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcxcix{%
And fight them until no mischief remains and the entire religion is only for Allah; then if they desist, Allah sees all what they do.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcc{%
And if they turn away, then know that Allah is your Master; so what an Excellent Master and what an Excellent Supporter!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that whatever you take as war booty, a fifth of that belongs to Allah and His Noble Messenger, and to relatives, and orphans, and the needy, and the traveller – if you have accepted faith in Allah and what We sent down to Our bondman on the decisive day – the day when two armies had met; and Allah is Able to do all things.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mccii{%
When you were on the near bank and the disbelievers on the far bank, and the caravan below you; and had you made an agreement between one another, you would have failed to reach on the appointed time – but this is in order that Allah may complete a thing that must be done – that he who dies may die by a clear proof and he who lives may live by a clear proof; and indeed Allah is surely, All Hearing, All Knowing.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcciii{%
When O dear Prophet, Allah used to show the disbelievers in your dream as only a few*; and O Muslims, had He shown them to you as many, you would have certainly lost courage and disputed over the affair, but Allah rescued (you); indeed He knows what lies within the hearts. (* They numbered more but their actual strength was equal to only a few.)\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcciv{%
And when at the time of fighting He made the disbelievers seem few to you, and you as few in their sight, in order for Allah to conclude the matter that must be done; and towards Allah is the return of all matters.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mccv{%
O People who Believe! When you meet an army, hold firm and remember Allah profusely, in order that you succeed.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey Allah and His Noble Messenger, and do not dispute with one another for you will lose courage again and your strength will be lost, and patiently endure; indeed Allah is with those who patiently endure.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mccvii{%
And do not be like those who came out from their houses proudly, and to be seen by men, and they prevent people from Allah’s way; and all their actions are within Allah’s control.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mccviii{%
And when Satan made their deeds seem good in their sight and said, “This day no one can overpower you, and you are under my protection”; so when the two armies came face to face, he scrambled back and said, “I am unconcerned with you – I can see what is not visible to you – I fear Allah”; and Allah’s punishment is severe.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mccix{%
When the hypocrites and those in whose hearts is a disease were saying, “These Muslims are proud of their religion”; and whoever trusts Allah, then indeed Allah is Almighty, Wise.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mccx{%
And if you see the angels when they are removing the souls of the disbelievers, hitting them on their faces and their backs; “Taste more of the punishment of the fire!” (Punishment in the grave is proven by this verse.)\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mccxi{%
“This is the recompense of what your own hands have sent ahead, and Allah does not oppress His bondmen.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mccxii{%
Like the ways of Firaun’s people, and those before them; they disbelieved in the signs of Allah – therefore Allah seized them on account of their sins; indeed Allah is Most Powerful, Severe in Punishing.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mccxiii{%
This is because Allah does not change the favour He has bestowed upon any people until they first change themselves, and indeed Allah is All Hearing, All Knowing.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mccxiv{%
Like the ways of Firaun’s people and those before them; they denied the signs of Allah – We therefore destroyed them on account of their sins and We drowned the people of Firaun; and they all were unjust.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mccxv{%
Indeed the worst beasts in the sight of Allah are the people who disbelieve and do not accept faith.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mccxvi{%
Those with whom you made a treaty, then they break their agreement each time and do not fear.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mccxvii{%
So if you find them in battle, kill them in a manner which makes those behind them scamper back, in the hope that they may learn a lesson.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mccxviii{%
And if you apprehend treachery from a nation, then throw back their treaty towards them in reciprocity; indeed Allah does not like the treacherous.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mccxix{%
And never may the disbelievers pride that they have escaped; indeed they can never defeat.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mccxx{%
And keep ready for them the maximum of forces you can and the maximum number of horses you can keep tethered, in order to instil awe in the hearts of those who are the enemies of Allah and who are your enemies, and in the hearts of some others whom you do not know; Allah knows them; and whatever you spend in Allah's cause will be repaid to you in full and you will never be in a loss.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mccxxi{%
And if they incline towards peace, you too lean towards it, and trust Allah; indeed He only is the All Hearing, the All Knowing.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mccxxii{%
And if they wish to deceive you, then indeed Allah is Sufficient for you; it is He Who has given you strength, with His help and with the Muslims.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
And has created harmony among their hearts; if you had spent all that is in the earth you could not have created harmony among their hearts, but Allah has created harmony among them; indeed He only is Almighty, Wise.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Herald of the Hidden! Allah is Sufficient for you and for all these Muslims who follow you.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Herald of the Hidden! Urge the believers to fight; if there are twenty persevering men among you, they shall overcome two hundred; and if there are a hundred among you, they shall overcome a thousand disbelievers because the disbelievers are a people who do not have sense.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
So now Allah has made an ease upon you and He knows that you are weak; so if there are a hundred persevering men among you, they shall overcome two hundred; and if there are a thousand among you, they shall overcome two thousand by the command of Allah; and Allah is with those who patiently endure.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It does not befit any Prophet to capture the disbelievers alive until he has profusely shed their blood in the land; you people desire the wealth of this world; and Allah wills the Hereafter, and Allah is Almighty, Wise.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Had Allah not pre-destined a matter then, O Muslims, a terrible punishment would have come upon you due to the ransom you took from the disbelievers.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mccxxix{%
Therefore benefit from the booty you have received, lawful and good; and keep fearing Allah; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Herald of the Hidden! Say to the captives whom you possess, “If Allah finds any goodness in your hearts, He will give you better than what has been taken from you, and will forgive you; and Allah is Oft Forgiving, Most Merciful.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
And if they wish to deceive you, they have already been disloyal to Allah, because of which He has given these disbelievers in your control; and Allah is All Knowing, Wise.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Indeed those who accepted faith and left their homes and belongings for Allah, and fought with their wealth and their lives in Allah's cause, and those who gave shelter and provided help, are the heirs of one another; and those who believed but did not leave their homes – you have no right in their estates until they migrate; and if they seek help from you in the matter of religion then it is your duty to provide help, except against the people between whom and you is a treaty; and Allah sees your deeds.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
And the disbelievers are the heirs of one another – if you do not do so, there will be turmoil in the land and a great chaos.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
And those who believed and migrated and fought in Allah's cause, and those who gave shelter and provided help – it is they who are the true believers; for them is pardon, and an honourable sustenance.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who afterwards believed and migrated and fought along with you – they too are from among you; and family members (blood relations) are nearer to one another in the Book of Allah; indeed Allah knows everything.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen Severance of ties is proclaimed by Allah and on behalf of His Noble Messenger, towards the polytheists with whom you had a treaty.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
Travel freely in the land for four months, and bear in mind that you cannot escape from Allah, and that Allah will humiliate the disbelievers.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
And proclaim from Allah and His Noble Messenger to all men on the day of the Great Pilgrimage (Haj) that Allah is disgusted with the polytheists, and so is His Noble Messenger; so if you repent it is better for you; but if you turn away, then know that you cannot escape from Allah; and give the disbelievers the glad tidings of a painful punishment.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
Other than those polytheists with whom you had a treaty, and they have not diminished anything from your treaty nor supported anyone against you – therefore fulfil their treaty up to the appointed term; indeed Allah befriends the pious.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mccxl{%
Then when the sacred months have passed, slay the polytheists wherever you find them, and catch them and make them captive, and wait in ambush for them at every place; then if they repent and keep the prayer established and pay the charity, leave their way free; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mccxli{%
And O dear Prophet (Mohammed – peace and blessings be upon him), if a polytheist seeks your protection, give him protection so that he may hear the Word of Allah, and then transport him to his place of safety; this is because they are an unwise people.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be a treaty with Allah and with His Noble Messenger for the polytheists, except for those with whom you made a treaty near the Sacred Mosque? So as long as they remain firm on the treaty for you, you too remain firm for them; indeed Allah is pleased with the pious.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mccxliii{%
Therefore how – when they are such that if they gain control over you, they would not have regard for any relations nor for any treaty? They please you with their mouths whereas their hearts contain rejection; and most of them are disobedient.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They exchanged the verses of Allah for an abject price, therefore prevented from His way; indeed what they do is extremely evil.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mccxlv{%
In respect of the Muslims, they do not keep regard for any relations nor any pacts; it is they who are the rebels.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
Then if they repent and keep the prayer established and pay the charity, they are your brothers in religion; and we explain Our verses in detail for the people of knowledge.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
And if they break their promises after making a treaty and malign your religion, then fight the leaders of disbelief – indeed their promises are nothing – in the hope that they may desist.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will you not fight the people who broke their promises, and intended to expel the Noble Messenger whereas they had started it? Do you fear them? So Allah has more right that you should fear Him, if you have faith.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mccxlix{%
So fight them – Allah will punish them at your hands, and He will disgrace them and assist you over them, and He will soothe the hearts of the believers.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mccl{%
And He will remove the anxiety of their hearts; and Allah may accept the repentance of whomever He wills; and Allah is All Knowing, Wise.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mccli{%
Are you under the illusion that you would be left just like this, whereas Allah has not yet made known those of you who will fight and not confide their secrets with anyone except Allah and His Noble Messenger and the Muslims? And Allah is Well Aware of your deeds.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcclii{%
It does not befit the polytheists to assemble in Allah’s mosques after themselves bearing witness of their disbelief; in fact all their deeds are wasted; and they will remain in the fire forever.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mccliii{%
Only those enliven the mosques of Allah who believe in Allah and the Last Day and establish prayer and pay the obligatory charity and fear none except Allah – so it is likely that they will be among the people of guidance.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mccliv{%
So have they taken the quenching of the pilgrims’ thirst and servicing of the Sacred Mosque as equal (in merit) to him who accepted faith in Allah and the Last Day, and fought in Allah’s way? They are not equal before Allah; and Allah does not guide the unjust.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who accepted faith, and left their homes and fought with their wealth and their lives in Allah’s way have a greater rank before Allah; and it is they who have succeeded.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord gives them the glad tidings of His mercy and His pleasure, and the Gardens in which are everlasting favours for them.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcclvii{%
They will abide in it for ever and ever; indeed with Allah is the great reward.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O People who Believe! Do not consider your fathers and your brothers as your friends if they prefer disbelief over faith; and whoever among you befriends them – then it is he who is the unjust.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say, “If your fathers, and your sons, and your brothers, and your wives, and your tribe, and your acquired wealth, and the trade in which you fear a loss, and the houses of your liking – if all these are dearer to you than Allah and His Noble Messenger and fighting in His way, then wait until Allah brings about His command; and Allah does not guide the sinful.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcclx{%
Indeed Allah helped you on many occasions – and on the day of Huneyn – when you prided in your multitude, so it did not benefit you at all, and the earth despite being vast became restricted for you – then you turned back and returned.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then Allah sent down His calm upon His Noble Messenger and upon the Muslims, and sent down armies you did not see, and punished the disbelievers; and such is the reward of the deniers.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Then afterwards Allah will give repentance to whomever He wills; and Allah is Oft Forgiving, Most Merciful.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O People who Believe! The polytheists are utterly filthy*; so after this year do not let them come near the Sacred Mosque; and if you fear poverty**, then Allah will soon make you wealthy with His grace, if He wills; indeed Allah is All Knowing, Wise. (* Filthy in body and soul. **Due to loss of trade.)\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight against the People given the Book(s) who do not accept faith in Allah and the Last Day, and who do not treat as forbidden what is forbidden by Allah and by His Noble Messenger, and who do not follow the true religion, until they pay the tariff with their own hands with humiliation.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcclxv{%
And the Jews said, “Uzair is the son of Allah”, and the Christians said “The Messiah is the son of Allah”; they utter this from their own mouths; they speak like the former disbelievers; may Allah kill them; where are they reverting!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They have taken their rabbis and their monks as Gods besides Allah and (also) Messiah the son of Maryam; and they were not commanded except to worship only One God – Allah; none is worthy of worship except Him; Purity is to Him from all that they ascribe as partners (to Him).\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
They wish to extinguish the light of Allah with their mouths, but Allah will not agree except that He will perfect His light, even if the disbelievers get annoyed.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
It is He Who has sent His Noble Messenger with guidance and the true religion, in order to prevail over all other religions – even if the polytheists get annoyed.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O People who Believe! Indeed many of the (Jewish) rabbis and the (Christian) monks unjustly devour people's wealth and prevent from Allah’s way; and those who hoard up gold and silver and do not spend it in Allah’s way – so them give the glad tidings of a painful punishment.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcclxx{%
The day when it will be heated in the fire of hell, and their foreheads and their sides and their backs will be branded with them; “Here is what you hoarded for yourselves; so now taste the joy of your hoarding!”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
Indeed the number of months before Allah is twelve – in the Book of Allah – since the day He created the heavens and the earth, of which four are sacred; this the straight religion; so do not wrong yourselves in those months; and constantly fight against the polytheists as they constantly fight against you; and know well that Allah is with the pious.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
Their postponing of the months is nothing but furtherance in disbelief – the disbelievers are misled by it – they decree it lawful in one year and regard it forbidden in another year, in order to equate to the number of the months which Allah has made sacred, and to make lawful what Allah has forbidden; their evil deeds seem good in their sight; and Allah does not guide the disbelievers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O People who Believe! What is the matter with you, that when it is said to you, “Migrate in Allah's cause”, you sit on the ground with heaviness? Have you preferred this worldly life over the Hereafter? And the wealth of the life of this world, in comparison with the Hereafter, is but only a little.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If you do not migrate, He will afflict you with a painful punishment and bring other people in your stead and you will not be able to harm Him in the least; and Allah is Able to do all things.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If you do not help him (Prophet Mohammed – peace and blessings be upon him), Allah has helped him – when he had to go forth due to the mischief of the disbelievers, just as two men* – when they were in the cave, when he was saying to his companion “Do not grieve; indeed Allah is with us”; then Allah caused His calm to descend upon him and helped him with armies you did not see, and disgraced the word of the disbelievers; and Allah’s Word is supreme; and Allah is the Almighty, the Wise. (* The Holy Prophet migrated only with S. Abu Bakr (who later became the first caliph) as his sole companion.)\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
Migrate – whether willingly or with a heavy heart and fight in Allah's cause with your wealth and your lives; this is better for you, if you realise.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Had there been some wealth near at hand or a short journey, they would have certainly accompanied you, but the difficult path became very distant for them; and they will now swear by Allah that “Had we been able, we would have surely accompanied you”; they destroy their own souls; and Allah knows that undoubtedly, they are indeed liars.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
May Allah forgive you*; why did you permit them** until the truthful ones had been manifested to you and the liars been exposed? (* This is an expression of love for the Holy Prophet – peace and blessings be upon him. ** The hypocrites had been permitted to stay back from the holy war.)\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
And those who believe in Allah and the Last Day will not seek exemption from you for not fighting with their wealth and their lives; and Allah well knows the pious.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
Only those ask for such an exemption from you who do not believe in Allah and the Last Day, and whose hearts are in doubt – so they waver in their doubts.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
And if going forth were acceptable to them, they would have made preparations for it, but Allah Himself disliked their getting up (to fight) so He filled them with laze and it was said “Continue sitting with those who remain seated.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
If they had gone forth among you, you would then not gain any increase from them except trouble, and seeking to cause turmoil they would run rumours among you; and their spies are among you; and Allah well knows the unjust.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
Indeed they had sought to cause turmoil at the outset, and O dear Prophet the scheme turned otherwise* for you, so much so that the truth came and the command of Allah appeared, and they disliked it. (* In your favour.)\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
And among them is one who requests you that, “Grant me exemption (from fighting) and do not put me to test”; pay heed! They have indeed fallen into trial; and indeed hell surrounds the disbelievers.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good befalls you they dislike it; and were some calamity to befall you, they would say, “We had resolved our matters in advance”, and would turn away rejoicing.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say, O dear Prophet “Nothing shall befall us except what Allah has destined for us; He is our Master; and the Muslims must rely only on Allah.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say, “What do you wait for to happen to us, except one of the two good things?* And for you, we look forward to Allah afflicting you with a punishment from Himself or by our hands; so wait – we too await with you.” (*Death in Allah’s way or victory.)\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say, “Spend willingly or with a heavy heart, it will never be accepted from you; indeed you are a disobedient people.”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
And their spending was not stopped being accepted, except because they disbelieved in Allah and His Noble Messenger, and they come to prayer with heavy hearts, and they do not spend except unwillingly.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mccxc{%
So let not their riches or their children surprise you; Allah only intends to punish them in the life of this world with these things and that they die only as disbelievers.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mccxci{%
And they (the hypocrites) swear by Allah that they are from among you (Muslims); and they are not from among you – however those people are afraid.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mccxcii{%
If they find some refuge, or caves, or a place to hide, they will break the bonds and return there.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mccxciii{%
And among them is one who slanders you regarding the distribution of charity; so if they receive some of it they would be happy – and if not, thereupon they get displeased!\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mccxciv{%
How excellent it would be, if they were pleased with what Allah and His Noble Messenger had given them and said, “Allah suffices us; Allah will now give us by His munificence, and (so will) Allah’s Noble Messenger – and towards Allah only are we inclined.”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mccxcv{%
The obligatory charity* is only for the destitute and the really needy, and those who collect it, and for those in whose hearts the love of Islam needs to be instilled**, and to free slaves, and to debtors, and in Allah's cause***, and to the traveller; this is decreed by Allah; and Allah is All Knowing, Wise. (* This applies only to Zakat. ** The new convert to Islam. *** To the fighter having no provisions for holy war.)\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And among them (the hypocrites) are those who trouble* the Herald of the Hidden (the Prophet) and say, “He is only ears**”; say “He is a listener for your good, he believes in Allah and believes in what the Muslims say, and is a mercy for the Muslims among you”; and for those who trouble the Noble Messenger of Allah, is a painful punishment. (*To disrespect / trouble the Holy Prophet – peace and blessings be upon him – is blasphemy. **He believes whatever he is told.)\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear by Allah in your presence in order to please you; whereas Allah – and His Noble Messenger – had more right that they should have pleased Him if they had faith.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Do they not know that for one who opposes Allah and His Noble Messenger, is the fire of hell, to remain in it forever? This is the greatest humiliation.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites fear for a chapter being revealed regarding them, which may disclose what is hidden in their hearts; say, “Keep mocking; Allah will certainly disclose what you fear.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mccc{%
And if you ask them, they will say, “We were just having fun and pastime”; say, “What! You mock at Allah and His verses and His Noble Messenger?”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mccci{%
“Do not feign excuses, you have turned disbelievers after becoming Muslims”; if We forgive some of you*, We shall punish others because they were guilty. (* One who kept quiet and later repented.)\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocrite men and women are all the same; enjoining wrong and forbidding right, and being tight-fisted*; they have forgotten Allah, so Allah has forsaken them; indeed the hypocrites – it is they who are really disobedient. (* Not spending in Allah's cause)\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah has promised the hypocrite men and hypocrite women and the disbelievers, the fire of hell in which they will remain forever; that is sufficient for them; and Allah’s curse is upon them; and for them is a never ending punishment.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mccciv{%
Like those who were before you – they were mightier than you in strength, and had more wealth and children than you; so they spent their portion – you spent your portion just as those before you spent their portion and you fell into shame (sin) like they had fallen into shame; their deeds have been wasted in the world and in the Hereafter; it is they who are the losers.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcccv{%
Did not the news of those before them reach them – the people of Nooh, and the A’ad, and the Thamud – the people of Ibrahim, the people of Madyan and the dwellings that were overturned? Their Noble Messengers had brought clear proofs to them; so it did not befit Allah’s Majesty to oppress them, but in fact they wronged themselves.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcccvi{%
And the Muslim men and Muslim women are the friends of one another; enjoining right and forbidding wrong, and keeping the prayer established and paying the obligatory charity, obeying Allah and His Noble Messenger; these are upon whom Allah will soon have mercy; indeed Allah is the Almighty, the Wise.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah has promised the Muslim men and Muslim women, Gardens beneath which rivers flow – they will abide in it forever – and pure dwellings in Gardens of everlasting stay; and the greatest (reward) is Allah’s pleasure; this is the supreme success.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Herald of the Hidden! Fight against the disbelievers and the hypocrites, and be stern with them; and their destination hell; and what an evil place to return!\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcccix{%
And they swear by Allah that they did not say it; whereas indeed they had certainly uttered the words of disbelief, and after having entered Islam turned disbelievers and had wished for what they did not get; and what annoyed them except that Allah, and His Noble Messenger, made them prosperous with His grace? So if they repent, it is better for them; and if they turn away, Allah will afflict them with a painful punishment – in this world and the Hereafter; and they will have neither a protector nor any supporter in the entire earth.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcccx{%
And among them are those who made a covenant with Allah that, “If He gives us by His munificence, we will surely give charity and surely become righteous.”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcccxi{%
Therefore when Allah gave them by His munificence, they hoarded it and turning their faces, went back.* (* Reneged on their promise).\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So following this, Allah put hypocrisy in their hearts until the day when they will meet Him – the result of their breaching the promise made to Allah, and because they lied.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Do they not know that Allah knows their secrets and the schemes they whisper, and that Allah is the All Knowing of all the hidden?\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
Those who find fault in the Muslims who give the charity wholeheartedly and in those who gain nothing except from their own toil – so they mock at them; Allah will punish them for their mocking; and for them is a painful punishment.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Whether you (O dear Prophet Mohammed – peace and blessings be upon him) ask forgiveness for them* or not ask forgiveness for them; even if you ask forgiveness for them seventy times, Allah will not forgive them; that is because they disbelieved in Allah and His Noble Messenger, and Allah does not guide the sinful. (* for the hypocrites.)\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who were left behind rejoiced that behind the Noble Messenger of Allah they had remained seated, and they were unwilling to fight in Allah's cause with their lives or their wealth, and said “Do not venture out in the heat”; say, “The fire of hell is the hottest”; if only they understood!\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
So they should laugh a little and weep much; the reward of what they used to earn.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
Then if Allah takes you back to a group of them and they seek permission from you to go out to fight, say to them, “You shall never go out with me nor ever fight with me against any enemy; you were happy to remain seated for the first time, therefore remain seated with those who stay behind.”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcccxix{%
And never offer funeral prayers for any of them* who dies, nor stand by his grave**; indeed they disbelieved in Allah and His Noble Messenger, and they died as sinners. (* It is forbidden to offer funeral prayers for the hypocrites. ** To ask forgiveness for them).\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcccxx{%
And do not be surprised at their wealth or their children; Allah only wills to torment them with it in this world, and that they pass away upon disbelief.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
And when a chapter is sent down that “Accept faith in Allah and fight along with His Noble Messenger”, the men of means among them seek exemption from you and say, “Leave us, for us to be with those who sit.”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They preferred to be with the women who stay behind, and their hearts have been sealed, so they do not understand.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the Noble Messenger and those who accepted faith with him, fought with their wealth and lives; and for them only are the virtues (rewards); and it is they who have achieved the goal.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
Allah has kept ready for them Gardens beneath which rivers flow, abiding in it forever; this is the greatest success.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
And came the ignorant* who make excuses seeking exemption, and those who lied to Allah and His Noble Messenger remained seated; a painful punishment will soon reach the disbelievers among them. (* of faith)\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is no reproach upon the old nor upon the sick nor upon those who do not have the means to spend, provided they remain faithful to Allah and His Noble Messenger; and there is no way of reproach against the virtuous; and Allah is Oft Forgiving, Most Merciful.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor against those who humbly present themselves before you in order that you provide them a mount, and receive an answer from you that “I do not have any beast to carry you” – and so they turn back with eyes overflowing with tears, due to the sorrow that they could not find the means to spend.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
The way (of reproach) is only against those who seek exemption from you although they are rich; they preferred to be with the women who stay behind – and Allah has sealed their hearts, so they do not know anything.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They will make excuses to you when you return to them; say, “Do not make excuses – we shall never believe you – Allah has given us your tidings; and Allah and His Noble Messenger will now see your deeds, and then you will return to Him Who knows everything, the hidden and the visible – He will inform you of all what you used to do.”\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will now swear by Allah before you, when you return to them, in order that you do not pay attention to them; so do not bother about them; they are indeed filthy; and their destination is hell; the reward of what they used to earn.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They swear before you that you may be pleased with them; so if you become pleased with them, then indeed Allah will never be pleased with the sinful.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The ignorant are more severe in disbelief and hypocrisy, and deserve to remain ignorant of the commands which Allah has revealed to His Noble Messenger; and Allah is All Knowing, Wise.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
And some of the ignorant are those who when spending in Allah's cause consider it a ransom, and await the coming of the cycles (of misfortunes) upon you; upon them only is the evil cycle of misfortune; and Allah is All Hearing, All Knowing.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
And some villagers are those who believe in Allah and the Last Day, and consider the spending as the means of obtaining proximity to Allah and obtaining the prayers of the Noble Messenger; pay heed! Yes indeed it is the means of proximity for them; Allah will soon admit them into His mercy; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
And leading everyone, the first are the Muhajirs* and the Ansar**, and those who followed them with virtue – Allah is pleased with them and they are pleased with Him, and He has kept ready for them Gardens beneath which rivers flow, to abide in it for ever and ever; this is the greatest success. (* The immigrants. **Those who helped the immigrants.)\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
And some of the illiterates around you are hypocrites; and some of the people of Medinah; hypocrisy has become ingrained in them; you do not know them*; We know them; We shall soon punish them twice** – they will then be consigned towards the terrible punishment.*** (*Until now or as well as We do. ** In life and in the grave *** of hell.)\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
And there are others who have acknowledged their sins and mixed a good deed with another that was bad; it is likely that Allah will accept their repentance; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
O dear Prophet (Mohammed – peace and blessings be upon him) take the obligatory charity from their wealth, by which you may cleanse them and make them pure, and pray in their favour; indeed your prayer is the contentment of their hearts; and Allah is All Hearing, All Knowing.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Do they not know that Allah only accepts repentance of His bondmen and He takes the charity* and that Allah only is the Most Acceptor of Repentance, the Most Merciful? (* into His control.)\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mcccxl{%
And say “Keep on with your works – Allah will now see your deeds, and so will His Noble Messenger and the Muslims; and soon you will return to the One Who knows everything – the hidden and the visible – so He will inform you of what you used to do.”\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mcccxli{%
And some are kept waiting for Allah’s command – He may punish them or accept their repentance; and Allah is All Knowing, Wise.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And those (hypocrites) who built a mosque to cause harm, and due to disbelief, and in order to cause divisions among the Muslims, and to await the one who is at the outset an opponent of Allah and His Noble Messenger; and they will surely swear that “We wished only good”; and Allah is witness that they are indeed liars.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Never stand (for worship) in that mosque*; indeed the mosque** that has been founded on piety from the very first day deserves that you should stand in it; in it are the people who wish to thoroughly cleanse themselves; and Allah loves the clean. (*The mosque built by the hypocrites. ** The mosque at Quba, built by the Holy Prophet and his companions. The merit of praying 2 Raka’ Nawafil in it is equal to the reward of an Umrah.)\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
So is one who established his foundation upon the fear of Allah and upon His pleasure better, or the one who laid his foundation upon the brink of a falling precipice, so it fell along with him into the fire of hell? And Allah does not guide the unjust.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
The building which they erected will constantly keep disturbing their hearts unless their hearts are torn to pieces; and Allah is All Knowing, Wise.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Indeed Allah has purchased from the Muslims their lives and their wealth in exchange of Paradise for them; fighting in Allah's cause, slaying and being slain; a true promise incumbent upon His mercy, (mentioned) in the Taurat and the Injeel and the Qur’an; who fulfils His promise better than Allah? Therefore rejoice upon your deal that you have made with Him; and this is the great success.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
Those who repent, those who worship, those who praise, those who fast, those who bow, those who prostrate, those who show right and forbid wrong and those who keep the limits of Allah in sight; and give glad tidings to the Muslims.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It does not befit the Prophet and those who believe, to pray for the forgiveness of polytheists even if they may be their relatives, after it has become clear to them that they are the people of hell.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
And the seeking of forgiveness for his father (paternal uncle) by Ibrahim was only because of a promise he had made to him; then when it became clear to him that he was an enemy of Allah, Ibrahim broke off ties with him; indeed Ibrahim is surely very soft-hearted, most forbearing.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mcccl{%
And it does not befit Allah’s Majesty to send a nation astray after He has guided them until He has made clear to them what they should avoid; indeed Allah knows everything.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mcccli{%
Indeed for Allah only is the kingship of the heavens and the earth; He gives life and He gives death; and other than Allah, you have neither a Protector nor any Supporter.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mccclii{%
Indeed Allah’s mercy inclined towards the Herald of the Hidden, and the Muhajirs and the Ansar who stood by him in the time of hardship, after it was likely that the hearts of a group among them would turn away – He then inclined towards them with mercy; indeed He is Most Compassionate, Most Merciful upon them.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And also upon the three who were kept in waiting; when the earth, vast as it is, was restricted for them, and they became weary of their own lives and became certain that there is no refuge from Allah except with Him; He then accepted their repentance in order that they remain repentant; indeed Allah is the Most Acceptor of Repentance, the Most Merciful.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O People who Believe! Fear Allah, and be with the truthful.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mccclv{%
It did not befit the people of Medinah and the people of the villages around them, to stay behind the Noble Messenger of Allah, nor to consider their own lives dearer than his life; that is because the thirst or the pain or the hunger that afflicts them in Allah's cause, and the step they tread on a place that angers the disbelievers, and whatever harm they cause the enemy – a good deed is recorded for them in lieu of all of these; indeed Allah does not waste the wages of the virtuous.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mccclvi{%
And whatever they spend, small or great, or any valley they cross – it is all recorded for them, so that Allah may reward them for their best deeds.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mccclvii{%
And it is not possible for the Muslims that all of them go out; so it should be that a party from each group goes forth in order to gain knowledge in religion, and upon returning they warn their people in the hope that they may avoid.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O People who Believe – fight the disbelievers who are near to you, and let them find severity in you, and know well that Allah is with the pious.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mccclix{%
And whenever a chapter is sent down, some of them say, “Whose faith among you has this promoted?” So it has promoted the faith of the believers and they are rejoicing!\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mccclx{%
And for those in whose hearts is a disease, it has added filth to their filth, and they died as disbelievers.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mccclxi{%
Do they not observe that they are tested once or twice every year? Yet they do not repent, nor do they heed advice!\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever a chapter is sent down, one of them looks at the other; “Is there someone watching you?” – and then they turn away; Allah has inverted their hearts because they are a people who do not understand.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
Indeed there has come to you a Noble Messenger from among you – your falling into hardship aggrieves him, most concerned for your well being, for the Muslims most compassionate, most merciful.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
Then if they turn away, say (O dear Prophet Mohammed – peace and blessings be upon him), “Allah suffices me; there is no worship except for Him; only Him have I trusted, and He is the Lord Of The Great Throne.”\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif-Lam-Ra*; these are verses of the Book of wisdom. (*alphabets of the Arabic language; Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Are people amazed that We have sent to a man among them, the divine revelation that “Warn the people and convey glad tidings to the believers that for them with their Lord is the place* of truth”? The disbelievers say, “Indeed he is an open magician.” (* Positions of honour on the Day of Resurrection or in heaven.)\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Indeed your Lord is Allah Who created the heavens and the earth in six days, then as befits His Majesty, established Himself upon the Throne* – He plans all matters; there is no intercessor except after His permission;* such is Allah, your Lord – therefore worship Him; so do you not ponder? (* Of Control over everything.** Prophet Mohammed (peace and blessings be upon him) will be the first to be granted permission to intercede.)\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
Towards Him only you all are to return; the promise of Allah; indeed He creates for the first time and then after its extinction creates it again, in order to give those who believe and do good deeds, the reward of justice; and for the disbelievers, boiling water to drink and a painful punishment – the recompense of their disbelief.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mccclxix{%
It is He Who created the sun radiating and the moon shining and appointed positions for it, for you to know the number of the years, and the account; Allah has not created it except with the truth; He explains the verses in detail for the people of knowledge.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mccclxx{%
Indeed in the alternation of the day and night, and all that Allah has created in the heavens and the earth, are signs for people who are pious.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Indeed those who do not expect to meet Us and have preferred the worldly life and are content with it, and those who neglect Our signs, –\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
Their destination is hell – the recompense of their deeds.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Indeed those who accepted faith and did good deeds, their Lord will guide them due to their faith; rivers will flow beneath them in the Gardens of favours.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
Their prayers in it will be, “Purity is to You, O Allah” and their greetings in it will be, “Peace”; and the conclusion of their prayers is, “All praise is to Allah, the Lord Of The Creation.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
Were Allah to send misfortune to the people as quickly as they hasten for the good*, their appointed term would have been finished; so We leave those who do not expect to meet Us, to wander in their rebellion. (* The way they wish the good to reach them quickly.)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
And when some hardship reaches man he prays to Us, while reclining and sitting and standing; and when We remove his hardship, he goes away as if he had never prayed to Us because of any hardship; this is how the deeds of the transgressors are made seeming good to them.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
And indeed We destroyed several generations before you when they crossed the limits – and their respective Noble Messengers came to them with clear proofs, but they were not such as would believe; this is how We reward the guilty.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We appointed you as caliphs in the earth after them, in order that We might see what deeds you perform.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And when Our clear verses are recited to them, the people who do not expect to meet Us say, “Bring a Qur’an other than this one, or change it”; say (O dear Prophet Mohammed – peace and blessings be upon him), “I do not have the right to change it on my own; I only follow what is divinely revealed to me; if I were to disobey my Lord*, then I fear the punishment of the Great Day (of Resurrection). (* Which is impossible.)\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say, “Had Allah willed I would not have recited it to you nor would He have made it known to you; so before this* I have spent an age among you; so do you not have sense?” (* Before Allah’s command to recite the Qur’an to you.)\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
So who is more unjust than one who fabricates a lie concerning Allah and denies His signs? Indeed the guilty shall never prosper.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
And they worship the thing other than Allah, which neither harms them nor benefits them*, and they say, “These are our intercessors** before Allah”; say, “What! You inform Allah of something which in His knowledge does not exist in the heavens or in the earth?” Purity and Supremacy are to Him, above their association. (* Some things like the sun, stars, trees are useful but they too are created by Allah. Their worship will not benefit – in fact it is harmful ** Only the virtuous will be granted permission by Allah to intercede.)\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
Mankind were only one nation* and then they differed, and had it not been for a promise** from your Lord, the matters in which they differed would have been decided here itself. (* On one proper faith. ** The account on the Last Day.)\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
And they say, “Why is not a sign sent down upon him from his Lord?” Proclaim, (O dear Prophet Mohammed – peace and blessings be upon him), “The hidden is only for Allah, therefore wait; I too am waiting with you.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
And when We give mankind the taste of mercy after some hardship which had afflicted them, they immediately start conspiring against Our signs; proclaim, “The secret plan of Allah is the fastest”; indeed Our angels record your scheming.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
It is He Who transports you over the land and the sea; to the extent that when you are in ships – and the ships sail with them with a favourable breeze and they rejoice at it – a gust of strong wind reaches them and waves come to them from every side and they realise that they are surrounded, – thereupon they pray to Allah as His sincere bondmen that, “If You rescue us from this, we will surely be thankful.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
Then when He rescues them, they start wrongfully committing oppression in the earth; O mankind! Your oppression is only a torment against yourselves; derive the benefit until you live in this world; you have then to return to Us and thereupon We shall show you your misdeeds.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
The example of the life of this world is similar to the water which We sent down from the sky, so due to it the earth’s vegetation grew in abundance – that which men and cattle eat; to the extent that when the earth has taken on her ornaments and is well beautified, and her owners thought that it is within their control, Our command came to it at night or at day – so We made it harvested as if it had not existed yesterday; this is how We explain the verses for the people who ponder.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
And Allah calls to the abode of peace, and guides whomever He wills on the Straight Path.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcccxc{%
For the people of virtue, is goodness and more than that; and neither will the blackness nor disgrace come upon their faces; it is they who are the people of Paradise; they will abide in it forever.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcccxci{%
And (for) those who earned evil*, the recompense of evil is equal to it – and disgrace will come upon them; they will have no one to save them from Allah; as if their faces are covered with pieces of the dark night; it is they who are the people of the fire; they will remain in it forever. (* The disbelievers.)\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
And on the day when We raise all of them together, then say to the polytheists, “Stay in your place – you and your partners (false deities)”; so We shall separate them from the believers, and their partners will say to them, “When did you ever worship us!?”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
“Therefore Allah suffices as a Witness between us and you, that we were not even aware that you worshipped us!”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
Here will every soul come to know what it has sent ahead, and they will be returned to Allah – their true Master, and they will lose all that they used to fabricate.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say, (O dear Prophet Mohammed – peace and blessings be upon him), “Who provides you sustenance from the sky and the earth? Or Who is the Owner of the ears and the eyes? And Who brings forth the living from the dead and Who brings forth the dead from the living? And Who plans all matters?” So they will now say, “Allah”; therefore say, “Then why do you not fear?”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
So such is Allah, your True Lord; therefore what remains after the truth, except error? So where are you reverting?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
This is how the Word of your Lord is proved concerning the sinful, so they will not believe.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say, “Is there any one among your partners (false deities) that can create for the first time and then after its extinction, create it again?” Proclaim, “Allah creates for the first time and then after its extinction, creates it again – so where are you reverting?”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say, “Is there any among your partners that shows the right path?” Say, “Allah shows the right path; so who should be obeyed – the One Who shows the right path, or one who does not even find the right path unless he is guided? So what has happened to you? What sort of a judgement you impose!”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcd{%
And most of them do not follow anything except assumptions; indeed assumption does not serve the least purpose (in place) of the truth; indeed Allah knows their deeds.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcdi{%
And this noble Qur’an is not such that anyone can invent it, without Allah revealing it – but it surely is a confirmation of the Books preceding it and is an explanation of all that is written on the (preserved) tablet – there is no doubt in it – it is from the Lord Of The Creation.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcdii{%
What! They dare say that “He has fabricated it”? Say, “Then bring one chapter like it and, other than Allah, call everyone you can if you are truthful.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcdiii{%
On the contrary, they denied the thing the knowledge of which they could not master, whereas they have not yet seen its outcome; similarly those before them had denied, therefore see what sort of fate befell the unjust!\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcdiv{%
And among them is one who accepts faith in it, and among them is one who does not accept faith in it; and your Lord well knows the mischievous.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcdv{%
And if they deny you, say, “For me are my deeds, and for you are your deeds; you have no concern with what I do, and I have no relation with what you do.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcdvi{%
And among them are some who listen to you; so will you make the deaf hear even if they do not have any sense?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And among them is one who gazes at you; so will you guide the blind* even if they cannot perceive? (* Deaf or blind to guidance.)\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Indeed Allah does not oppress men at all, but they do wrong themselves.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcdix{%
And on the day when He will raise all of them together, as if they had never stayed on earth except for a moment during the day, they will recognise one another; for completely ruined are those who denied the meeting with Allah and were not on guidance.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcdx{%
And whether We show you (O dear Prophet Mohammed – peace and blessings be upon him) part of what We promise them or whether We call you towards Us before it – in any case they have to return to Us – then Allah is the Witness of their deeds.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcdxi{%
And in every nation was a Noble Messenger (from Allah); so when their Noble Messenger came to them, they were judged with fairness, and they were not wronged.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcdxii{%
And they say, “When will this promise come, if you are truthful?”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say, “I have no autonomy to benefit or hurt myself, except what Allah wills*; for every nation is a fixed promise; when their promise comes, they cannot postpone it nor can they advance it one moment. (* To empower me.)\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say, “What is your opinion – if His punishment comes upon you at night or during the day, so what is there in it for which the guilty are being hasty?”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcdxv{%
“So will you believe it only when it has occurred? What! You believe in it now, whereas you were impatient* for it before? (* Eagerly demanding for it to occur.)\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Then the unjust will be told, “Taste the punishment forever; and you will be repaid only what you used to earn.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
And they ask you “Is it a reality*?” Say, “Yes, by oath of my Lord, indeed surely it is a reality, and you will not be able to escape.” (* The punishment of the hereafter.)\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
And if each unjust soul owned everything that is in the earth, it would have certainly given it in order to redeem itself; and they secretly felt repentant when they saw the punishment; and it has been judged between them with fairness and they will not be wronged.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Pay heed! Indeed everything that is in the heavens and the earth belongs only to Allah; pay heed! Indeed Allah’s promise is true, but most of them do not know.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mcdxx{%
And He gives life and gives death, and towards Him you will return.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O mankind! The advice has come to you from your Lord and a cure for the hearts – and guidance and mercy for believers.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say, “Upon Allah’s munificence and upon His mercy – upon these should the people rejoice”; that is better than all their wealth and possessions.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say, “What is your opinion – (regarding) the sustenance that Allah has sent down for you? So you have, on your own, deemed lawful and unlawful in it!”; say, “Has Allah given you permission for it, or do you fabricate a lie against Allah?”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
And what do they, who fabricate lies against Allah, assume will be their state on the Day of Resurrection? Indeed Allah is Most Munificent upon mankind, but most people are not thankful.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
And whatever work you (O dear Prophet Mohammed – peace and blessings be upon him) are engaged in and recite a part of the Qur’an from Him, and whatever you people do, We are Witness upon you from the time you begin it; and there is nothing in the earth or in the heaven worth the weight of the smallest particle hidden from your Lord, nor anything smaller or greater than it, which is not recorded in a clear Book.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Pay heed! Indeed upon the friends of Allah is neither any fear, nor any grief. (The friends of Allah are the best in the creation.)\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who have accepted faith and practice piety.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
There are good tidings for them in the life of this world and in the Hereafter; the Words of Allah cannot change; this is the supreme success.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
And do not grieve at their speech (O dear Prophet Mohammed – peace and blessings be upon him); indeed all honour is for Allah and He is the All Hearing, the All Knowing.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Indeed all those in the heavens and all those in the earth are in Allah’s control; and what do those who pray to the partners instead of Allah, follow? They do not follow anything except assumption, and they only make guesses.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
It is He Who created the night for you so that you may gain rest in it and the day giving sight; indeed in this are signs for the people who heed.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They said, “Allah has created a son for Himself”- Purity is to Him! He is the Perfect (Unwanting, free of needs); to Him only belongs all whatever is in the heavens and all whatever is in the earth; “You do not have any proof of this; do you say a thing concerning Allah which you do not know?”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say, “Indeed those who fabricate lies against Allah will never succeed.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
Enjoying a little in the earth, they have then to return to Us – We will then make them taste a severe punishment, the recompense of their disbelief.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
Read to them the story of Nooh; when he told his people, “O my people – if my standing here and reminding you of Allah’s signs have been intolerable for you – so I have trusted only Allah – then work jointly and strengthen your work along with your false deities, leaving no doubt regarding your work – then do whatever you can to me, and do not give me respite.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
“Then if you turn away, I do not ask any fee from you; my reward is only upon Allah, and I am commanded to be of the Muslims.”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
In response they denied him, so We rescued him and those with him in the ship, and made them caliphs, and We drowned those who denied Our signs; therefore see what sort of fate befell those who had been warned!\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then after him, We sent other Noble Messengers to their respective people – so they came to them with clear proofs – so they were not such as to believe in what they had denied before; this is how We set seals upon the hearts of rebels.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then after them, We sent Moosa and Haroon along with Our signs, to Firaun and his court members, so they were proud and were a guilty people.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcdxl{%
So when the truth came to them from Us, they said, “Indeed this is a clear magic.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Said Moosa, “What! You speak in this manner regarding the truth when it has come to you? Is this magic? And magicians never succeed.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said, “Have you two come to us to revert us from what we found our fathers upon, and that the leadership in the land may only be for you two? And we shall never believe in you both.”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
And Firaun said, “Bring every expert magician to me.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
So when the magicians came, Moosa said to them, “Cast whatever you intend to cast.”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
Therefore when they had cast, Moosa said, “This what you have brought, is magic; Allah will now make it void; indeed Allah does not make the works of the mischievous successful.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
“And Allah will prove the truth by His Words, even if the guilty get annoyed.”\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
So none accepted faith in Moosa, except a few descendants of his people, fearing Firaun and his court members, that they would force them to revert; and indeed Firaun was a rebel in the land; and indeed he crossed the limits.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
And Moosa said, “O my people! If you have accepted faith in Allah, then you should rely only upon Him, if you are Muslims.”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They said, “We have relied only upon Allah; Our Lord! Do not make us a test* for the unjust people.” (* By giving them power over us.)\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcdl{%
“And with Your mercy, rescue us from the disbelievers.”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We sent the divine revelation to Moosa and his brother that, “Build houses for your people in Egypt and make your houses as places of worship, and keep the prayer established, and give glad tidings to the Muslims.”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcdlii{%
And Moosa prayed, “Our Lord! You have given Firaun and his chiefs adornment and wealth in the life of this world, our Lord, that they may lead astray from Your path; our Lord! Destroy their riches and harden their hearts so that they may not accept faith until they witness the painful punishment.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcdliii{%
He said, “The prayer of you two is accepted, therefore remain firm, and do not follow the way of the unwise.”\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We transported the Descendants of Israel across the sea, therefore Firaun and his army pursued them with rebellion and injustice; until when the drowning overcame him he cried, “I accept faith that there is no True God except the One in Whom the Descendants of Israel believe, and I am a Muslim.”\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcdlv{%
“What! Now?* Whereas you were disobedient from the start and you were mischievous!” (This was said to Firaun.* Accepting faith at the time of death is of no use.)\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
“This day We shall salvage your body so that you may be a sign for those after you; and indeed most people are neglectful of Our signs.”\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
And indeed We provided the Descendants of Israel a place of honour, and bestowed good sustenance to them; and they did not fall into dispute except after the knowledge had come to them; indeed your Lord will judge between them on the Day of Resurrection concerning the matters in which they used to differ.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
And if you, O listener, have any doubt in what We have sent down towards you, then question those who have read the Book before you; undoubtedly, towards you has come the truth from your Lord, therefore do not be of those who doubt.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcdlix{%
And never be of those who denied the signs of Allah, for you will then be of the losers.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Indeed those for whom the Word of your Lord has proved true, will not believe.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
Even if every sign comes to them, until they witness the painful punishment.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
So if only had there been one dwelling* that believed and its belief would have benefited it – except the nation of Yunus (Jonah)! When they accepted faith, We removed the disgraceful punishment in the life of this world from them, and let them enjoy for a while. (* That was destroyed after being warned.)\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
And if your Lord willed, all those who are in the earth – everyone of them – would have accepted faith; so will you (O dear Prophet Mohammed – peace and blessings be upon him) force the people until they become Muslims?\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
And no soul can accept faith except by the command of Allah; and He sets the punishment upon those who do not have sense.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Proclaim, “Observe what is in the heavens and the earth”; and the signs and the Noble Messengers do not benefit the people who are not destined to believe.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
So what are they waiting for, except the days similar to the days of those who passed away before them? Say, “Then wait! I too am waiting with you.”\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then We shall save Our Noble Messengers and the believers – this is it; it is incumbent upon Our mercy to save the Muslims.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “O people! If you are in doubt concerning my religion, then (know that) I will never worship those whom you worship instead of Allah – but I worship Allah Who will give you death; and I am commanded to be of the believers.”\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
“And that ‘Set your face straight* for religion, apart from all others; and never be of those who ascribe partners (to Allah)’.” (* Your intention sincerely for religion.)\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
“And other than Allah, do not worship that which cannot benefit you nor cause you harm; then if you do so, you would be of the unjust.” (* Some things like the sun, stars, trees are useful but they too are created by Allah. Their worship will not benefit – in fact it is harmful.)\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
“And if Allah afflicts you with some suffering, there is none who can remove it except Him; and if He wills good for you, there is none who can repel His munificence; He bestows it upon whomever He wills from among His bondmen; He is the Oft Forgiving, the Most Merciful.” (* Help, cure, monetary aid etc., whatever benefit derived from any source, reaches us because Allah has given the source this power and is actually through the grace and mercy of Allah.)\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say, “O people! The truth* has come to you from your Lord; so whoever came to guidance, has come to guidance for his own benefit; and whoever strayed, has strayed for his own harm; and I am not a trustee over you.” (* Prophet Mohammed – peace and blessings be upon him, or Islam or the Qur’an.)\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And (O dear Prophet Mohammed – peace and blessings be upon him) follow what is divinely revealed to you, and have patience till Allah gives His command; and He is the Best of Rulers.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif-Lam-Ra*; “This is a Book, the verses of which are full of wisdom – then explained in detail – from the Wise, the Well Aware.” (* Alphabets of the Arabic language; Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
“That do not worship anyone except Allah; indeed I am for you a Herald of Warning and Glad Tidings, from Him.”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
“And ask forgiveness from your Lord and incline towards Him in repentance, He will provide you excellent sustenance until the appointed time and will bestow superiority to every one who excels; and if you turn away, I then fear the punishment of the Great Day upon you.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
“To Allah only you have to return, and He is Able to do all things.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
Pay heed! They fold up their breasts in order to conceal from Allah; pay heed! Even when they fully cover themselves up with their clothes, Allah knows all that what hide and all what they disclose; indeed He knows what is in the hearts.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
And there is none that walks upon the earth whose sustenance does not depend on the mercy of Allah – He knows where it shall stay and where it shall be deposited; everything is in a clearly explaining Book.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
And it is He Who created the heavens and the earth in six days – and His Throne was upon the water – so that He might test you, as to who among you have the best deeds*; and if you (O dear Prophet Mohammed – peace and blessings be upon him) say, “Indeed you will be raised again after death”, the disbelievers will surely say, “This is nothing but clear magic.” (* The creation of all things is in order to test mankind.)\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We postpone the punishment upon them for a specified time, they will surely say, “What holds it back?” Pay heed! On the day when it comes upon them, it will not be averted from them, and the very punishment they mocked at will encompass them.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
And if We bestow man the enjoyment of some mercy from Us and later withdraw it from him; surely he is most despairing, ungrateful.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
And if We bestow upon him the enjoyment of a favour after a misfortune that had befallen him, he will surely say, “The evils have gone away from me”; indeed he is jubilant, boastful.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
Except those who patiently endured and did good deeds; for them is forgiveness, and a great reward.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
So will you forsake part of what is divinely revealed to you and be disheartened because they say, “Why has not a treasure been sent down along with him?”, or “An angel should have come with him”? You are purely a Herald of Warning*; and Allah is the Guardian over all things. (* Therefore do not grieve over their sayings.)\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
What! They dare say that “He has fabricated it”? Say “Therefore bring ten fabricated chapters like these, and call on everyone you can other than Allah, if you are truthful.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
So O Muslims, if they are unable to reply to this challenge of yours, then know well that it is sent down only with the knowledge of Allah; and that except Him, there is no real God; so will you now accept?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Whoever desires the life of this world and its comforts, We shall give them the full reward for their deeds in it, and not make any reduction in it.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
These are the ones for whom there is nothing in the Hereafter except the fire; and all that they did there has gone to waste and all their deeds are destroyed.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcdxc{%
So is the one who is upon the clear proof* from his Lord, and comes a witness upon it from Allah, and before it the Book of Moosa, a leader and a mercy; they accept faith in it; and whoever denies it from all the groups, then the fire is promised for him; so O listener, do not have any doubt concerning it; indeed it is the truth from your Lord; but most people do not believe. (* The Jews who accepted faith in the Qur’an.)\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mcdxci{%
And who is more unjust than the one who fabricates a lie against Allah? They will be presented before their Lord, and the witnesses* will say, “These are they who lied concerning their Lord; the curse of Allah be upon the unjust!” (* The Prophets and angels.)\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
Those who prevent from the way of Allah and wish deviation in it; and it is they who disbelieve in the Hereafter.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
They will not be able to escape in the earth, nor do they have any protecting friends apart from Allah; they will have punishment upon punishment; they were unable to hear, nor used to see. (* Hear or see the truth.)\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
It is they who put their souls into ruin, and they lost all that they used to fabricate.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
They will be, unnecessarily, the greatest losers in the Hereafter.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
Indeed those who believed and performed good deeds and directed themselves towards their Lord – they are the people of Paradise; they will abide in it forever.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The example of the two groups is like one being blind and deaf, and the other seeing and hearing; are they equal in condition? So do you not ponder?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
And indeed We sent Nooh to his people that, “Indeed I am for you a clear Herald of Warning.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
“That you must worship none except Allah; indeed I fear the punishment of the calamitous day upon you.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@md{%
The chiefs of his people, who were disbelievers, said, “We see that you are just a mortal like us, and we do not see anyone following you except the most lowly among us, without insight; and we do not find any merit in you above us – in fact, we consider you liars.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdi{%
He said, “O my people! What is your opinion – if I am on a clear proof from my Lord and He has bestowed mercy upon me from Him, so you remained blind towards it; shall we force it upon you although you dislike it?”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdii{%
“And O my people! I do not ask any wealth from you for it; my reward is only upon Allah, and I am not going to repel the Muslims; indeed they will meet their Lord, but I find you people completely ignorant.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdiii{%
“And O my people! Who would rescue me from Allah if I repel them? So do you not think?”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdiv{%
“And I do not say to you, ‘I have the treasures of Allah’ nor that ‘I gain knowledge of the hidden’, nor do I say that, ‘I am an angel’ nor do I say to those whom your sights consider lowly, that Allah will never give them any good; Allah well knows what is in their hearts; if I do so, I would then be of the unjust.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdv{%
They said, “O Nooh, you have disputed with us and disputed in the extreme, therefore bring upon us what you promise us, if you are truthful.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said, “Allah will surely bring that upon you if He wills, and you will not be able to escape.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdvii{%
“And my advice will not benefit you if I wish you good, when Allah wills to keep you astray; He is your Lord and to Him you will return.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdviii{%
What! They dare say that, “He has fabricated it”? Say, “If I may have fabricated it, then my sin is upon me, and I am unconcerned with your sins.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was divinely revealed to Nooh that “None of your people will become Muslims, except those who have already accepted faith – therefore do not grieve at what they do.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdx{%
“And build the ship in front of Us, and by Our command, and do not speak to Me regarding the unjust; they will surely be drowned.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdxi{%
And Nooh builds the ship; and whenever the chiefs of his people passed by him, they used to laugh at him; he said, “If you laugh at us, then a time will come when we will laugh at you just as you laugh.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdxii{%
“So now you will come to know – upon whom comes the punishment that disgraces him, and upon whom descends the punishment that continues forever.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdxiii{%
To the extent that when Our command came and the oven overflowed, We said, “Board into the ship a couple – male and female – from every kind, and your family members, except those upon whom the Word has been passed*, and all other Muslims”; and only a few Muslims were with him. (* Whose fate has been sealed.)\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdxiv{%
And he said, “Board it – upon Allah’s name is its movement and its stopping; indeed my Lord is surely Oft Forgiving, Most Merciful.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdxv{%
And the same carries them amid waves like mountains; and Nooh called out to his son whereas he was standing apart, “O my son! Embark along with us*, and do not be with the disbelievers.” (* As a Muslim.)\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdxvi{%
He said, “I shall take the refuge of a mountain – it will save me from the water”; said Nooh, “Today there is none who can rescue from the punishment of Allah, except upon whom He has mercy”; and the wave came in between them, so he remained amongst the drowning.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was commanded, “O earth, swallow your water and, O sky, stop” – and the water was dried up and the matter was completed – and the ship stopped upon the mount Al-Judi and it was said, “Away with the unjust nation!”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Nooh prayed to his Lord – submitted he, “My Lord! Indeed my son is also of my family, and surely Your promise is true and You are the Greatest Ruler of all.”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said, “O Nooh, he is not of your family; his deeds are most improper; therefore do not ask Me a thing of which you do not have knowledge; I advise you not to be unwise.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdxx{%
He submitted, “My Lord! I seek your refuge from asking you the thing of which I do not have knowledge; and if You do not forgive me and do not have mercy on me, I would then be a loser.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said, “O Nooh! Alight from the ship along with peace from Us and the blessings that are upon you and upon some groups that are with you; and some groups are those whom We shall let enjoy this world and then a painful punishment from Us will reach them.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdxxii{%
These are the tidings of the hidden, which We reveal to you (O dear Prophet Mohammed – peace and blessings be upon him); you did not know them nor did your people, before this; therefore patiently endure; indeed the excellent fate is for the pious.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And towards the people of A’ad, their fellow man Hud; he said, “O my people! Worship Allah – there is no other True God except Him; you are purely fabricators.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
“O my people! I do not ask any fee from you for it; my reward is only upon Him Who has created me; so do you not have sense?”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdxxv{%
“And O my people! Seek forgiveness from your Lord, then incline towards Him in repentance – He will send abundant rain from the sky upon you and will give you much more strength than you have – and do not turn away committing crimes!”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said, “O Hud! You have not come to us with any proof and we will not forsake our deities upon your saying, nor will we believe you.”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
“We only say that you have been severely struck by one of our deities”; he said, “I make Allah a witness, and you all bear witness that I have no relation with whatever you ascribe (as partners to Allah)”-\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
“Besides Him – therefore all of you scheme against me and do not give me respite.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdxxix{%
“I rely upon Allah, Who is my Lord and your Lord; there is not a creature that walks, whose forelock is not in His control; indeed my Lord can be found on the Straight Path.”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdxxx{%
“Then if you turn away, I have conveyed to you what I was sent with towards you; and my Lord will bring others in your stead; and you will not be able to cause Him any harm; indeed my Lord is a Guardian over all things.”\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our command came, We rescued Hud and the Muslims who were with him, by Our mercy; and We saved them from a severe punishment.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
And these are the A’ad – they denied the signs of their Lord and disobeyed His Noble Messengers and followed the commands of every stubborn disobedient.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And a curse followed them in the world, and on the Day of Resurrection; pay heed! Indeed A’ad disbelieved in their Lord; away with A’ad, the people of Hud!\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And to the Thamud tribe, We sent their fellow man Saleh; he said, “O my people! Worship Allah, there is no other True God except Him; He created you from the earth and established you in it, so seek forgiveness from Him and incline towards Him in repentance; indeed my Lord is Close, Acceptor of Prayer.”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said, “O Saleh! You seemed very promising among us, before this – What! You forbid us from worshipping the deities of our forefathers? And indeed we have fallen into a deeply intriguing doubt concerning what you call us to.”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said, “O my people! What is your opinion – if I am on clear proof from my Lord and He has bestowed upon me mercy from Him, so who will rescue me from Allah if I disobey Him? So you will not increase anything for me, except loss!”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
“And O my people! This is the she-camel of Allah – a sign for you – so let her graze in Allah’s earth, and do not touch her with an evil intention for an imminent punishment will reach you.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
In response they hamstrung her, he therefore said, “Enjoy a further three days in your homes; this is a promise that will not be untrue.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
Therefore when Our command came, We rescued Saleh and the Muslims who were with him by Our mercy, and from the disgrace of that day; indeed your Lord is the Strong, the Almighty.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdxl{%
And the terrible scream seized the unjust – so at morning they remained lying flattened in their homes.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdxli{%
As if they had never lived there; indeed the tribe of Thamud disbelieved in their Lord; away with the Thamud!\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdxlii{%
And indeed Our angels came to Ibrahim with glad tidings – they said, “Peace”; he answered, “Peace” and without delay brought a roasted calf.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdxliii{%
And when he saw their hands not reaching towards it, he thought they were pretending and inwardly started fearing them; they said, “Do not be afraid – we are sent to the people of Lut.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And his wife was standing by and she started laughing*, so We gave her glad tidings regarding Ishaq, and following Ishaq, regarding Yaqub.** (* She was glad that the disbelieving people of Lut would be destroyed.** The birth of these two.)\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said, “Oh woe to me – will I bear a child whereas I am an old woman, and this my husband, is an old man? This is something really extraordinary.”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
The angels said, “Do you wonder at the command of Allah? Allah’s mercy and His blessings be upon you, O people of this house; indeed He only is Most Praiseworthy, Most Honourable.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
And when Ibrahim’s fear abated and the glad tidings reached him, he argued with Us regarding the people of Lut.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Indeed Ibrahim is most forbearing, very soft hearted, penitent.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdxlix{%
“O Ibrahim, turn away from this; indeed your Lord’s command has come; and indeed a punishment will come upon them, which will not be averted.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our angels came to Lut, he was distressed for them and was disheartened due to them, and said, “This is a day of great hardship.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came running towards him; and they were in the habit of committing evil deeds; he said, “O my people! These women of the tribe are my daughters* – they are purer for you – therefore fear Allah and do not disgrace me in the midst of my guests; is there not even a single righteous man among you?” (* The wives of those people.)\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said, “You know that we have no right to the daughters of your tribe; and you obviously know what we desire.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said, “If only I had the strength against you or were able to get the refuge of some strong support!”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdliv{%
The angels said, “O Lut! We are the sent ones of your Lord – they cannot get to you, therefore during the night take your entire household with you – and not one of you may turn around and see – except your wife*; she too will be afflicted with the same as they will be; indeed their promise is at morn; is not the morning imminent?” (* She was a disbeliever and sided with the culprits.)\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdlv{%
So when Our command came, We turned that township upside down and showered it continuously with stones of fired clay.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdlvi{%
That are marked, in the custody your Lord; and those stones are not at all far from the unjust!\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And to Madyan their fellow man Shuaib; he said, “O my people! Worship Allah – there is no other True God except Him; and do not make reductions in measure and weight – indeed I see you prosperous, and I fear the punishment of the Besieging Day (of Resurrection) upon you.”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdlviii{%
“O my people! Measure and weigh in full with justice, and do not give the people their goods diminished, and do not roam about in the earth causing turmoil.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdlix{%
“That which remains from Allah’s bestowal is better for you, if you believe; and I am not at all a guardian over you.”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said, “O Shuaib! Does your prayer command you that we forsake the deities of our forefathers or that we may not do as we wish with our own property? Yes indeed – only you are very intelligent, most righteous*.” (* They mocked at him with sarcasm.)\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said, “O my people! What is your opinion – if I am on a clear proof from my Lord and He has bestowed me with an excellent sustenance from Him (shall I ignore all this?); and the matter I forbid you to do, I do not wish that I myself act against it; I only intend to make improvements as far possible; my guidance is only from Allah; I rely only upon Him and towards Him only do I incline.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdlxii{%
“And O my people! May not your opposition to me occasion the coming upon you of the thing similar to what befell the people of Nooh or the people of Hud or the people of Saleh; and the people of Lut are not at all far from you!”\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
“Ask forgiveness from your Lord and then incline towards Him in repentance; indeed my Lord is Most Merciful, Most Affectionate.”\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said, “O Shuaib! We do not understand most of what you say, and indeed we perceive you weak among us; were it not for your relatives, we would have stoned you; and in our sight, you have no respect at all.”\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said, “O my people! Is the pressure upon you from my relatives, worth more than Allah? And you put Him* behind your backs; indeed whatever you do is all within my Lords’ control.” (* His command / my preaching.)\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
“And O my people! Keep on with your works in your positions, I am doing mine; very soon you will come to know – upon whom comes the punishment that will disgrace him, and who is the liar; and wait – I too am waiting with you.”\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our command came, We rescued Shuaib and the Muslims who were with him by Our mercy; and the terrible scream seized the unjust – so at morning they remained lying flattened in their homes.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
As if they had never lived there; away with the Madyan, just as the Thamud were removed afar!\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And indeed We sent Moosa with Our revelations and a clear domination.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdlxx{%
Towards Firaun and his court members, thereupon they followed the commands of Firaun; and the work of Firaun was not proper.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He will lead his people on the Day of Resurrection, therefore landing them into hell; and what a wretched place to land into!\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
And a curse followed them in the world, and on the Day of Resurrection; what a wretched gift is what they received.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
These are the tidings of the townships, which We relate to you (O dear Prophet Mohammed – peace and blessings be upon him) – some of them still stand and some are cut off.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
And We did not oppress them at all, but it is they who wronged themselves – therefore their deities, whom they worshipped other than Allah, did not in the least benefit them when your Lord’s command came; and due to them, they increased nothing but ruin.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
And similar is the seizure of your Lord when He seizes the townships upon their injustice; indeed His seizure is painful, severe.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Indeed in this is a sign for one who fears the punishment of the Hereafter; this is the day on which everyone will be gathered, and this is the Day of Attendance.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
And We do not postpone it except for a fixed term.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
When that day comes, no one will speak without His permission; so among them are the ill-fated and the fortunate.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
So those who are ill-fated, are in the fire – they will bray like donkeys in it.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
Remaining in it as long as the heavens and the earth remain, except as much as your Lord willed*; indeed your Lord may do whatever, whenever, He wills. (* Remaining forever even after the heavens and the earth are destroyed.)\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
So those who are fortunate are in Paradise – abiding in it as long as the heavens and the earth remain, except as much as your Lord willed; this is the everlasting favour.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
So O listener (followers of this Prophet), do not fall into doubt by what these disbelievers worship; they only worship just as their forefathers worshipped before; and indeed we shall pay them their due in full, undiminished.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
And indeed We gave Moosa the Book, hence there was discord regarding it; and were it not for a Word that had been previously passed from your Lord, the matter would have immediately been decided regarding them; and indeed they are in an intriguing doubt concerning it.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
And indeed to each and every one, your Lord will fully repay his deeds; He is Informed of their deeds.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
Therefore remain firm the way you are commanded to, and those who have turned along with you, and O people – do not rebel; indeed He is seeing your deeds.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And do not incline towards the unjust, for the fire will touch you – and you do not have any supporter other than Allah – then you will not be helped.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And keep the prayer established at the two ends of the day and in some parts of the night; indeed good deeds wipe out the evil deeds; this is an advice to those who heed it.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And have patience, for Allah does not waste the wages of the righteous.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
So why were not there some people, from the generations before you, who had some goodness remaining in them in order to prevent (others) from causing turmoil in the earth? Except a few among them – the very ones whom We had rescued; and the unjust remained pursuing what they were given, and they were guilty.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mdxc{%
And your Lord is not such as to destroy townships without reason, while their people are righteous.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mdxci{%
And had your Lord willed, He would have made mankind one nation – and they will always keep differing.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mdxcii{%
Except those upon whom your Lord had mercy; and this is why He created them; and the Word of your Lord has been concluded that, “Indeed I will, surely, fill hell with jinns and men combined.”\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mdxciii{%
And We relate to you all the accounts of Noble Messengers, in order to steady your heart with it; and in this the truth has come to you, and for the Muslims a preaching and advice.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mdxciv{%
And say to the disbelievers, “Keep on with your works in your places; we are carrying out ours.”\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mdxcv{%
“And wait – we too are waiting.”\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
“And for Allah only are the hidden of the heavens and of the earth, and towards Him only is the return of all matters – therefore worship Him and trust Him; and your Lord is not unaware of what you do.”\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif-Lam-Ra*; these are verses of the clear Book. (* Alphabets of the Arabic language; Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
Indeed We have sent down an Arabic Qur’an, so that you may perceive.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We relate to you the best narrative because We have sent the divine revelation of this Qur’an, to you; although surely you were unaware before this.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdc{%
Remember when Yusuf (Joseph) said to his father, “O my father! I saw eleven stars and the sun and the moon – I saw them prostrating to me.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdci{%
He said, “O my child! Do not relate your dream to your brothers, for they will hatch a plot against you; indeed Satan is an open enemy towards mankind.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcii{%
“And this is how your Lord will choose you and teach you how to interpret events, and will perfect His favours upon you and upon the family of Yaqub, the way He perfected it upon both your forefathers, Ibrahim and Ishaq; indeed your Lord is All Knowing, Wise.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdciii{%
Indeed in Yusuf and his brothers are signs* for those who enquire**. (* Of the truthfulness of Prophet Mohammed – peace and blessings be upon him. ** The Jews who enquired about their story.)\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdciv{%
When they said, “Indeed Yusuf and his brother* are dearer to our father than we are, and we are one group; undoubtedly our father is, clearly, deeply engrossed in love.” (* Of the same mother.)\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcv{%
“Kill Yusuf or throw him somewhere in the land, so that your father’s attention may be directed only towards you, and then after it you may again become righteous!”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcvi{%
A speaker among them said, “Do not kill Yusuf – and drop him into a dark well so that some traveller may come and take him away, if you have to.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said, “O our father! What is the matter with you that you do not trust us with Yusuf, although we are in fact his well-wishers?”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcviii{%
“Send him with us tomorrow so that he may eat some fruits and play, and indeed we are his protectors.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcix{%
He said, “I will indeed be saddened by your taking him away, and I fear that the wolf may devour him, whilst you are unaware of him.” (* Prophet Yaqub knew of what was about to happen.)\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said, “If the wolf devours him, whereas we are a group, then surely we are useless!”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So when they took him away – and all of them agreed that they should drop him in the dark well; and We sent the divine revelation to him, “You will surely tell them of their deed at a time when they will not know.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcxii{%
And at nightfall they came to their father, weeping.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
Saying, “O our father! We went far ahead while racing, and left Yusuf near our resources – therefore the wolf devoured him; and you will not believe us although we may be truthful.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought his shirt stained with faked blood; he said, “On the contrary – your hearts have fabricated an excuse for you; therefore patience is better; and from Allah only I seek help against the matters that you relate.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcxv{%
And there came a caravan – so they sent their water-drawer, he therefore lowered his pail; he said, “What good luck, this is a boy!”; and they hid him as a treasure; and Allah knows what they do.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
And the brothers sold him for an improper price, a limited number of coins; and they had no interest in him.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
And the Egyptian who purchased him said to his wife, “Keep him honourably – we may derive some benefit due to him or we may adopt him as our son”; and this is how we established Yusuf in the land, and that We might teach him how to interpret events; and Allah is Dominant upon His works, but most men do not know.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And when he matured to his full strength, We bestowed him wisdom and knowledge; and this is how We reward the virtuous.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcxix{%
And the woman in whose house he was, allured him not to restrain himself and she closed all the doors – and said, “Come! It is you I address!”; he said, “(I seek) The refuge of Allah – indeed the governor is my master – he treats me well; undoubtedly the unjust never prosper.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcxx{%
And indeed the woman desired him; and he too would have desired her were he not to witness the sign of his Lord*; this is what We did, to turn away evil and lewdness from him; indeed He is one of Our chosen bondmen. (* Allah saved him and he never desired this immorality.)\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
And they both raced towards the door, and the woman tore his shirt from behind, and they both found her husband at the door; she said, “What is the punishment of the one who sought evil with your wife, other than prison or a painful torture?”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
Said Yusuf, “It was she who lured me, that I may not guard myself” – and a witness from her own household testified; “If his shirt is torn from the front, then the woman is truthful and he has spoken incorrectly.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
“And if his shirt is torn from behind, then the woman is a liar and he is truthful.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
So when the governor saw his shirt torn from behind, he said, “Indeed this is a deception of women; undoubtedly the deception of women is very great.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
“O Yusuf! Disregard this – and O woman! Seek forgiveness for your sin; indeed you are of the mistaken.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
And some women of the city said, “The governor’s wife is seducing her young slave; indeed his love has taken root in her heart; and we find her clearly lost.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
And when she heard of their secret talk, she sent for them and prepared cushioned mattresses for them and gave a knife to each one of them and said to Yusuf, “Come out before them!” When the women saw him they praised him and cut their hands, and said, “Purity is to Allah – this is no human being; this is not but an honourable angel!”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said, “This is he on whose account you used to insult me; and indeed I tried to entice him, so he safeguarded himself; and indeed if he does not do what I tell him to, he will surely be imprisoned, and will surely be humiliated.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said, “O my Lord! Prison is dearer to me than the deed they invite me to; and if You do not repel their deceit away from me, I may incline towards them and be unwise.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
So his Lord heard his prayer and repelled the women’s deceit away from him; indeed He only is the All Hearing, the All Knowing.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then after having seeing all the signs, they all decided that he should be imprisoned for some time.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
And two young men went to prison along with him; one of them said, “I dreamt that I am pressing wine”; the other said, “I dreamt that I am carrying some bread upon my head from which birds were eating”; “Tell us their interpretation; indeed we see that you are virtuous.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
Said Yusuf, “The food which you get will not reach you, but I will tell you the interpretation of this before it comes to you; this is one of the sciences my Lord has taught me; indeed I did not accept the religion of the people who do not believe in Allah and are deniers of the Hereafter.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
“And I have chosen the religion of my forefathers, Ibrahim and Ishaq and Yaqub; it is not rightful for us to ascribe anything as a partner to Allah; this is a grace of Allah upon us and upon mankind, but most men are not thankful.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
“O both my fellow-prisoners! Are various lords better, or One Allah, the Dominant above all?”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
“You do not worship anything besides Him, but which are merely names coined by you and your forefathers – Allah has not sent down any proof regarding them; there is no command but that of Allah; He has commanded that you do not worship anyone except Him; this is the proper religion, but most people do not know.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
“O my two fellow-prisoners! One of you will give his lord (the king) wine to drink; regarding the other, he will be crucified, therefore birds will eat from his head; the command has been given concerning the matter you had enquired about.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And of the two, Yusuf said to the one whom he sensed would be released, “Remember me, in the company of your lord”; so Satan caused him to forget to mention Yusuf to his lord, he therefore stayed in prison for several years more.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
And the king said, “I saw in a dream seven healthy cows whom seven lean cows were eating, and seven green ears of corn and seven others dry; O court-members! Explain my dream, if you can interpret dreams.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They answered, “These are confused dreams – and we do not know the interpretation of dreams.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdcxli{%
And of the two the one who was released said – and after a long time he had remembered – “I will tell you its interpretation, therefore send me forth.”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
“O Yusuf! O truthful one! Explain for us the seven healthy cows which seven lean cows were eating and the seven green ears of corn and seven others dry, so I may return to the people, possibly they may come to know.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
He said, “You will cultivate for seven years continuously; so leave all that you harvest in the ear, except a little which you eat.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
“Then after that will come seven hard years which will devour all that you had stored for them, except a little which you may save.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
“Then after that will come a year when the people will be given rain and in which they will extract juices.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
And the king said, “Bring him to me”; so when the bearer came to him, Yusuf said, “Return to your lord and ask him what is the status of the women who had cut their hands; indeed my Lord knows their deception.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
The king said, “O women! What was your role when you tried to entice Yusuf?” They answered, “Purity is to Allah – we did not find any immorality in him”; said the wife of the governor, “Now the truth is out; it was I who tried to entice him, and indeed he is truthful.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
Said Yusuf, “I did this so that the governor may realise that I did not betray him behind his back, and Allah does not let the deceit of betrayers be successful.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
“And I do not portray my soul as innocent; undoubtedly the soul excessively commands towards evil, except upon whom my Lord has mercy; indeed my Lord is Oft Forgiving, Most Merciful.”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdcl{%
And the king said, “Bring him to me so that I may choose him especially for myself”; and when he had talked to him he said, “Indeed you are today, before us, the honourable, the trusted.”\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdcli{%
Said Yusuf, “Appoint me over the treasures of the earth; indeed I am a protector, knowledgeable.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdclii{%
And this is how We gave Yusuf the control over that land; to stay in it wherever he pleased; We may convey Our mercy to whomever We will, and We do not waste the wages of the righteous.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdcliii{%
And undoubtedly the reward of the Hereafter is better, for those who accept faith and remain pious.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And Yusuf’s brothers came and presented themselves before him, so he recognised them whereas they remained unaware of him.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he provided them with their provisions he said, “Bring your step-brother to me; do you not see that I measure in full and that I am the best host?”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdclvi{%
“And if you do not bring him to me, there shall be no measure (provisions) for you with me and do not ever come near me.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said, “We will seek him from his father – this we must surely do.”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdclviii{%
He said to his slaves, “Place their means back into their sacks, perhaps they may recognise it when they return to their homes, perhaps they may come again.”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdclix{%
So when they returned to their father, they said, “O our father! The provisions have been denied to us, therefore send our brother with us so that we may bring the provisions, and we will surely protect him.”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said, “Shall I trust you regarding him the same way I had trusted you earlier regarding his brother? Therefore Allah is the Best Protector; and He is More Merciful than all those who show mercy.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their belongings they found that their means had been returned to them; they said, “O our father! What more can we ask for? Here are our means returned to us; we may get the provision for our homes and guard our brother, and get a camel-load extra; giving all these is insignificant for the king.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdclxii{%
He said, “I shall never send him with you until you give me an oath upon Allah that you will bring him back to me, unless you are surrounded”; and (recall) when they gave him their oath that “Allah’s guarantee is upon what we say.” (* He knew that Bin Yamin would be restrained.)\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
And he said, “O my sons! Do not enter all by one gate – and enter by different gates; I cannot save you against Allah; there is no command but that of Allah; upon Him do I rely; and all those who trust, must rely only upon Him.”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered from the place where their father had commanded them to; that would not at all have saved them against Allah – except that it was Yaqub’s secret wish, which he fulfilled; and indeed he is a possessor of knowledge, due to Our teaching, but most people do not know.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdclxv{%
And when they entered in the company Yusuf, he seated his brother close to him and said, “Be assured, I really am your brother – therefore do not grieve for what they do.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
And when he had provided them their provision, he put the drinking-cup in his brother’s bag, and then an announcer cried, “O people of the caravan! You are indeed thieves!”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They answered and turned towards them, “What is it you cannot find?”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said, “We cannot find the king’s cup, and for him who brings it is a camel-load, and I am its guarantor.”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdclxix{%
They said, “By Allah, you know very well that we did not come here to cause turmoil in the land, and nor are we thieves!”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdclxx{%
They said, “And what shall be the punishment for it, if you are liars?”\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They said, “The punishment for it is that he in whose bag it shall be found, shall himself become a slave for it; this is how we punish the unjust.”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
So he first searched their bags before his brother’s bag, then removed it from his brother’s bag; this was the plan We had taught Yusuf; he had no right to take his brother by the king’s law, except if Allah wills; We may raise in ranks whomever We will; and above every possessor of knowledge is another scholar.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said, “If he steals, then indeed his brother has stolen before”; so Yusuf kept this in his heart and did not reveal it to them; he replied within himself, “In fact, you are in a worse position; and Allah well knows the matters you fabricate.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said, “O governor! He has a very aged father, so take one of us in his stead; indeed we witness your favours.”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said, “The refuge of Allah from that we should take anyone except him with whom our property was found – we would then surely be unjust.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
So when they did not anticipate anything from him, they went away and started consulting each other; their eldest brother said, “Do you not know that your father has taken from you an oath upon Allah, and before this, how you had failed in respect of Yusuf? Therefore I will not move from here until my father permits or Allah commands me; and His is the best command.”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
“Return to your father and then submit, ‘O our father! Indeed your son has stolen; we were witness only to what we know and we were not guardians of the unseen.’\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
‘And ask the township in which we were, and the caravan in which we came; and indeed we are truthful.’”\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
Said Yaqub, “Your souls have fabricated an excuse for you; therefore patience is excellent; it is likely that Allah will bring all* of them to me; undoubtedly only He is the All Knowing, the Wise.” (* All three including Yusuf.)\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away from them and said, “Alas – the separation from Yusuf!” and his eyes turned white with sorrow, he therefore kept suppressing his anger.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said, “By Allah, you will keep remembering Yusuf till your health fails you or you lose your life.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said, “I complain of my worry and grief only to Allah, and I know the great traits of Allah which you do not know.”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
“O my sons, go and search for Yusuf and his brother, and do not lose hope in the mercy of Allah; indeed none lose hope in the mercy of Allah except the disbelieving people.”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
Then when they reached in the company of Yusuf they said, “O governor! Calamity has struck us and our household, and we have brought goods of little value, so give us the full measure and be generous to us; undoubtedly Allah rewards the generous.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said, “Are you aware of what you did to Yusuf and his brother when you were unwise?”\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said, “Are you, in truth you, really Yusuf?” He said, “I am Yusuf and this is my brother; indeed Allah has bestowed favour upon us; undoubtedly whoever practices piety and patience – so Allah does not waste the wages of the righteous.”\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said, “By Allah, undoubtedly Allah has given you superiority over us, and we were indeed guilty.”\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said, “There is no reproach on you, this day! May Allah forgive you – and He is the Utmost Merciful, of all those who show mercy.”\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
“Take along this shirt of mine and lay it on my father’s face, his vision will be restored; and bring your entire household to me.” (Prophet Yusuf knew that this miracle would occur.)\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdcxc{%
When the caravan left Egypt, their father said*, “Indeed I sense the fragrance of Yusuf, if you do not call me senile.” (* Prophet Yaqub said this in Palestine, to other members of his family. He could discern the fragrance of Prophet Yusuf’s shirt from far away.)\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said, “By Allah, you are still deeply engrossed in the same old love of yours.”\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
Then when the bearer of glad tidings came, he laid the shirt on his face, he therefore immediately regained his eyesight*; he said, “Was I not telling you? I know the great traits of Allah which you do not know!” (This was a miracle that took place by applying Prophet Yusuf’s shirt.)\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said, “O our father! Seek forgiveness for our sins, for we were indeed guilty.”\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said, “I shall soon seek forgiveness for you from my Lord; indeed He only is the Oft Forgiving, the Most Merciful.”\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
So when they all reached in Yusuf’s company, he kept his parents close to him, and said, “Enter Egypt, if Allah wills, in safety.”\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he seated his parents on the throne, and they all prostrated before him; and Yusuf said, “O my father! This is the interpretation of my former dream; my Lord has made it true; and indeed He has bestowed favour upon me, when He brought me out of prison and brought you all from the village, after Satan had created a resentment between me and my brothers; indeed my Lord may make easy whatever He wills; undoubtedly He is the All Knowing, the Wise.”\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
“O my Lord! you have given me a kingdom* and have taught me how to interpret some events; O Creator of the heavens and the earth – you are my Supporter in the world and in the Hereafter; cause me to die as a Muslim, and unite me with those who deserve Your proximity.” (* Prophethood and the rule over Egypt. Prophet Yusuf said this prayer while his death approached him.)\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
These are some tidings of the Hidden which We divinely reveal to you (O dear Prophet Mohammed – peace and blessings be upon him); and you were not with them when they set their task and when they were scheming.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
And however much you long for, most men will not accept faith.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mdcc{%
You do not ask them any fee in return for it; this is not but an advice to the entire world.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mdcci{%
And how many signs exist in the heavens and the earth, over which most people pass and remain unaware of them!\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them are such that they do not believe in Allah except while ascribing partners (to Him)!\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Do they remain complacent over Allah’s punishment coming and surrounding them, or the Last Day coming suddenly upon them whilst they are unaware?\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Proclaim, “This is my path – I call towards Allah; I, and whoever follows me, are upon perception; and Purity is to Allah – and I am not of the polytheists.”\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mdccv{%
And all the Noble Messengers We sent before you, were exclusively men – towards whom We sent the divine revelations, and were dwellers of townships; so have not these people travelled in the land and seen what sort of fate befell those before them? And undoubtedly the abode of the Hereafter is better for the pious; so do you not have sense?\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mdccvi{%
To the extent that when the Noble Messengers lost hope from the visible means, and the people thought that they had spoken wrongly, Our help came to them – therefore whoever We willed was saved; and Our punishment is never averted from the guilty.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mdccvii{%
Indeed in their tidings is enlightenment for the men of understanding; this (the Qur’an) is not some made up story but a confirmation of the Books before it, and a detailed explanation of all things, and a guidance and a mercy for the Muslims.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif-Lam-Meem-Ra*; these are verses of the Book; and that which has been sent down upon you from your Lord is true, but most men do not believe. (* Alphabets of the Arabic language – Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdccix{%
It is Allah Who raised up the heavens without columns for you to observe, then (in the manner befitting His Majesty) established Himself upon the Throne (of control), then subjected the sun and the moon; each one runs for up to an appointed term; Allah plans the works and explain the signs in detail, so that you may believe in meeting with your Lord.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdccx{%
And it is He Who spread out the earth and made mountains as anchors and rivers in it; and in it made all kinds of fruits in pairs – He covers the night with the day; indeed in this are signs for people who ponder.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And in the earth are various regions, and are close to each other – and gardens of grapes and fields, and date-palms, growing from a single branch and separately, all being given one water; and in fruits, We make some better than others in eating; indeed in this are signs for people of intellect.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdccxii{%
And if you are amazed, then indeed the amazement is at their saying that, “Will we, after having turned to dust, be created anew?” They are those who have disbelieved in their Lord; and they are those who will have shackles around their necks; and they are the people of hell; remaining in it forever.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
And they urge you to hasten the punishment before the mercy, whereas the punishments of those before them have concluded; and indeed your Lord gives the people a sort of pardon* despite their injustice; and indeed the punishment of your Lord is severe. (* By delaying their punishment despite their disbelief.)\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
The disbelievers say, “Why is not a sign sent down upon him from his Lord?” You are purely a Herald of Warning, and a guide for all nations.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah knows all what is inside the womb of every female, and every increase and decrease of the wombs; and all things are with Him by a set measure.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
The All Knowing of all things hidden and visible, the Great, the Supreme.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
Equal* are the one among you who speaks softly and one who speaks aloud, and one who is hidden during the night and one who walks during the daytime. (* For Allah.)\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
For man are angels of alternating duties, in front and behind him, who guard him by Allah’s command; indeed Allah does not change His favour upon any nation until they change their own condition; and when Allah wills misfortune for a nation, it cannot be repelled; and they do not have any supporter besides Him.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdccxix{%
It is He Who shows you the lightning, for fear and for hope, and raises the heavy clouds.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdccxx{%
And the thunder proclaims His purity with praise, and the angels out of fear of Him; and He sends the bolt of lightning – it therefore strikes upon whom He wills, whilst they are disputing concerning Allah; and severe is His seizure.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
Only the prayer to Him is truthful; and whomever they pray to besides Him, do not hear them at all, but like one who has his hands outstretched towards water that it may come into his mouth, and it will never come; and every prayer of the disbelievers remains wandering.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
And to Allah only prostrate all those who are in the heavens and in the earth, willingly or helplessly – and their shadows – every morning and evening. (Command of prostration \# 2).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “Who is the Lord of the heavens and the earth?” Proclaim, “Allah”; Say, “So have you appointed such as supporters besides Him, who can neither benefit nor harm themselves?”; say, “Will the blind and the sighted ever be equal? Or will the realms of darkness and the light ever be equal?” Have they appointed such as partners to Allah who created something like Allah did? Therefore their creation and His creation seemed alike to them? Proclaim, “Allah is the Creator of all things, and He Alone is the Dominant over all.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sent down water from the sky, so valleys flowed according to their measure, therefore the water flow brought forth the froth swollen upon it; and upon which they ignite the fire, to make ornaments and tools, from that too rises a similar froth; Allah illustrates that this is the example of the truth and the falsehood; the froth then bursts and disappears; and that which is of use to people, remains in the earth; this is how Allah illustrates the examples.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who obeyed the command of Allah is goodness and if those who did not obey Him owned all that is in the earth and in addition a similar one like it, they would give it to redeem their souls; it is they who will have a wretched account, and their destination is hell; and what a wretched resting place!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
So will he, who knows that what is sent down upon you from your Lord is the truth, ever be equal to him who is blind? Only the men of understanding heed advice.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
Those who fulfil the pact of Allah, and do not renege on the covenant.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
Those who unite what Allah has commanded to be united, and fear their Lord, and apprehend the evil of the account.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
Those who were patient in order to gain their Lord’s pleasure and kept the prayer established and spent in Our cause part of what We bestowed upon them, secretly and openly, and repel evil by responding with goodness – for them is the gain of the final abode.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
The everlasting Gardens of Eden which they will enter, and the deserving among their forefathers and their wives and their descendants – the angels will enter upon them from every gate.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
(Saying), “Peace be upon you, the recompense of your patience – so what an excellent gain is the final abode!”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
And those who break the pact of Allah after its ratification, and sever what Allah has commanded to be joined, and spread turmoil in the earth – their share is only the curse and their destiny is the wretched abode.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah eases and restricts the sustenance for whomever He wills; and the disbelievers rejoiced upon the life of this world; and the life of this world, as compared with the Hereafter, is just a brief utilisation.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
And the disbelievers said, “Why was not a sign sent down upon him from his Lord?” Proclaim, “Indeed Allah sends astray whomever He wills, and guides towards Himself the one who comes towards Him.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
“Those who accepted faith and whose hearts gain solace from the remembrance of Allah; pay heed! Only in the remembrance of Allah is the solace of hearts!”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
“Those who accepted faith and did good deeds – for them is joy and an excellent outcome.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Similarly We sent you (O dear Prophet Mohammed – peace and blessings be upon him) towards the nation, before whom other nations have passed away, for you to recite to them the divine revelations We sent down to you, whereas they are denying the Most Gracious; proclaim, “He is my Lord – there is no worship except for Him; I rely only upon Him and only towards Him is my return.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
And were such a Qur’an to come that would cause the mountains to move, or the earth to split asunder, or the dead to speak, even then these disbelievers would not believe; in fact, all matters are only at Allah’s discretion; so have not the Muslims despaired in that, had Allah willed, He would have guided all mankind? Disasters shall continue to strike the disbelievers on account of their deeds, or descend near their homes until Allah’s promise comes; indeed Allah does not break the promise.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
And indeed the Noble Messengers before you were also mocked – I therefore gave the mockers respite for some days and then seized them; so how (dreadful) was My punishment!\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdccxl{%
So is He who keeps a watch over the deeds of every soul (equal to their appointed partners)? And (yet) they ascribe partners to Allah! Proclaim, “Just name them – or is it that you inform Him of something which in His knowledge does not exist in the earth – or is it just superficial talk?” In fact, their deceit seems good to the disbelievers and are prevented from the path; and whomever Allah sends astray, so there is none to guide him.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdccxli{%
They will be punished in the life of this world, and indeed the punishment of the Hereafter is the most severe; and there is none to save them from Allah.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
A description of the Paradise which is promised to the pious; rivers flow beneath it; its fruits are unending, and its shade; this is the reward of those who fear; and the fate of the disbelievers is fire.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
And those to whom We gave the Book* rejoice at what is divinely revealed to you**; and of those groups are some who deny parts of it; proclaim, “I am commanded only that I worship Allah and not ascribe any partner to Him; towards Him do I call, and towards Him only I have to return.” (* Scholars among the Jews and Christians who accepted faith. ** The Holy Qur’an.)\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
And similarly We have revealed this as a command in Arabic; and O listener (follower of this Prophet), if you follow their desires after the knowledge having come to you, then you will have neither a supporter nor any saviour against Allah.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
And indeed We sent Noble Messengers before you, and made wives and children for them; and it is not the task of any Noble Messenger to bring a sign except by Allah’s command; and all promises have a time prescribed.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah erases and confirms whatever He wills; and only with Him is the real script.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
And whether We show you a promise that is given to them, or call you to Us before it – so in any case, upon you is just the conveyance*, and for Us is the taking of the account. (* Of the message.)\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
Do they not perceive that We are reducing their dwellings from all directions? And Allah gives the command – there is none that can postpone His command; and He spends no time in taking account.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
And indeed those before them had plotted; therefore Allah Himself is the Master of all strategies; He knows all what every soul earns; and soon will the disbelievers realise for whom is the final abode.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdccl{%
The disbelievers say, “You are not a (Noble) Messenger (of Allah)”; proclaim, “Allah is a Sufficient Witness between me and you, and (so is) he who has knowledge of the Book.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif-Lam-Ra; it is a Book which We have sent down upon you (O dear Prophet Mohammed – peace and blessings be upon him) so that you may bring forth people from the realms of darkness into light – by the command of their Lord, towards the path of the Most Honourable, the Most Praiseworthy.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdcclii{%
Allah – because all that is in the heavens and in the earth belongs only to Him; and woe is for the disbelievers through a severe punishment.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdccliii{%
To whom the worldly life is dearer than the Hereafter, and who prevent from the way of Allah and wish deviations in it; they are in extreme error.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdccliv{%
And We sent every Noble Messenger with the same language as his people*, so that he may clearly explain to them; then Allah sends astray whomever He wills, and He guides whomever He wills; and He only is the Most Honourable, the Wise. (* Prophet Mohammed (peace and blessings be upon him) was taught all the languages as he is sent towards all.)\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdcclv{%
And indeed We sent Moosa along with Our signs that, “Bring your people from the realms of darkness into light – and remind them of the days of Allah*; indeed in them are signs for every greatly enduring, grateful person.” (* When various favours were bestowed – in order to give thanks and be patient.)\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
And when Moosa said to his people, “Remember Allah’s favour upon you when He rescued you from the people of Firaun who were inflicting you with a dreadful torment, and were slaying your sons and sparing your daughters; and in it occurred a great favour of your Lord.”* (* On the 10th day of Moharram – therefore the Jews used to fast on that day as thanksgiving.)\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And remember when your Lord proclaimed, “If you give thanks, I will give you more, and if you are ungrateful then (know that) My punishment is severe.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Moosa said, “If you and all who are in the earth turn disbelievers, then indeed Allah is definitely Independent (Unwanting), Most Praiseworthy.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Did not the tidings of those before you reach you? The people of Nooh, and the A’ad and the Thamud, and those after them? Only Allah knows them; their Noble Messengers came to them with clear proofs, they therefore raised their hands towards their own mouths, and said, “We disbelieve in what you have been sent with, and we are in a deeply intriguing doubt regarding the path you call us to.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their Noble Messengers said, “What! You doubt concerning Allah, the Creator of the heavens and the earth? He calls you that He may forgive some of your sins and until the time of death give you a life free from punishment”; they said, “You are just human beings like us; you wish to prevent us from what our forefathers used to worship – therefore now bring some clear proof to us.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their Noble Messengers said to them, “We are indeed human beings like you, but Allah bestows favour upon whomever He wills, among His bondmen*; it is not our task to bring any proof to you except by the command of Allah; and only upon Allah must the Muslims rely.” (* Therefore Prophets and other men are not equal in status.)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
“And what is the matter with us that we should not rely on Allah? He has in fact shown us our ways; and we will surely be patient upon the troubles you cause us; and those who trust must rely only upon Allah.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
And the disbelievers said to their Noble Messengers, “We will surely expel you from our land, unless you accept our religion”; so their Lord sent them the divine revelation that, “Indeed We will destroy these unjust people.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
“And indeed We will establish you in the land after them; this is for him who fears to stand before Me and fears the commands of punishment declared by Me.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
And they sought a decision, and every stubborn rebel was destroyed.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
Hell went after him, and he will be made to drink liquid pus*. (* Discharged from the wounds of other people in hell.)\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
He will sip it with difficulty but be unable to swallow, and death will approach him from every side and he will not die; and a severe punishment is after him.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
The state of those who disbelieve in their Lord is that their deeds are like ashes which the strong wind blew away on a stormy day; they got nothing from all that they earned; this is the extreme error.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Have you not seen that Allah has created the heavens and the earth with true purpose? If He wills, He can remove you all and bring a new creation.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
And this is not at all difficult for Allah.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
They will all publicly come in the presence of Allah – then those who were weak will say to those who were the leaders, “We were your followers – is it possible for you to avert some of Allah’s punishment from us?” They will answer, “If Allah had guided us, we would have guided you; it is the same for us, whether we panic or patiently endure – we have no place of refuge.” (* This conversation will take place between the disbelievers and their leaders.)\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And Satan will say when the matter has been decided, “Indeed Allah had given you a true promise – and the promise I gave you, I made it untrue to you; and I had no control over you except that I called you and you obeyed me; so do not accuse me, blame only yourselves; neither can I help you, nor can you help me; I have no concern with your ascribing me as a partner (to Allah); indeed for the unjust is a painful punishment.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
And those who believed and did good deeds will be admitted into Gardens beneath which rivers flow, abiding in it forever, by the command of their Lord; their greeting in it is “Peace”.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Did you not see how Allah illustrated the example of a sacred saying? Like a sacred tree, which has firm roots and branches reaching into heaven.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
Bearing fruit at all times by the command of its Lord; and Allah illustrates examples for people so that they may understand.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the example of a bad saying is like a filthy tree, which is cut off above the ground, therefore not having stability.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Allah keeps the believers firm upon the truth in the life of this world and in the Hereafter; and Allah sends the unjust astray; and Allah may do whatever He wills.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Did you not see those who exchanged the grace of Allah for ungratefulness and led their people down to the home of destruction?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
Which is hell; they will enter it; and what a wretched place of stay!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they ascribed equals to Allah to mislead from His way; say, “Enjoy a while, for your end will be the fire.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Say to the bondmen of Mine who believe, that they must keep the prayer established and spend in Our way from what We have given them, secretly and publicly, before the advent of a day in which there will be no trade nor friendship.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
It is Allah Who created the heavens and the earth, and sent down water from the sky, therefore producing some fruits for you to eat; and subjected the ships for you, that they may sail upon the sea by His command; and subjected the rivers for you.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
And subjected the sun and the moon for you, which are constantly moving; and has subjected the night and the day for you.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
And He gave you much of what you seek; and if you enumerate the favours of Allah, you will never be able to count them; indeed man is very unjust, most ungrateful.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And remember when Ibrahim prayed, “O my Lord! Make this town (Mecca) a safe one, and safeguard me and my sons from worshipping idols.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
“O my Lord! The idols have led many people astray; so whoever followed me, is indeed mine; and whoever disobeyed me – then indeed You are Oft Forgiving, Most Merciful.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
“O our Lord! I have settled some of my descendants in a valley having no cultivation, near Your Sacred House – O our Lord! So that they may keep the prayer established, therefore incline some hearts of men towards them, and provide them fruits to eat – perhaps they may be thankful.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
“O our Lord! You know what we hide and what we disclose; and nothing is hidden from Allah, neither in the earth nor in the heavens.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
“All praise is to Allah Who gave me Ismail and Ishaq, in my old age; indeed my Lord is the Listener of Prayer.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdccxc{%
“O my Lord! Maintain me as one who establishes prayer, and some of my descendants; O our Lord! and accept my prayer.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdccxci{%
“O our Lord! And forgive me, and my parents, and all the Muslims on the day when the account will be established.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
And do not ever assume that Allah is unaware of what the unjust do; He does not give them respite but for a day in which the eyes will become fixed, staring.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
They shall come out running in bewilderment, with their heads raised, their gaze not returning to them; and their hearts will not have any calm.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
And warn the people of a day when the punishment will come upon them, therefore the unjust will say, “O our Lord! Give us respite for a little while – for us to obey Your call and follow the Noble Messengers”; (It will be said) “So had you not sworn before that, ‘We have not to move to any place else from the earth’?”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
“And you dwelt in the houses of those who had wronged themselves and it became very clear to you how We had dealt with them, and We illustrated several examples for you.”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
And indeed they carried out their scheme, and their scheming is within Allah’s control; and their scheme was not such that could move these mountains*. (* The revelations / signs of Allah.)\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
So do not ever assume that Allah will not fulfil His promise to His Noble Messengers; indeed Allah is the Dominant, the Avenger.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
On the day when the earth will be changed to other than this earth, and the heavens – and they will all come forth standing before Allah, the One, the Dominant above all.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
And on that day you will see the guilty linked together in chains.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdccc{%
Their cloaks will be of pitch and fire will cover their faces.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdccci{%
In order that Allah may repay each soul what it had earned; indeed Allah spends no time in judging the account.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This is the message to be conveyed to all mankind – and in order to warn them with it, and for them to know that He is the only One God, and for men of understanding to heed advice.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif-Lam-Ra; these are verses of the Book and the bright Qur’an.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdccciv{%
The disbelievers will ardently wish that if only they had been Muslims! (At the time of death / in their graves / on the Day of Resurrection.)\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Leave them to eat and enjoy, and for aspiration to involve them in play – so they will shortly come to know.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
And every dwelling that We destroyed, had a known decree for it.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No group may advance its appointed promise nor postpone it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
And they said, “O you upon whom the Qur’an has been sent, you are indeed insane.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdcccix{%
“Why do you not bring angels to us, if you are truthful?”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We do not send down angels without reason, and if the angels descend they would not get any respite!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
Indeed We have sent down the Qur’an, and indeed We Ourselves surely are its Guardians. (This is one of the miracles of the Qur’an – no one has been able to change even one letter of its text, despite every effort. It has remained in its original form since the 6th Century (A. D) and will remain so forever. Other Holy Books such as the Torah and the Bible have lost their originality.)\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
And indeed We sent Noble Messengers before you, to the former nations.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
And never does a Noble Messenger come to them, but they mock at him.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
This is how We make the mocking* enter the hearts of the guilty. (* The acts of disbelief.)\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
They do not believe in him, and the tradition of earlier nations has passed.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
And if We open for them a gate in the heavens, to ascend it through the day –\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
Even then they would say, “Our sights have been hypnotised – in fact, a magic spell has been cast upon us.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
And indeed We created towers in the skies, and beautified it for the beholders.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
And We have kept it guarded from every outcast devil.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
Except one who comes to eavesdrop – therefore a bright flame goes after him.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
And We spread out the earth, and placed mountains as anchors in it, and in it grew all things by a proper measure.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And created livelihoods for you in it, and created those for whom you do not provide the sustenance.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
And there is not a thing the treasure* of which is not with Us; and We do not send it down except by a known measure. (* The power to create it.)\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
And We sent the winds that relieve the clouds’ burden, therefore caused water to descend from the sky, then give it to you to drink; and you are not at all its treasurers.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
And indeed it is We Who give life and it is We Who cause death, and We are the Inheritors.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
And indeed We know those among you who came forward and indeed We know those among you who remained behind.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
Indeed your Lord only will raise them all on the Day of Resurrection; indeed only He is Wise, All Knowing.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
Indeed We created man from sounding clay made out of black smelly mud.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
And created the jinn before him, from smokeless fire.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
And recall when your Lord said to the angels, “I will create man from sounding clay made out of black smelly mud.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
“Therefore when I have properly fashioned him and breathed into him a chosen noble soul from Myself, fall down before him in prostration.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
Therefore all the angels, each and every one of them, fell prostrate.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
Except Iblis (Satan); he refused to be among those who prostrated.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
Said Allah, “O Iblis! What happened to you that you stayed apart from those who prostrated?”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
He answered, “It does not befit me to prostrate myself to a human whom You have created from sounding clay made out of black smelly mud.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
Said Allah, “Therefore exit from Paradise, for you are an outcast.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
“And indeed you are accursed till the Day of Judgement.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
He said, “My Lord! Grant me respite till the day when they will all be raised.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
Said Allah, “You are of those given respite.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
“Till the Day of a well-known time.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
He said, “My Lord! I swear by the fact that You sent me astray, I shall distract them in the earth, and I shall lead all of them astray.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
“Except those among them who are Your chosen bondmen.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
Said Allah, “This path* leads straight towards Me.” (* The path of the chosen bondmen.)\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
“Indeed you do not have any power over My bondmen, except those wanderers who follow you.” (The devil is unsuccessful in tempting Allah’s chosen bondmen to commit sin.)\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
And indeed hell is the promise for all of them.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
It has seven gates; for each gate is a portion assigned from them.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
Indeed the pious are amidst Gardens and springs.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
“Enter them with peace, in safety.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
And We have removed any resentments which were in their breasts – they are brothers, sitting face to face on thrones.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdcccl{%
Neither any hardship is to reach them in it, nor are they to be expelled from it.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Inform My bondmen that undoubtedly, I surely am the Oft-Forgiving, the Most Merciful.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdccclii{%
And that indeed the punishment of Mine is a painful punishment.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And inform them of Ibrahim’s guests.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
When the angels came to him and said, “Peace"; he said, “We feel afraid of you.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They said, “Do not fear – we convey to you the glad tidings of a knowledgeable boy.”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said, “Do you convey to me the glad tidings upon old age reaching me? So upon what do you convey glad tidings?” (* Prophet Ibrahim said this out of surprise.)\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They said, “We have given you true tidings, therefore do not lose hope.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He said, “Who is it that despairs from the mercy of his Lord, except those who are astray?”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdccclix{%
He said, “And what is your next task, O the sent angels?”\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said, “We have been sent towards a guilty nation.”\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
“Except the family of Lut; we shall rescue all of them.”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
“Except his wife – we have decided that she is of those who will stay behind.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
And when the sent angels came to the house of Lut.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
He said, “You are an unfamiliar people.”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said, “In fact we have brought to you the matter which these people doubted.”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
“And we have brought to you a true command, and indeed we are truthful.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
“Therefore journey with your household while a portion of the night remains, and you tread behind them – and none of you may turn around and see, and proceed directly to the place you are commanded to.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We informed him the decision of this command, that at morning the root of the disbelievers would be cut off.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
And the people of the city came rejoicing. (* To the house of Prophet Lut.)\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
He said, “These are my guests – do not dishonour me.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
“And fear Allah and do not disgrace me.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They said, “Had we not forbidden you from meddling in the affairs of anyone?”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
He said, “These women of our tribe are my daughters, if you have to.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
By your life O dear Prophet (Mohammed – peace and blessings be upon him) – they are indeed straying in their intoxication.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
Therefore the scream overcame them at sunrise.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
And We turned the township upside down and rained upon them stones of heated clay.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Indeed in this are signs for people who perceive.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
And indeed that township is upon a road still in use.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Indeed in this are signs for the believers.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
And indeed the Dwellers of the Woods were unjust.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
We therefore took revenge from them; and indeed both these townships are situated on an open road.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
And the people of the Hijr (rocks) denied the Noble Messengers.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
And We gave them Our signs, and they remained averse to them.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
And they used to carve dwellings in the hills, without fear.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
So the scream overcame them at morning.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
Therefore their earnings did not in the least benefit them.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
And We have not created the heavens and the earth and all that is between them, except with the Truth; and indeed the Last Day will come, therefore (O dear Prophet Mohammed – peace and blessings be upon him), forbear graciously.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Indeed your Lord only is the Great Creator, the All Knowing.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
And indeed We have given you seven verses that are repeated, and the great Qur’an.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Do not direct your eyes towards the things We have given to some of their couples to enjoy, and do not at all grieve because of them, and take the Muslims within the folds of your mercy.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And proclaim, “Indeed I, yes I, am the clear Herald of Warning.”\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
(Of a punishment) Like the one We sent down upon the dividers.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
Those who broke the Word of Allah into several parts. (Those who broke the Torah / Bible or changed its text – or those who called the Qur’an a fabrication / poetry.)\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
Therefore, by your Lord, We shall question every one of them.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
About all what they used to do.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
Therefore publicly announce what you are commanded, and turn away from the polytheists.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
Indeed We suffice you against these mockers.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
Those who ascribe another God along with Allah; so they will soon come to know.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
And indeed We know that you are disheartened by their speech.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcm{%
Therefore proclaim the Purity of your Lord with praise, and be of those who prostrate.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcmi{%
And keep worshipping your Lord, till death* comes to you. (* The certainty.)\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen The command of Allah is arriving soon, therefore do not seek to hasten it; Purity and Supremacy are to Him, above all the partners (they ascribe).\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sends down the angels with the soul of faith – the divine revelations – towards those among His bondmen He wills that, “There is no worship except for Me, therefore fear Me.”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He created the heavens and the earth with the truth; Supreme is He above their ascribing of partners (to Him).\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mcmv{%
He created man from a drop of fluid, yet he is an open quarreller!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And He created cattle; in them are warm clothing and uses for you, and you eat from them.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And in them is your elegance, when you bring them home at evening, and when you leave them to graze.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mcmviii{%
And they transport your loads to a town where you could not reach except utterly exhausted; indeed your Lord is Most Compassionate, Most Merciful.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mcmix{%
And horses, and mules, and donkeys so that you may ride them, and for adornment; and He will create what you do not know*. (* All modern means of transport – by air, sea, land and even in space – evidence this.)\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mcmx{%
And the middle path rightly leads to Allah – any other path is wayward; and had He willed He would have brought all of you upon guidance.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mcmxi{%
It is He Who sent down water from the sky – you drink from it, and from it are trees you use as pasture.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mcmxii{%
With this water He produces for you crops, and olives, and dates, and grapes, and all kinds of fruit; indeed in this is a sign for people who ponder.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
And He subjected the night and the day for you – and the sun and the moon; and the stars are subjected to His command; indeed in this are signs for people of intellect.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And the things He has created for you in the earth, of numerous colours; indeed in this is a sign for people who remember.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mcmxv{%
And it is He Who subjected the sea for you, so you eat fresh meat from it, and extract ornaments from it which you wear; and you see ships ploughing through it and in order that you may seek His munificence and that you may give thanks.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He placed mountains as anchors in the earth so that it may not shake along with you, and streams and roads for you to find course.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And landmarks; and they are guided by the star.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
So will He Who creates ever be like one who does not create? So do you not heed advice?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mcmxix{%
And if you enumerate the favours of Allah, you will never be able to count them; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And Allah knows what you conceal and what you disclose.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
And those whom they worship other than Allah, do not create anything but are themselves created.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
They are dead, not alive; and they do not know when will the people be raised.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your God is One God; so those who do not believe in the Hereafter – their hearts deny and they are proud.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Certainly Allah knows what they hide and what they disclose; indeed He does not like the proud.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And when it is said to them, “What has your Lord sent down?”, they say, “The tales of former people.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
In order to bear their full burdens on the Day of Resurrection, and some burdens of those whom they mislead with their ignorance; pay heed! What an evil burden they bear!\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Indeed those before them had plotted, so Allah seized the foundations of their building, therefore the roof fell down upon them from a height, and the punishment came upon them from a place they did not know.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then on the Day of Resurrection He will disgrace them and proclaim, “Where are My partners, concerning whom you disputed”; the people of knowledge will say, “All disgrace and evil is upon the disbelievers this day.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
Those whose souls the angels remove whilst they were wronging themselves; so now they will plead “We never used to do any wrong”; ``Yes you did, why not? Indeed Allah well knows what you used to do."\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
“So now enter the gates of hell, remaining in it for ever”; so what an evil destination for the arrogant!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And it was said to the pious, “What has your Lord sent down?” They said, “Goodness”; for those who did good in this world is goodness, and the final home is the best; and indeed what an excellent final home for the pious.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
Everlasting Gardens of Eden which they will enter, beneath which rivers flow – in it they will get whatever they wish; this is how Allah rewards the pious.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
Those whose souls the angels remove in a state of purity, saying, “Peace be upon you – enter Paradise, the reward of your deeds.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
So what are they waiting for, except that the angels come upon them or that your Lord’s punishment comes? Those before them did exactly this; and Allah did not oppress them at all, but it is they who used to wrong themselves.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
So the evils of their deeds struck them, and what they used to mock at surrounded them.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
And the polytheists said, “Had Allah willed, we would not have worshipped anything besides Him – neither we nor our forefathers – and nor would we have forbidden anything, whilst being disassociated with Him”; those before them did exactly this; so what is (incumbent) upon the Noble Messengers, except to plainly convey (the message)?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
And indeed We sent to every nation a Noble Messenger (proclaiming) that “Worship Allah and beware of the devil”; therefore Allah guided some of them, and error proved true upon some of them; therefore travel in the land and see what sort of fate befell the deniers!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
If you (O dear Prophet Mohammed – peace and blessings be upon him) desire for their guidance, then indeed Allah does not guide one whom He misleads, and they do not have any aides.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
And they swore by Allah most vehemently in their oaths that, “Allah will not raise up the dead”; yes He will, why not? A true promise obligatory upon Him, but most men do not know.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcmxl{%
In order that He may make clear to them the matter in which they differed, and the disbelievers may realise that they were liars.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcmxli{%
And Our command for anything to occur, when We will it, is that We only say to it, “Be” – and it thereupon happens.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
And to those who migrated in Allah's cause after being oppressed, We shall indeed give them a good place in the world, and indeed the reward of the Hereafter is extremely great; if only the people knew!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
Those who patiently endured and who rely only upon Allah.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
And We did not send before you except men, towards whom We sent divine revelations – so O people, ask the people of knowledge if you do not know. (* All the Prophets were men.)\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
Along with clear proofs and writings; and We have sent down this Remembrance towards you (O dear Prophet Mohammed – peace and blessings be upon him) so that you may explain to mankind what has been revealed towards them, and that they may ponder.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
So do they who conspire evils, not fear that Allah may bury them in the earth, or that the punishment may come to them from a place they do not know?\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or that He may seize them while they move here and there, for they cannot escape?\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or that He may seize them whilst constantly ruining them? For indeed your Lord is Most Compassionate, Most Merciful.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
And have they not observed that the shadows of the things Allah has created incline to the right and to the left, in prostration to Allah, and that they are servile?\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcml{%
And to Allah only prostrates whatsoever is in the heavens and whatsoever moves in the earth, and the angels – and they are not proud.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcmli{%
They bear upon themselves the fear of their Lord, and do only what they are commanded.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcmlii{%
And Allah has proclaimed, “Do not ascribe two Gods; indeed He is the only One God; therefore fear Me alone.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcmliii{%
And to Him only belongs all whatever is in the heavens and in the earth, and obeying Him only is obligatory; so will you fear anyone other than Allah?\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcmliv{%
And whatever blessings you have, are all from Allah – then whenever misfortune reaches you, towards Him only do you seek refuge.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcmlv{%
And then, when He averts the misfortune from you, a group among you starts ascribing partners to their Lord!\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
In order to deny the favours We have given them; so enjoy a little; for you will soon come to know.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And for things unknown, they assign a portion of the sustenance We have given them; by Allah – you will certainly be questioned regarding all that you used to fabricate.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they assign daughters to Allah – Purity is to Him! – and assign for themselves what they wish.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mcmlix{%
And when one among of them receives the glad tidings of a daughter, his face turns black for the day, and he remains seething.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mcmlx{%
Hiding from the people because of the evil of the tidings; “Will he keep her with disgrace, or bury her beneath the earth?”; pay heed! Very evil is the judgement they impose!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
Those who do not believe in the Hereafter, for them only is the evil state; and the Majesty of Allah is Supreme; and He only is the Most Honourable, the Wise.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
Were Allah to seize people on account of their injustices, He would not have left anyone walking on the earth, but He gives them respite up to an appointed promise; then when their promise comes they cannot go back one moment nor come forward.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
And they assign to Allah that which is abhorred by themselves, and their tongues speak the lies that goodness is for them; so it occurred that for them is the fire, and they have crossed the limits.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By Allah, We indeed sent Noble Messengers to several nations before you, but Satan made their misdeeds appear good to them – so he only is their companion this day, and for them is a punishment, most painful.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
And We did not send down this Book towards you except for you to clearly explain to them the matters in which they may differ, and a guidance and a mercy for the believers.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
And Allah sent down water from the sky and with it revived the earth after its death; indeed in this is a sign for people who keep ears*. (* That listen to the truth.)\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And indeed in cattle is a lesson for you; We provide you drink from what is in their bellies – pure milk from between the excretion and the blood, palatable for the drinkers.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And from the fruits of date and grapes, for you make juices and good nourishment from them; indeed in this is a sign for people of intellect.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And your Lord inspired the bee that, “Build homes in hills, and in trees, and in rooftops.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
“Then eat from all kinds of fruits, and tread the ways of your Lord which are soft and easy for you”; from their bellies comes a drink of various colours, in which is health for mankind; indeed in this is a sign for people who ponder.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
And Allah created you, and will then remove your souls; and among you is one who is sent back to the most lowly age, so knowing nothing after having had knowledge; indeed Allah knows everything, is Able to do all things.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
And Allah has made some among you superior above others in livelihood; so those to whom the superiority is given, will not return their livelihood to their slaves, so they may all become equal in this respect; so do they deny the favours of Allah?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
And Allah has created for you wives of your own breed, and has given you from your wives, sons and grandsons, and has provided sustenance for you from good things; so do they believe in falsehood and deny the favours of Allah?\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And they worship such besides Allah, who do not have power to provide them any sustenance from the heavens or the earth, nor can they do anything.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
Therefore do not ascribe equals to Allah; indeed Allah knows whereas you do not know.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah has illustrated an example – there is a slave, himself the property of another, not owning anything – and another one upon whom We have bestowed a good livelihood from Us, he therefore spends from it, secretly and publicly; will they be equal? All praise is to Allah; in fact, most of them do not know.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
And Allah has illustrated an example – two men – one of them dumb, unable to do anything, and he is a burden on his master – wherever his master sends him, he brings back no good; will he be equal to one who gives the command of justice and is on the Straight Path?\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
And for Allah only are the hidden things of the heavens and the earth, and the matter of Resurrection is not but like the batting of an eyelid – in fact closer than this; indeed Allah is Able to do all things.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
And Allah brought you forth from your mothers’ wombs, whilst you did not know anything* – and gave you ears and eyes and hearts, for you to be grateful. (* Prophet Mohammed and Prophet Jesus, among others, are exceptions to this rule – peace and blessings be upon them.)\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Have they not seen the birds, subservient in the open skies? No one holds them up except Allah; indeed in this are signs for the people who believe.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
And Allah has given you houses for staying, and made some houses from the hides of animals, which are easy for you on your day of travel and on the day of stopover – and from their wool, and fur, and hair, some household items and utilities for a while.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And Allah has provided you shade with the things He has created, and created for you refuge in the hills, and created some clothing for you to protect you from the heat, and some clothing to protect you during conflict; this is how He completes His favour upon you, so that you may obey.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
Then if they turn away, O dear Prophet, (Mohammed – peace and blessings be upon him) upon you is nothing but to clearly convey (the message).\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognise the favour* of Allah and then deny it, and most of them are disbelievers. (* Prophet Mohammed (peace and blessings be upon him) and / or all the favours of Allah.)\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
And the day when We will raise up a witness from every nation – then there will be no leave for the disbelievers, nor will they be appeased.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
And when the unjust will see the punishment, from that time on it will not be lightened for them, nor will they get respite.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when the polytheists will see their ascribed partners, they will say, “Our Lord! These are our partners whom we used to worship besides You”; so they will strike back at them with the saying, “You are indeed liars!”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
And on that day they will fall humbly before Allah, and they will lose all that they used to fabricate.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those who disbelieved and prevented from the way of Allah – We added punishment upon the punishment – the recompense of their mischief.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcmxc{%
And the day when We will raise from every group, a witness from among them, in order to testify against them and will bring you O dear Prophet (Mohammed – peace and blessings be upon him) as a witness upon them all; and We have sent down this Qur’an upon you which is a clear explanation of all things, and a guidance and a mercy and glad tidings to the Muslims.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Indeed Allah decrees the commands of justice and kindness, and of giving to relatives, and forbids from the shameful and evil and rebellion; He advises you so that you may pay heed.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
And fulfil the covenant of Allah when you have made the promise, and do not break your oaths after ratifying them, and you have made Allah a Guarantor over you; indeed Allah knows your deeds.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And do not be like the woman broke her thread into bits after she had manufactured it; you make your oaths a phoney excuse between yourselves lest one nation may not be more than the other; Allah just tries you with it; and He will surely clarify for you on the Day of Resurrection, the matters in which you differed.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
Had Allah willed He would have made you all one nation, but He sends astray whomever He wills and guides whomever He wills; and you will certainly be questioned regarding your deeds.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
And do not make your oaths phoney excuses between yourselves, so that a foot may not slip after being steadfast and you may taste evil because you were preventing from Allah’s way; and lest you be severely punished.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
And do not exchange the covenant of Allah to procure an abject price; that which is with Allah is better for you, if you know.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
What you have will perish, and that which is with Allah will remain forever; and indeed We shall pay the patiently enduring a recompense which befits the best of their deeds.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whoever does good deeds – whether a male or female – and is a Muslim, We shall sustain him an excellent life, and shall certainly pay them a recompense which befits the best of their deeds.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
And when you recite the Qur’an, seek the refuge of Allah from Satan the outcast.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mm{%
Indeed he has no power over the believers and who rely only upon their Lord.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmi{%
Satan’s power is only over those who make friendship with him and ascribe him as a partner (in worship).\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmii{%
And when We replace a verse* by another – and Allah well knows what He sends down – the disbelievers say, “You are just fabricating”; in fact most of them do not know. (* The command of one verse by another.)\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmiii{%
Proclaim, “The Holy Spirit* has rightly brought it down from your Lord, to make the believers steadfast, and a guidance and glad tidings for the Muslims.” (* Angel Jibreel – peace and blessings be upon him.)\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmiv{%
And indeed We know that they say, “This Qur’an is being taught by some other man”; the one they refer to speaks a foreign language, whereas this is clear Arabic!\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmv{%
Those who disbelieve in the signs of Allah – Allah does not guide them, and for them is a punishment, most painful.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmvi{%
Only those who do not believe in Allah’s signs attribute lies and fabrications; and they themselves are liars.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmvii{%
The one who disbelieves in Allah after accepting faith – except him who is forced to and whose heart is still firmly upon faith – but whoever is wholeheartedly a disbeliever, upon them is the wrath of Allah; and for them is a great punishment.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmviii{%
This is because the worldly life was dearer to them than the Hereafter; and because Allah does not guide such disbelieving people.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmix{%
These are the ones whose hearts, ears, and eyes Allah has sealed; and they are the neglectful.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmx{%
So it occurred that they are the losers in the Hereafter.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmxi{%
Then indeed your Lord – for those who migrated after they had been oppressed, and then fought and remained patient – indeed your Lord is then, surely, Oft Forgiving, Most Merciful.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmxii{%
The day when every soul will come quarrelling against itself, and every soul will be fully repaid for what it did, and they will not be wronged.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmxiii{%
And Allah has illustrated an example of a township – which dwelt in peace and security, its provisions coming in abundance from every side – in response the township started being ungrateful of Allah’s favours, therefore Allah made it taste the punishment by covering it with a cloak of starvation and fear, on account of their deeds.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmxiv{%
And indeed a Noble Messenger came to them from among them – in response they denied him, and therefore the punishment seized them, and they were unjust.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmxv{%
Therefore eat the lawful and good sustenance Allah has provided you, and be grateful for the blessings of your Lord, if you worship Him.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmxvi{%
Only these are forbidden for you – the carrion, and blood, and flesh of swine, and that which has been slaughtered while proclaiming the name of any other besides Allah; so one who is compelled and does not eat out of desire, nor more than what is necessary, then indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And do not say – the lie which your tongues speak – “This is lawful, and this is forbidden” in order to fabricate a lie against Allah; indeed those who fabricate lies against Allah will never prosper.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmxviii{%
A little enjoyment – and for them is a punishment, most painful.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmxix{%
And especially for the Jews We forbade which We related to you earlier; and We did not oppress them, but it is they who wronged themselves.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmxx{%
Then indeed your Lord – for those who unwittingly commit evil and then repent and reform themselves – indeed your Lord is then, surely, Oft Forgiving, Most Merciful.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Indeed Ibrahim was a leader, obedient to Allah, and detached from all; and he was not a polytheist.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmxxii{%
Grateful for His blessings; Allah chose him and guided him to the Straight Path.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We gave him goodness in this world; and indeed in the Hereafter he is worthy of proximity.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
And then We sent you (O dear Prophet Mohammed – peace and blessings be upon him) the divine revelation that, “Follow the religion of Ibrahim, who was free from all falsehood; and was not a polytheist.”\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The Sabbath was made obligatory only upon those who differed in it; and indeed your Lord will judge between them on the Day of Resurrection concerning the matter in which they differed.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Call towards the path of your Lord with sound planning and good advice, and debate with them in the best possible way; indeed your Lord well knows him who has strayed from His path, and He well knows the guided.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
And if you mete out punishment, then punish similarly as you were afflicted; and if you patiently endure, then indeed patience is better for the patiently enduring.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
And O dear Prophet (Mohammed – peace and blessings be upon him) patiently endure – and your patience is only due to the guidance of Allah – and do not grieve for them, and do not be disheartened by their deceits.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmxxix{%
Indeed Allah is with the pious and the virtuous.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Purity is to Him Who took His bondman in a part of the night from the Sacred Mosque to the Aqsa Mosque around which We have placed blessings, in order that We may show him Our great signs; indeed he is the listener, the beholder. (This verse refers to the physical journey of Prophet Mohammed – peace and blessings be upon him – to Al Aqsa Mosque and from there to the heavens and beyond. The entire journey back to Mecca was completed within a small part of the night.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
And We gave Moosa the Book, and made it a guidance for the Descendants of Israel that, “Do not appoint anyone as a Trustee besides Me.”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
The descendants of those whom We boarded along with Nooh; he was indeed a grateful bondman.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We decreed for the Descendants of Israel in the Book that, “You will indeed create great turmoil in the earth twice, and you will surely become very proud.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
So when the first of those promises came, We sent upon you Our extremely militant bondmen – they therefore entered the cities pursuing you; and this was a promise that had to be fulfilled.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
We then reversed your attack upon them, and aided you with wealth and sons and increased your numbers.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
If you do good deeds, you will for your own good – and if you commit evil, it is for yourself; therefore when the second of those promises came – so the enemy maim your faces, and enter the mosque as they had entered it the first time, and destroy until they ruin all they could capture.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
It is likely that your Lord may have mercy on you; and if you repeat the mischief, We will repeat the punishment; and We have made hell a prison for the disbelievers.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Indeed this Qur’an guides to the most Straight Path, and gives glad tidings to the believers who do good deeds, that for them is a great reward.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
And those who do not believe in the Hereafter – We have kept prepared for them a punishment, most painful.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmxl{%
And man prays for evil like the way he seeks goodness; and man is very hasty.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmxli{%
And We created the night and the day as two signs – We therefore kept the sign of the night indistinct, and the sign of the day visible – so that you may seek the munificence of your Lord, and know the calculation of the years, and the accounting; and We have explained all things in detail, distinctively.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmxlii{%
And We have attached the destiny of every man to his neck; and We shall bring forth a register for him on the Day of Resurrection, which he will find open.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmxliii{%
It will be said, “Read your ledger; this day you are sufficient to take your own account.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whoever came to guidance, has come for his own good; and whoever went astray, has strayed for his own ruin; and no burdened soul will bear another’s burden; and We never punish until We have sent a Noble Messenger.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmxlv{%
And when We will to destroy a township We send the commands to its prosperous people, thereupon they do not obey them, and so the Word is proved upon it – We therefore destroy and ruin it.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
And many a generation We did destroy after Nooh! And Allah is Sufficient, Aware of the sins of His bondmen, the Beholder.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
Whoever desires this fleeting one, We may give him quickly – whatever We will, to whomever We will; and then assign hell for him; for him to enter it condemned, pushed around.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
And whoever desires the Hereafter and strives for it accordingly, and is a believer – so only their effort has borne fruit.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmxlix{%
We provide help to all – to these and to those, by the bestowal of your Lord; and there is no constraint on the bestowal of your Lord.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mml{%
Observe how We have given superiority to some over others; and indeed the Hereafter is the greatest in rank and the highest in excellence.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmli{%
O listener, do not set up another God with Allah, for you will then remain seated condemned, helpless.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmlii{%
And your Lord has ordained that you do not worship anyone except Him, and treat your parents with kindness; if either of them or both reach old age in your presence, do not say “Uff”* to them and do not rebuff them, and speak to them with the utmost respect. (* Any expression of disgust.)\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmliii{%
And lower your wing humbly for them, with mercy, and pray, “My Lord! Have mercy on them both, the way they nursed me when I was young.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord is Well Aware of what is in your hearts; if you are worthy, then indeed He is Oft Forgiving for those who repent.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmlv{%
And give the relatives their rights, and to the needy, and to the traveller; and do not waste needlessly.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmlvi{%
Indeed those who needlessly waste are brothers of the devils; and the devil is very ungrateful to his Lord.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmlvii{%
And if you turn away from these*, expecting the mercy of your Lord, for which you hope, then speak to them an easy word. (* The companions of the Holy Prophet, who sought his assistance.)\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And do not keep your hand tied to your neck nor open it completely, lest you remain seated – reproached, weary.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmlix{%
Indeed your Lord eases the livelihood and restricts it, for whomever He wills; He Well Knows, Beholds His bondmen.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmlx{%
And do not kill your children, fearing poverty; We shall provide sustenance to them as well as to you; indeed killing them is a great mistake.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmlxi{%
And do not approach adultery – it is indeed a shameful deed; and a very evil way.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmlxii{%
And do not wrongfully kill any living being which Allah has forbidden; and for whoever is slain wrongfully, We have given the authority to his heir, so he should not cross limits in slaying; he will surely be helped.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
And do not approach the wealth of the orphan except in the best possible way, till he reaches adulthood; and fulfil the promise; indeed the promise will be asked about.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
And correctly measure when you measure, and weigh correctly with the scales; this is better, and has a better outcome.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmlxv{%
And do not pursue the matter you do not have the knowledge of; indeed the ear, and the eye, and the heart – each of these will be questioned.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
And do not walk haughtily on the earth; you can never split the earth, nor be as high as the hills.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
Of all this related before, the evil among it is disliked by your Lord.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
This is part of the divine revelations of wisdom that your Lord has sent down to you (O dear Prophet Mohammed – peace and blessings be upon him); and O listener, do not set up another God with Allah, for you will then be thrown into hell – rebuked, rebuffed.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmlxix{%
Has your Lord chosen sons for you, and created daughters for Himself from among the angels? Indeed you utter a profound word!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmlxx{%
And We have explained in this Qur’an in various ways, for them to understand; and it increases nothing except their hatred towards it.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “If there were other Gods besides Him” – as they utter – “then they would have certainly found a way towards* the Owner of the Throne!”. (* To fight against Him.)\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Purity and Supremacy are to Him from what they utter, a Great Supremacy!\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens and the earth and all those in them say His Purity; and there is not a thing that does not proclaim His purity with praise, but you do not understand their proclamation of purity; indeed He is Most Forbearing, Oft Forgiving.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
And when you read the Qur’an O dear Prophet (Mohammed – peace and blessings upon him), We created an invisible barrier between you and those who do not believe in the Hereafter.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
And We placed covers upon their hearts so they may not understand it, and deafness in their ears; and when you mention your Only Lord in the Qur’an, they flee turning their backs in hatred.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We know well why they listen when they lend ears to you, and when they discuss among themselves, when the unjust say, “You have not followed except a man who is under a magic spell.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
See the kind of examples they invent for you! They therefore strayed, so cannot find a path.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
And they say, “When we have become bones and decomposed, will we really be raised up anew?”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Proclaim, “Become stones or iron.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
“Or some other creation which you deem great”; so they will now say, “Who will create us again?”; proclaim, “He Who created you for the first time”; so now they will mockingly shake their heads at you, and question, “When is this going to occur?”; say, “It could perhaps be soon.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
“The day when He will call you and you will come praising Him, thinking you have stayed only a little.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
And tell My bondmen to speak that which is the best; undoubtedly Satan sows discord among them; indeed Satan is man’s open enemy.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord knows you well; if He wills He may have mercy upon you, or if He wills, He may punish you; and We have not sent you (O dear Prophet Mohammed – peace and blessings be upon him) as a guardian over them.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
And your Lord knows well all those who are in the heavens and the earth; and indeed among the Prophets We gave excellence to some above others, and We gave the Zaboor to Dawud.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Proclaim, “Call upon those whom you assume besides Allah – so they do not have any power to relieve the misfortune from you nor to avert it.”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
The devoted bondmen whom these disbelievers worship, themselves seek the means of proximity from their Lord, that who among them is the closest (to his Lord), and hope for His mercy and fear His punishment; indeed the punishment of your Lord is to be feared.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
And there is no such dwelling but which We shall destroy before the Day of Resurrection, or punish it severely; this is written in the Book.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
And We remained constrained from sending such signs, because the former people denied them; and We gave the Thamud the she-camel for enlightenment, so they oppressed it; and We do not send such signs except to warn.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
And when We proclaimed to you, “Indeed all mankind is within the control of your Lord”; and We did not create the spectacle* which We showed you except to try mankind, and the Tree** which is cursed in the Qur’an; and We warn them – so nothing increases for them except extreme rebellion. (* The Ascent of the Holy Prophet to the heavens and beyond, which the disbelievers denied as just a dream. ** The Zakkum tree which will grow in hell and be the food for its inhabitants.)\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmxc{%
And recall when We ordered the angels that, “Prostrate before Adam” – so they all prostrated except Iblis; he said, “Shall I prostrate before one whom You have created from clay?”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmxci{%
He said, “Behold this* – the one whom You have honoured above me – if You give me respite till the Day of Resurrection, I will surely crush his descendants, except a few.” (* Prophet Adam.)\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmxcii{%
He said, “Be gone – therefore whoever among them follows you – so hell is the recompense for you all, a sufficient punishment.”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmxciii{%
“And mislead those whom you can among them with your voice, and raise an army against them with your cavalry and infantry, and be their partner in wealth and children, and give them promises”; and Satan does not promise them except with deception.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmxciv{%
“Indeed My bondmen* – you do not have any power over them”; and your Lord is Sufficient as a Trustee. (* The chosen virtuous bondmen)\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmxcv{%
Your Lord is He Who sails the ship upon the seas for you, so that you may seek His munificence; indeed He is Most Merciful upon you.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
And when calamity strikes you upon the sea, all those whom you worship are lost, except Him; then when He rescues you towards land, you turn away; and man is extremely ungrateful.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Are you unafraid that He may bury an edge of the same land along with you, or send a shower of stones upon you, and you find no supporter for yourselves?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or are you unafraid that He may again take you back to the sea, then send against you a ship-breaking gust of wind, therefore drowning you because of your disbelief – then you may not find for yourself anyone to come after Us for this?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmxcix{%
Indeed We have honoured the Descendants of Adam and transported them over land and sea, and gave them good things as sustenance, and made them better than most of Our creation.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmc{%
On the day when We shall summon every group along with its leader; so whoever is given his register in his right hand – these will read their accounts and their rights will not be suppressed even a thread. (* They will be given the full reward.)\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmci{%
Whoever is blind* in this life will be blind in the Hereafter, and even more astray. (* To the truth – disbelieving.)\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcii{%
And it was close that they were about to mislead you somewhat from the divine revelation We sent to you, for you to attribute something else* to Us; and if it were**, they would have accepted you as a friend. (* Other than the divine revelation. ** Which is impossible.)\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmciii{%
And had We not kept you steadfast, possibly you might have inclined to them just a little.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmciv{%
And if it were*, We would then have made you taste a double life and a double death – you would then not find any supporter against Us. (* Which is impossible.)\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcv{%
And indeed it was close that they frighten you in the land for them to oust you from it – and if it were, they would not have stayed after you, but a little.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcvi{%
The tradition of the Noble Messengers We sent before you – and you will not find Our rules changing.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Keep the prayer established, from the declining of the sun until darkness of the night, and the Qur’an at dawn; indeed the angels witness the reading of the Qur’an at dawn.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And forego sleep* in some part of the night – an increase for you**; it is likely your Lord will set you on a place where everyone will praise you***. (* For worship. ** Obligatory only upon the Holy Prophet. *** On the Day of Resurrection.)\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcix{%
And pray, “My Lord! Admit me with the truth and take me out with the truth*, and give me from Yourself a helpful dominance**.” (* Wherever I come or go ** Through spread of Islam.)\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcx{%
And proclaim, “The Truth has arrived and falsehood has vanished; indeed falsehood had to vanish.” (* With the arrival of the Last Prophet – Mohammed peace and blessings be upon him)\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcxi{%
And We send down in the Qur’an that which is a cure for the Muslims, and a mercy – and it increases only ruin for the unjust.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcxii{%
And when We bestow favours upon man, he turns away and goes far away towards himself; and when evil touches him he despairs.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Proclaim, “Each one works according to his own pattern; and your Lord well knows him who is more upon guidance.”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
They ask you concerning the soul; proclaim “The soul is an entity by the command of my Lord, and you have not received knowledge except a little.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcxv{%
And if We willed We could have taken away the revelations which We have sent to you – you would then not find anyone who could advocate for you before Us for this.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
Except the mercy of your Lord; indeed His munificence upon you (O dear Prophet Mohammed – peace and blessings be upon him) is extremely great.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Proclaim, “If all mankind and jinns agree to bring an equivalent to the Qur’an, they will not be able to bring its equal – even if they were to help each other.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
And indeed We have illustrated all kinds of examples in the Qur’an for mankind – so most men did not accept, except to be ungrateful.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcxix{%
And they said, “We will not accept faith in you, until you cause a spring to gush forth from the earth for us.”\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcxx{%
“Or you have a garden of date-palms and grapes, and you make gushing rivers to flow in it.”\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
“Or you cause the sky to fall upon us in pieces like you said – or bring Allah and the angels as Witness.”\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
“Or you have a house of gold, or you ascend up into heaven; and even then we shall not believe in your ascent unless you send down a book upon us, which we may read”; say (O dear Prophet Mohammed – peace and blessings be upon him), “Purity is to my Lord – who am I except a human, sent by Allah?” (* These can be done, only when Allah commands.)\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
And what prevented people from believing when the guidance came to them, except their saying that, “What! Allah has sent a human as a Noble Messenger?”?\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Proclaim, “If there were angels walking peacefully on the earth, We would send down only an angel from heaven, as a Noble Messenger towards them.”\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Proclaim, “Allah is Sufficient as Witness between me and you all; indeed He is Well Aware of, the Beholder of His bondmen.”\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
And only he whom Allah guides, is upon guidance; and whomever He sends astray – you will therefore not find for them any supporters besides Him; and We shall raise them by their faces on the Day of Resurrection – blind, dumb and deaf; their destination is hell; whenever it is about to extinguish, We will inflame it more for them.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
This is their reward because they disbelieved in Our signs and said, “When we are bones and decomposed, will we really be created again and raised up again?”\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
Do they not see that Allah Who has created the heavens and the earth is Able to create people similar to them, and has set a term for them in which there is no doubt? So the unjust do not accept without being ungrateful.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Proclaim, “If you owned the treasures of the mercy of my Lord, you would hoard them too for fear that they may get spent; and man is a big miser.”\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
And indeed We gave Moosa nine clear signs, therefore ask the Descendants of Israel when he came to them – in response Firaun said, “O Moosa – I think you are under a magic spell.”\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
He said, “You certainly know that these have not been sent down except by the Lord of the heavens and the earth, the eye-openers* for the hearts; and I think that you, O Firaun, will surely be ruined.” (* The signs which enlighten the hearts.)\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
He therefore wished to expel them from the earth, so We drowned him and his companions, all together.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And after him, We said to the Descendants of Israel, “Reside in this land – then when the promise of the Hereafter comes, We will bring you all huddled together.”\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
And We sent down the Qur’an with the truth, and it has come down only for the truth; and We did not send you except as a Herald of glad tidings and warnings.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
And We sent down the Qur’an in parts, that you may gradually recite it to the people, and We sent it down slowly in stages.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Proclaim, “Whether you accept faith in it or not”; indeed those who received knowledge before the Qur’an came, fall down prostrate on their faces when it is recited to them.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
And they say, “Purity is to our Lord – indeed the promise of our Lord had to come true.”\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
And they fall down on their faces weeping, and this Qur’an increases their humility. (Command of prostration \# 4).\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Proclaim, “Pray calling (Him) Allah or calling (Him) the Most Gracious; whichever name you call with – they are all His magnificent names; and do not offer your prayers very loudly or very softly, and seek a way between them.”\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say, “All praise is to Allah, Who has not chosen a son for Himself, and none is His partner in kingship, and none is His supporter due to weakness, and say ‘Allah is Great’ to proclaim His greatness.”\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen All praise is to Allah Who sent down the Book upon His bondman, and has not kept any deviation in it.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
A just Book, to warn of Allah’s severe punishment, and to give glad tidings to the believers who do good deeds, that for them is an excellent reward.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
In which they will abide forever.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
And to warn those who say “Allah has chosen a child.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
They do not have any knowledge of it – nor did their forefathers; profound is the word that comes out of their mouths; they only speak a lie.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Possibly you may risk your life by grieving (O dear Prophet Mohammed – peace and blessings be upon him) for them if they do not believe in this narration.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
We have indeed placed all that is on the earth as its adornment in order that We may test them, who among them has the best deeds.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
And indeed We shall one day make all that is on it a barren plain.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Did you know that the People of the Cave and People close to the Woods, were Our exceptional signs?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcl{%
When the young men took refuge in the Cave – then said, “Our Lord! Give us mercy from Yourself, and arrange guidance for us in our affair.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcli{%
We then thumped upon their ears in the Cave for a number of years. (* Put them to sleep.)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmclii{%
We then awakened them to see which of the two groups more accurately tells the period they had stayed.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We shall narrate their account to you accurately; they were young men who believed in their Lord, and We increased the guidance for them.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcliv{%
And We made their hearts steadfast when they stood up and said, “Our Lord is the Lord of the heavens and the earth – we shall not worship any other deity except Him – if it were, we have then said something excessive.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmclv{%
“These – the people of ours – have set up Gods besides Allah; why do they not bring a clear proof regarding them? And who is more unjust than one who fabricates a lie against Allah?”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmclvi{%
“And when you have disassociated yourself from them and all what they worship besides Allah – so take refuge in the Cave – your Lord will spread His mercy for you and arrange ease for you in your affairs.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmclvii{%
And O dear Prophet (Mohammed – peace and blessings be upon him) you will see the sun that when it rises it shifts away to the right of their cave, and when it sets it shifts away to their left, and they are in the open ground of that cave; this is from among the signs of Allah; whomever Allah guides – only he is therefore guided; and whomever He sends astray – you will never find for him a friend who guides.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmclviii{%
And you may think they are awake, whereas they are asleep; and We turn them over to the right and the left – and their dog is on the threshold of the cave, with its paws outstretched; O listener, were you to look at them closely, you would turn back running away from them, and be filled with their dread.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmclix{%
And similarly We awakened them so that they may enquire about each other; a speaker among them said, “How long have you stayed here?” Some among them said, “We have stayed a day or part of a day”; the others said, “Your Lord well knows how long you have stayed; therefore send one of you to the city with this silver coin – he may then check which food available there is purer, in order to bring some of it for you to eat – and he must be courteous and not inform anyone about you.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmclx{%
“Indeed if they come to know about you, they will stone you or turn you back to their religion – and if so, you will never prosper.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmclxi{%
And this is how We made them known for people to know that the promise of Allah is true and that there is no doubt concerning the Last Day; when the people began disputing among themselves regarding them, they said, “Construct a building over their cave”; their Lord well knows them; those who dominated in this matter said, “We promise we will build a mosque over them.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmclxii{%
So the people will now say, “They are three, their dog is the fourth”; and some will say, “They are five, their dog is the sixth” – just blind guesses; and some will say, “They are seven, and their dog is the eighth”; proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “My Lord well knows their number – no one knows them except a few”; therefore do not debate concerning them except what has occurred, and do not ask any of the People of the Book(s) anything concerning them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And never say about anything that, “I will do this tomorrow.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
Except “If Allah wills”; and remember your Lord when you forget, and say, “It is likely that my Lord will guide me to a more accurate way of virtue than this.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And they stayed in their Cave for three hundred years* and nine more*. (* 300 according to the Solar calendar and 309 according to the Lunar calendar.)\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say, “Allah well knows how long they stayed; for Him only are the hidden of the heavens and the earth; how well He sees and hears! They do not have any supporter besides Him; and He does not associate anyone in His command.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
And recite the Book of your Lord which has been divinely revealed to you; there is none who can change His Words; and you will never find a refuge besides Him.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And restrain yourself along with those who pray to their Lord morning and evening, seeking His pleasure; and may not your sight fall on anything besides them; would you desire the adornment of the life of this world? And do not follow him whose heart We have made neglectful of Our remembrance – the one who has followed his own desires and his matter has crossed the limits.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmclxix{%
And proclaim, “The Truth is from your Lord”; so whoever wills may accept faith, and whoever wills may disbelieve – We have indeed prepared for the disbelievers a fire the walls of which will surround them; if they plead for water, their plea will be answered with water like molten metal which shall scald their faces; what an evil drink it is; and what an evil destination is hell!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmclxx{%
Indeed those who believed and did good deeds – We do not waste the reward of those whose deeds are good.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
For them are everlasting Gardens of Eden, beneath which rivers flow – in it they will be given bracelets of gold to adorn, and shall wear green clothes made of fine silk and gold embroidery, reclining upon thrones in it; what an excellent reward; and what an excellent abode is Paradise!\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
And relate to them the account of the two men – to one We gave two gardens of grapes, and covered them with date-palms and kept farms between them.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Both the gardens gave yields and gave no shortfall in it – and We made a river to flow between the two.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
And he had fruit; he therefore said to his companion – and he used to debate with him – “I exceed you in wealth, and am more powerful in respect of men.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
He went into his garden and wronging himself said, “I do not think that this will ever perish.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
“I do not think that the Last Day will ever be established – and even if I return to my Lord I will surely find a haven better than this garden.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His companion debating with him answered, “What! You disbelieve in Him Who has created you from dust, then from a drop of liquid, and then created you as a complete man?”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
“But I just say that only Allah is my Lord, and I do not ascribe anyone as a partner to my Lord.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
“And why was it not that you would have said when you entered your garden, ‘Whatever Allah wills – we do not have any strength except with the help of Allah’ – if you had observed me lesser than you in wealth and children.”?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
“So it is likely that my Lord will give me a garden better than yours, and send bolts of lightning from the skies on your garden – it therefore turns into a barren plain.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
“Or its water may sink into the earth, so you may never be able to find it.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
And his fruits were surrounded – he therefore remained helplessly wringing his hands upon all that he had spent on it – and it lay fallen on its canopy – and he says, “If only I had not ascribed any partner to my Lord!”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
And he had no group to help him against Allah, nor was he capable of taking revenge.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
Here brought to light is that the authority is only for Allah, the True; the reward He bestows is the best, and believing in Him has the best outcome.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
And relate to them the example of the life of this world – like water which We sent down from the sky, therefore vegetation of the earth grew forth in abundance with it to become dry hay which the winds scatter; and Allah is the Controller of all things.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and sons are ornaments of the life of this world; and good deeds that last – their reward is better before your Lord, and are better in respect of hope.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
And the Day when We move the hills and you see the earth flattened plain, and We shall raise all of them together – so not leaving out any one of them.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
And everyone shall be presented before your Lord in rows; “Indeed you have come to Us exactly as We had created you for the first time – in fact you thought that We shall never appoint a promised time for you!”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the Book shall be placed – and you will see the guilty dreading what is written in it and saying, “Woe to us – what sort of a Book is this that it has not left out any small sin nor a great one, which it has not included!” And they found all that they did confronting them; and your Lord does not wrong any one.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcxc{%
And recall when We commanded the angels that, “Prostrate before Adam” – so they all prostrated, except Iblis; he was of the jinn, he therefore rebelled against his Lord’s command; “What! You choose him and his offspring as your friends instead of Me, whereas they are your enemies?” And what an evil alternative did the unjust get.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcxci{%
Neither did I make them witness the creations of the heavens and the earth, nor witness their own creation; nor does it befit My Majesty to choose misleaders as aides.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
And the Day when He will proclaim, “Call those partners of Mine whom you had assumed” – so they will call out to them – they will not answer them, and We shall create a field of destruction between them.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And when the guilty see hell, they will be certain of falling into it, and will find no place to escape from it.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
And We have indeed illustrated all kinds of examples for mankind in this Qur’an; and man is the most quarrelsome of all.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
And what prevented men from accepting faith when guidance came to them, and from asking forgiveness from their Lord except that the tradition of the former nations come upon them or that they confront various kinds of punishments?\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
And We do not send the Noble Messengers except as Heralds of glad tidings and warnings; and the disbelievers debate by means of falsehood to drive away the Truth with it, and they took My signs and warnings they were given, as a mockery!\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
And who is more unjust than one who, when reminded of the signs of his Lord, turns away from them and forgets what his hands have sent forward? We have put covers on their hearts so as not to understand the Qur’an, and deafness in their ears; and even if you call them to guidance, they will never attain the right path.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
And your Lord is the Oft Forgiver, the Merciful; if He seized them for their deeds, He would soon send the punishment upon them; but for them is an appointed time from which they will not find any refuge.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And these towns – We destroyed them when they committed injustice, and We had set an appointed time for their destruction.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcc{%
And recall when Moosa said to his assistant, “I will not give up until I reach the place where the two seas meet or until I have progressed for ages.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcci{%
And when they reached the place where the two seas meet, they forgot about their fish, and it took its way into the sea, making a tunnel. (The dead fish came alive and went into the water.)\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmccii{%
So when they had gone beyond that place, Moosa said to his assistant, “Bring our breakfast – we have indeed faced great exertion in this journey of ours.”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He said, “Just imagine – when we had taken shelter near the rock, so indeed I forgot the fish; and none but Satan caused me to forget to mention it; and the fish took its way into the sea – its amazing!”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcciv{%
Said Moosa, “This is exactly what we wanted”; so they came back retracing their steps.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmccv{%
So they found a bondman* from amongst Our (chosen) bondmen, to whom We had given mercy from Us, and had bestowed the inspired knowledge from Ourselves. (* Hazrat Khidr – peace be upon him.)\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Moosa said to him, “May I stay with you upon the condition that you will teach me the righteousness that you have been taught?”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmccvii{%
He said, “You will never be able to patiently stay with me.”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmccviii{%
“And how will you bear something which your knowledge does not encompass?”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmccix{%
Said Moosa, “Allah willing, you will soon find me patient and I will not do anything against your instructions.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmccx{%
He said, “Therefore if you stay with me, do not ask me about anything until I myself mention it to you.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they both set out; until when they had boarded the boat, the chosen bondman ruptured the boat; said Moosa, “Did you make a hole in the boat in order to drown its passengers? You have indeed done an evil thing.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmccxii{%
He said, “Did I not say that you will never be able to patiently stay with me?”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
Said Moosa, “Do not apprehend me upon my forgetting, and do not impose difficulty on me in my task.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
So they set out again; until when they met a boy, the chosen bondman slew him – Moosa said, “Did you slay an innocent soul not in retribution for another? You have indeed done an extremely evil thing.”\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmccxv{%
He said, “Did I not tell you that you will never be able to patiently stay with me?”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
Said Moosa, “If I ask you anything after this, do not stay with me; indeed your condition from me is fulfilled.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
So they both set out again; until they came to the people of a dwelling – they asked its people for food – they refused to invite them – then in the village they both found a wall about to collapse, and the chosen bondman straightened it; said Moosa, “If you wished, you could have taken some wages for it!”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
He said, “This is the parting between you and me; I shall now tell you the interpretation of the matters you could not patiently bear.”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmccxix{%
“In respect of the boat – it belonged to the poor people who worked on the river, so I wished to flaw it – and behind them was a king who would capture every sound ship.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmccxx{%
“And in respect of the boy – his parents were Muslims and we feared that he may incite them to rebellion and disbelief.”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
“So we wished that their Lord may bestow them a child – better, purer and nearer to mercy.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
“And in respect of the wall – it belonged to two orphan boys of the city, and beneath it was their treasure, and their father was a virtuous man; therefore your Lord willed that they should reach their maturity and remove their treasure; by the mercy of your Lord; and I have not done this at my own command; this is the interpretation of the matters you could not patiently bear.” (* Hazrat Khidr was given the knowledge of the hidden – as in all three explanations he gave).\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
And they ask you regarding Zul-Qarnain; say, “I shall recite his story to you.”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
Indeed We gave him authority in the land and bestowed him the means of everything.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
He therefore pursued a purpose.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
To the extent that when he reached the setting-place of the sun, he found it setting in a muddy spring, and found a nation there; We said, “O Zul-Qarnain – either punish them or choose kindness for them.”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He submitted, “Regarding one who has done injustice, we shall soon punish him – he will then be brought back to his Lord, Who will punish him severely.”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
“And regarding one who believed and did good deeds – so his reward is goodness; and we shall soon give him an easy command.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
He again pursued a purpose.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
To the extent that when he reached the rising-place of the sun, he found it rising upon a nation for which We had not kept any shelter from it.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
So it is; and Our knowledge encompasses all that he possessed.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
He again pursued a purpose.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
Until, when he came between two mountains, he found before them a nation that did not appear to understand any speech.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said, “O Zul-Qarnain – indeed Yajuj and Majuj* are spreading chaos in the land – so shall we assign for you a consideration upon the condition that you set up a wall between us and them?” (* Gog and Magog.)\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said, “That which my Lord has given me control over is better, therefore help me with strength – I shall set up a barrier between you and them.”\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
“Give me sheets of iron”; until when he had raised the wall equal to the edge of the two mountains, he said, “Blow”; to the extent that he made it ablaze – he said, “Bring me molten copper to pour upon it.”\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
Therefore Yajuj and Majuj were neither able to surmount it, nor could they pierce it.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
He said, “This is the mercy of my Lord; then when the promise of my Lord arrives, He will blow it to bits; and my Lord’s promise is true.”\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
And on that day We shall release them in groups surging like waves one after another, and the Trumpet will be blown – so We shall gather them all together. (* Gog and Magog will come out during the time of Eisa (Jesus – when he comes back to earth) and cause great destruction in the land.)\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmccxl{%
And We shall bring hell in front of the disbelievers.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmccxli{%
The ones whose eyes were covered from My remembrance, and who could not bear to hear Truth.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Do the disbelievers assume that they will be able to choose My bondmen as supporters other than Me? Indeed We have prepared hell to welcome the disbelievers.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “Shall we inform you whose are the most failed works?”\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
“Of those whose efforts are lost in (pursuit of) the life of this world, and they think that they are doing good deeds.”\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
The people who disbelieved in the signs of their Lord and in the meeting with Him, therefore all their deeds are in vain –We shall therefore not establish any weighing for them on the Day of Resurrection.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
This is their reward – hell – because they disbelieved, and made a mockery of My verses and My Noble Messengers.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
Indeed those who believed and did good deeds – their welcome are the Gardens of Paradise.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
They will abide in it for ever, never wanting to shift from it.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Proclaim, “If the sea became ink for the Words of my Lord, the sea would indeed be used up and the Words of my Lord would never – even if we bring another like it for help.”\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmccl{%
Proclaim, “Physically I am a human* like you – my Lord sends divine revelations to me – that your God is only One God; so whoever expects to the meet his Lord must perform good deeds and not ascribe anyone as a partner in the worship of his Lord.” (* Human but not equal to you, in fact the greatest in spiritual status.)\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf-Ha-Ya-A’in-Sad. (* Alphabets of the Arabic language – Allah and to whomever He reveals know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcclii{%
This is the remembrance of the mercy of your Lord upon His bondman Zakaria.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmccliii{%
When he softly prayed to his Lord.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmccliv{%
He submitted, “O my Lord – my bones have become weak and old age shines forth from my head, and O my Lord, I have never been disappointed in my prayer to you.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcclv{%
“And I fear my relatives after me and my wife is barren therefore bestow upon me from Yourself one who will take up my work.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
“He being my successor and the heir of the Descendants of Yaqub (Jacob); and my Lord, make him a cherished* one.” (* Make him a Prophet among the Descendants of Israel.)\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
“O Zakaria! We give you the glad tidings of a son whose name is Yahya (John) – before him, We have not created anyone of this name.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He submitted, “My Lord – how can I have a son whereas my wife is barren and I have reached infirmity due to old age?”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcclix{%
He (the angel) said, “So it is; your Lord says, ‘This is easy for Me – in fact I created you before this, at a time when you did not exist.’”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcclx{%
He said, “My Lord, give me a sign”; He said, “Your token is that you will not speak to people for three nights, although in proper health.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
He therefore emerged upon his people from the mosque, and told them through gestures, “Keep proclaiming the Purity (of your Lord) morning and evening.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
“O Yahya – hold the Book firmly”; and We gave him Prophethood in his infancy. (Prophet Yahya was only 2 years old at that time.)\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
And compassion from Ourselves, and chastity; and he was extremely pious.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
And was good to his parents and not forceful, nor disobedient.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
And peace is upon him the day he was born, and the day he will taste death, and the day he will be raised alive.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And remember Maryam in the Book; when she went away from her family to a place towards east.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
So there she screened herself from them; We therefore sent Our Spirit towards her – he appeared before her in the form of a healthy man. (Angel Jibreel – peace be upon him.)\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said, “I seek the refuge of the Most Gracious from you – if you fear God.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
He said, “I am indeed one sent by your Lord; so that I may give you a chaste son.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said, “How can I bear a son? No man has ever touched me, nor am I of poor conduct!”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said, “So it is; your Lord has said, ‘This is easy for Me’; and in order that We make him a sign for mankind and a Mercy from Us; and this matter has been decreed.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
So she conceived him, and she went away with him to a far place.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
Then the pangs of childbirth brought her to the base of the palm-tree; she said, “Oh, if only had I died before this and had become forgotten, unremembered.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
(The angel) Therefore called her from below her, “Do not grieve – your Lord has made a river flow below you.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
“And shake the trunk of the palm-tree towards you – ripe fresh dates will fall upon you.” (This was a miracle – the date palm was dry and it was winter season.)\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
“Therefore eat and drink and appease your eyes; so if you meet any person then say, ‘I have pledged a fast (of silence) to the Most Gracious – I will therefore not speak to any person today.’”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
So carrying him in her arms, she brought him to her people; they said, “O Maryam, you have indeed committed a great evil!”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
“O sister of Haroon, neither was your father an evil man nor was your mother of poor conduct!”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
Thereupon she pointed towards the child; they said, “How can we speak to an infant who is in the cradle?”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
The child proclaimed, “I am Allah’s bondman; He has given me the Book and made me a Herald of the Hidden (a Prophet).”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
“And He has made me blessed wherever I be; and ordained upon me prayer and charity, as long as I live.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
“And has made me good to my mother and not made me forceful, ill-fated.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
“And peace is upon me the day I was born, and on the day I shall taste death, and on the day I will be raised alive.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
This is Eisa (Jesus), the son of Maryam; a true statement, in which they doubt.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It does not befit Allah to appoint someone as His son – Purity is to Him! When He ordains a matter, He just commands it, “Be” – and it thereupon happens.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
And said Eisa, “Indeed Allah is my Lord and your Lord – therefore worship Him; this is the Straight Path.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
Then groups among them differed; so ruin is for the disbelievers from the witnessing of a Great Day.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
Much will they listen and much will they see, on the Day when they come to Us, but today the unjust are in open error.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
And warn them of the Day of Regret when the matter will have been decided; and they are in neglect, and they do not accept faith.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmccxc{%
Indeed We shall inherit the earth and all that is on it, and only towards Us will they return.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmccxci{%
And remember Ibrahim in the Book; he was very truthful, a Herald of the Hidden (a Prophet).\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
When he said to his father,* “O my father – why do you worship one which neither hears nor sees, and cannot benefit you in any way?” (* His uncle Azar.)\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
“O my father, indeed a knowledge has come to me which did not come to you – therefore follow me, I will show you the Straight Path.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
“O my father, do not be a bondman of the devil; indeed the devil is disobedient towards the Most Gracious.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
“O my father, I fear that a punishment from the Most Gracious may reach you, so you would become a companion of the devil.”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
He said, “What! You turn away from my Gods, O Ibrahim? If you do not desist, I will certainly stone you, and keep no relation with me for a long while.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
He said, “Stop it – peace be upon you; I shall seek forgiveness for you from my Lord; indeed He is very kind to me.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
``And I shall remain separated from you and all that you worship other than Allah and shall worship my Lord; possibly, by worshipping my Lord, I will not be amongst the unfortunate.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
So when he had separated from them and what they worshipped other than Allah, We bestowed him Ishaq and Yaqub; and We made each of them a Herald of the Hidden.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmccc{%
And We gave them Our mercy, and assigned for them a true and high repute.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmccci{%
And remember Moosa in the Book; he was indeed a chosen one, and he was a Noble Messenger, a Herald of the Hidden.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcccii{%
We called him from the right side of the mountain Tur, and brought him close to reveal Our secret.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And with Our mercy We bestowed upon him his brother Haroon, a Prophet.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And remember Ismail in the Book; he was indeed true to his promise and was a Noble Messenger, a Prophet.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcccv{%
He used to command his people to offer prayer and give charity, and was liked by his Lord.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And remember Idrees in the Book; he was indeed very truthful, a Prophet.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
And We lifted him to a high position. (Living with soul & body in heaven, after his death.)\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
It is these upon whom Allah has bestowed favour among the Prophets, from the descendants of Adam; and from those whom We boarded along with Nooh; and from the descendants of Ibrahim and Israel; and from those whom We guided and chose; when the verses of the Most Gracious were recited to them, they fell down, prostrating and weeping. (* Command of Prostration \# 5.)\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcccix{%
And after them came the unworthy successors who squandered prayer and pursued their own desires, so they will soon encounter the forest of Gai in hell.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcccx{%
Except those who repented and accepted faith and did good deeds – so these will enter heaven, and they will not be deprived* in the least. (* Of their due reward.)\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
Everlasting Gardens of Eden, which the Most Gracious has promised to His bondmen in the unseen; indeed His promise will come.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They will not hear any lewd talk in it, but only Peace; and in it for them is sustenance, every morning and evening.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
It is the Paradise that We will bequeath to those among Our bondmen who remain pious.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
(Said Angel Jibreel to Prophet Mohammed – peace and blessings be upon them) “And we angels do not come down except by the command of your Lord; to Him only belongs all that is ahead of us and all that is behind us and all that is between them; and your Lord is not forgetful.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
Lord of the heavens and the earth and all that is between them – therefore worship Him and be firm in His worship; do you know any other of the same name as His?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
And says man, “When I am dead, will I soon be brought forth alive?”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Does not man remember that We created him before this, and he was non existent?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
So by your Lord, We shall assemble them and the devils – all of them – and bring them around hell, fallen on their knees.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
We shall then pick out from every group the one who was most arrogant towards the Most Gracious.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
Moreover, We well know those who most deserve to be burned in hell.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
And there is none among you who shall not pass over hell; this is an obligatory affair, binding upon your Lord. (Allah will make everyone pass over the back of hell – on a thin bridge.)\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
We shall then rescue the pious – and leave the unjust in it, fallen on their knees.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
And when Our clear verses are recited to them, the disbelievers say to the Muslims, “Which group has a better home, and a better alliance?”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
And many a generation We did destroy before them, who exceeded them in wealth and pomp!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Proclaim, “For one in error – so the Most Gracious may give him respite; to the extent that when they see the thing which they are promised – either the punishment or the Last Day; so then they will come to know for whom is the evil rank and whose army is weak.”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
And Allah will increase the guidance for those who have received guidance; and good deeds that remain have the best reward before your Lord, and the best outcome.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
So have you seen him who denied Our signs and says, “I shall certainly be given wealth and children?”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Has he seen the Hidden, or has he made a pact with the Most Gracious?\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
Never; We shall now record what he says and give him a prolonged punishment.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
And it is We only Who shall inherit what he says (belongs to him), and he will come to Us, alone.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have chosen Gods besides Allah, so that they may provide them strength!\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
Never; soon they will deny ever worshipping them, and will turn into their opponents.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Did you not see that We sent devils upon the disbelievers, so they excite them abundantly?\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So do not be impatient for them (O dear Prophet Mohammed – peace and blessings be upon him); We are only completing their number.* (* The number of days left for them or their evil deeds.)\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
On the day when We shall assemble the righteous towards the Most Gracious, as guests.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
And drive the guilty towards hell, thirsty.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
People do not own the right to intercede, except those* who have made a covenant with the Most Gracious. (* The Holy Prophets and virtuous people will be given the permission to intercede. Prophet Mohammed – peace and blessings be upon him – will be the first to intercede.)\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And the disbelievers said, “The Most Gracious has chosen an offspring.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
You have indeed brought an extremely grave speech!\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
The heavens are close to being torn apart by it, and the earth being split asunder, and the mountains succumbing and falling down.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
Due to their ascribing of an offspring to the Most Gracious.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
And it does not befit the Most Gracious to choose an offspring!\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
All those who are in the heavens and the earth will come to the Most Gracious as His bondmen.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
He knows their number and has counted each one of them.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
And each one of them will come before Him on the Day of Resurrection, alone.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Indeed those who believed and did good deeds – the Most Gracious will appoint love for them. (In the hearts of other believers.)\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
We have therefore made this Qur’an easy upon your tongue, (O dear Prophet Mohammed – peace and blessings be upon him) for you to announce glad tidings with it to those who fear, and warn those who are quarrelsome.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
And many a generation We did destroy before them; do you see any one of them or hear their faintest sound?\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta-Ha.* (O dear Prophet Mohammed – peace and blessings be upon him) (Alphabets of the Arabic language – Allah and to whomever He reveals know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not sent down this Qur’an upon you (O dear Prophet Mohammed – peace and blessings be upon him) for you to fall into hardship! (Either because he used to pray at length during the night or because he was distressed due to the disbelievers not accepting faith.)\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcccli{%
Except as a reminder for one who fears.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmccclii{%
Sent down by One Who created the earth and the lofty heavens.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
The Most Gracious Who, befitting His Majesty, took to the Throne (of control).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
To Him only belongs all whatever is in the heavens and all whatever is in the earth, and all whatever is between them, and all whatever is beneath this wet soil.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmccclv{%
And if you speak aloud – so He surely knows the secret and that which is more concealed.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah – there is no worship except for Him; His only are the best names.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
And did the news of Moosa reach you?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire and said to his wife, “Wait – I have seen a fire – perhaps I may bring you an ember from it or find a way upon the fire.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmccclix{%
So when he came near the fire, it was announced, “O Moosa!”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmccclx{%
“Indeed I am your Lord, therefore take off your shoes; indeed you are in the holy valley of Tuwa!”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
“And I have chosen you, therefore listen carefully to what is divinely revealed to you.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
“Indeed it is Me, Allah – there is no God except I – therefore worship Me and keep the prayer established for My remembrance.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
“The Last Day will surely come – it was close that I hide it from all – in order that every soul may get the reward of its effort.” (He revealed it to His Prophets, so that people may fear and get ready. The exact time is not revealed to the people.)\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
“Therefore never let one, who does not accept faith in it and follows his own desires, prevent you from accepting this, so then you become ruined.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
“And what is this in your right hand, O Moosa?”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
He said, “This is my staff; I support myself on it, and I knock down leaves for my sheep with it, and there are other uses for me in it.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
He said, “Put it down, O Moosa!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
So Moosa put it down – thereupon it became a fast moving serpent.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
He said, “Pick it up and do not fear; We shall restore it to its former state.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
“And put your hand inside your armpit – it will come out shining white, not due to any illness – one more sign.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
“In order that We may show you Our great signs.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
“Go to Firaun, he has rebelled.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
Said Moosa, “My Lord, open up my breast for me.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
“And make my task easy for me.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
“And untie the knot of my tongue.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
“In order that they may understand my speech.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
“And appoint for me a viceroy from among my family.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
“That is Haroon, my brother.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
“Back me up with him.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
“And make him a partner in my task.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
“In order that we may profusely proclaim Your Purity.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
“And profusely remember You.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
“Indeed You see us.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
He said, “O Moosa, you have been granted your prayer.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
“And indeed We had bestowed upon you a favour one more time.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
“When We inspired in your mother’s heart whatever was to be inspired.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
“That, ‘Put him into a chest and cast it into the river, so the river shall deposit it on to a shore – therefore one who is an enemy to Me and you, shall pick him up’; and I bestowed upon you love from Myself; and for you to be brought up in My sight.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
“When your sister went, then said, ‘Shall I show you the people who may nurse him?’ And We brought you back to your mother in order to soothe her eyes and that she may not grieve; and you killed a man, so We freed you from sorrow, and tested you to the maximum; you therefore stayed for several years among the people of Madyan; then you came (here) at an appointed time, O Moosa.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
“And I created you especially for Myself.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
“You and your brother, both go with My signs, and do not slacken in My remembrance.”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
“Both of you go to Firaun; he has indeed rebelled.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
“And speak to him courteously, that perhaps he may ponder or have some fear.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
They both submitted, “Our Lord – indeed we fear that he may oppress us or deal mischievously.”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He said, “Do not fear – I am with you, All Hearing and All Seeing.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
“Therefore go to him and say, ‘We are the sent ones of your Lord, therefore let the Descendants of Israel go with us, and do not trouble them; we have indeed brought to you a sign from your Lord; and peace be upon him who follows the guidance.’\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
‘It has indeed been revealed to us that the punishment is upon the one who denies and turns away.’”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
Said Firaun, “So who is the Lord of you both, O Moosa?”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
He said, “Our Lord is One Who gave everything its proper shape, then showed the path.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
Said Firaun, “What is the state of the former generations?”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcd{%
He said, “Their knowledge is with my Lord, (recorded) in a Book; my Lord neither strays nor forgets.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcdi{%
The One Who has made the earth a bed for you and kept operative roads for you in it and sent down water from the sky; so with it We produced different pairs of vegetation.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcdii{%
Eat, and graze your cattle; indeed in this are signs for people of intellect.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
From the earth We have created you, and to it We shall return you, and from it We shall raise you again.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
And indeed We showed him all Our signs – so he denied them and did not accept.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He said, “Have you come to us in order to expel us from our land by your magic, O Moosa?”\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
“So we will also produce before you a similar magic, therefore set up an agreed time between us and you, from which neither we nor you shall turn away, at a level place.”\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
Said Moosa, “Your meeting is the day of the festival, and that the people be assembled at late morning.”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
So Firaun went away and gathered his schemes,* then came. (* 72000 magicians and their materials.)\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcdix{%
Moosa said to them, “Ruin is to you – do not fabricate a lie against Allah, that He may destroy you by a punishment; and indeed one who fabricates lies has failed.”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcdx{%
So they differed with one another in their task, and secretly conferred.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
They said, “Undoubtedly these two are magicians for sure, who wish to expel you from your land by the strength of their magic, and destroy your exemplary religion!”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
“Therefore strengthen your scheme, and come forth in rows; indeed whoever dominates this day has succeeded.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said, “O Moosa, either you throw first – or shall we throw first?”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
He said, “Rather, you may throw”; thereupon their cords and their staves, by the strength of their magic, appeared to him as if they were (serpents) moving fast.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
And Moosa sensed fear in his heart.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We said, “Do not fear – it is you who is dominant.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
“And cast down which is in your right hand – it will devour all that they have fabricated; what they have made is only a magician’s deceit; and a magician is never successful, wherever he comes.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
Therefore all the magicians were thrown down prostrate – they said, “We accept faith in the One Who is the Lord of Haroon and Moosa.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
Said Firaun, “You accepted faith in him before I permitted you! He is indeed your leader who taught you magic; I therefore swear, I will cut off your hands and your legs from alternate sides, and crucify you on the trunks of palm-trees, and you will surely come to know among us two, whose punishment is more severe and more lasting.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said, “We shall never prefer you above the clear proofs that have come to us from the One Who has created us – therefore carry out what you want to; only in the life of this world will you be able to!”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
“Indeed we have accepted faith in our Lord, so that He may forgive us our sins and the magic which you forced us to perform; and Allah is Better, and the Most Lasting.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Indeed the one who comes guilty to his Lord – so undoubtedly for him is hell; neither dying nor living in it.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
And the one who presents himself as a believer before Him, having done good deeds – so for them are the high ranks.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
Everlasting Gardens of Eden beneath which rivers flow, abiding in them for ever; and this is the reward of one who became pure.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
And We divinely inspired Moosa that, “Journey with My bondmen in a part of the night and strike a dry path in the sea for them, you shall have no fear of Firaun getting to you, nor any danger.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
So Firaun went after them with his army – therefore the sea enveloped them, the way it did.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
And Firaun led his people astray, and did not guide them.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
O Descendants of Israel, indeed We rescued you from your enemy, and We made a covenant with you on the right side of Mount Tur, and sent down Manna and Salwa upon you.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
“Eat the good clean things We have provided you, and do not exceed the limits in respect of it causing My wrath to descend upon you; and indeed the one on whom My wrath descended, has fallen.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
And indeed I am Most Oft Forgiving for him who repented and accepted faith and did good deeds, and then remained upon guidance.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
“And why did you come in haste ahead of your people, O Moosa?”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He submitted, “They are here, just behind me – and O my Lord, I hastened towards You, in order to please You.”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
He said, “We have therefore tried your people after you came, and Samri has led them astray.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
So Moosa turned back to his people, angry and grieving; he said, “O my people, had not your Lord given you a good promise? Did a long time pass away for you, or did you wish that your Lord’s wrath come upon you, therefore you broke your promise with me?”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They said, “We did not renege on our promise to you on our own will, but we were made to carry the burdens of ornaments of the people, so we cast them – and similarly did Samri cast.”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
He therefore made a calf for them – a lifeless body, making sounds like a cow – so they said, “This is your God and the God of Moosa; whereas Moosa has forgotten.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
So do they not see that it does not answer to any of their speech? And has no power to cause them any harm or benefit?\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
And undoubtedly Haroon had told them before it that, “O my people – you have needlessly fallen into trial because of this; and indeed your Lord is the Most Gracious, therefore follow me and obey my command.”\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They said, “We will continue to squat* before it, till Moosa returns to us.” (* Continue worshipping it.)\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
Said Moosa, “O Haroon – what prevented you when you saw them going astray?”\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
“That you did not come after me? So did you disobey my order?”\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
He said, “O son of my mother, do not clutch my beard nor the hair on my head; I feared that you may say, ‘You have caused a division among the Descendants of Israel and did not wait for my advice.’”\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
Said Moosa, “And what is your explanation, O Samri?”\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
He said, “I witnessed what the people did not witness – I therefore took a handful from the tracks* of the angel, then threw it** – and this is what seemed pleasing to my soul.” (* The marks left behind by the mount of Angel Jibreel. ** Into the mouth of the calf.)\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
Said Moosa, “Therefore go away, for in this life your punishment is that you exclaim ‘Do not touch!’* And indeed for you is a time appointed, which you cannot break; and look at your deity, in front of which you remained squatting the whole day; we swear we will surely burn it and, smashing it into bits, discharge it into the river.” (* He was cursed with a disease.)\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
“Your God is only Allah – other than for Whom there is no worship; His knowledge encompasses all things.”\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
This is how We relate the former tidings to you (O dear Prophet Mohammed – peace and blessings be upon him); and We have given you a Remembrance* from Ourselves. (*The Holy Qur’an.)\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whoever turns away from it, will bear a burden on the Day of Resurrection.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
They will remain in it forever – what an evil burden it will be for them on the Day of Resurrection!\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmcdl{%
On the day when the Trumpet is blown and We shall assemble the guilty on that day, blue -eyed.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmcdli{%
Whispering secretly among themselves, “You have not stayed on earth but for ten days.”\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We know well what they will utter, whereas the wisest among them will say, “You have stayed just for a day.”\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
They ask you regarding the mountains; proclaim, “My Lord will blow them into bits and scatter them.”\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
“Therefore leaving the earth just as an empty plain.”\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
“In which you shall neither see ups nor downs.”\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that day they will run after a caller, there will be no deviation in it; and voices shall become hushed before the Most Gracious, so you will not hear except a faint sound.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
On that day no one’s intercession shall benefit except his to whom the Most Gracious has given permission and whose word He has liked. (The Holy Prophets and virtuous people will be given the permission to intercede. Prophet Mohammed – peace and blessings be upon him – will be the first to intercede.)\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knows all that is before them and all that is behind them, whereas their knowledge cannot encompass it.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
And all faces shall bow before the Living, the All Sustaining; and the one who bore the burden of injustice, has failed.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
And the one who does some good deeds, and is a Muslim – he shall have no fear of injustice, nor suffer any loss.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
And this is how We revealed it as an Arabic Qur’an, and in different ways gave promises of punishment, that they may fear or it may create some pondering in their hearts.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
Therefore Supreme is Allah, the True King; and do not hasten in the Qur’an (O dear Prophet Mohammed – peace and blessings be upon him) until its divine revelation has been completed to you; and pray, “My Lord, bestow me more knowledge.”\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
And indeed before this We made a covenant with Adam, so he forgot, and We did not find its intention (in him).\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And when We commanded the angels, “Prostrate before Adam” – so they all prostrated, except Iblis; he refused.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
We therefore said, “O Adam, he is your and your wife’s enemy, so may he not get you both out from heaven, so you then fall into hardship.”\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
“Indeed for you in heaven is that you may never be hungry nor be unclothed.”\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
“And that you never feel thirsty nor hot sunshine hurt you.”\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
So the devil incited him, saying, “O Adam, shall I show you the tree of immortality and a kingdom that does not erode?”\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
So they both ate from it – thereupon their shame became manifest to them, and they started applying on themselves the leaves of heaven; and Adam lapsed in obeying his Lord, so did not reach his goal. (Of achieving immortality)\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
Then his Lord chose him, and inclined towards him with His mercy, and guided him.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
He said, “Both of you go down from heaven, one of you is an enemy to the other; then if the guidance from Me comes to you – then whoever follows My guidance, will not go astray nor be ill-fated.”\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
“And the one who turned away from My remembrance – for him is a confined existence, and We shall raise him blind on the Day of Resurrection.”\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He will say, “O my Lord, why have You raised me blind, whereas I was sighted?”\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
He will say, “Similarly did Our signs come to you but you forgot them; and in the same way, nobody will heed you today.”\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
And this is how We reward him who transgresses and does not accept faith in the signs of his Lord; and indeed the punishment of the Hereafter is the most severe and more lasting.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
So did they not gain guidance from (knowing) how many generations We have destroyed before them, among whose dwellings they walk? Indeed in it are signs for men of intellect.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
And had not a command of your Lord been passed, then the punishment would have gripped them – and had a term not been appointed.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
Therefore (O dear Prophet Mohammed – peace and blessings be upon him), patiently forbear upon their speech, and praising your Lord proclaim His Purity, before the sun rises and before it sets; and proclaim His Purity at some times of the night and at the two ends of the day, in the hope that you be pleased. (*With the great reward from your Lord)\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
And O listener, do not extend your eyes towards what We have given to disbelieving couples to enjoy – the bloom of the worldly life – so that We may test them with it; and the sustenance of your Lord is the best, and more lasting.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
And command your household to establish prayer, and yourself be steadfast in it; We do not ask any sustenance from you; We will provide you sustenance; and the excellent result is for piety.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
And the disbelievers said, “Why does he not bring to us a sign from his Lord?”; did not the explanation of what is in the former Books, come to them?\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
And had We destroyed them with some punishment before the advent of a Noble Messenger, they would have certainly said, “Our Lord, why did You not send a Noble Messenger to us, so we would have followed Your signs, before being humiliated and disgraced?”\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Proclaim, “Each one is waiting; so you too wait; very soon you will come to know who are the people of the right path, and who has attained guidance.”\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen The people’s reckoning is near, whereas they are in neglect, turned away!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
Whenever a new advice comes to them from their Lord, they do not listen to it except while playing.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
Their hearts are involved in play; and the unjust secretly conferred, “What is he, except another a human like you?! So do you follow magic although you have perceived?”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
And the Prophet said, “My Lord knows all that is spoken in the heavens and in the earth; and He only is the All Hearing, the All Knowing."\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
Rather they said, “These are confused dreams, but in fact he has fabricated it – but in fact he is a poet; so he must bring us some sign, like those who were sent before.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
There is not a township before them which did not believe which We have not destroyed; so will they believe?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
And We did not send (Prophets) before you except men, to whom We sent divine revelations – therefore, O people, ask the people of knowledge if you do not know.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
And We did not create them without bodies so they would not eat food – nor that they abide on earth forever.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
We then fulfilled the promise to them, therefore rescued them and whomever We willed, and destroyed the transgressors.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
We have indeed sent down towards you a Book, in which is your repute; so do you not have sense?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
And many a township did We destroy, for they were unjust, and We created other nations after them.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
And when they tasted Our punishment, they immediately started fleeing from it.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
The angels said to them, “Do not flee and return to the comforts that were given to you and to your homes, perhaps you will be questioned.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They cried, “Woe to us, we were indeed unjust!”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
So they kept saying this until We made them cut off, extinguished.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
And We have not created the heavens and the earth and all that is between them, unnecessarily.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmd{%
If We willed to choose a pastime, We could have chosen it from Ourselves – if We wanted to.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdi{%
But in fact We hurl the truth upon falsehood, so it scatters its brains – thereupon it vanishes; and for you is the ruin due to the matters you fabricate.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdii{%
And to Him only belong all those who are in the heavens and in the earth; and those with Him are not conceited towards worshipping Him, nor do they tire.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They say His Purity night and day, and do not slacken.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Have they appointed from the earth, Gods that create something?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdv{%
If other than Allah, there were Gods* in the heavens and the earth, they would be destroyed; therefore Purity is to Allah, Owner of the Throne, from the matters that they fabricate. (* Which is not possible. ** The heavens and the earth.)\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He is not questioned whatever He does, whereas they will all be questioned.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Or have they set up other Gods besides Allah? Say, “Bring your proof; this is the remembrance of those with me and those before me”; but in fact most of them do not know the Truth, so they turn away.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdviii{%
And We did not send any Noble Messenger before you, but We divinely revealed to him that, “There is no God except I (Allah), therefore worship Me alone.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdix{%
And they said, “The Most Gracious has chosen a son – Purity is to Him! In fact they are honourable bondmen.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdx{%
They do not speak before He has, and they act only at His command.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows what is before them and what is behind them, and they do not intercede except for him whom He likes, and they fear with awe of Him. (The Holy Prophets and virtuous people will be given the permission to intercede. Prophet Mohammed – peace and blessings be upon him – will be the first to intercede.)\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdxii{%
And the one among them who says, “I am a God beside Allah” – We shall reward him with hell; this is how We punish the unjust.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Did not the disbelievers observe that the heavens and the earth were together, so We parted them, and we made every living thing from water? So will they not accept faith?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We have placed mountains as anchors in the earth so that it may not shake with them; and We kept wide roads in it, so that they may find guidance.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdxv{%
And We have made the sky a roof, protected; and they turn away from its signs.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
And it is He Who created the night and the day, and the sun and the moon; each one floats in an orbit.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
And before you, We did not appoint on earth a never-ending life for any human; will they, if you depart, become immortal?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every living being must taste death; and We test you with harm and with good – a trial; and to Us only you have to return.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdxix{%
And when the disbelievers see you, they do not appoint you except as an object of mockery; “Is he the one who speaks ill of your Gods?”; whereas they deny the remembrance of the Most Gracious Himself!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man has been created hasty; very soon I shall show you My signs, do not be impatient.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
And they say, “When will this promise occur, if you are truthful?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If only the disbelievers realised the time when they will not be able to stop the fire from their faces and from their backs – and nor are they to be helped.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
In fact it will suddenly come upon them, therefore shocking them, and they will not be able to repel it nor will they be given respite.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
And indeed the Noble Messengers before you were mocked at, but their mockery ruined the mockers themselves.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Proclaim, “Who guards you night and day from the Most Gracious?” In fact they have turned away from the remembrance of their Lord.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Do they have some Gods who protect them from Us? Neither can they save themselves nor save their friends from Us.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
But in fact We have given these (disbelievers) and their fathers a benefit to the extent that life became long for them; so do they not see that We are reducing the land from its borders? So will these be victorious?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him) “I warn you only with the divine revelation; and the deaf do not hear the call when warned.”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
And if a whiff of your Lord’s punishment were to touch them, they would certainly say, “Woe to us – we were indeed unjust!”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
And We shall set up the scales of justice on the Day of Resurrection – therefore no soul will be wronged in the least; and if a thing is equal to a grain of mustard seed, We will bring it; and We are Sufficient to (take) account.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
And indeed We gave Moosa and Haroon the Judgement* and a light and an advice for the pious. (* The Holy Book Taurat.)\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
Those who fear their Lord without seeing and who apprehend the Last Day.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
This is a blessed remembrance, sent down by Us; so do you deny it?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
And indeed We bestowed Ibrahim with guidance from the beginning, and We were Aware of him.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
When he said to his father and his people, “What are these idols before whom you squat (worshipping)?”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said, “We found our forefathers worshipping them.”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said, “Indeed you all – you and your forefathers – were in open error.”\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said, “Have you brought the Truth to us, or are you just making fun?”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said, “In fact, your Lord is the Lord of the heavens and the earth, the One Who created them; and I am of those who testify to it.”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdxl{%
“And, by oath of Allah, I shall seek to harm your idols after you have gone away and turned your backs.”\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdxli{%
He shattered them all, except the biggest among them, that perhaps they may question it.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said, “Who has done this to our Gods? He is indeed cruel!”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
Some among them said, “We heard a youth speak ill of them – the one called Ibrahim.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said, “Therefore bring him in front of the people, perhaps they may testify.”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said, “Did you do this to our Gods, O Ibrahim?”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
Said he, “Rather, their chief may have done it; so question them, if they can speak.”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
So they turned towards their own selves and (inwardly) said, “Indeed you yourselves are unjust.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
Again they were inverted upon their heads; saying, “You know well that these do not speak.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
He said, “What! You worship, instead of Allah, one that neither benefits you nor harms you?”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdl{%
“Disgrace be upon you and all the idols whom you worship instead of Allah; so do you not have sense?”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said, “Burn him and help your Gods, if you want to.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We said, “O fire, become cool and peaceful upon Ibrahim.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdliii{%
And they wished to cause him harm, so We made them the greatest of losers.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdliv{%
And We rescued him and Lut towards the land which We have blessed for the entire world.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We bestowed him Ishaq, and Yaqub the grandson; and We made all of them worthy of Our proximity.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them leaders who guide by Our command, and We sent them the divine revelation to do good deeds and to keep the prayer established and to give charity; and they used to worship Us.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And We gave Lut the kingdom and knowledge, and We rescued him from the township that committed vile deeds; indeed those evil people were disobedient.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We admitted him into Our mercy; indeed he is among those who deserve Our proximity.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And before this when Nooh called Us – We therefore heard his prayer and rescued him and his household from the great calamity.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdlx{%
And We helped him against the people who denied Our signs; indeed they were evil people, We therefore drowned them all.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And remember Dawud and Sulaiman, when they were deciding the dispute of a field, when some people’s sheep had strayed into it at night; and We were Present at the time of their deciding.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
And We explained the case to Sulaiman; and to both We gave the kingdom and knowledge; and subjected the hills to proclaim the Purity along with Dawud, and (also subjected) the birds; and these were Our works.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
And We taught him to make a garment for you, to protect you from your hurt; so will you be thankful?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And We subjected the fast wind for Sulaiman, which moved by his command towards the land in which We have placed blessings; and We know everything.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And among the devils, were those who dived (in water) for him and did works other than this; and We had kept them restrained.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And remember Ayyub (Job), when he called his Lord that, “Hardship has afflicted me, and You are the Most Merciful of all those who have mercy.”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
We therefore heard his prayer and removed the adversity that had afflicted him, and We gave him his family and in addition bestowed along with them a similar number, by mercy from Ourselves – and an advice for the people who worship.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And remember Ismail, and Idrees, and Zul-Kifl; they were all patiently enduring.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
And We admitted them into Our mercy; indeed they are among those who deserve Our proximity.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And remember Zun-Noon,* when he left in anger, assuming that We would not restrict him – he therefore called out in the realms of darkness, saying, “There is no God except You, Purity is to You; I have indeed committed a lapse.” (* Prophet Yunus – peace and blessings upon him)\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
We therefore heard his prayer and rescued him from grief; and similarly We shall rescue the Muslims.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And remember Zakaria, when he prayed to his Lord, “O my Lord – do not leave me alone, and You are the Best Inheritor.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
We therefore heard his prayer; and bestowed him Yahya, and cured his wife for him; indeed they used to hasten to perform good deeds, and pray to Us with hope and fear; and used to weep before Us.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And remember the woman who maintained her chastity, We therefore breathed Our Spirit into her and made her and her son a sign for the entire world.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Indeed this religion of yours, is one religion; and I am your Lord, therefore worship Me.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
And others have shattered their works into pieces among themselves; all have to return to Us.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
So whoever does some good deeds, and is a believer, then his efforts will not be ignored; and We are recording it.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
And it is forbidden for any township which We have destroyed, that they may return. (Once the disbelievers face death, their return to earth is impossible.)\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
Till the time when Yajuj and Majuj are released, and they will be flowing down from every height.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
And the True Promise has come near – thereupon the eyes of the disbelievers will become fixed, staring wide; saying “Woe to us – we were in neglect of this, but in fact we were unjust.”\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
“Indeed you* and all that you worship** besides Allah, are the fuel of hell; in it you must go.” (* All disbelievers ** Idols and disbelievers who claimed to be Gods. The Prophets like Eisa and Uzair who were worshipped are exempt from this, and so are Maryam, and trees and the moon etc.)\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
“Had these been Gods they would not go into hell; and they have to remain in it.”\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
They will bray in it and not be able to hear anything in it.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
Indeed those to whom Our promise of goodness has been made, have been kept far away from hell.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
And they will not hear its faintest sound; and they will forever abide in whatever their hearts desire.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The greatest fear will not aggrieve them, and the angels will welcome them; saying “This is your day, which you were promised.”\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
The day when We shall roll up the heavens as the recording angel rolls up the register of deeds; We shall make him similar to Our making him the first time; this is a promise upon Us; We certainly have to do it.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
And indeed We wrote, after the reminder in the Zaboor that, “My virtuous bondmen will inherit the earth.”\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
This Qur’an is sufficient for people who are devout.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmdxc{%
And We did not send you (O dear Prophet Mohammed – peace and blessings be upon him) except as a mercy for the entire world. (Prophet Mohammed – peace and blessings be upon him – is the Prophet towards all mankind.)\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Proclaim, “It is divinely revealed to me that your God is the only One God – Allah; do you therefore become Muslims?”\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
Then if they turn away, proclaim, “I have proclaimed a war against you on equal terms; and what do I know whether the promise which is given to you, is close or far?”\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
“Indeed Allah knows whatever is said, and knows all what you conceal.”\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
“And what do I know – it may be a trial for you, and an enjoyment for a time.”\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
And the Prophet submitted, “My Lord – render the true judgement”; “And only the help of Our Lord, the Most Gracious, is sought against all what you fabricate.”\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O people, fear your Lord; indeed the earthquake of the Last Day is a tremendous thing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
On the day when you will witness it, every nursing mother will forget her nurseling and every pregnant one will discharge her burden, and you (O dear Prophet Mohammed – peace and blessings be upon him) will see people as if they are drunk, whereas they will not be intoxicated, but the fact is that Allah’s punishment is very severe.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
And among people are some who argue concerning Allah without knowing, and blindly follow every rebellious devil.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
(The devil) Upon whom is decreed that whoever befriends him, he will certainly mislead him and show him the path to hell.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdc{%
O people, if you doubt your revival on the Day of Resurrection, then ponder that We created you from dust, then from a drop of liquid, then from a clot, then from a piece of flesh formed and without form, so that We show you Our signs for you; and We keep whomever We want inside the mothers’ wombs up to an appointed time, then extract you as infants, then in order that you reach your puberty; and among you is one who dies earlier, and among you is one put to the most abject age, so after having knowledge, knows nothing; and you see the earth desolate, then when We sent down water upon it, it freshened up and developed and produced beautiful pairs of all kinds.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdci{%
This is because Allah only is True and because He will revive the dead, and because He is Able to do all things.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And because the Last Day will come, there is no doubt in it – and because Allah will revive those who are in the graves.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And there is one who argues concerning Allah without having knowledge nor any proof nor a clear text.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdciv{%
With his neck turned away from the truth, in order to deceive from the way of Allah; for him is disgrace in this world and on the Day of Resurrection We shall make him taste the punishment of fire.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdcv{%
“This is the recompense of what your hands have sent ahead, and Allah does not oppress His bondmen."\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And there are some men who worship Allah upon an edge; then if some good occurs to them, they are content; and if some trial comes, they turn way upon their faces; a loss of this world and the Hereafter; and this is the complete loss.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
They worship such, beside Allah, which neither harms them nor benefits them; this only is the extreme error.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
They worship one from whom harm is expected more than the benefit; indeed what an evil master and indeed what an evil friend!\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdcix{%
Indeed Allah will admit those who believed and did good deeds, into Gardens beneath which rivers flow; indeed Allah does whatever He wills.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Therefore whoever assumes that Allah will not assist His Prophet (Mohammed – peace and blessings be upon him) in this world and the Hereafter, should extend a rope upwards and hang himself, and then see whether his scheme has taken away what he envies.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
And so it is, that We sent down this Qur’an – clear verses – and that Allah guides whomever He wills.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Indeed the Muslims, and the Jews, and the Sabeans, and the Christians and the fire worshippers and the polytheists – indeed Allah will decide between all of them on the Day of Resurrection; indeed Allah witnesses all things.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Did you not see that for Allah prostrate those who are in the heavens and in the earth, and the sun, and the moon, and the stars, and the hills, and the trees, and the beasts, and many among mankind; and there are many upon whom the punishment has been decreed; and he whom Allah disgraces – there is none to give him honour; indeed Allah may do whatever He wills. (Command of Prostration \# 6)\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These are the two groups who fought concerning their Lord; so those who disbelieved – garments of fire have been fashioned for them; and boiling water will be poured onto their heads.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
With which will melt what is in their bellies, and their skins.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
And for them are rods of iron.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Whenever they wish to come out of it due to suffocation, they will be returned to it again and it will be commanded, “Taste the punishment of fire!”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
Indeed Allah will admit those who believed and did good deeds into Gardens beneath which rivers flow – in it they will be made to wear armlets of gold, and pearls, and in it their garment is silk.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
And they were guided to sacred speech; and they were shown the path of the Most Praiseworthy.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
Indeed those who have disbelieved and prevent from the way of Allah and from this Sacred Mosque, which We have appointed for all mankind – its resident and the foreigner have the same rights in it; and whoever wrongfully intends injustice in it – We shall make him taste a painful punishment.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
And remember when We showed Ibrahim the right place of the Sacred House (mosque) and commanded that, “Do not ascribe anything as a partner to Me, and keep My House clean for those who encircle it and those who stay in it (for worship) and those who bow and prostrate.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
“And publicly announce the pilgrimage to all people – they will come to you, on foot and on every lean she-camel, coming from every far distant journey.” (The announcement by Prophet Ibrahim reached each and every soul.)\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
In order that they may gain their benefit, and mention the name of Allah on the appointed days as He has bestowed the sustenance to them – the inarticulate animals; therefore eat from them yourself and feed the distressed destitute.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
They must then remove their dirt and fulfil their pledges and go around the Free House.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
So it is; and whoever reveres the sacred things of Allah – that is then a goodness for him in the sight of his Lord; the inarticulate animals are lawful to you except those the forbidding of which is recited to you, therefore shun the filth of idols, and avoid false speech.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Devoting yourself to Allah, not ascribing any partner to Him; and whoever ascribes partners to Allah is as if he has fallen from the sky and the birds snatch him or the wind blows him away to a far-off place.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
So it is; and whoever reveres the symbols of Allah – this is then part of the piety of the hearts.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
In the cattle are benefits for you up to a fixed time and then they are to be brought to the Free House.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
And for every nation We have appointed a sacrifice, that they may mention the name of Allah over the inarticulate animal which He has provided them; so (remember) your God is One God, therefore submit only to Him; and give glad tidings (O dear Prophet Mohammed – peace and blessings be upon him) to the humble.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
Those whose hearts fear when Allah is mentioned, and those who patiently endure whatever befalls them, and those who keep the prayer established, and who spend part of what We have provided to them.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
And the large sacrificial animals – the camels and the cows – We have made them among the symbols of Allah, there is goodness for you in them; therefore mention the name of Allah over them with their one leg tied and standing on three feet; then when their flanks have fallen, eat from it yourself and feed the one who patiently awaits, and the beggar; this is how We have given them in your control, so that you be grateful.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
Never does their flesh nor their blood reach Allah, but your piety successfully reaches Him; this is how We have given them in your control so that you may speak His Greatness for guiding you; and O dear Prophet (Mohammed – peace and blessings be upon him) give glad tidings to the virtuous.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Indeed Allah repels the afflictions of the Muslims; indeed Allah does not like any extremely disloyal ingrate.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Permission is granted to those against whom the disbelievers wage war, as they are being wronged; and indeed Allah is Able to assist them.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
Those who were unjustly expelled from their homes just because they said, “Allah is Our Lord”; and had Allah not repelled some men by means of other men, the abbeys, churches, synagogues and mosques – in which the name of Allah is profusely mentioned – would definitely be demolished; and indeed Allah will assist the one who helps His religion; indeed surely Allah is Almighty, Dominant.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
The people who, if We give them control in the land, would keep the prayer established and pay charity and enjoin virtue and forbid from evil; and for Allah only is the result of all works.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
If they belie you (O dear Prophet Mohammed – peace and blessings be upon him), then indeed the people of Nooh, and the tribes of A’ad and Thamud have belied before them.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
And (so did) the people of Ibrahim and the people of Lut.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
And the people of Madyan; and Moosa was belied, so I gave the disbelievers respite and then seized them, so how (dreadful) was My punishment!\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
And many a township did We destroy, for they were oppressors – so they now lie flat on their roofs, and many a well lying useless and many a palace in ruins.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
So have they not travelled in the land, to have hearts with which to understand and ears to hear with? So it is not the eyes that are blind, but it is the hearts in the bosoms, that are blind.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
And they ask you for the punishment – they are impatient – and Allah will not make His promise untrue; and indeed a single day before Allah is like a thousand years in your calculation.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
And to many a township did I give respite although they were oppressors; then I seized them; and towards Me is the return.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Proclaim, “O mankind, I am for you only a clear Herald of Warning.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
So those who believed and did good deeds, for them are forgiveness, and an excellent sustenance.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
And those who strive in Our signs with the intention of disputing, are the people of fire.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
And all the Noble Messengers or Prophets whom We sent before you – it occurred with all of them – that whenever they recited (the message) Satan included a bit (from his own speech) in their recitation to the people; so Allah obliterates what Satan includes and then Allah fortifies His verses; and Allah is All Knowing, Wise.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
So that He may make what the devil includes a trial for those in whose hearts is a disease, and those whose hearts are hardened; indeed the unjust are extremely quarrelsome.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
And so that the people given the knowledge may know that it is the truth from your Lord, in order that they may accept faith in it, therefore their hearts may humble before Him; and indeed Allah will guide the believers on the Straight Path.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdcl{%
And the disbelievers will always be in doubt of it, to the extent that the Last Day will suddenly come upon them, or will come upon them the punishment of a day the result of which is not at all good for them.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdcli{%
For Allah only is the kingship on that day; He will judge between them; so those who believed and did good deeds are in Gardens of content.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdclii{%
And those who disbelieved and denied Our signs – for them will be a disgraceful punishment.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
And those who left their homes and belongings in Allah's cause and were then killed or died – Allah will therefore indeed provide for them an excellent sustenance; and indeed the sustenance bestowed by Allah is the best.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
He will certainly admit them to a place they will love; and indeed Allah is All Knowing, Most Forbearing.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdclv{%
So it is; and whoever retaliates similarly to the affliction he was made to suffer, and then he is wronged again – so Allah will definitely assist him; indeed Allah is Oft Pardoning, Oft Forgiving.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
This is because Allah inserts the night into a part of the day and inserts the day into a part of the night, and because Allah is All Hearing, All Seeing.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
This is because Allah only is the Truth, and what they worship other than Him, is itself falsehood, and because Allah only is the Supreme, the Great.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Did you not see that Allah sent down water from the sky, so the earth became green at morn? Indeed Allah is Pure, Aware.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him only belongs all that is in the heavens and all that is in the earth; and indeed Allah only is the Perfect (Not Needing Anything), the Most Praiseworthy.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Did you not see that Allah has given in your control all that is in the earth – and the ship that moves upon the sea by His command? And He restricts the heavens that it may not fall on to the earth except by His command; indeed Allah is Most Compassionate, Most Merciful upon mankind.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
And it is He Who gave you life, then will cause you to die, and will then revive you; indeed man is very ungrateful.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
For each nation We have made the rules of worship for them to follow – so never should they quarrel with you in this matter – and call them towards your Lord; indeed you are upon the Straight Path.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
And if they quarrel with you, say, “Allah well knows your evil deeds.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
Allah will judge between you on the Day of Resurrection concerning what you dispute.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Did you not realise that Allah knows all that is in the heavens and in the earth? Indeed all this is in a Book; indeed this is easy for Allah.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
And they worship those instead of Allah regarding whom He has not sent down any proof, and those regarding whom they themselves do not have any knowledge; and there are no supporters for the unjust.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
And when Our clear verses are recited to them, you will see traces of anger in the faces of the disbelievers; possibly they may attack those who recite Our verses to them; say, “Shall I show you what is worse than your current state? That is the fire! Allah has promised it to the disbelievers; and what a wretched place to return!”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O people, an example is being illustrated therefore listen to it attentively; “Those whom you worship besides Allah can never create a fly even if they all come together for it; and if a fly took away something from them, they cannot retrieve that from it; how weak are the seeker and the sought!”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They did not realise the importance of Allah as was His right; indeed Allah is Almighty, Dominant.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooses the Noble Messengers from the angels, and from men; indeed Allah is All Hearing, All Seeing.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows all that is before them and all that is behind them; and towards Allah is the return of all matters.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O People who Believe, bow and prostrate yourselves, and worship your Lord, and do good deeds in the hope of attaining salvation.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
And fight in Allah's cause as is the true manner of fighting; He has preferred you and has not kept any hardship upon you in religion; the religion of your father Ibrahim; Allah has named you Muslims – in the previous Books and in this Qur’an, so that the Noble Messenger be your guardian and witness, and you be witness against other people; therefore keep the prayer established and give charity, and hold fast to the rope of Allah; He is your Master; so what an excellent Master and what an excellent Supporter!\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Successful indeed are the believers.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
Those who humbly cry in their prayers.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
And who do not incline towards indecent matters.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
And who pay the (obligatory) charity.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
And who guard their private organs.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
Except from their wives or the legal bondwomen that they possess, for then there is no blame upon them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
So whoever desires more than these two – they are crossing the limits.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
And those who keep proper regard for their trusts and their pledges.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
And who guard their prayers.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
They are the inheritors.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
Those who will get the inheritance of Paradise; they will abide in it forever.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
Indeed We created man from a chosen soil.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
Then made him a drop of fluid in a secure shelter.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
We then turned the drop of fluid into a clot of blood, then the clot into a small lump of flesh, then the lump into bones, then covered the bones with flesh; then developed it in a different mould; therefore Most Auspicious is Allah, the Best Creator.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
Then after that, certainly all of you are to die.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
Then you will all be raised on the Day of Resurrection.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
And indeed We have created seven paths above you; and We are not unmindful of the creation.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And We sent down water from the sky in proper measure, then stored it in the earth; and indeed We are Able to take it away!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
So with it We produced gardens of date-palms and grapes for you, in which is abundant fruit for you and you eat therefrom.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
And created the tree that comes forth from Mount Sinai – that grows containing oil and curry for the eaters.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And indeed in the cattle is a lesson for you; We give you to drink what is in their bellies, and there are many benefits for you in them, and in them is your food.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
And you are carried on them and on the ship.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
And indeed We sent Nooh towards his people – he therefore said, “O my people! Worship Allah, you do not have any other God except Him; so do you not fear?”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
So the disbelieving chieftains of his people said, “He is just a human like you, he wishes to become your leader; and had Allah willed, He would have sent down angels; We did not hear this in the case of our forefathers.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
“He is not but a man insane, therefore wait for some time.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
Submitted Nooh, “My Lord! Help me as they deny me.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcc{%
So We sent him the divine revelation that, “Make the ship in front of Our sight, and by Our command – then when Our command comes and the oven overflows, embark in it two of every couple, and from your household except those upon whom the Word has been decreed; and do not speak to Me in respect of these unjust people; they will surely be drowned.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcci{%
“And when you and those with you have safely boarded the ship say, ‘All praise is to Allah Who has rescued us from the unjust.’”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And pray, “My Lord! Cause me to alight at a blessed place – and You are the Best of all who bring to settle.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Indeed, surely in this are signs and indeed surely, We were examining.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then after them, We created another generation.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdccv{%
So We sent among them a Noble Messenger from among them (saying), “Worship Allah, you do not have any other God except Him; so do you not fear?”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
And said the leaders of his people, who disbelieved and denied the confronting of the Hereafter – and We had given them comfort in the worldly life – that, “He is nothing but a human like you, he eats from what you eat and drinks from what you drink.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
“If you were to obey a human like yourselves, then surely you are losers!”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
“Does he promise you that when you die and turn into dust and bones, you will be raised again?”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdccix{%
“How remote, (really) how remote is the promise you are given!”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdccx{%
“There is nothing except our life of this world, we die and we live, and we are not to be raised.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
“He is just a man who has fabricated a lie against Allah, and we are not going to believe him.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said, “My Lord! Help me as they deny me.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
Said Allah, “They will soon wake up at morn, regretting.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
So the true Scream seized them – We therefore made them like rotten hay; so away with the unjust people!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then after them, We created other generations.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No nation can go before its term ends nor stay back.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
We then sent our Noble Messengers, one after another; whenever a nation’s Noble Messenger came to it they denied him, We therefore united the succeeding with the old, and made them history; so far removed be the people who do not believe!\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
We then sent Moosa and his brother Haroon, with Our signs and a clear proof.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
Towards Firaun and his court members – in response they were haughty, and they were in dominance.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
They therefore said, “Shall we believe in two humans like ourselves, whereas their nation is servile to us?”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they denied them – therefore became of those who were destroyed.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And indeed We gave Moosa the Book, that they may attain guidance.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made the son of Maryam (Prophet Eisa) and his mother a sign, and We gave them shelter on a height, a place to stay and visible springs.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
“O Noble Messengers, eat good clean things, and do good deeds; I know all that you do.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
“And indeed this religion of yours is one religion only and I am your Lord, therefore fear Me.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But their nations broke their tasks into pieces; every group happy with what it has.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
So leave them in their intoxication till a time.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Do they assume that the wealth and sons which We provide them –\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
Are quickly giving them goodness? In fact, they do not know.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Indeed those who are overwhelmed due to the fear of their Lord –\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
And those who believe in the signs of their Lord –\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
And those who do not ascribe any partner to their Lord –\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
And those who give what they give and their hearts fear for they have to return to their Lord.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
These people hasten to perform goodness, and it is they who shall reach it first.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
And We do not burden any soul beyond its capacity, and with Us is a Book* that speaks the truth, and they will not be wronged. (* The preserved tablet or the record of one’s deeds.)\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
On the contrary, their hearts are in neglect of this and their works are different than those of the believers, the works that they are doing.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
To the extent that when We seized the wealthy among them with punishment, they immediately began imploring.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
“Do not implore this day; you will not be helped by Us.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
“My verses were recited to you, so you used to turn back on your heels.”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
“Priding yourself in serving the Sacred Mosque; at night you utter indecent stories in it, while discarding the truth.”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Have they not pondered the matter, or did that come to them, which did not come to their forefathers?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or is it that they did not recognise their Noble Messenger, therefore they consider him alien?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or they say, “He is afflicted by a demon”; in fact he brought the Truth to them, and most of them dislike the Truth.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
And had the Truth followed their desires, then indeed the heavens and the earth and all those who are in them would be destroyed; in fact We brought to them a thing in which lay their repute, so they are turned away from their own repute.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Do you (O dear Prophet Mohammed – peace and blessings be upon him) ask any fee from them? So the reward of your Lord is the best; and He is the Best Provider of Sustenance.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
And indeed you call them to the Straight Path.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
And indeed those who do not believe in the Hereafter are deviated from the Straight Path.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
And if We have mercy upon them and remove the calamity which has befallen them, they would still stubbornly persist, wandering in their rebellion.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
And indeed We grasped them with punishment, so neither did they submit themselves to their Lord, nor do they cry humbly.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdccl{%
To the extent that when We opened the gate of a severe punishment for them, they thereupon lie despairingly in it.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdccli{%
And it is He Who has created ears and eyes and hearts for you; very little is the right you acknowledge.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
And it is He Who has spread you in the earth, and towards Him you are to be raised.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
And it is He Who gives life and causes death, and for Him are the alternations of night and day; so do you not have sense?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
On the contrary, they said the same as what the former people used to say.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They say, “Will we, when we die and turn into dust and bones, be raised again?”\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
“Indeed this promise was given to us and before us to our forefathers – this is nothing but stories of earlier people.”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say O dear Prophet (Mohammed – peace and blessings be upon him), “To Whom does the earth and all that is in it belong to, if you know?”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
Thereupon they will say, “To Allah”; proclaim, “Therefore why do you not ponder?”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say, “Who is the Lord of the seven heavens, and the Lord of the Tremendous Throne?”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
Thereupon they will say, “Such greatness is only that of Allah”; say, “So why do you not fear?”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say, “In Whose hand is the control over all things, and He provides refuge, and none can provide refuge against Him, if you know?”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
Thereupon they will say, “Such greatness is only that of Allah”; say, “Then by what magic are you deceived?”\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
In fact We brought the Truth to them, and indeed they are liars.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
Allah has not chosen any child, nor any other God along with Him – were it so, each God would have taken away its creation, and each one would certainly wish superiority over the other; Purity is to Allah above all the matters they fabricate.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
The All Knowing, of every hidden and the visible – so Supremacy is to Him over their ascribing of partners (to Him).\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Pray, “My Lord! If You show me the promise they are given,”\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
“Therefore my Lord, do not group me with the unjust.”\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
And indeed We are Able to show you the promise they are given.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel evil with the best deeds; We well know the matters that they fabricate.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And submit, “My Lord! I seek Your refuge from the instigation of the devils.”\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
“And my Lord, (I seek) Your refuge from their coming to me.”\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
Until, when death comes to one* of them, he says, “O my Lord, send me back!” (The disbelievers)\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
“Perhaps I may do some good deeds in what I have left behind”; this is just a word that he utters from his mouth; and confronting them is a barrier until the day in which they will be raised.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
So when the Trumpet is blown – so there will neither be any relationship among them* that day, nor will they ask about one another. (The disbelievers)\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Therefore the ones whose scales prove heavy – they are the successful.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
And the ones whose scales prove light – it is they who put their lives into ruin, remaining in hell forever.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The fire shall scorch their faces, and they will remain dejected in it.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
“Were not My verses recited to you, so you used to deny them?”\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say, “Our Lord! Our ill-fate overcame us, and we were the astray people.”\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
“Our Lord, remove us from hell – then if we do the same, we are the unjust.”\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
Allah will say, “Remain rebuked in it, and do not speak to Me.”\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
``Indeed there was a group among My bondmen who said, 'Our Lord! We have accepted faith, therefore forgive us and have mercy on us, and You are the Best Among The Merciful.' ”\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
“So you took them for a mockery until your mocking at them made you forget My remembrance, and you used to laugh at them!”\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
“Indeed this day I have rewarded them for their endurance, so that it is they who are the successful.”\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
He will say, “How long did you stay on earth, counting by the number of years?\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will say, “We stayed a day or part of a day, so ask those who keep count.”\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say, “You stayed but only a little, if you knew.”\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
So do you think that We have created you needlessly, and that you do not have to return to Us?\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
So Most Supreme is Allah, the True King; there is no God except Him; Lord of the Throne of Honour.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
And the one who worships any other God along with Allah – of which he does not have any proof – his account is with his Lord; indeed there is no salvation for the disbelievers.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And (O dear Prophet Mohammed – peace and blessings be upon him) say, “My Lord! Forgive and have mercy, and You are the Best of all the Merciful.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen This is a chapter which We have sent down and decreed its commands, and in which We have sent down clear verses, in order that you may ponder.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The adulteress and the adulterer – punish each one of them with a hundred lashes; and may you not have pity on them in the religion to Allah, if you believe in Allah and the Last Day; and a group of believers must witness their punishment.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The adulterer shall not marry except an adulteress or a polytheist woman, and none shall marry an adulteress except an adulterer or a polytheist; and this is forbidden for the believers.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
And those who accuse chaste women and do not bring four witnesses to testify – punish them with eighty lashes and do not ever accept their testimony; and it is they who are the wicked.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
Except those who repent after this and reform themselves; so indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
And those who accuse their wives and do not have witnesses except their own statements – for such the testimony is that he bear the testimony four times by the name of Allah that he is truthful.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
And the fifth time, that the curse of Allah be upon him if he is a liar.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
And the punishment shall be averted from the woman if she bears the testimony four times by the name of Allah, that the man is a liar.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdccc{%
And the fifth time, that the wrath of Allah be upon her if the man is truthful.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdccci{%
And were it not for Allah’s munificence and His mercy upon you and that Allah is the Acceptor of Repentance, the Wise – He would then have unveiled you.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Indeed those who have brought this great accusation are a group from among you; do not consider it bad for you; on the contrary, it is good for you; for each man among them is the sin that he has earned; and for the one among them who played the greatest part in it – for him is a terrible punishment.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Why was it not that the believing men and women, when you heard it, thought good of their own people, and had said, “This is a clear accusation”?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did they not bring four witnesses upon it? Since they did not bring witnesses, they themselves are liars before Allah.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
And were it not for Allah’s munificence and His mercy upon you in the world and in the Hereafter, a terrible punishment would have reached you for the discussions you fell into.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
When you rumoured with your tongues after hearing such matters, and uttered with your mouths about which you had no knowledge, and you considered it light; and that, in the sight of Allah, is very great.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
And why was it not that, when you heard it, you would have said, “It does not befit us to speak regarding this; Purity is to You, O Allah – this is a great accusation.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah advises you never to speak like this again, if you have faith.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
And Allah clearly explains the verses for you; and Allah is All Knowing, Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Indeed those who wish that slander should spread among the Muslims – for them is a painful punishment in this world and in the Hereafter; and Allah knows, and you do not know.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
And were it not for Allah’s munificence and His mercy upon you, and that Allah is Forgiving, Most Merciful – you would have tasted its outcome.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O People who Believe! Do not follow the footsteps of the devil; and whoever follows the footsteps of the devil – so he will only bid the indecent and the evil; and were it not for Allah’s munificence and His mercy upon you, none of you would ever become pure – but Allah purifies whomever He wills; and Allah is All Hearing, All Knowing.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
And may not those who possess superiority (in wealth) among you and possess capacity, swear not to give to the relatives and to the needy, and to immigrants in Allah's cause; and they should forgive and forbear; do you not like that Allah may forgive you? And Allah is Oft Forgiving, Most Merciful.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Indeed those who accuse the innocent virtuous, believing women – upon them is a curse in this world and in the Hereafter; and for them is a terrible punishment.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On the day when their tongues and their hands and their feet will testify against them, regarding what they used to do.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
On that day Allah will give them their true punishment, and they will know that Allah only is the Clear Truth.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Vile women for vile men, and vile men for vile women; and virtuous women for virtuous men, and virtuous men for virtuous women; such are innocent of what these people say; for them are forgiveness, and an honourable sustenance.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O People who Believe! Do not enter the houses except your own until you obtain permission and have conveyed peace upon its inhabitants; this is better for you, in order that you may ponder.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
And if you do not find anyone in them, even then do not enter without the permission of their owners; and if it is said to you, “Go away” then go away – this is much purer for you; and Allah knows your deeds.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
There is no sin upon you to enter houses not made especially for someone’s habitation, and you have permission for its use; and Allah knows what you disclose and what you hide.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Command the Muslim men to keep their gaze low and to protect their private organs; that is much purer for them; indeed Allah is Aware of their deeds.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And command the Muslim women to keep their gaze low and to protect their chastity, and not to reveal their adornment except what is apparent, and to keep the cover wrapped over their bosoms; and not to reveal their adornment except to their own husbands or fathers or husbands’ fathers, or their sons or their husbands’ sons, or their brothers or their brothers’ sons or sisters’ sons, or women of their religion, or the bondwomen they possess, or male servants provided they do not have manliness, or such children who do not know of women’s nakedness, and not to stamp their feet on the ground in order that their hidden adornment be known; and O Muslims, all of you turn in repentance together towards Allah, in the hope of attaining success. (It is incumbent upon women to cover themselves properly.)\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
And enjoin in marriage those among you who are not married, and your deserving slaves and bondwomen; if they are poor, Allah will make them wealthy by His munificence; and Allah is Most Capable, All Knowing.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
And those who do not have the means to get married must keep chaste till Allah provides them the resources by His munificence; and the bondwomen in your possession who, in order to earn something, seek a letter of freedom from you – then write it for them if you consider some goodness in them; and help them in their cause with Allah’s wealth which He has bestowed upon you; and do not force your bondwomen into the dirty profession, while they wish to save themselves, in order to earn some riches of the worldly life; and if one forces them then indeed Allah, upon their remaining compelled, is Oft Forgiving, Most Merciful.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
And indeed We have sent down towards you clear verses, and some account of those who preceded you, and advice for the pious.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the Light of the heavens and the earth; the example of His light is like a niche in which is a lamp; the lamp is in a glass; the glass is as if it were a star shining like a pearl, kindled by the blessed olive tree, neither of the east nor of the west – it is close that the oil itself get ablaze although the fire does not touch it; light upon light; Allah guides towards His light whomever He wills; and Allah illustrates examples for mankind; and Allah knows everything. (The Holy Prophet is a light from Allah)\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
In the houses (mosques) which Allah has commanded to erect and in which His name is taken – praising Allah in them at morn and evening,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
(Are) Those men, whom neither any bargain nor any trade distracts from the Remembrance of Allah and from establishing the prayer and from paying the charity – they fear the day when the hearts and the eyes will be overturned.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
In order that Allah may reward them for their best deeds and by His munificence, bestow upon them an increased reward; and Allah gives sustenance to whomever He wills, without account.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
And those who disbelieved – their deeds are like a mirage in the wasteland, so the thirsty may believe it to be water; to the extent that when he came close to it, he found it is nothing and found Allah close to him, so He filled his account; and Allah is Swift At Taking Account.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or like realms of darkness on a deep sea, which is covered by a wave, the wave covered by another wave, and above it is a cloud; layers of darkness upon darkness; if he removes his hand it does not seem visible; and the one to whom Allah does not provide light – there is no light for him anywhere.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Have you not seen that all those who are in the heavens and the earth praise Allah, and the birds with their wings spread (also praise Him)? Each one has learnt its prayers and its words of praise; and Allah knows their deeds.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
And for Allah only is the kingship of the heavens and the earth; and towards Allah is the return.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
Have you not seen that Allah slowly transports the clouds, then gathers them together, then heaps them together, so you see the rain coming forth from between them? And from the sky He sends down hail from the mountains of ice, then sends them upon whomever He wills, and averts them from whomever He wills; it is close that the flash of its lightning take away the eyesight.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
Allah alternates the day and the night; indeed in this is a lesson for those who can perceive.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
And Allah created every animal on earth, from water; so among them is a kind that moves upon its belly; and among them is a kind that moves upon two legs; and among them a kind that moves upon four legs; Allah creates whatever He wills; indeed Allah is Able to do all things.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
And We indeed sent down clear verses; and Allah may guide whomever He wills to the Straight Path.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
And they say, “We have accepted faith in Allah and His Noble Messenger, and we obey”; then after that a group among them turns away; and they are not Muslims.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
And when called towards Allah and His Noble Messenger in order that the Noble Messenger may judge between them, thereupon a group among them turns away.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
And if the judgement is in their favour, they come towards it willingly.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Are their hearts diseased, or do they have doubts, or do they fear that Allah and His Noble Messenger will oppress them? In fact they themselves are the unjust.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
The saying of the Muslims when they are called towards Allah and His Noble Messenger in order that the Noble Messenger judge between them is that they submit, “We hear and we obey”; and it is they who have attained the goal.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
And whoever obeys the command of Allah and His Noble Messenger, and fears Allah, and practices piety – so it is they who are the successful.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
And they swore by Allah most vehemently in their oaths that if you order them, they will go forth to holy war; say, “Do not swear; obedience according to the law is required; indeed Allah knows what you do.”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Proclaim, “Obey Allah and obey the Noble Messenger; so if you turn away, then the Noble Messenger is bound only for what is obligatory upon him, and upon you is the duty placed upon you”; and if you obey the Noble Messenger, you will attain guidance; and the Noble Messenger is not liable except to plainly convey.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah has promised those among you who believe and do good deeds, that He will certainly give them the Caliphate in the earth the way He gave to those before them; and that He will certainly establish for them their religion which He has chosen for them, and will turn their prior fear into peace; they must worship Me and not ascribe anything as a partner to Me; and whoever is ungrateful after this – it is they who are the disobedient.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
And keep the prayer established and pay the obligatory charity and obey the Noble Messenger, in the hope of attaining mercy.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Do not ever think that the disbelievers can escape from Our control in the land; and their destination is the fire; and indeed what a wretched outcome!\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O People who Believe! The slaves you possess and those among you who have not attained adulthood, must seek your permission on three occasions; before the dawn prayer, and when you remove your garments in the afternoon, and after the night prayer; these three times are of privacy for you; other than these three times, it is no sin for you or for them; moving about around you and among each other; and this is how Allah explains the verses for you; and Allah is All Knowing, Wise.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
And when the boys among you reach adulthood, then they too must seek permission like those before them had sought; this is how Allah explains His verses for you; and Allah is All Knowing, Wise.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
And the old women residing in houses who do not have the desire of marriage – it is no sin upon them if they discard their upper coverings provided they do not display their adornment; and avoiding even this is better for them; and Allah is All Hearing, All Knowing.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
There is no restriction upon the blind nor any restraint upon the lame nor any constraint upon the sick nor on any among you if you eat from your houses, or the houses of your fathers, or the houses of your mothers, or the houses of your brothers, or the houses of your sisters, or the houses of your fathers’ brothers, or the houses of your fathers’ sisters, or the houses of your mothers’ brothers, or the houses of your mothers’ sisters, or from the houses you are entrusted the keys of, or from the house of a friend – there is no blame upon you if you eat together or apart; therefore when you enter the houses, say greetings to your people – the excellent prayer at the time of meeting, from Allah, blessed and pure; this is how Allah explains the verses to you in order that you may understand.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
The believers are only those who accept faith in Allah and His Noble Messenger and when they are present with the Noble Messenger upon being gathered for some task, do not go away until they have taken his permission; indeed those who seek your permission, are those who believe in Allah and His Noble Messenger; so if they seek your permission for some affair of theirs, give the permission to whomever you wish among them, and seek Allah’s forgiveness for them; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Do not presume among yourselves the calling of the Noble Messenger equal to your calling one another; Allah knows those among you who sneak away by some pretext; so those who go against the orders of the Noble Messenger must fear that a calamity may strike them or a painful punishment befall them. (To honour the Holy Prophet – peace and blessings be upon him – is part of faith. To disrespect him is blasphemy.)\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Pay heed! Indeed to Allah only belong whatsoever is in the heavens and in the earth; He knows the condition you are in; and on the Day when they are returned to Him, He will then inform them of whatever they did; and Allah knows all things.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Most Auspicious is He Who has sent down the Furqan (the Criterion – the Holy Qur’an) upon His chosen bondman for him to be a Herald of Warning to the entire world. (Prophet Mohammed – peace and blessings be upon him – is the Prophet towards all mankind.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
The One to Whom belongs the kingship of the heavens and of the earth, and has not chosen a child, and has no partner in His kingship, and He has created everything and kept it in proper measure.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
And people have appointed other Gods besides Him, those who do not create anything but are themselves created, and those who do not have the power to harm or benefit themselves, and who do not have any authority over death or life nor over resurrection.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
And the disbelievers said, “This is nothing but a slur he has fabricated and others have helped him upon it”; so indeed the disbelievers have stooped to injustice and lie.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
And they said, “These are stories of the former people, which he has written down, so they are read to him morning and evening.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “It is sent down by Him Who knows all the secrets of the heavens and the earth; indeed He Oft Forgiving, Most Merciful."\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
And they said, “What is the matter with this (Noble) Messenger, that he eats food and walks in the markets? Why was not an angel sent down along with him, to give warning along with him?”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
“Or that he should have obtained a hidden treasure, or should have had a garden from which to eat”; and the unjust said, “You do not follow but a man under a magic spell.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
O dear Prophet (Mohammed – peace and blessings be upon him) see how they invent examples for you – they have therefore gone astray, unable find a road.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Most Auspicious is He Who, if He wills, may make it much better for you – Gardens beneath which rivers flow, and may create high palaces for you.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
In fact they deny the Last Day; and We have kept prepared a blazing fire for those who deny the Last Day.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it will see them from afar, they will hear its raging and roaring.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they are thrown into a narrow place in it, bound in chains, they will pray for death in it.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
It will be said “Do not pray this day for one death – and pray for many deaths.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say, “Is this better or the Everlasting Gardens which are promised to those who fear? That is their reward and their outcome.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
“In it for them is all that they may desire, abiding in it for ever; a promise incumbent upon your Lord, that is prayed for.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
And on the day when He will assemble them and all what they worship instead of Allah – then will say to those deities, “Did you mislead my bondmen or did they themselves forget the path?”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will submit, “Purity is to You – it was not rightful for us to appoint any Master besides You; but You gave them and their forefathers usage to the extent that they forgot Your Remembrance; and they were indeed the people who destroy themselves.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
“So the deities have belied what you state – so now you can neither avert the punishment nor help yourself; and whoever among you is unjust, We shall make him taste a terrible punishment.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
And all the Noble Messengers We sent before you were like this – eating food and walking in the markets; and We have made some of you a test for others; so will you, O people, patiently endure? And O dear Prophet, your Lord is All Seeing.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
And those who do not expect to meet Us said, “Why were the angels not sent down to us or we been able to see our Lord?” Indeed they thought too highly of themselves and they turned extremely rebellious.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
The day when they will see the angels – that day will not be of any happiness for the guilty – and they will cry, “O God, erect a barrier between us and them!”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
And We turned all the deeds they had performed into scattered floating specks of dust.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
And for the People of the Garden on that day is a better destination and account, and a better place of afternoon rest.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
And the day when the sky will be split asunder with clouds and the angels will be sent down in full.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
The true kingship on that day belongs to the Most Gracious; and that is hard for the disbelievers.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
And the day when the unjust will gnaw his hands, saying, “Alas, if only I had chosen a way along with the (Noble) Messenger (of Allah)!”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
“Woe to me – alas, if only I had not taken that one for a friend.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
“He indeed led me astray from the advice that had come to me”; and Satan deserts man, leaving him unaided.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
And the Noble Messenger submitted, “O my Lord – indeed my people took this Qur’an as worthy of being abandoned.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
And this is how We had appointed guilty people as enemies to every Prophet; and Allah is Sufficient, to guide and to aid.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
And the disbelievers say, “Why was the Qur’an not sent down to him all at once?” This is how We sent it in stages, in order to strengthen your heart with it and We read it slowly, in stages.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
And they will never bring you an example, but We shall bring you a true narration and better than it.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
Those who will be dragged on their faces towards hell – theirs is the worst destination and they are the most astray.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
And indeed We gave Moosa the Book and appointed with him his brother Haroon as a deputy.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
We therefore said, “Go, both of you, to the people who have denied Our signs”; then ruining the people, We destroyed them completely.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And the people of Nooh – when they denied the Noble Messengers, We drowned them and made them a sign for mankind; and We have kept prepared a painful punishment for the unjust.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
And the tribes of A’ad and the Thamud, and the people of the Wells, and many a generation between them.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
And We illustrated examples to each one of them; and ruining them, annihilated them all.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
And indeed they have visited the township upon which had rained a harmful rain; so were they not seeing it? In fact, they never expected to be raised again.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
And when they see you (O dear Prophet Mohammed – peace and blessings be upon him) they take you but as a mockery, “Is this the one whom Allah sent as a (Noble) Messenger?”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
“Possibly he would have misled us away from our Gods had we not been firm upon them”; soon they will know, when they see the punishment, who was astray from the path.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Did you see the one who chose his own desires as his God? So will you accept the responsibility of guarding him?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or do you think that most of them hear or understand something? They are not but like the cattle – in fact more astray from the path than them!\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcm{%
O dear Prophet, did you not see your Lord, how He spread the shade? And if He willed, He could have made it still; then We made the sun a proof upon it.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcmi{%
We then gradually withdraw it towards Us.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And it is He Who made the night a veil for you, and the sleep a rest, and made the day for getting up.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And it is He Who sent the winds giving glad tidings before His mercy; and We sent down purifying water from the sky.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
In order that We may revive a dead city with it, and give it to the many beasts and men that We have created, to drink.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcmv{%
And indeed We kept cycles of water among them that they may remember; so most men did not accept, except to be ungrateful.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
If We willed, We could have sent a Herald of Warning to every village.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So do not listen to the disbelievers and, with this Qur’an, fight a great war against them.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And it is He Who caused the two joint seas to flow- one is palatable, very sweet, and the other is salty, very bitter; and kept a veil between them and a preventing barrier.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He Who created man from water, then appointed relatives and in-laws for him; and your Lord is All Able.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcmx{%
And they worship such, other than Allah, which neither benefit nor hurt them; and the disbeliever helps the devil instead of his Lord.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
And We have not sent you (O dear Prophet Mohammed – peace and blessings be upon him) except as a Herald of glad tidings and warnings.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Proclaim, “I do not ask any fee from you for this, except that whoever wills may take the way to his Lord.”\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
And trust the Living One Who will never die, and praising Him proclaim His Purity; and He is Sufficient upon the sins of His bondmen, All Aware.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
The One Who created the heavens and the earth and all that is between them in six days, then befitting His Majesty, established Himself upon the Throne (of control); the Most Gracious – therefore ask the one who knows, concerning Him!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
And when it is said to them, “Prostrate to the Most Gracious” – they say, “And what is the Most Gracious? Shall we prostrate to whatever you command us?” And this command only increases the hatred in them. (Command of Prostration \# 7)\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Most Auspicious is He Who created lofty towers in the sky and placed a lamp in it, and the luminous moon.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And it is He Who created the alternation of the night and day for one who wishes to remember or intends to give thanks.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
And the bondmen of the Most Gracious who walk upon the earth humbly, and when the ignorant address them they answer, “Peace”. (Good –bye)\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
And who spend the night prostrating and standing, for their Lord.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
And who submit, “Our Lord – avert the punishment of hell from us; indeed its punishment is a permanent neck-shackle.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
Indeed it is a most wretched abode.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
And those who, when spending, neither exceed the limits nor act miserly, and stay in moderation between the two.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
And those who do not worship any other deity along with Allah, and do not unjustly kill any living thing which Allah has forbidden, nor commit adultery; and whoever does this will receive punishment.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
The punishment shall be increased for him on the Day of Resurrection, and he will remain in it forever, with humiliation.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
Except one who repents and accepts faith and does good deeds – so Allah will turn their evil deeds into virtues; and Allah is Oft Forgiving, Most Merciful.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
And whoever repents and does good deeds – so he has inclined towards Allah with repentance as was required.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
And those who do not give false testimony, and when they pass near some indecency, they pass by it saving their honour.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
And those who, when they are reminded of the signs of their Lord, do not fall deaf and blind upon them.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
And who submit, “Our Lord, soothe our eyes with our wives and our children, and make us leaders of the pious.”\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
They will be rewarded the highest position in heaven, the recompense of their patience, and they will be welcomed with honour and greetings of peace.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
They shall abide in it forever; what an excellent abode and place of stay.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him) “You have no value before My Lord if you do not worship Him; so you have denied – therefore the punishment that remains, will occur.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta-Seen-Meem. (Alphabets of the Arabic language – Allah, and to whomever he reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are verses of the clear Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
Possibly you may risk your life (O dear Prophet Mohammed – peace and blessings be upon him) by grieving, because they did not believe.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We will, We can send down on them a sign from the sky so that their leaders would remain bowed before it.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
And never does a new advice come to them from the Most Gracious, but they turn away from it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
Indeed they have denied, so now soon coming upon them are the tidings of what they used to scoff at.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Have they not seen the earth, that how many honourable pairs We have created in it?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Indeed in this is a sign; and most of them will not accept faith.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
And indeed your Lord – indeed only He is the Almighty, the Most Merciful.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
And (remember) when your Lord said to Moosa, “Go to the unjust people.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
“The nation of Firaun; will they not fear?”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said, “My Lord, I fear that they will deny me.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
“I feel hesitant, and my tongue does not speak fast, therefore make Haroon also a Noble Messenger.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
“And they have an accusation against me, so I fear that they may kill me.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
He said, “Not like this (any more); both of you go with Our signs, We are with you, All Hearing.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
“Therefore approach Firaun then proclaim, ‘We both are Noble Messengers of the Lord Of The Creation.’\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
‘That you let the Descendants of Israel go with us.’”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmcml{%
Said Firaun, “Did we do not raise you amongst us, as a child? And you spent many years of your life among us!”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmcmli{%
“And you committed the deed of yours that you committed, and you were ungrateful.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
Said Moosa, “I did that at a time when I was unaware of the consequences.” (In anger – See verse 28:15)\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
“I therefore went away from you as I feared you – so my Lord commanded me and appointed me as one of the Noble Messengers.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
“And is this some great reward for which you express favour upon me – that you have enslaved the Descendants of Israel?”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Said Firaun, “And what is the Lord Of The Creation?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
Said Moosa, “Lord of the heavens and the earth and all that is between them; if you believe.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
Said Firaun to those around him, “Are you not listening with attention?”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
Said Moosa, “Your Lord and the Lord of your forefathers preceding you.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
Said Firaun, “This (Noble) Messenger of yours, who has been sent towards you, has no intelligence!”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
He said, “The Lord of the East and the West and all that is between them; if you have sense.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
Said Firaun, “If you ascribe any one else as a God other than me, I will surely imprison you.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
Said Moosa, “Even if I bring to you something clear?”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
Said Firaun, “Then bring it, if you are of the truthful.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
So Moosa put down his staff and it became a visible serpent.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he drew forth his hand, thereupon it shone bright before the beholders.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
Said Firaun to the court members around him, “He is indeed an expert magician.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
“He wishes to expel you out of your land by his magic; so what is your advice?”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said, “Stop him and his brother, and send gatherers to the cities.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
“To bring to you every expert great magician.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the magicians were gathered at a set time on a day appointed.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
And it was said to the people, “Have you (also) gathered?”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
The people said, “Perhaps we may follow the magicians if they are victorious.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
So when the magicians came, they said to Firaun, “Will we get some reward if we are victorious?”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said, “Yes, and you will then become close to me.”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Moosa said to them, “Cast whatever you intend to cast.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
So they threw down their ropes and their staves and exclaimed, “By the honour of Firaun, indeed victory is ours!”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Therefore Moosa put forth his staff – so it immediately began swallowing all their fabrications.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
The magicians therefore fell down prostrate.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
They said, “We have accepted faith in the Lord Of The Creation.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
“The Lord of Moosa and Haroon.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
Said Firaun, “You accepted faith in him before I permitted you! He is indeed your leader who taught you magic; so now you will come to know; I swear, I will certainly cut off your hands and your feet from alternate sides, and crucify all of you.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said, “No harm (in it), we will return to our Lord.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
“We hope that our Lord will forgive us our mistakes, as we are the first to believe.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
And We sent the divine revelation to Moosa that, “Journey along with My bondmen within the night, for you will be pursued.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
So Firaun sent gatherers into the cities.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
They announced “These people are a small group.”\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
“And indeed they have angered all of us.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
“And indeed we are an alert army.”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
We therefore got them out from the gardens and water springs.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
And from treasures and nice houses.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
So it was; and We made the Descendants of Israel its inheritors.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
So the Firaun’s people followed them at sunrise.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
And when the two groups saw each other, those with Moosa said, “They have caught us.”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
Said Moosa, “Never! Indeed my Lord is with me, He will now show me the way.”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
So We sent the divine revelation to Moosa that, “Strike the sea with your staff”; thereupon the sea parted; so each part was like a huge mountain.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
And We brought the others close to that place.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
And We saved Moosa and all those with him.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
Then drowned the others.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Indeed in this is surely a sign, and most of them were not Muslims.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmm{%
And indeed your Lord – only He is the Almighty, the Most Merciful.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmi{%
And recite to them the news of Ibrahim.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmii{%
When he said to his father and his people, “What do you worship?”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said, “We worship idols, and we keep squatting in seclusion before them.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said, “Do they hear you when you call?”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmv{%
“Or do they benefit you or harm you?”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said, “In fact we found our forefathers doing likewise.”\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said, “Do you see these – (the idols) whom you worship?”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmviii{%
“You and your forefathers preceding you.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmix{%
“They are all my enemies, except the Lord Of The Creation.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmx{%
“The One Who created me, so He will guide me.”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmxi{%
“And the One Who feeds me and gives me to drink.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmxii{%
“And when I fall ill, so it is He Who heals me.”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
“And He will give me death, then resurrect me.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
“And the One Who, upon Whom I pin my hopes, will forgive me my mistakes on the Day of Judgement.”\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmxv{%
“My Lord, bestow me the command and join me with those who deserve your proximity.”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
“And give me proper fame among the succeeding generations.”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
“And make me among the inheritors of the Gardens of serenity.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
“And forgive my father* – he is indeed astray.” (His paternal uncle)\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmxix{%
“And do not disgrace me on the day when everyone will be raised.”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmxx{%
“The day when neither wealth will benefit nor will sons.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
“Except he who presented himself before Allah, with a sound* heart.” (Intact or unblemished.)\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
And Paradise will be brought close for the pious.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
And hell will be revealed for the astray.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
And it will be said to them, “Where are those whom you used to worship?”\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
“Instead of Allah? Will they help you or retaliate?”\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
So they and all the astray were flung into hell.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
And all the armies of Iblis. (Satan)\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
And they will say, and they will be quarrelling in it:\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
“By oath of Allah, we were indeed in open error.”\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
“When we considered you equal to the Lord Of The Creation.”\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
“And none misled us but the guilty.”\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
“So now we do not have any intercessors.” (The believers shall have intercessors, the disbelievers none).\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
“Nor a caring friend.”\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
“So if only were we to go back, in order to become Muslims!”\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Indeed in this is a sign; and most of them were not believers.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
And indeed your Lord – only He is the Almighty, the Most Merciful.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The people of Nooh denied the Noble Messengers.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
When their fellowman Nooh said to them, “Do you not fear?”\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
“I am indeed a trustworthy Noble Messenger of Allah to you.”\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmmxl{%
“Therefore fear Allah, and obey me.”\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmmxli{%
“And I do not ask from you any fee for it; my reward is only upon the Lord Of The Creation.”\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
“Therefore fear Allah, and obey me.”\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said, “Shall we believe in you, whereas the abject people are with you?”\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said, “What do I know what their deeds are?”\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
“Indeed their account is only upon my Lord, if you perceive.”\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
“And I will not repel the Muslims.”\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
“I am not but clearly a Herald of Warning.”\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said, “O Nooh, if you do not desist you will surely be stoned.”\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said, “My Lord, my people have denied me.”\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmml{%
“Therefore make a decisive judgement between me and them, and rescue me and the believers along with me.”\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmmli{%
So We saved him and those with him in a laden ship.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmmlii{%
Then after it, We drowned the rest.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Indeed in this is a sign; and most of them were not believers.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmmliv{%
And indeed your Lord, only He is the Almighty, the Most Merciful.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmmlv{%
(The tribe of) A’ad denied the Noble Messengers.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
When their fellowman Hud said to them, “Do you not fear?”\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
“I am indeed a trustworthy Noble Messenger of Allah to you.”\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
“Therefore fear Allah and obey me.”\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmmlix{%
“And I do not ask from you any fee for it; my reward is only upon the Lord Of The Creation.”\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmmlx{%
“What! You build a structure on every height, to laugh at the passers-by?”\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
“And prefer strong palaces, that perhaps you may live for ever?”\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
“And when you apprehend someone, you seize him mercilessly?”\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
“Therefore fear Allah, and obey me.”\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
“Fear Him Who has aided you with the things you know.”\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
“He aided you with cattle and sons.”\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
“And with gardens and water-springs.”\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
“Indeed I fear upon you the punishment of a Great Day.”\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said, “It is the same for us, whether you advise us or not be of the preachers.”\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
“This is nothing but the tradition of former people.”\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
“And we will not be punished.”\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
In response they denied him – We therefore destroyed them; indeed in this is a sign; and most of them were not believers.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
And indeed your Lord – only He is the Almighty, the Most Merciful.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
The Thamud tribe denied the Noble Messengers.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
When their fellowman Saleh said to them, “Do you not fear?”\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
“I am indeed a trustworthy Noble Messenger of Allah to you.”\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
“Therefore fear Allah and obey me.”\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
“And I do not ask from you any fee for it; my reward is only upon the Lord Of The Creation.”\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
“Will you be left peacefully in these favours over here?”\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
“In gardens and water springs?”\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
“And fields and palm-trees, with delicate tendrils?”\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
“And you carve out dwellings in the mountains, with skill?”\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
“Therefore fear Allah and obey me.”\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
“And do not follow those who exceed the limits.”\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
“Those who spread turmoil in the earth, and do no reform.”\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said, “You are under a magic spell.”\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
“You are just a human like us; therefore bring some sign if you are truthful.”\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said, “This is the she-camel – one day shall be her turn to drink, and on the other appointed day, shall be your turn.”\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
“And do not touch her with evil intentions for the punishment of the Great Day will seize you.”\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
So they hamstrung her, and in the morning could only regret.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mmmxc{%
The punishment therefore seized them; indeed in this is a sign; and most of them were not believers.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mmmxci{%
And indeed your Lord – only He is the Almighty, the Most Merciful.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The people of Lut denied the Noble Messengers.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
When their fellowman Lut said to them, “Do you not fear?”\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
“I am indeed a trustworthy Noble Messenger of Allah to you.”\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
“Therefore fear Allah and obey me.”\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
“And I do not ask from you any fee for it; my reward is only upon the Lord Of The Creation.”\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
“What! Among all the creatures, you commit the immoral acts with men?”\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
“And leave the wives your Lord has created for you? In fact you are people who exceed the limits.”\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said, “O Lut, if you do not desist, you will be expelled.”\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said, “I am disgusted with your works.”\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mmmci{%
“My Lord, rescue me and my family from their deeds.”\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mmmcii{%
We therefore rescued him and his entire family.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mmmciii{%
Except one old woman, who stayed behind.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mmmciv{%
We then destroyed the others.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mmmcv{%
And We showered a rain upon them; so what a wretched rain for those who were warned!\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Indeed in this is a sign; and most of them were not Muslims.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
And indeed your Lord – only He is the Almighty, the Most Merciful.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The People of the Woods denied the Noble Messengers.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mmmcix{%
When Shuaib said to all of them, “Do you not fear?”\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mmmcx{%
“I am indeed a trustworthy Noble Messenger of Allah to you.”\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
“Therefore fear Allah and obey me.”\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
“And I do not ask from you any fee for it; my reward is only upon the Lord Of The Creation.”\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
“Measure in full, and do not be of those who reduce.”\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
“And weigh with a proper balance.”\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
“And do not give the people their goods diminished, and do not roam the earth causing turmoil.”\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
“And fear Him Who created you and the earlier creations.”\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said, “You are under a magic spell.”\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
“You are just a human like us, and indeed we consider you a liar.”\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
“Therefore cause a part of the sky to fall upon us, if you are of the truthful.”\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said, “My Lord is Well Aware of what you do.”\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
In response they denied him – therefore the punishment of the day of the tent* seized them; that was indeed a punishment of a Great Day. (The clouds formed a tent and rained fire upon them).\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Indeed in this is a sign; and most of them were not Muslims.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
And indeed your Lord – only He is the Almighty, the Most Merciful.\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
And indeed this Qur’an has been sent down by the Lord Of The Creation.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
The Trustworthy Spirit brought it down. (Angel Jibreel – peace be upon him.)\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
Upon your heart, for you to convey warning.\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
In plain Arabic language.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
And indeed it is mentioned in the earlier Books.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
And was this not a sign for them, that the scholars of the Descendants of Israel may recognise this Prophet?\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
And had We sent it down upon a person other than an Arab,\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
In order that he read it to them, even then they would not have believed in it.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
This is how We have made (the habit of) denying embedded in the hearts of the guilty.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe in it to the extent that they see the painful punishment.\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
So it will come upon them suddenly, whilst they will be unaware.\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
They will therefore say, “Will we get some respite?”\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
So do they wish to hasten Our punishment?\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Therefore observe, that if We give them some comforts for some years, –\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
And then the promise that is given to them, does come upon them-\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
So of what benefit will be the comforts that they were using?\qt@no{(207)}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
And never did We destroy a township which did not have Heralds of warning, –\qt@no{(208)}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
To advise; and We never oppress.\qt@no{(209)}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
And this Qur’an was not brought down by the devils.\qt@no{(210)}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
They are unworthy of it, nor can they do it.\qt@no{(211)}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Indeed they have been banished from the place of hearing.\qt@no{(212)}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
Therefore do not worship another deity along with Allah, for you will be punished.\qt@no{(213)}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And O dear Prophet (Mohammed – peace and blessings be upon him), warn your closest relatives.\qt@no{(214)}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
And spread your wing of mercy for the believers following you.\qt@no{(215)}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
So if they do not obey you, then say, “Indeed I am unconcerned with what you do.”\qt@no{(216)}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And rely upon (Allah) the Almighty, the Most Merciful.\qt@no{(217)}}%
\qt@newcmd\qurantrans@en@mmmcl{%
Who watches you when you stand up.\qt@no{(218)}}%
\qt@newcmd\qurantrans@en@mmmcli{%
And watches your movements among those who prostrate in prayer.\qt@no{(219)}}%
\qt@newcmd\qurantrans@en@mmmclii{%
Indeed only He is the All Hearing, the All Knowing.\qt@no{(220)}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I inform you upon whom do the devils descend?\qt@no{(221)}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend on every great accuser, extreme sinner. (The magicians)\qt@no{(222)}}%
\qt@newcmd\qurantrans@en@mmmclv{%
The devils convey upon them what they heard, but most of them are liars.\qt@no{(223)}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
And the astray follow the poets.\qt@no{(224)}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
Did you not see that they keep wandering in every valley?\qt@no{(225)}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
And they speak what they do not do?\qt@no{(226)}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Except those who believed and did good deeds, and profusely remembered Allah, and took revenge after they had been wronged*; and soon the unjust will come to know upon which side they will be overturned**. (* The Muslim poets who praise Allah and the Prophet. ** The disbelievers will be punished.)\qt@no{(227)}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta-Seen*; these are verses of the Qur’an and the clear Book. (Alphabets of the Arabic language – Allah, and to whomever he reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
A guidance and glad tidings for the believers.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
Those who keep the prayer established and pay the charity and are certain of the Hereafter.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
Those who do not believe in the Hereafter – We have made their deeds seem good to them, so they are astray.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
It is they for whom is the worst punishment, and they will be the greatest losers in the Hereafter.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
And indeed you (O dear Prophet Mohammed – peace and blessings be upon him), are taught the Qur’an from the Wise, the All Knowing.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
(Remember) when Moosa said to his wife, “I have sighted a fire; I will soon bring its news to you, or bring for you an ember from it so that you may warm yourselves.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
So when he reached it, it was proclaimed, “Blessed is he who is in the location of the fire (Moosa) and those who are close to it (the angels); and Purity is to Allah, the Lord Of The Creation.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
“O Moosa, I am indeed, in truth, Allah the Almighty, the Wise.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
“And put down your staff”; so when he saw it writhing like a serpent, he turned moving away without looking back; We said, “O Moosa, do not fear; indeed the Noble Messengers do not fear in My presence.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
“Except the one* who does injustice and then after evil changes it for virtue – then indeed I am Oft Forgiving, Most Merciful.” (Other than the Prophets.)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
“And put your hand inside your armpit – it will come out shining white, not due to any illness; a sign among the nine signs towards Firaun and his people; they are indeed a lawless nation.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
Then when Our enlightening signs came to them, they said, “This is clear magic.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
And they denied them – whereas in their hearts they were certain of them – due to injustice and pride; therefore see what sort of fate befell the mischievous!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
And We indeed bestowed great knowledge to Dawud and Sulaiman; and they both said, “All praise is to Allah, Who bestowed us superiority over many of His believing bondmen.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Sulaiman became Dawud’s heir; and he said, “O people, we have indeed been taught the language of birds, and have been given from all things; this surely is a manifest favour.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
And assembled together for Sulaiman were his armies of jinns and men, and of birds – so they had to be restricted.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
Until when they came to the valley of the ants, a she ant exclaimed, “O ants, enter your houses – may not Sulaiman and his armies crush you, unknowingly.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
He therefore smiled beamingly at her speech*, and submitted, “My Lord, bestow me guidance so that I thank you for the favour which You bestowed upon me and my parents, and so that I may perform the good deeds which please You, and by Your mercy include me among Your bondmen who are worthy of Your proximity.” (Prophet Sulaiman heard the voice of the she ant from far away.)\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
And he surveyed the birds – he therefore said, “What is to me that I do not see the Hudhud (hoopoe), or is he really absent?”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
“I will indeed punish him severely or slay him, or he must bring to me some clear evidence.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
So Hudhud did not stay absent for long, and presenting himself submitted, “I have witnessed a matter that your majesty has not seen, and I have brought definite information to you from the city of Saba.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
“I have seen a woman who rules over them, and she has been given from all things, and she has a mighty throne.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
“I found her and her nation prostrating before the sun instead of Allah, and Satan has made their deeds seem good to them thereby preventing them from the Straight Path – so they do not attain guidance.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
“Why do they not prostrate to Allah, Who brings forth the things hidden in the heavens and the earth, and knows all what you hide and all what you disclose?”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
“Allah – there is no True God except Him, the Owner of the Great Throne.” (Command of Prostration \# 8)\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
Said Sulaiman, “We shall now see whether you spoke the truth or are among the liars.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
“Go with this letter of mine and drop it upon them – then move aside from them and see what they answer in return.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
The woman said, “O chieftains, indeed a noble letter has been dropped upon me.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
“Indeed it is from Sulaiman, and it is (begins) with ‘Allah – beginning with the name of – the Most Gracious, the Most Merciful.’”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
“That ‘Do not wish eminence above me, and present yourselves humbly to me, with submission.’”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said, “O chieftains, advise me in this matter of mine; I do not give a final decision until you are present with me.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said, “We possess great strength and are great warriors, and the decision is yours, therefore consider what you will command.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said, “Indeed the kings, when they enter a township, destroy it and disgrace its honourable people; and this is what they do.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
“And I shall send a present to them, then see what reply the envoys bring.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
So when the envoy came to Sulaiman, he said, “Are you helping me with wealth? What Allah has bestowed upon me is better than what He has given you; rather it is you who are delighted at your gift.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
“Go back to them – so we shall indeed come upon them with an army they cannot fight, and degrading them shall certainly drive them out from that city, so they will be humiliated.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
Said Sulaiman, “O court members, which one of you can bring me her throne before they come humbled in my presence?”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
An extremely evil jinn said, “I will bring it in your presence before you disperse the assembly; and I am indeed strong and trustworthy upon it.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
Said one who had knowledge of the Book, “I will bring it in your majesty’s presence before you bat your eyelid”; then when he saw it set in his presence*, Sulaiman said, “This is of the favours of my Lord; so that He may test me whether I give thanks or am ungrateful; and whoever gives thanks only gives thanks for his own good; and whoever is ungrateful – then indeed my Lord is the Independent (Not Needing Anything), the Owner Of All Praise.” (A miracle which occurred through one of Allah’s friends.)\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmcc{%
Said Sulaiman, “Disguise her throne in front of her so that we may see whether she finds the way* or becomes of those who remain unknowing.” (*Recognises her throne.)\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmcci{%
Then when she came, it was said to her, “Is your throne like this? She said, “As if this is it! And we came to know about this incident beforehand and submit (to you).”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccii{%
And the thing she used to worship instead of Allah prevented her; she was indeed from the disbelieving people.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
It was said to her, “Enter the hall”; and when she saw it she thought it was a pool and bared her shins*; said Sulaiman, “This is only a smooth hall, affixed with glass”; she said, “My Lord, I have indeed wronged myself, and I now submit myself along with Sulaiman to Allah, the Lord Of The Creation.” (* In order to cross it)\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And indeed We sent to the Thamud, their fellowman Saleh that, “Worship Allah”, thereupon they became two parties quarrelling.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said, “O my people, why do you hasten upon the evil before the good? Why do you not seek forgiveness from Allah? Perhaps there may be mercy upon you.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said, “We consider you an evil omen, and your companions”; he said, “Your evil omen is with Allah – in fact you people have fallen into trial.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
And there were nine persons in the city who used to cause turmoil in the land and did not wish reform.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
Swearing by Allah they said to one another, “We will indeed attack him and his family at night, and then say to his heir, ‘We were not present at the time of slaying of this household, and indeed we are truthful.’”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmccix{%
So they devised a scheme, and We made our secret plan, and they remained neglectful.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmccx{%
Therefore see what was the result of their scheming – We destroyed them and their entire nation.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
So these are their houses fallen flat, the recompense of their injustice; indeed in this is a sign for people who know.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We rescued those who accepted faith and used to fear.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And (remember) Lut when he said to his people, “What! You stoop to the shameful whereas you can see?”\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
“What! You lustfully go towards men, leaving the women?! In fact, you are an ignorant people.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
Therefore the answer of his people was nothing except that they said, “Expel the family of Lut from your township; these people wish purity!”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
We therefore rescued him and his family, except his wife; We had decreed that she is of those who will remain behind.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We showered a rain upon them; so what a wretched rain for those who were warned!\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “All praise is to Allah, and peace upon His chosen bondmen; is Allah better or what you ascribe as His partners?”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Or He Who created the heavens and the earth, and sent down water from the sky for you; so We grew delightful gardens with it; you had no strength to grow its trees; is there a God along with Allah?! In fact they are those who shun the right path.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Or He Who made the earth for habitation, and placed rivers within it, and created mountains as anchors for it, and kept a barrier between the two seas? Is there a God along with Allah?! In fact, most of them are ignorant.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Or He Who answers the prayer of the helpless when he invokes Him and removes the evil, and makes you inheritors of the earth? Is there a God along with Allah?! Very little do they ponder!\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Or He Who shows you the path in the darkness of the land and the sea, and He Who sends the winds before His mercy, heralding glad tidings? Is there a God along with Allah?! Supremacy is to Allah above all that they ascribe as partners!\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Or He Who initiates the creation, then will create it again, and He Who provides you sustenance from the skies and the earth? Is there a God along with Allah?! Proclaim, “Bring your proof, if you are truthful!”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “None in the heavens and the earth know the hidden by themselves, except Allah; and they do not know when they will be raised.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
Has their knowledge advanced so much as to know the Hereafter? On the contrary, they are in doubt concerning it; in fact they are blind towards it.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
And the disbelievers said, “Will we, when we and our forefathers have turned into dust, be removed again?”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
“Indeed this promise was given to us, and before us to our forefathers – this is nothing but stories of former people.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
“Proclaim, (O dear Prophet Mohammed – peace and blessings be upon him), “Travel in the land and see what sort of fate befell the guilty.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
And do not grieve upon them, nor be distressed because of their scheming.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
And they say, “When will this promise come, if you are truthful?”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say, “It could be that a part of what you are impatient for is (already) after you.”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
Indeed your Lord is Most Munificent upon mankind, but most men do not give thanks.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
And indeed your Lord knows what is hidden in their bosoms, and what they disclose.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
And all the hidden secrets of the heavens and the earth are (written) in a clear Book. (The Preserved Tablet)\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Indeed this Qur’an narrates to the Descendants of Israel most of the matters in which they differ.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
And indeed it is a guidance and a mercy for the Muslims.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Indeed your Lord judges between them with His command; and He is the Almighty, the All Knowing.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
Therefore rely on Allah; you are indeed upon the clear Truth.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Indeed the dead* do not listen to your call nor do the deaf* listen to your call, when they flee turning back. (The dead and deaf implies the disbelievers.)\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
And you will not guide the blind out of their error; and none listen to you except those who accept faith in Our signs, and they are Muslims.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the Word (promise) appears upon them, We shall bring forth for them a beast from the earth to speak to them – because the people were not accepting faith in Our signs. (This beast will rise from the earth, when the Last Day draws near.)\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
And the Day when We will raise from every nation an army that denies Our signs – so the former groups will be held back for the latter to join them.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
Until when they all come together, He will say, “Did you deny My signs whereas your knowledge had not reached it, or what were the deeds you were doing?”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word has appeared upon them because of their injustice, so now they do not speak.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
Did they not see that We created the night for them to rest in, and created the day providing sight? Indeed in this are signs for the people who have faith.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
And the Day when the Trumpet is blown – so all those who are in the heavens and the earth will be terrified, except whomever Allah wills; and everyone has come to Him, in submission.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
And you will see the mountains presuming them fixed whereas they will be moving like the clouds; this is Allah’s making, Who created all things with wisdom; indeed He is Informed of what you do.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whoever brings a good deed – for him is a reward better than it; and they will be safe from the terror on that Day.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And whoever brings evil – so their faces will be dipped into the fire; what reward will you get, except what you did?\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmccl{%
“I (Prophet Mohammed – peace and blessings be upon him) have been commanded to worship the Lord of this city, Who has deemed it sacred, and everything belongs to Him; and I have been commanded to be among the obedient.”\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmccli{%
“And to recite the Qur’an”; so whoever attained the right path, has attained it for his own good; and whoever goes astray – so say, “Indeed I am only a Herald of Warning.”\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And proclaim, “All praise is to Allah – He will soon show you His signs so you will recognise them”; and (O dear Prophet Mohammed – peace and blessings be upon him) your Lord is not unaware of what you, O people, do.”\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta-Seen-Meem. (Alphabets of the Arabic language – Allah and to whomever he reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are verses of the clear Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We shall narrate to you the true tidings of Moosa and Firaun, for the people who have faith.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Indeed Firaun had achieved dominance in the earth and made its people subservient to him – seeing a group among them weak, he used to kill their sons and spare their women; he was indeed very mischievous.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
And We willed to favour those who were weak in the earth, and to make them leaders and to make them the inheritors (of the land and wealth of Firaun’s people).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
And to give them control in the land, and to show Firaun and Haman and their armies what they fear from them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
And We inspired the mother of Moosa that, “Suckle him; then when you fear for him, cast him into the river and do not fear nor grieve; We shall indeed return him back to you and make him one of the Noble Messengers.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
So the family of Firaun picked him up, in order that he become their enemy and a sorrow upon them; indeed Firaun and Haman and their armies were guilty.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
And Firaun’s wife said, “This child is the comfort of my eyes and yours*; do not kill him; perhaps he may benefit us, or we may adopt him as our son” – and they were unaware. (Had Firaun also said the same, Allah would have granted him faith.)\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
And in the morning, the heart of Moosa’s mother became impatient; and she would have almost certainly given away his secret had We not strengthened her heart, so that she may have faith in Our promise.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
And she said to his sister, “Go after him” – she therefore observed him from far, and they were not aware.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
And We had already forbidden suckle-nurses for him, so she said, “Shall I show you a household that will nurse this child of yours, and they are his well-wishers?”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
So We returned him to his mother in order to soothe her eyes and not grieve, and to know that Allah’s promise is true – but most people do not know.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he reached his maturity and full strength, We gave him wisdom and knowledge; and this is how We reward the virtuous.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the city when its inhabitants were sleeping unaware in the afternoon – he therefore found two men fighting; one was from Moosa’s group, and the other from among his enemies; so the one who was of Moosa’s group pleaded to Moosa for help against him who was of his enemies – therefore Moosa punched him thereby finishing him; he said, “This act was from the devil*; indeed he is an open enemy, a misleader.” (* The act of oppressing the man from Bani Israel).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He said, “My Lord! I have indeed wronged my soul* therefore forgive me” – He therefore forgave him; indeed only He is the Oft Forgiving, the Most Merciful. (* By getting angry.)\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said, “My Lord! The way You have bestowed favour upon me, so never will I be a supporter of the guilty.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
So he was in the city at morning fearing, waiting to see what happens – thereupon he sighted the one who had appealed to him the day before, crying out to him for help; Moosa said to him, “Indeed you are clearly astray.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
So when Moosa wished to apprehend the man who was an enemy to them both, he said, “O Moosa! Do you wish to kill me the way you killed a man yesterday? You only wish to become a strict ruler in the land, and not to make reform.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
And a man came running from the outer part of the city; he said, “O Moosa! Indeed the court members are considering killing you, therefore go away – I surely am your well-wisher.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he left the city in fear, waiting to see what happens; he said, “My Lord! Rescue me from the unjust people.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
And when he turned his attention towards Madyan he said, “It is likely that my Lord will show me the right path.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
And when he came to the water of Madyan he found a group of men, watering their animals; and away from them he found two women restraining their animals; he said, “What is the matter with you?” They said, “We do not water our animals till all the shepherds water and take away their animals; and our father is very old.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
Therefore Moosa watered their animals for them, and then turned towards the shade and said, “My Lord! I am in need of the sustenance you may send down for me.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
So one of the two women approached him, walking shyly; she said, “My father is calling you, in order to give you wages because you watered our animals for us”; when Moosa came to him and had told him the story, he said, “Do not fear, you are safe from the unjust people.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
One of the two women said, “O my father! Employ him – indeed a strong and trustworthy employee is better.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said, “I wish to give you one of these two daughters of mine in marriage, the bridal money being that you work for me for eight years; then if you complete ten years, it will be from you; and I do not wish to put you in hardship; Allah willing, you will probably find me of the righteous.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
Said Moosa, “This is agreed between me and you; there shall be no claim upon me if I fulfil any of these two terms; and Allah is the Trustee upon this word of ours.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
So when Moosa completed his term and was travelling with his wife, he saw a fire in the direction of the Mount (Sinai); he said to his wife “Stay here – I have sighted a fire in the direction of the mount – perhaps I may bring you some news from it, or an ember so that you may warm yourselves.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
And when he reached the fire, he was called out to from the right side of the valley in the blessed field, from the tree, “O Moosa! Indeed I am truly Allah, the Lord Of The Creation.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
“Put down your staff”; so when Moosa saw it writhing like a serpent, he turned moving away without looking back; “O Moosa! Come forth and do not fear; indeed you are in peace.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
“Put your hand inside your armpit – it will come out shining white, not due to any illness; and put your hand on your chest to remove the fear – so these are two proofs from your Lord to Firaun and his court members; indeed they are a lawless people.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
He submitted, “My Lord! I killed a soul among them and I fear they will kill me.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
“And my brother Haroon – he is more eloquent than I am in speech, therefore in order to help me, appoint him as a Noble Messenger so that he confirms me; I fear that they will deny me.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
He said, “We will soon strengthen your arm with your brother, and give you both dominance, so they will not be able to harm you; due to Our signs; you both, and those who will follow you, will be victorious.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
Therefore when Moosa came to them with Our clear signs they said, “This is nothing but invented magic, and we never heard anything like this among our forefathers.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
And said Moosa, “My Lord well knows him who has brought guidance from Him, and for whom will be the abode the Hereafter; indeed the unjust never attain success.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
And Firaun said, “O court members! I do not know of any other God for you, except myself; therefore, O Haman, build a lofty palace for me by baking concrete in order that I may sneak a look at the God of Moosa – and according to me, he is indeed a liar.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he and his soldiers wrongfully sought greatness in the land, and assumed they would never be brought back to Us.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
We therefore seized him and his armies, and hurled them into the sea; therefore see what sort of fate befell the unjust!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We made them leaders of the people of hell, inviting towards the fire; and they will not be helped on the Day of Resurrection.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
And We set a curse after them in this world; and evil is for them on the Day of Resurrection.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
And We indeed gave Moosa the Book after We had destroyed the former generations, having enlightenment for mankind, and a guidance and a mercy, for them to accept advice.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
And you (O dear Prophet Mohammed – peace and blessings be upon him) were not on the western side of the Mount when We sent the command of Prophethood to Moosa, and you were not present. (Yet you narrate the account very clearly to the Jews and Christians.)\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
However, We created generations and ages passed by upon them; and nor were you dwelling with the people of Madyan reciting Our verses to them – however it is We Who made the Noble Messengers.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
And nor were you beside the Mount when We proclaimed – however it is a mercy from your Lord* so that you may warn a nation towards whom no Herald of Warning came before you, in the hope of their heeding advice. (*That He has bestowed knowledge of the hidden to you)\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
Otherwise, if some disaster befell them because of what their own hands have sent forward they would say, “Our Lord! Why did you not send a Noble Messenger towards us, so we may have followed Your signs and accepted faith?”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccc{%
So when the Truth* from Us came to them, they said, “Why has he not been given what was given to Moosa?” Had they not disbelieved in what was earlier given to Moosa? They said, “They are two magicians, who support each other”; and said, “We disbelieve in both of them.” (* Prophet Mohammed – peace and blessings be upon him).\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Therefore bring a Book from Allah which is better guiding than these two – I will follow it – if you are truthful.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
So if they do not accept your challenge, then know that they only follow their desires; and who is more astray than one who follows his desires away from the guidance of Allah? Indeed Allah does not guide the unjust.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
And We indeed sent down the Word continuously for them, so that they may ponder.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those to whom We gave the Book before it, accept faith in it. (Some scholars among Jews / Christians).\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
And when these verses are recited to them, they say, “We accept faith in it – indeed it is the Truth from our Lord – and indeed we had surrendered even before this.”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
They will be given double the reward, the recompense of their patience – and they repel evil with good, and spend part of what We have provided them.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
And when they hear indecent speech, they ignore it and say, “For us are our deeds and for you are your deeds; peace be to you (good bye); we are not interested in the ignorant.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
Indeed it is not such that you can guide whomever you love, but Allah guides whomever He wills; and He well knows the people upon guidance.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
And they say, “If we follow the guidance along with you, people would snatch us away from our land”; did We not establish them in a safe Sacred Land, towards which are brought fruits of all kinds – the sustenance from Us? But most of them do not know.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many towns did We destroy which had stooped to self indulgence! So here lie their dwellings, uninhabited after them except a little; and only We are the Inheritors.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
And never does your Lord destroy towns until He sends a Noble Messenger to their principal town, reciting Our verses to them; and We never destroy towns unless its people are unjust.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
And whatever you have been given, is a usage in the life of this world and its adornment; and that which is with Allah is better and more lasting; so do you not have sense?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
So is he whom We have given a good promise – he will therefore get it – equal to him whom We gave the usage of the life of this world to enjoy, and who will then be brought captive on the Day of Resurrection?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
On the day when He will call to them – He will therefore proclaim, “Where are those partners of Mine, whom you had assumed?”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those against whom the Word will have proved true will say, “Our Lord! These are they whom we led astray; we led them astray the way we ourselves went astray; we are unconcerned with them and we incline towards You – they never worshipped us!”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
And it will be said to them, “Call unto your ascribed partners” – so they will call unto them and they will not listen to them, and they will behold the punishment; if only they had obtained guidance!\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
And on the Day when He will call to them and proclaim, “What answer did you give to the Noble Messengers?”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
So on that Day the tidings will be blinded* for them, therefore they will not ask one another. (* They will forget at that moment).\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
So whoever repented and accepted faith and did good deeds, so it is likely that he will be among the successful.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
And your Lord creates whatever He wills, and chooses; they do not have any power to choose; Purity and Supremacy are to Allah above their ascribing partners (to Him).\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And your Lord knows what is hidden in their breasts, and what they disclose.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is Allah – there is no God except Him; only His is the praise in this world and in the Hereafter; and only His is the command, and it is towards Him that you will be returned.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Proclaim, “What is your opinion – if Allah makes it night continuously for you till the Day of Resurrection then, other than Allah, who is the God who could bring you light? So do you not heed?”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say, “What is your opinion – if Allah makes it day continuously for you till the Day of Resurrection then, other than Allah, who is the God who could bring you night for you to rest during it? So do you not perceive?”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
And with His mercy He made the night and day for you, so that you may rest during the night and seek His munificence during the day, and for you to be thankful.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
On the day when He will call to them – He will therefore proclaim, “Where are those partners of Mine, whom you had assumed?”\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And We shall proclaim taking out a witness from each group, “Bring your proof” – so they will realise that the Truth (Right) is for Allah, and they will lose all that they had fabricated.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Indeed Qaroon was from the people of Moosa – he then oppressed them; and We gave him so many treasures that their keys were a heavy burden for a strong group; when his people said to him, “Do not show off – indeed Allah does not like the boastful.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
“And seek the abode of the Hereafter with the wealth that Allah has given you, and do not forget your part in this world, and do favours (to others) the way Allah has favoured you, and do not seek to cause turmoil in the earth; indeed Allah does not like the mischievous.”\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said, “I got this only due to a knowledge I have”; and does he not know that before him Allah destroyed the generations who were stronger than him and more in number? And there is no questioning of the guilty regarding their sins.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
He therefore came before his people in his pomp; said those who desired the worldly life, “If only we were to get what Qaroon has been given – he is indeed very fortunate.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
And said those who were given the knowledge, “Woe to you – the reward of Allah is better for one who accepts faith and does good deeds; and only those who are patient will receive it.”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
We therefore buried him and his house into the earth; so he had no group to help save him from Allah; nor could he take revenge.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And those who had the day before desired his status, said in the morning, “It is strange – Allah expands the sustenance for whomever He wills among His bondmen, and restricts it; if Allah had not been gracious to us He would have buried us too; strangely, the disbelievers do not prosper.”\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
This abode of the Hereafter – We make it for those who do not wish greatness in the land nor turmoil; and the Hereafter is only for the pious.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whoever brings virtue, for him is better than it; and whoever brings evil – so those who commit evil will not be repaid except to the extent of their deeds.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
Indeed He Who has ordained the Qur’an upon you, will surely bring you back to where you wish; proclaim, “My Lord well knows him who came with guidance, and him who is in open error.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
And you held no expectations of the Book being sent down upon you, except that it is a mercy from your Lord – therefore never support the disbelievers. (You did not crave for it but trusted in the mercy of your Lord).\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And never may they prevent you from the verses of Allah after they have been sent down upon you, and call towards your Lord, and never be among those who ascribe partners (to Him).\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And do not worship any other God along with Allah; there is no God except Him; all things are destructible except His Entity; only His is the command, and it is towards Him that you will be returned.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif-Lam-Meem. (Alphabets of the Arabic language – Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do men fancy that they will be left just upon their declaring, “We believe”, and they will not be tested?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
We indeed tested those before them – so Allah will surely test the truthful, and will surely test the liars.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or do they who commit evil deeds imagine that they can escape from Us? What an evil judgement they impose!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Whoever expects to meet Allah – then indeed the time appointed by Allah will come; and He is the All Hearing, the All Knowing.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
And whoever strives in Allah's cause, strives only for his own benefit; indeed Allah is Independent of the entire creation.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
And those who accepted faith and did good deeds – We will indeed relieve their sins and reward them for the best of their deeds.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
And upon man We ordained kindness towards parents; and if they strive to make you ascribe a partner with Me, about which you do not have any knowledge, then do not obey them; towards Me only is your return and I will tell you what you used to do.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
And those who accepted faith and did good deeds – We shall indeed include them among the virtuous.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
And some people say, “We believe in Allah” – so if they are afflicted with some adversity in Allah’s way, they consider the chaos created by men as the punishment from Allah; and if the help comes from your Lord, they will surely say, “Indeed we were with you”; does not Allah well know what is in the hearts of the entire creation?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
And indeed Allah will make known the believers, and indeed He will expose the hypocrites.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
And the disbelievers said to the Muslims, “Follow our path and we will bear your sins”; whereas they will not bear anything from their sins; they are indeed liars.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
And they will surely bear their own burdens and some other burdens along with their own; and they will undoubtedly be questioned on the Day of Resurrection concerning what they had fabricated.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
And indeed We sent Nooh to his people – he therefore stayed with them for a thousand years, less fifty; so the flood seized them, and they were unjust.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
And We rescued him and the people aboard the ship, and made the ship a sign for the entire world.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And (remember) Ibrahim – when he said to his people, “Worship Allah and fear Him; that is better for you, if you knew!”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
“You worship only idols instead of Allah, and only forge a clear lie; indeed those whom you worship instead of Allah do not control your sustenance – therefore seek your sustenance from Allah, and worship Him, and be grateful to Him; it is towards Him that you will be returned.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
“And if you deny, then many nations have denied before you; and the Noble Messenger is not responsible except to plainly convey (the message).”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
Have they not seen how Allah initiates the creation, then will create it again? Indeed that is easy for Allah.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Travel in the land and see how He creates for the first time, then Allah brings forth the next development; indeed Allah is Able to do all things.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He punishes whomever He wills and has mercy upon whomever He wills; and towards Him only you are to return.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
Neither can you escape (from His control) in the earth nor in the sky; and for you, other than Allah, there is neither a friend nor a supporter.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
And those who did not believe in My signs and in meeting Me, are those who have no hope of My mercy, and for them is a painful punishment.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
So his people could not answer him except to say, “Kill him or burn him” – so Allah rescued him from the fire; indeed in this are signs for people who believe.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
And Ibrahim said, “You have chosen only idols instead of Allah, with whom your friendship is only in the life of this world; then on the Day of Resurrection you will deny and curse each other; and the destination for all of you is hell, and you do not have supporters.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
So Lut believed in him; and Ibrahim said, “I migrate towards my Lord; indeed only He is the Almighty, the Wise.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We bestowed Ishaq and Yaqub to him, and kept the Prophethood and the Book among his descendants, and We gave him his reward in the world; and in the Hereafter he is indeed among those who deserve Our proximity.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And We rescued Lut when he said to his people, “You indeed commit the shameful; such that no one in the creation has ever done before you.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
“What! You commit the immoral with males, and cut off the roads; and you speak evilly in your gatherings?” So his people had no answer except to say, “Bring the punishment of Allah upon us if you are truthful!”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He submitted, “My Lord! Help me against these mischievous people.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our sent angels came with glad tidings to Ibrahim, they said, “We will surely destroy the people of that town; indeed its inhabitants are unjust.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
He said, ``Lut is in it!”; they said, “We know very well who all are there; we shall rescue him and his family, except his wife; she is of those who will stay behind.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
And when Our sent angels came to Lut, he was unhappy at their arrival and was depressed – and they said, “Do not fear or grieve; we will surely rescue you and your family, except your wife, who is of those who will stay behind.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
“We will indeed cause a punishment from the sky to descend upon the inhabitants of this town – the recompense of their disobedience.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And We have undoubtedly kept a part of it as a clear sign for people of intellect.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And We sent towards Madyan, their fellowman Shuaib – he therefore said, “O my people! Worship Allah, and anticipate the Last Day, and do not roam the earth spreading turmoil.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
In response they denied him – thereupon the earthquake seized them – so at morning they remained lying flattened in their homes.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And We destroyed the A’ad and the Thamud, and you already know their dwellings; Satan made their deeds appear good to them and prevented them from the path, whereas they could perceive.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And (We destroyed) Qaroon, Firaun and Haman; and indeed Moosa came to them with clear signs, so they were arrogant in the land, and they could never escape from Our control.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
So We caught each one upon his sin; so among them is one upon whom We sent a shower of stones; and among them is one who was seized by the Scream; and among them is one whom We buried in the earth, and among them is one whom We drowned; it did not befit Allah’s Majesty to oppress them, but they were wronging themselves.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The example of those who choose masters other than Allah is like that of the spider; it makes the web its house; and indeed the weakest house of all is that of the spider; if only they knew.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Allah knows what they worship instead of Him; He is the Almighty, the Wise.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
And We illustrate these examples for mankind; and none except the knowledgeable understand them.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
Allah created the heavens and the earth with the truth; indeed in this is a sign for the Muslims.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
O dear Prophet (Mohammed – peace and blessings be upon him), recite from the Book which has been sent down to you, and establish the prayer; indeed the prayer stops from indecency and evil; and indeed the remembrance of Allah is the greatest; and Allah knows all what you do.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And O Muslims, do not argue with the People given the Book(s) except in the best manner – except (with) those among them who oppress, and say, “We believe in what has been sent down towards us and what has been sent towards you – and ours and your God is One, and we have submitted ourselves to Him.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
And this is how We sent down the Book to you O dear Prophet (Mohammed – peace and blessings be upon him); so those to whom We gave the Book believe in it; and some of these (polytheists) accept faith in it; and none except the disbelievers reject Our signs.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
And you (O dear Prophet Mohammed – peace and blessings be upon him) were not reading any Book before it, nor writing with your right hand – if it were, the people of falsehood would surely have doubted.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
In fact they are clear verses in the hearts of those who have been given knowledge; and none deny Our verses except the unjust.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
And they said, “Why did not signs come down to him from his Lord?” Say, “Signs are only with Allah; and I am purely a Herald of plain warning.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
Is it not enough for them that We have sent down the Book upon you, which is read to them? Indeed in it are mercy and advice for the Muslims.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Allah is Sufficient as a Witness between me and you; He knows all what is in the heavens and in the earth; and those who accepted faith in falsehood and denied faith in Allah – it is they who are the losers.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
And they urge you to hasten the punishment; and if a time had not been fixed, the punishment would have certainly come upon them; and it will indeed come upon them suddenly whilst they are unaware.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They urge you to hasten the punishment; and indeed hell has encompassed the disbelievers.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
The day when the punishment will envelop them from above them and from below their feet, and He will say, “Taste the flavour of your deeds!”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My bondmen who believe! Indeed My earth is spacious – therefore worship Me alone.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every soul must taste death; then it is to Us that you will return.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
And those who believed and did good deeds – indeed We will, surely, place them on high positions in Paradise beneath which rivers flow, abiding in it for ever; what an excellent reward of the performers!\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
Those who patiently endured and who rely only upon their Lord.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcd{%
And many creatures walk upon the earth that do not carry their own sustenance; Allah provides the sustenance to them and to you; and only He is the All Hearing, the All Knowing.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
And if you ask them, “Who created the heavens and the earth, and subjected the sun and the moon?”, they will surely say, “Allah”; so where are they reverting?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah eases the sustenance for whomever He wills among His bondmen, and restricts it for whomever He wills; indeed Allah knows all things.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
And if you ask them, “Who sent down the water from the sky, and with it revived the earth after its death?”, they will surely say, “Allah”; proclaim, “All praise is to Allah”; in fact most of them do not have any sense.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
And this worldly life is nothing but pastime and game; indeed the abode of the Hereafter – that is indeed the true life; if only they knew.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
And when they board the ships they pray to Allah, believing purely in Him; so when He delivers them safely to land, they immediately begin ascribing partners (to Him)!\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
In order to be ungrateful for Our favours; and to use the comforts; therefore they will soon come to know.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Did they not observe that We have created a refuge in the Sacred Land, and people around them are snatched away? So do they believe in falsehood and are ungrateful for the favours of Allah?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who is more unjust than one who fabricates lies against Allah, or denies the truth* when it comes to him? Is there not a place in hell for disbelievers? (* The Holy Prophet and / or the Holy Qur’an).\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
And those who strove in Our way – We shall surely show them Our paths; and indeed Allah is with the virtuous.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif-Laam-Meem. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Romans have been defeated.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
In the nearby land, and after their defeat they will soon be victorious.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
Within a few (up to nine) years time; only for Allah is the command, before and after; and the believers will rejoice on that day.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
With the help of Allah; He helps whomever He wills; and only He is the Almighty, the Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
The promise of Allah; Allah does not renege on His promise, but most people do not know.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know only the visible worldly life; and are totally neglectful of the Hereafter.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Have they not inwardly pondered – that Allah has not created the heavens and the earth, and all that is between them, except with truth and a fixed term? And indeed many people deny the meeting with their Lord.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
And did they not travel in the land to see what sort of fate befell those before them? They were stronger than them, and they cultivated the land and inhabited it more than them, and their Noble Messengers came to them with clear proofs; so it did not befit Allah’s Majesty to oppress them, but it was they who used to wrong themselves.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Then the fate of those who committed evil to the extreme was that they denied the signs of Allah and used to mock at them.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
Allah initiates the creation, then will create it again – then it is to Him that you will return.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
And on the Last Day– when it is established, the guilty* will lose all hope. (* The disbelievers.)\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
And the partners they ascribed will not be their intercessors – and they will deny their partners.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
And on the Last Day – that day they will all separate.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
So those who believed and did good deeds – they will be hosted in the Garden.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
And those who disbelieved, and denied Our signs and confronting the Hereafter – they will be hauled into the punishment.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So proclaim the Purity of Allah when you witness the night and the morning.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
And only His is the praise in the heavens and the earth – and before the day ends and at noon.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He brings forth the living from the dead, and brings forth the dead from the living, and He revives the earth after its death; and this how you will be raised.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And among His signs is that He created you from dust, and therefore you are human beings spread in the earth.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And among His signs is that He created spouses for you from yourselves for you to gain rest from them, and kept love and mercy between yourselves; indeed in this are signs for the people who ponder.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And among His signs is the creation of the heavens and the earth, and the differences in your languages and colours; indeed in this are signs for people who know.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And among His signs is your sleeping during the night and day, and your seeking His munificence; indeed in this are signs for people who heed.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And among His signs is that He shows you the lightning, instilling fear and hope, and sends down water from the sky, so revives the earth after its death; indeed in this are signs for people of intellect.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And among His signs is that the heavens and the earth remain established by His command; then when He calls you – from the earth – you will thereupon emerge.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
And to Him only belong all those who are in the heavens and the earth; all are submissive to Him.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
And it is He Who initiates the creation, and will then create it again – and this, according to you, should be easier for Him! And for Him only is the Supreme Majesty in the heavens and the earth; and only He is the Almighty, the Wise.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He illustrates an example for you from your own selves; do you have for yourselves, among the bondmen you possess, partners in the sustenance We have bestowed upon you, thereby you become equal in respect of it – you fearing them the way you fear each other? This is how We illustrate detailed signs for the people of intellect.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
Rather the unjust followed their own desires, without knowledge; so who can guide one whom Allah has sent astray? And they do not have supporters.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
Therefore set your attention for obeying Allah, devoted solely to Him; the foundation set by Allah, upon which He created man; do not change what Allah has created; this is the proper religion – but most people do not know.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
Inclining towards Him – and fear Him, and keep the prayer established, and never be of the polytheists.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
Those who broke their religion into several parts and became different groups; every group is happy with what it has.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
And when some affliction reaches men, they pray to their Lord inclining towards Him – and when He gives them a taste of His mercy, thereupon a group among them begins setting up partners to their Lord!\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
In order to be ungrateful for Our bestowal; “Therefore enjoy”; you will soon come to know.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We sent down to them any proof, which therefore tells them of My partners?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
And when We give people the taste of mercy they rejoice at it; and if an ill fortune reaches them because of what their hands have sent ahead – thereupon they lose hope!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
And did they not see that Allah eases the sustenance for whomever He wills and restricts it for whomever He wills? Indeed in this are signs for people who believe.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
Therefore give the relative his right, and to the needy, and to the traveller; this is better for those who seek the pleasure of Allah; and it is they who are the successful.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
And that which you give upon usury, in order that it may increase the creditors’ property, will not increase before Allah; and the charity you give seeking the pleasure of Allah – only that will increase manifold.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
It is Allah Who created you and then provided you sustenance, then will cause you to die, and will then give you life again; is there any among your ascribed partners that can do any of these things? Purity and Supremacy are to Him, above their ascribing of partners (to Him)!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Chaos appears in the land and the sea because of the evil deeds which people’s hands have earned, in order to make them taste the flavour of some of their misdeeds – in order that they may come back.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Travel in the land, and see what sort of fate befell the former people; and most of them were polytheists.”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
Therefore set your attention for worshipping, before the day from Allah which cannot be averted – on that day people will be split, separated.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Whoever disbelieves, then the calamity of his disbelief is only on him; and those who do good deeds, are preparing for themselves.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
In order to reward those who believed and did good deeds, by His munificence; indeed He does not like the disbelievers.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And among His signs is that He sends winds heralding glad tidings, to make you taste His mercy, and so that the ships may sail by His command, and so that you may seek His munificence, and for you to give thanks.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
And indeed We sent several Noble Messengers before you, to their nations – so they came to them with clear signs – We therefore took revenge from the guilty; and it is incumbent upon Our mercy, to help the Muslims.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
It is Allah Who sends the winds raising the clouds – therefore spreads them in the sky as He wills and shatters them – so you see the rain dropping from inside it; so when He delivers it upon whomever He wills among His bondmen, thereupon they rejoice.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
Although they had lost hope before it was sent down upon them.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
Therefore observe the result of Allah’s mercy, how He revives the earth after its death; He will indeed resurrect the dead; and He is Able to do all things.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
And if We send a wind and they see their fields yellow because of it, then indeed they would become ungrateful after it.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
For you do not make the dead hear nor make the deaf hear the call when they flee, turning back. (The disbelievers are referred to as dead and deaf.)\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
Nor do you guide the blind out of their error; you only make those hear who believe in Our signs, so they have submitted. (The disbelievers are referred to as blind.)\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
It is Allah Who created you weak, then after weakness gave you strength, then after strength gave you weakness and old age; He creates whatever He wills; and only He is the All Knowing, the Able.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
And on the day when the Last Day is established, the guilty will swear that they did not stay except for an hour; this is how they keep straying.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
And said those who received knowledge and faith, “You have indeed stayed in the decree of Allah until the Day of Restoration; so this is the Day of Restoration, but you did not know.”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
So on that day the unjust will not benefit from their excuses, nor will anyone ask them for compensation.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
And indeed We have illustrated all kinds of examples in this Qur’an for mankind; and indeed if you bring a sign to them, the disbelievers will say, “You are upon nothing but falsehood.”\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
This is how Allah sets seal upon the hearts of the ignorant.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
Therefore patiently endure, indeed the promise of Allah is true; and may not those who do not have faith make you impatient.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif-Lam-Meem. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are verses of the wise Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
Guidance and mercy for the righteous.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
Those who keep the prayer established and pay the charity and accept faith in the Hereafter.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
It is they who are on guidance from their Lord, and only they are the successful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
And some people buy words of play, in order to mislead from Allah’s path, without knowledge; and to make it an article of mockery; for them is a disgraceful punishment.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
And when Our verses are recited to him he haughtily turns away as if he did not hear them – as if there is deafness in his ears; so give him the glad tidings of a painful punishment.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
Indeed those who believed and did good deeds – for them are Gardens of serenity.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
In which they will abide; it is a true promise of Allah; and only He is the Almighty, the Wise.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He created the heavens without any supports visible to you, and cast mountains as anchors into the earth so that it may not shake with you, and spread all kinds of beasts in it; and We sent down water from the sky so thereby grew all kinds of refined pairs in it.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
Allah has created this – therefore show me what has been created by those other than Him; in fact the unjust are in open error.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
And indeed We bestowed wisdom to Luqman (saying) that, “Be grateful to Allah”; and whoever is grateful, is grateful for his own good; and whoever is ungrateful – then indeed Allah is the Absolute, the Most Praiseworthy.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And remember when Luqman said to his son, and he used to advise him, “O my son! Never ascribe anything as a partner to Allah; indeed ascribing partners to Him is a tremendous injustice.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
And We ordained upon man concerning his parents; his mother bore him enduring weakness upon weakness, and his suckling is up to two years – therefore be thankful to Me and to your parents; finally towards Me is the return.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
And if they force you, that you ascribe a partner to Me a thing concerning which you do not have knowledge – so do not obey them and support them well in the world; and follow the path of one who has inclined towards Me; then towards Me only is your return, and I shall tell you what you used to do.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
“O my son! If the evil deed is equal to the weight of a mustard-seed, and even if it is in a rock, or in the heavens, or wherever in the earth, Allah will bring it forth; indeed Allah knows all the minutest things, the All Aware.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
“O my son! Keep the prayer established, and enjoin goodness and forbid from evil, and be patient upon the calamity that befalls you; indeed these are acts of great courage.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
“And do not contort your cheek while talking to anyone, nor boastfully walk upon the earth; indeed Allah does not like any boastful, haughty person.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
“And walk moderately and soften your voice; indeed the worst voice is the voice of the donkey.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
Did you not see that Allah has made all whatever is in the heavens and all whatever is in the earth, subservient for you and bestowed His favours upon you in full, both visible and hidden? And some men argue regarding Allah, with neither knowledge, nor guidance, nor a clear Book!\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
And when it is said to them, “Follow what Allah has sent down”, they say, “On the contrary, we shall only follow that upon which we found our forefathers”; even if the devil was calling them to the punishment of hell?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
Whoever submits his face to Allah and is righteous – so he has indeed grasped the firm knot; and towards Allah only is the culmination of all things.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
And whoever disbelieves – then do not be aggrieved by his disbelief (O dear Prophet Mohammed – peace and blessings be upon him); they have to return to Us, and We will inform them what they were doing; indeed Allah knows what lies within the hearts.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We shall give them some usage, then making them helpless take them towards a severe punishment.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
And if you ask them, “Who created the heavens and the earth?” – they will surely answer, “Allah”; proclaim, “All Praise is to Allah”; in fact most of them do not know.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
To Allah only belongs whatsoever is in the heavens and in the earth; indeed Allah only is the Absolute, the Most Praiseworthy.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
And if all the trees in the earth were pens, and the seas were its ink, with seven more seas to back it up – the Words of Allah will not finish; indeed Allah is Almighty, Wise.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
Creating you all and raising you from the dead are like that of one soul*; indeed Allah is All Hearing, All Knowing. (He can create you slowly or all at once).\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
O listener, did you not see that Allah brings the night in a part of the day and brings the day in a part of the night, and that He has subjected the sun and the moon – each one runs for its fixed term – and that Allah is Well Aware of your deeds?\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
This is because only Allah is the Truth, and all that they worship besides Him are falsehood, and because only Allah is the Supreme, the Great.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmd{%
Did you not see that the ship sails on the sea by Allah’s grace, so that He may show you some of His signs? Indeed in this are signs for every greatly enduring, grateful person.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdi{%
And if a wave comes upon them like mountains, they pray to Allah believing purely in Him; then when He brings them safely to land, some of them remain upon justice; and none will deny Our signs except an extremely unfaithful, ungrateful person.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O mankind! Fear your Lord, and fear the Day in which no father will benefit his child; nor will any good child be of any benefit to the father; indeed Allah’s promise is true; so never may the worldly life deceive you; and never may the great cheat deceive you in respect of Allah’s commands.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Indeed Allah has the knowledge of the Last Day! And He sends down the rain; and He knows all what is in the mothers’ wombs; and no soul knows what it will earn tomorrow; and no soul knows the place where it will die; indeed Allah is the All Knowing, the Informer. (He may reveal the knowledge to whomever He wills.)\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif-Lam-Meem. (Alphabets of the Arabic language – Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdv{%
The revelation of the Book is, without doubt, from the Lord Of The Creation.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
What! They dare say that, “He has fabricated it”? In fact it is the Truth from your Lord, in order that you warn a nation towards whom no Herald of Warning came before you, in the hope of their attaining guidance.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
It is Allah Who created the heavens and the earth, and all what is between them, in six days, then (befitting His Majesty) established Himself over the Throne (of control); leaving Allah, there is neither a friend nor an intercessor for you; so do you not ponder?\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He plans (all) the job(s) from the heaven to the earth – then it will return to Him on the Day which amounts to a thousand years in your count.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdix{%
This is the All Knowing – of all the hidden and the visible, the Most Honourable, the Most Merciful.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdx{%
The One Who created all things excellent, and Who initiated the creation of man from clay.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
Then kept his posterity with a part of an abject fluid.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
Then made him proper and blew into him a spirit from Him, and bestowed ears and eyes and hearts to you; very little thanks do you offer!\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
And they said, “When we have mingled into the earth, will we be created again?”; in fact they disbelieve in the meeting with their Lord.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Proclaim, “The angel of death, who is appointed over you, causes you to die and then towards your Lord you will return.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
And if you see when the guilty will hang their heads before their Lord; “Our Lord! We have seen and heard, therefore send us back in order that we do good deeds – we are now convinced!”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
And had We willed We would have given every soul its guidance, but My Word is decreed that I will certainly fill hell with these jinns and men, combined.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
“Therefore taste the recompense of your forgetting the confronting of this day of yours; We have abandoned you – now taste the everlasting punishment, the recompense of your deeds!”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
Only those believe in Our signs who, when they are reminded of them, fall down in prostration and proclaim the Purity of their Lord while praising Him, and are not conceited. (Command of prostration \# 9).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Their sides stay detached from their beds and they pray to their Lord with fear and hope – and they spend from what We have bestowed upon them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
So no soul knows the comfort of the eyes that is kept hidden for them*; the reward of their deeds. (Paradise)\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
So will the believer ever be equal to the one who is lawless? They are not equal!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
Those who accepted faith and did good deeds – for them are the Gardens of (everlasting) stay; a welcome in return for what they did.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
And those who are lawless – their destination is the fire; whenever they wish to come out of it, they will be returned into it, and it will be said to them, “Taste the punishment of the fire you used to deny!”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
And We shall indeed make them taste the smaller punishment before the greater punishment, so that they may return.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who is more unjust than one who is preached to from the verses his Lord, then he turns away from them? We will indeed take revenge from the guilty.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
And indeed We bestowed the Book to Moosa, therefore have no doubt in its acquisition, and made it a guidance for the Descendants of Israel.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And We made some leaders among them, guiding by Our command, when they had persevered; and they used to accept faith in Our signs.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Indeed your Lord will judge between them on the Day of Resurrection concerning the matters in which they used to differ.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
And did they not obtain guidance by the fact that We did destroy many generations before them, so now they walk in their houses? Indeed in this are signs; so do they not heed?\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
And do they not see that We send the water to the barren land and produce crops with it, so their animals and they themselves eat from it? So do they not perceive?\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
And they say, “When will this decision take place, if you are truthful?”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Proclaim, “On the Day of Decision*, the disbelievers will not benefit from their accepting faith, nor will they get respite.” (* Of death or of resurrection)\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
Therefore turn away from them and wait – indeed they too have to wait.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Herald of the Hidden (the Prophet), continue to fear Allah and never listen to the disbelievers and the hypocrites; indeed Allah is All Knowing, Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
And keep following what is sent down to you from your Lord; O people! Indeed Allah is seeing your deeds.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And trust Allah; and Allah is Sufficient as a Trustee.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah has not kept two hearts in the body of any man; nor has He made them your mothers those wives of yours, whom you declare to be your mothers; nor has He made them your sons, whom you have adopted; this is the statement of your mouths; and Allah proclaims the truth and it is He Who shows the path.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call them with their fathers’ names – this is more suitable in the sight of Allah; and if you do not know their fathers, then they are your brothers in the faith, (and your cousins as humans) and your friends; and there is no sin upon you for what you did unknowingly in the past – however it is a sin what you do with your heart’s intention; and Allah is Oft Forgiving, Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is closer to the Muslims than their own lives, and his wives are their mothers; and the relatives are closer to each other in the Book of Allah, than other Muslims and immigrants, except that you may be kind towards your friends; this is written in the Book.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And remember O dear Prophet (Mohammed – peace and blessings be upon him) when We took a covenant from the Prophets – and from you – and from Nooh, and Ibrahim, and Moosa, and Eisa the son of Maryam; and We took a firm covenant from them.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
So that He may question the truthful regarding their truth; and He has kept prepared a painful punishment for the disbelievers.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O People who believe! Remember the favour of Allah upon you when some armies came against you, so We sent against them a windstorm and the armies you could not see; and Allah sees your deeds.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
When the disbelievers came upon you from above you and from below you, and when the eyes became fixed in stare and the hearts came up to the throats, and you were imagining matters regarding Allah.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
That proved be the testing ground for the Muslims, and they were subjected to a severe shake.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And when the hypocrites, and those in whose hearts is a disease, began saying, “Allah and His Noble Messenger have not given us a promise except one of deceit.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a group among said, “O people of Medinah! This is no place of stay for you, therefore go back to your homes”; and a group among them sought exemption from the Prophet by saying, “Our homes are unprotected” whereas their homes were not unprotected; they willed nothing except to flee.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
And if the armies had come upon them from the outskirts of Medinah and demanded disbelief from them, they would certainly have given them their demand and would not have hesitated in it except a little.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
And indeed before this they had agreed with Allah that they would not turn their backs; and the covenant of Allah will be questioned about.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Proclaim, “Fleeing will never benefit you if you flee from death or killing, and even then you will not be given the usage of this world except a little.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say, “Who is he who can avert the command of Allah from you, if He wills harm for you or wills to have mercy upon you?” And other than Allah, they will not find any friend or supporter.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Indeed Allah knows those among you who prevent others from the holy war, and those who say to their brothers, “Come towards us”; and they do not come to fight, except a few.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
They reduce the help towards you; so when a fearful time comes, you will observe them looking at you with eyes rolling like one enveloped by death; then when the time of fear is over, they begin slandering you with sharp tongues in their greed for the war booty; they have not accepted faith, therefore Allah has nullified their deeds; and this is easy for Allah.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They assume that the armies of the disbelievers have not gone away; and were the armies to come again, their wish would be to go out to the villages seeking information about you; and were they to stay among you even then they would not fight, except a few.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
Indeed following the Noble Messenger of Allah is better for you – for one who is confident of Allah and the Last Day, and remembers Allah much.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
And when the Muslims saw the armies, they said, “This is what Allah and His Noble Messenger promised us, and Allah and His Noble Messenger have spoken the truth”; and it did not increase anything for them but faith and acceptance of Allah’s will.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Among the Muslims are the men who have proved true what they had covenanted with Allah; so among them is one who has already fulfilled his vow, and among them is one still waiting; and they have not changed a bit.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
In order that Allah may reward the truthful for their truthfulness, and punish the hypocrites if He wills, or give them repentance; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
And Allah turned back the disbelievers in their hearts’ jealousy, gaining no good; and Allah sufficed the Muslims in their fight; and Allah is Almighty, Most Honourable.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And He brought down from their forts, the People given the Book(s) who had supported them, and instilled awe into their hearts – you slay a group among them and another group you make captive.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He bequeathed you their lands and their houses and their wealth, and land that you have not yet set foot upon; and Allah is Able to do all things.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Herald of the Hidden! Say to your wives, “If you desire the worldly life and its adornment – therefore come, I shall give you wealth and a befitting release!”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
“And if you desire Allah and His Noble Messenger and the abode of the Hereafter – then indeed Allah has kept prepared an immense reward for the virtuous among you.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O the wives of the Prophet! If any among you dares to commit an act contrary to decency, for her will be double the punishment of others; and this is easy for Allah.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
And whoever among you remains obedient towards Allah and His Noble Messenger and does good deeds – We shall give her double the reward of others, and have kept prepared for her an honourable sustenance.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
O the wives of the Prophet! You are not like any other women – if you really fear Allah, do not speak softly lest the one in whose heart is a disease have any inclination, and speak fairly.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And remain in your houses and do not unveil yourselves like the unveiling prevalent in the times of ignorance, and keep the prayer established, and pay the charity, and obey Allah and His Noble Messenger; Allah only wills to remove all impurity from you, O the People of the Household, and by cleansing you make you utterly pure. (*The Holy Prophet’s household.)\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And remember what is recited in your houses, from Allah’s verses and wisdom*; indeed Allah knows the minutest things, is All Aware. (The Holy Qur’an and the sayings- hadith – of the Holy Prophet.)\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Indeed the Muslim men and Muslim women, and the believing men and the believing women, and the men who obey and the women who obey, and the truthful men and the truthful women, and the patient men and the patient women, and the humble men and the humble women, and charitable men and the charitable women, and the fasting men and the fasting women, and the men who guard their chastity and the women who guard their chastity, and the men who profusely remember Allah and the women who profusely remember Allah – for all of them, Allah has kept prepared forgiveness and an immense reward.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
And no Muslim man or woman has any right in the affair, when Allah and His Noble Messenger have decreed a command regarding it; and whoever does not obey the command of Allah and His Noble Messenger, has indeed clearly gone very astray.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
And O dear Prophet, remember when you said to him upon whom Allah has bestowed favour and you had bestowed favour, “Keep your wife with you, and fear Allah”, and you kept in your heart what Allah willed to make known, and you feared criticism from the people; and Allah has more right that you should fear Him; so when Zaid became unconcerned with her, We gave her to you in marriage, so that there may be no sin upon believers in respect of the wives of their adopted sons when they have become unconcerned with them; and the command of Allah must be carried out.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There is no blame upon the Prophet regarding the matter that Allah has decreed for him; it has been Allah’s tradition in those who passed before; and the command of Allah is a certain destiny.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
Those who deliver the messages of Allah and fear Him, and do not fear anyone except Allah; and Allah is Sufficient to take account.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Mohammed (peace and blessings be upon him) is not the father of any man among you – but he is the Noble Messenger of Allah and the Last of the Prophets*; and Allah knows all things. (* Prophet Mohammed – peace and blessings be upon him – is the Last Prophet. There can be no new Prophet after him).\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O People who Believe! Remember Allah profusely.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
And proclaim His Purity, morning and evening.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
It is He Who sends blessings upon you*, and so do His angels, so that He may bring you out from darkness into light; and He is Most Merciful upon the Muslims. (* Upon the companions of the Holy Prophet).\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
For them the salutation upon their meeting* is “Peace”; and an honourable reward is kept prepared for them. (* Upon death / while entering Paradise / meeting with Allah).\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Herald of the Hidden! We have indeed sent you as an observing present witness and a Herald of glad tidings and warning.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
And as a caller towards Allah, by His command, and as a sun that enlightens. (The Holy Prophet is a light from Allah.)\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
And give glad tidings to the believers that for them is Allah’s extreme munificence.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And do not please the disbelievers and the hypocrites, and overlook the pain they cause and rely upon Allah; and Allah suffices as a Trustee.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O People who Believe! If you marry Muslim women and divorce them without having touched them, so for you there is no waiting period for the women, which you may count; therefore give them some benefit and release them with a proper release.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Herald of the Hidden! We have indeed made lawful for you the wives to whom you have paid their bridal money, and the bondwomen you possess whom Allah gave you as war booty, and the daughters of your paternal uncles, and the daughters of your paternal aunts, and the daughters of your maternal uncles, and the daughters of your maternal aunts, those who migrated with you; and the believing woman if she gifts her life to the Prophet, if the Prophet desires to take her in marriage; this is exclusively for you, not for your followers; We indeed know what We have enjoined upon the Muslims concerning their wives and the bondwomen they possess – this exclusivity for you is so that you may not have constraints; and Allah is Oft Forgiving, Most Merciful.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
Put back in the order whom you wish among them and give your proximity to whomever you wish; and if you incline towards one whom you had set aside, there is no sin upon you in it; this command is closer to their eyes remaining soothed and not grieving, and all of them remaining happy with whatever you give them; and Allah knows what is in the hearts of you all; and Allah is All Knowing, Most Forbearing.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
Other women are not permitted for you after these, nor that you change them for other wives even if their beauty pleases you except the bondwomen whom you possess; and Allah is the Guardian over all things.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O People who Believe! Do not enter the houses of the Prophet without permission, as when called for a meal but not to linger around waiting for it – and if you are invited then certainly present yourself and when you have eaten, disperse – not staying around delighting in conversation; indeed that was causing harassment to the Prophet, and he was having regard for you; and Allah does not shy in proclaiming the truth; and when you ask the wives of the Prophet for anything to use, ask for it from behind a curtain; this is purer for your hearts and for their hearts; and you have no right to trouble the Noble Messenger of Allah, nor ever marry any of his wives after him; indeed that is a very severe matter in the sight of Allah. (To honour the Holy Prophet – peace and blessings be upon him – is part of faith. To disrespect him is blasphemy.)\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether you disclose a thing or keep it hidden – then indeed Allah knows all things.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
There is no sin upon your wives in (dealing with) their fathers, or their sons, or their brothers, or their brothers’ sons, or their sisters’ sons or women of their own religion, or their bondwomen; and O women, keep fearing Allah; indeed all things are present in front of Allah.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Indeed Allah and His angels send blessings on the Prophet; O People who Believe! Send blessings and abundant salutations upon him. (Everlasting peace and unlimited blessings be upon the Holy Prophet Mohammed.)\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Indeed those who trouble Allah and His Noble Messenger – upon them is Allah’s curse in the world and in the Hereafter, and Allah has kept prepared a disgraceful punishment for them. (To disrespect / trouble the Holy Prophet – peace and blessings be upon him – is blasphemy.)\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
And those who unnecessarily harass Muslim men and women, have burdened themselves with slander and open sin.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet! Command your wives and your daughters and the women of the Muslims to cover their faces with a part of their cloaks; this is closer to their being recognised and not being harassed; and Allah is Oft Forgiving, Most Merciful. (It is incumbent upon women to cover themselves properly.)\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites, and those in whose hearts is a disease, and the rumour mongers in Medinah do not desist, We shall then surely impel you against them, so then they will not remain your neighbours in Medinah except for a few days.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
Accursed – to be caught wherever found and to be slain thoroughly.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
The tradition of Allah prevalent among those who passed away before; and you will never find the traditions of Allah changing.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
People ask you regarding the Last Day; proclaim, “Its knowledge is only with Allah; and what do you know, the Last Day may really be near!”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Allah has indeed cursed the disbelievers, and has kept prepared for them a blazing fire.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
In which they will remain forever; in it they will find neither a protector nor any supporter.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
On the day when their faces will be overturned being roasted inside the fire, they will say, “Alas – if only we had obeyed Allah and obeyed His Noble Messenger!”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they will say, “Our Lord! We followed our chiefs and our elders – so they misled us from the path!”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdci{%
“Our Lord! Give them double the punishment of the fire and send upon them a mighty curse!”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O People who Believe! Do not be like the people who troubled Moosa – so Allah freed him from the allegations they had uttered; and Moosa is honourable in the sight of Allah.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O People who Believe! Fear Allah, and speak rightly.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
He will rectify your deeds for you and forgive you your sins; and whoever obeys Allah and His Noble Messenger, has indeed achieved a great success.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
We indeed offered the trust to the heavens and the earth and the mountains, but they refused it and were afraid of it – and man accepted it; indeed he is one who puts himself into hardship, is extremely unwise.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
In order that Allah may punish the hypocrite men, and the hypocrite women, and the polytheist men, and the polytheist women – and accept the repentance of believing men and believing women; and Allah is Oft Forgiving, Most Merciful.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen All praise is to Allah – to Him only belongs all whatever is in the heavens and all whatever is in the earth – and His is the praise in the Hereafter; and He is the Wise, the All Aware.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows all that goes into the earth and all that comes out of it, and all that descends from the skies and all that ascends into it; and only He is the Most Merciful, the Oft Forgiving.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
And the disbelievers said, “The Last Day will never come upon us”; proclaim, “Surely yes, why not? By oath of my Lord, it will surely come upon you – the All Knowing of the hidden; nothing is hidden from Him – equal to an atom or less than it or greater – in the heavens or in the earth, but it is in a clear Book.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
So that He may reward those who believed and did good deeds; it is these for whom is forgiveness, and an honourable sustenance.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
And those who strove in Our signs in order to defeat – for them is a punishment from the severe painful punishments.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
And those who received the knowledge know that what is sent down upon you from your Lord is the truth, and it shows the path of the Most Honourable, the Most Praiseworthy.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
And the disbelievers said, “Shall we show you a man who will tell you that ‘When you have disintegrated into the smallest pieces, you are to be created again’?”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
“Has he fabricated a lie against Allah, or is he insane?” Rather those who disbelieve in the Hereafter are in the punishment and extreme error.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
So did they not see what is before them and what is behind them in the sky and the earth? If We will, We can bury them into the earth or cause a part of the sky to fall on them; indeed in this is a sign for every repentant bondman.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
And indeed We gave Dawud the utmost excellence from Us; “O the hills and birds, repent towards Allah along with him”; and We made iron soft for him.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
“Make large coats of armour and keep proper measure while making; and all of you perform good deeds; I am indeed seeing your deeds.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And We gave the wind in Sulaiman’s control – its morning journey equal to a month’s course and the evening journey equal to a month’s course; and We sprung a stream of molten copper for him; and from the jinns, who worked before him by the command of his Lord; and those among them who turned away from Our command – We shall make them taste the punishment of the blazing fire.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They made for him whatever he wished – synagogues and statues, basins like ponds, and large pots built into the ground; “Be thankful, O the people of Dawud!” And few among My bondmen are grateful.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
So when We sent the command of death towards him, no one revealed his death to the jinns except the termite of the earth which ate his staff; and when he came to the ground, the truth about the jinns was exposed – if they had known the hidden, they would not have remained in the disgraceful toil.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
Indeed for (the tribe of) Saba was a sign in their dwelling-place – two gardens on the right and the left; “Eat the sustenance provided by your Lord and be grateful to Him”; a pure land and an Oft Forgiving Lord!\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
In response they turned away – We therefore sent upon them a tremendous flood, and in exchange of their two gardens gave them two gardens bearing bitter fruit, and tamarisk, and some berries.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
We gave them this reward – the recompense of their ingratitude; and whom do We punish, except the ungrateful?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
And We had made several towns upon the road between them and the towns which We had blessed – and kept them according to the length of the journey; “Travel safely in them, by night and by day.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
So they said, “Our Lord! Make the stage between our journeys longer” and they wronged themselves – We therefore turned them into fables and scattered them completely with adversity; indeed in this are signs for every greatly enduring, most grateful person.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
And indeed Iblis made his assumptions regarding them seem true, so they all followed him except the group of Muslims.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
And Satan had no control over them at all, except that We willed to reveal as to who believes in the Hereafter and who is in doubt of it; and your Lord is a Guardian over all things.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Proclaim, “Call those whom you assume (as Gods) besides Allah”; they do not own anything equal even to an atom either in the heavens or in the earth, nor do they have any share in them, nor is any one among them an aide to Allah.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
And intercession does not benefit before Him, except for one whom He permits; to the extent that when the fear is removed from their hearts by giving permission, they say to each other, “How splendidly has your Lord spoken!” They say, “All that He has proclaimed is the Truth; and He is the Supreme, the Great.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Proclaim, “Who provides you sustenance from the sky and the earth?” Proclaim, “Allah – and indeed either we or you are upon guidance, or in open error.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Proclaim, “You will not be questioned regarding the sins you assume we have committed, nor will we be questioned regarding your misdeeds.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say, “Our Lord will bring us all together, and then judge truthfully between us; and He is the Best Judge, the All Knowing.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say, “(Dare you) Show me those whom you have matched with Him – never! Rather only He is Allah, the Most Honourable, the Wise.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
And O dear Prophet, We have not sent you except with a Prophethood that covers the entire mankind, heralding glad tidings and warnings, but most people do not know. (Prophet Mohammed – peace and blessings be upon him – is the Prophet towards all mankind.)\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
And they say, “When will this promise come, if you are truthful?\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Proclaim “For you is the promise of a Day which you cannot postpone by one moment nor can you advance it.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
And the disbelievers said, “We shall never believe in this Qur’an nor in the Books that were before it”; and if only you see, when the unjust will be brought before their Lord; they will hurl allegations on one another; those who were subdued will say to those who were conceited, “If it were not for you, we would have certainly accepted faith.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
Those who were conceited will say to those who were subdued, “Did we stop you from the guidance after it came to you? In fact you yourselves were guilty!”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
Those who were subdued will say to those who were conceited, “Rather it was your deceit during night and day, for you commanded us to deny Allah and to set up equals to Him”; and inwardly they began regretting when they saw the punishment; and We placed shackles around the necks of the disbelievers; what recompense will they get except what they used to do?\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
And whenever We sent a Herald of Warning to any town, its wealthy people said, “We disbelieve in what you have been sent with.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
And they said, “We are greater in wealth and children; we will not be punished!”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Proclaim “Indeed my Lord eases the sustenance for whomever He wills and restricts it for whomever He wills, but most people do not know.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
And your wealth and your children are not capable of bringing you near to Us, but one who believes and did good deeds (is brought close); for them is double the reward – the recompense of their deeds and they are in high positions, in peace.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
And those who strive in Our signs in order to defeat, will be brought into the punishment.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say, “Indeed my Lord eases the sustenance for whomever He wills among His bondmen, and restricts it for whomever He wills; and whatever you spend in Allah's cause, He will restore it; and He is the Best Sustainer.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
And on the day when He will raise them all, and then say to the angels, “Did they worship you?”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They will say, “Purity is to you – only you are our Supporter, not they; in fact they worshipped the jinns; most of them believed only in them.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
So this day you will not have the power to benefit or hurt one another; and We shall say to the unjust, “Taste the punishment of the fire which you used to deny!”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
And if Our clear verses are recited to them, they say, “He is nothing but a man who wishes to turn you away from the deities of your forefathers!”; and they say, “This is nothing but a fabricated lie”; and said the disbelievers regarding the truth when it reached them, “This is nothing but obvious magic.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
And We did not give them any Books which they may read, nor did We send to them any Herald of Warning before you.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
And those before them had denied – and these have not reached even a tenth of what We had given them – so they denied My Noble Messengers; so how did My rejection turn out?\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Proclaim, “I advise you just one thing; that stand up for Allah's sake, in twos and ones, and then think”; there is not a trace of insanity in this companion of yours; he is not but a Herald of Warning for you, before the advent of a severe punishment!\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say, “Whatever fee I might have asked from you upon this, is yours; my reward is only upon Allah; and He is Witness over all things.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Proclaim, “Indeed my Lord sends down the truth; the All Knowing of all the hidden.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Proclaim, “The truth has come, and falsehood dare not commence nor return.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Proclaim, “If I stray, I stray only for my own harm; and if I attain guidance, it is because of what my Lord has sent down to me; indeed He is All Hearing, Close.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
And if only you see, when they will be forced into a terror from which they will be unable to escape, and are seized from a place nearby. (Wherever they go, they are never far).\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
And they will say, “We accept faith in it”; and how can they attain it from so far away? (After they have crossed the limit of life allotted to them.)\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
For they had disbelieved in it before; and they hurl allegations without seeing, from far away.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And a barrier is set between them and what they desire*, as was done for their earlier groups; indeed they are in a doubt that deceives. (To accept faith or return to earth)\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen All praise is to Allah, the Maker of the heavens and the earth, Who assigns angels as messengers – who have pairs of two, three, four wings; He increases in creation whatever He wills; indeed Allah is Able to do all things.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
No one can withhold the mercy which Allah opens to mankind; and whatever He withholds – so after it, none can release it; and only He is the Most Honourable, the Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O people! Remember the favour of Allah upon you; is there a Creator other than Allah who can provide you sustenance from the sky and the earth? There is no God except Him; so where are you reverting?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
And if they deny you, many Noble Messengers were denied before you; and towards Allah only is the return of all matters.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O people! Allah’s promise is indeed true; therefore do not ever let the worldly life deceive you; nor ever let the great cheat deceive you in respect of Allah’s commands.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Indeed Satan is your enemy, therefore you too take him as an enemy; he only calls his group so that they become the people of hell!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
For the disbelievers is a severe punishment; and for those who accepted faith and did good deeds is forgiveness, and an immense reward.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
So will one whose misdeeds are made seeming good to him – so he deems them good – be ever equal to the one who is upon guidance? Therefore indeed Allah sends astray whomever He wills, and guides whomever He wills; so may not your life be lost in despairing after them; Allah knows their deeds very well.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
And it is Allah Who sent the winds – so they raise clouds and We then direct it towards a dead city – so with it We revive the earth after its death; and this is how the resurrection will be.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
Whoever desires honour – therefore all honour belongs to Allah!* Towards Him only ascends the pure good speech, and He raises high the pious deed; and for those who conspire evil is a severe punishment; and their own conspiracy will be destroyed. (It is Allah Who bestows honour, to whomever He wills.)\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
And Allah created you from clay, then a drop of liquid, then made you as couples; and no female conceives or gives birth except with His knowledge; and every aged being that is given the age, and every one whose life is kept short – all this is in a Book; indeed this is easy for Allah.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
And the two seas are not alike; this is sweet, very sweet and palatable – and this is salty, bitter; and from each you eat fresh meat and extract the ornament which you wear; and you see the ship cleaving through it, so that you may seek His munificence, and in some way become grateful.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He brings the night in a part of the day and He brings the day in a part of the night; and He has subjected the sun and moon; each one runs to its fixed term; such is Allah, your Lord – only His is the kingship; and those whom you worship instead of Him do not own even the husk of a date-seed.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If you call them, they do not hear your call; and supposedly if they heard it, they cannot fulfil your needs; and on the Day of Resurrection they will deny your ascribed partnership; and none will inform you like Him Who informs.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O people! You are dependant on Allah; and Allah only is the Independent (Absolute, Not Needing Anything), the Most Praiseworthy.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He wills, He can take you away and bring other creatures.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
And this not at all difficult for Allah.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
And no burdened soul will carry another soul’s burden; and if a burdened soul calls another to share the burden, no one will carry any part of it, even if he is a close relative; O dear Prophet (Mohammed – peace and blessings be upon him), your warning only benefits those who fear their Lord without seeing and who keep the prayer established; and whoever cleansed himself, has cleansed for his own benefit; and towards Allah only is the return.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
And the blind and the sighted are not equal!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
And neither are darkness and brightness!\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
And neither are the shadow and the hot sunshine!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
And not equal are the living and the dead! Indeed Allah causes them to listen*, whomever He wills; and you cannot make those who are in the graves** listen. (* Listen to guidance **The disbelievers are referred to as dead, whose fates are sealed.)\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
You are purely a Herald of Warning.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
And O dear Prophet (Mohammed – peace and blessings be upon him), We have indeed sent you with the Truth, giving glad tidings and heralding warnings; and there was a Herald of Warning in every group.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
And if these disbelievers deny you, those before them had also denied; their Noble Messengers came to them with clear proofs and scriptures and the bright Book.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then I seized the disbelievers; so how did denial My rejection turn out?\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Have you not seen that it is Allah Who causes the water to descend from the sky? So with it We have grown various colourful fruits; and among the mountains are tracks white and red, of different hues, and others dark black.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
And similarly the colours of men and beasts and cattle, are different; among the bondmen of Allah, only the people of knowledge fear Him; indeed Allah is the Most Honourable, Oft Forgiving.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Indeed those who read the Book of Allah, and keep the prayer established, and spend from what We have bestowed upon them in secret and publicly, are hopeful of a trade in which there is never a loss.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
In order that He may reward them with goodness in full, and further increase it with His munificence; indeed He is Oft Forgiving, Most Appreciative.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
And the Book which We have divinely revealed to you – that is the Truth, confirming the Books which were before it; indeed Allah is Aware of His bondmen, All Seeing.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
We then made Our chosen bondmen the inheritors of the Book; so among them is one who wrongs himself; and among them is one who stays on the middle course; and among them is one who, by the command of Allah, surpassed others in good deeds; this is the great favour!\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
They shall enter the Gardens of everlasting stay (Eden) – in which they shall be given to adorn armlets of gold and pearls; and their garment in it is silk.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they will say; “All praise is to Allah Who has put away our grief; indeed Our Lord is Oft Forgiving, Most Appreciative.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
“The One Who has, by His munificence, established us in a place of serenity; in which no hardship shall ever reach us nor any fatigue affect us.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
And for those who disbelieved is the fire of hell; neither does their final seizure come that they may die, nor is its punishment lightened for them; this is how We punish every extremely ungrateful person.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
And they shall be screaming in it; “Our Lord! Extricate us, so that we may do good deeds, the opposite of what we used to do”; (It will be said to them) “And did We not give you an age long enough, in which anyone who wants to understand would have understood? And the Herald of Warning did come to you; therefore now taste it – for the unjust do not have any supporter.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Indeed Allah is All Knowing – of all the hidden things in the heavens and in the earth; indeed He knows what lies within the hearts.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
It is He Who has made you the successors of your predecessors in the earth; so whoever disbelieves – (the harm of) his disbelief falls only on him; and for the disbelievers, their disbelief increases nothing in their Lord’s sight except disgust; and for the disbelievers, their disbelief increases nothing for them except ruin.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Proclaim, “Just show me your partners (false deities) whom you worship other than Allah; show me which part of the earth have they created – or do they have any share in the heavens?” Or have We given them some Book, so they are on its clear proofs? In fact the unjust do not give promises to each other, except of deceit.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
Indeed Allah restrains the heavens and the earth from convulsing; and were they to convulse, who could stop them except Allah? Indeed He is Most Forbearing, Oft Forgiving.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
And they swore by Allah most vehemently in their oaths, that if a Herald of Warning came to them, they would be more upon guidance than any other group; then when a Herald of Warning did come to them, he increased nothing in them except hatred.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
Priding themselves in the earth and scheming evil; and the evil scheming falls only upon those who scheme it; so what are they waiting for, except the tradition of the earlier nations? So you will never find the traditions of Allah changing; and you will never find Allah’s law being avoided.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
And did they not travel in the land in order to see what sort of fate befell those who were before them, whereas they exceeded them in strength? And Allah is not such that anything in the heavens or in the earth can break away from His control; indeed He is All Knowing, Able.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
If Allah were to seize people upon their deeds, He would leave no creature walking on the surface of the earth, but He gives them respite till a fixed term; and when their term comes – so indeed Allah is observing all His bondmen!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Yaa-Seen (Alphabets of Arabic language – Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By oath of the wise Qur’an.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
You (O dear Prophet Mohammed – peace and blessings be upon him) are indeed one of the Noble Messengers.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
On the Straight Path.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
(The Qur’an is) Sent down by the Almighty, the Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
So that you may warn these people whose ancestors were not warned, they are therefore unaware.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
Undoubtedly, it (their disbelief) has proved true for most of them, so they will not believe.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
We have indeed put shackles around their necks reaching up to the chins, so they remain facing upwards.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
And We have set a wall before them and a wall behind them, and covered the top – so they are unable to see anything.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
And it is the same for them, whether you warn them or do not warn them – they will not believe.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
You warn only him who follows the advice and fears the Most Gracious without seeing; therefore give him glad tidings of forgiveness and an honourable reward.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
We will surely bring the dead to life and We record what they send ahead and the signs they will leave behind; and We have accounted all things in a clear Book.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
And relate to them the signs of the people of the city – when two emissaries came to them.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
When We had sent two towards them and they denied them both, so We fortified them with a third, and they all said, “Indeed we have been sent to you.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They said, “You are nothing but mortals like us; the Most Gracious has not sent down anything – you are nothing but liars.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
They answered, “Our Lord knows that surely, without doubt, we have been sent towards you.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
“And our duty is nothing but to plainly convey (the message).”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
They (the people of the city) said, “We think you are ominous; indeed, if you do not desist, we shall surely stone you to death, and you will surely face a grievous torture at our hands.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They said, “Your evil omens are with you! What! You get annoyed for being advised? In fact you are a people who transgress the limits!”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
And from the outermost part of the city came a man running; he said, “O my people! Obey those who have been sent.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
“Obey those who do not ask any fee from you, and they are on guidance.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
“And what is the matter with me that I should not worship Him Who created me, whereas it is towards Him that you are to return?”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
“What! Shall I appoint Gods other than Allah? So that if the Most Gracious should wish me any harm, their intercession would be of no use to me, nor would they be able to save me?”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
“Undoubtedly, I am then in open error.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
“Indeed I have believed in your Lord, so heed me.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said to him, “Enter Paradise”; he said, “If only my people knew!”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
“The manner in which my Lord has pardoned me and made me of the honoured ones!”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
And after him, We did not send down any army from heaven against his people, nor did We intend to send down an army.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was just one scream, and with it they were extinguished.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
And it was said, “Woe to those bondmen – whenever a Noble Messenger comes to them, they mock at him!”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Have they not seen how many generations We destroyed before them, which will not return to them?\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
And without exception, all of them will be brought forth before Us.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
And a sign for them is the dead earth; We gave it life and We produced from it grain, so they eat from it.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And We have placed in it gardens of dates and grapes, and We have made springs of water in it.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
So that they may eat from its fruits, whereas they are not manufactured by their hands! So will they not be grateful?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Purity is to Him Who created all pairs, from what the earth grows, and of themselves, and from the things they do not know.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
And a sign for them is the night; We strip the day out of it, thereupon they are in darkness.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun runs its course for its final destination; this is a command of the Almighty, the All Knowing.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And We have appointed positions for the moon till it returns like an old branch of the date palm.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
It is not for the sun to catch up with the moon, nor does the night surpass the day; and each one of them floats in its orbit.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And a sign for them is that We lodged them in a laden ship, while they were in their forefathers backs.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And We have created for them similar ships, in which they now ride.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
And if We will, We can drown them, so there would be no help in their distress, nor would they be saved.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
Unless by mercy from Us, and as a comfort for a while.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
And when it is said to them, “Beware of what is before you and what is behind you, in the hope of your gaining mercy”, they turn away!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
And whenever a sign comes to them from the signs of their Lord, they always turn away from it!\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said to them, “Spend in Allah’s cause, from what Allah has provided you”, the disbelievers say regarding the believers, “Shall we feed these, whom if Allah willed, would have fed? You are not but in open error!”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
And they say, “When will this promise be fulfilled, if you are truthful?”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They await just one scream, which will overcome them while they are involved in worldly disputes.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
Therefore neither able to make a will, nor returning to their homes.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
And the Trumpet will be blown – so they will come forth from the graves, running towards their Lord.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
Saying, “O our misfortune! Who has raised us from our sleep? This is what the Most Gracious had promised, and the Noble Messengers had spoken the truth!”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
It is just one scream, and every one of them will be brought together before Us!\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
So this day no soul will be wronged in the least; and you will not be compensated except for your deeds.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Indeed this day the dwellers of Paradise are in comfort, with blissful hearts.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
They and their wives are in shades, reclining on thrones.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
In it (paradise) are fruits for them and whatever they ask for.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
Upon them will be “Peace” – a Word from their Merciful Lord!\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
“And be separated (from others) this day, O you criminals!”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
“O Descendants of Adam! Did I not take a covenant from you that you shall not worship the devil? Undoubtedly, he is your open enemy.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
“And that you shall worship Me? This is the Straight Path.”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
“And he has indeed led a large number of you astray; so did you not have sense?”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
“This is hell, which you were promised.”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
“Enter it this day – the recompense of your disbelief.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
This day We will set a seal on their mouths, and their hands will speak out to Us and their feet will bear witness to their deeds.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
And had We willed, We could have quenched their eyes so they would rush towards the path, unable to see a thing.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
And had We willed, We could have disfigured their faces while they were in their homes, therefore unable to go forward or turn back.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
And whomever We bring to an old age, We reverse him in creation; so do they not understand?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
And We have not taught him (Prophet Mohammed- peace and blessings be upon him) to recite poetry, nor does it befit him; it is nothing but an advice and the bright Qur’an.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
To warn the living*, and to prove the Word against disbelievers. (Only the believers are deemed alive in Allah’s sight.)\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Did they not see that We have created animals for them from Our handiwork, so they are their owners?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
And have subjected the animals for them, so they ride some animals and eat some?\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
And for them in the animals are numerous different benefits and drinks; so will they not be grateful?\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
And they have appointed Gods other than Allah, that perhaps they may be helped!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They (the appointed Gods) cannot help them; and they and their armies will come (to Us), as captives.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
Therefore (O dear Prophet Mohammed – peace and blessings be upon him) do not grieve because of what they (the disbelievers) say; indeed We know what they conceal and what they disclose.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
And did not man see that We have created him from a drop of semen? Yet he is an open quarreller!\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he invents an example for Us, while forgetting his own creation, saying, “Who is such that can revive the bones when they have completely rotted away?”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “They will be revived by the One Who created them the first time; and He is the All Knowing of every creation.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
“The One Who has created for you fire from the green tree, so you kindle from it.”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
And is it not possible for the One Who created the heavens and the earth to create the likes of them? It is surely possible, why not? And He is the Great Creator, the All Knowing of everything.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
And His only task when He intends a thing is to command it, “Be” – and it thereupon happens!\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
Therefore Purity is to Him in Whose Hand* is the control over all things and it is towards Him that you will be returned. (Used as a metaphor to mean Power).\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By oath of those who establish proper ranks.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
And by oath of those who herd with a stern warning.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
And by oath of the groups that read the Qur’an.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
Indeed your God is surely only One.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and the earth and all that is between them – and the Lord of the sun’s rising points.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
We have indeed adorned the lowest heaven with stars as ornaments.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
And to protect it from every rebellious devil.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
They cannot listen to the speech of those on higher elevations and they are targeted from every side.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
To make them flee, and for them is a never-ending punishment.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
Except one who sometimes steals a part, so a blazing flame goes after him.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
Therefore ask them (O dear Prophet Mohammed – peace and blessings be upon him), “Are they a stronger creation, or are other things of our creation, (the angels, the heavens etc.)?” We have indeed created them from sticky clay.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
Rather you are surprised, whereas they keep mocking.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
And they do not understand, when explained to.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
And whenever they see a sign, they mock at it.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
And they say, “This is nothing but clear magic.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
“When we are dead and have turned into dust and bones, will we certainly be raised again?”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
“And also our forefathers?”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Proclaim, “Yes, and with disgrace.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
So that is just a single jolt, thereupon they will begin staring.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
And will say, “O our misfortune!” It will be said to them, “This is the Day of Justice.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
“This is the Day of Judgement, which you used to deny!”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
“Gather all the unjust persons and their spouses, and all that they used to worship!” –\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
“Instead of Allah – and herd them to the path leading to hell.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
“And stop them – they are to be questioned.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
“What is the matter with you, that you do not help one another?”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
In fact this day they have all surrendered.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
And some of them inclined towards others, mutually questioning.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
They said, “It is you who used to come to us from our right, in order to sway.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
They will answer, “You yourselves did not have faith!”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
“And we did not have any control over you; but in fact you yourselves were rebellious.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
“So the Word of our Lord has proved true upon us; we will surely have to taste (the punishment).”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
“We therefore led you astray, for we ourselves were astray!”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
So this day they all are partners in the punishment.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
This is how We deal with the guilty.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
Indeed, when it was said to them, “There is no God except Allah”, they were haughty.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
And they used to say, “Shall we forsake our Gods upon the sayings of a mad poet?”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
In fact he has brought the Truth, and testified for the Noble Messengers!\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
“You surely have to taste the painful punishment.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
“And you will not be compensated except for your deeds.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
Except the chosen bondmen of Allah.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
For them is the sustenance known to Us.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
Fruits; and they will be honoured.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
In Gardens of peace.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
Facing one another on thrones.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
Cups of wine will be presented to them in rounds, from a spring flowing in front of them.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
White, delicious for the drinkers.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
Neither does it intoxicate, nor give a headache.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
And with them are those who do not set gaze upon men except their husbands, the maidens with gorgeous eyes.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
As if they were eggs, safely hidden.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
So one among them turns to the other, questioning. –\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
The speaker among them said, “I had a companion.” –\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
“Who used to tell me, ‘Do you believe it is true?’ –\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
‘That when we are dead and have turned into dust and bones, that we will either be rewarded or punished?’”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
He said (to others on the thrones), “Will you take a glimpse (into hell) below?”\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
He therefore looked down and saw him amidst the blazing fire.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He said, “By Allah, you had nearly ruined me!”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
“And were it not for the munificence of my Lord, I too would have been seized and brought forth (captive)!”\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
“So are we never to die?” (The people of Paradise will ask the angels, with delight, after the announcement of everlasting life.)\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
“Except our earlier death, and nor will we be punished?”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
“This is, most certainly, the supreme success.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For such a reward should the workers perform.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
So is this welcome better, or the tree of Zaqqum?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
We have indeed made that a punishment for the unjust.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
Indeed it is a tree that sprouts from the base of hell.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
Its fruit like the heads of demons.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
So indeed they will eat from it, and fill their bellies with it.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
Then after it, indeed for them is the drink of boiling hot water.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
Then surely their return is towards hell.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
They had indeed found their forefathers astray.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
So they hastily follow their footsteps!\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
And indeed before them, most of the former people went astray.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
And indeed We had sent Heralds of warnings among them.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
Therefore see what sort of fate befell those who were warned!\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
Except the chosen bondmen of Allah.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
And indeed Nooh prayed to Us – so what an excellent Acceptor of Prayer We are!\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We rescued him and his household from the great calamity.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
And We preserved his descendants.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And We kept his praise among the latter generations.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
Peace be upon Nooh, among the entire people.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
This is how We reward the virtuous.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
He is indeed one of Our high ranking, firmly believing bondmen.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
We then drowned the others.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
And indeed Ibrahim is from his (Nooh’s) group.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
When he came to his Lord, with a sound heart. (Free from falsehood).\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
When he said to his father (paternal uncle) and his people, “What do you worship?”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
“What! You desire, through fabrication, Gods other than Allah?”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
“So what do you assume regarding the Lord Of The Creation?” (That He will not punish you?)\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
He then shot a glance at the stars.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
He then said, “I feel sick (of you)!”\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
And they turned their backs on him and went away. (The pagans thought he would transmit the disease).\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
He then sneaked upon their deities and said, “Do you not eat?”\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
“What is the matter with you, that you do not say anything?”\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
He then began striking them with his right hand, unseen by the people.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
So the disbelievers came running towards him.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said, “What! You worship what you yourselves have sculpted?”\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
“Whereas Allah has created you and your actions?”\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said, “Construct a building (furnace) for him, and then cast him in the blazing fire!”\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
So they tried to execute their evil scheme upon him – We therefore degraded them. (Allah saved him, by commanding the fire to turn cool).\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
And he said, “Indeed I shall go to my Lord Who will guide me.”\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
“My Lord! Give me a meritorious child.”\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
We therefore gave him the glad tidings of an intelligent son.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
And when he became capable of working with him, Ibrahim said, “O my son, I dreamt that I am sacrificing you – therefore now consider what is your opinion”; he said, “O my father! Do what you are commanded! Allah willing, you will soon find me patiently enduring!”\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
Then (remember) when they both submitted to Allah’s command, and Ibrahim lay his son facing downwards. (The knife did not hurt Ismail)\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
And We called out to him, “O Ibrahim!”\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
“You have indeed made the dream come true”; and this is how We reward the virtuous.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
Indeed this was a clear test.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We rescued him in exchange of a great sacrifice. (The sacrifice of Ibrahim and Ismail – peace be upon them – is commemorated every year on 10, 11 and 12 Zil Haj).\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
And We kept his praise among the latter generations.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
Peace be upon Ibrahim!\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
This is how We reward the virtuous.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
He is indeed one of Our high ranking, firmly believing bondmen.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And We gave him the glad tidings of Ishaq, a Herald of the Hidden, from among those who deserve Our proximity.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
And We sent blessings upon him and Ishaq; and among their descendants – some who do good deeds, and some who clearly wrong themselves.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
And We indeed did a great favour to Moosa and Haroon.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
And rescued them and their people from the great calamity.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And We helped them, so they were victorious.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
And We bestowed the clear Book to both of them.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
And guided them to the Straight Path.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We kept their praise among the latter generations.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
Peace be upon Moosa and Haroon!\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
This is how We reward the virtuous.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
Indeed they are two of Our high ranking, firmly believing bondmen.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
And indeed Ilyas is one of the Noble Messengers.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
When he said to his people, “Do you not fear?”\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
“What! You worship Baal (an idol) and leave the Best Creator?” –\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
“Allah – Who is your Lord and the Lord of your forefathers?”\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
In response they denied him, so they will surely be brought forth as captives.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
Except the chosen bondmen of Allah.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And We kept his praise among the latter generations.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
Peace be upon Ilyas!\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
This is how We reward the virtuous.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
He is indeed one of Our high ranking, firmly believing bondmen.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
And indeed Lut is one of the Noble Messengers.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
When We rescued him and his entire household.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
Except an old woman, who became of those who stayed behind.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
We then destroyed the others.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
And indeed you pass over them in the morning. –\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
And during the night; so do you not have sense?\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
And indeed Yunus is one of the Noble Messengers.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
When he left towards the laden ship.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
Then lots were drawn and he became of those who were pushed into the sea.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
The fish then swallowed him and he blamed himself. (For not waiting for Allah’s command.)\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
And were he not one of those who praise. –\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
He would have remained in its belly till the day when all will be raised.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
We then put him ashore on a plain, and he was sick.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
And We grew a tree of gourd (as a shelter) above him.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
And We sent him towards a hundred thousand people, in fact more.\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
So they accepted faith – We therefore gave them usage for a while.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
Therefore ask them (O dear Prophet Mohammed – peace and blessings be upon him), whether the daughters are for your Lord and the sons for them!\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or that have We created the angels as females, while they were present?\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Pay heed! It is their slander that they say. –\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
That “Allah has offspring”; and indeed, surely, they are liars.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
“Has he chosen daughters instead of sons?”\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
“What is the matter with you? What sort of a judgement you impose!”\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
“So do you not ponder?”\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
“Or do you have some clear proof?”\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
“Then bring forth your Book, if you are truthful!”\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
And they have appointed a relationship between Him and the jinns; and indeed the jinns surely know that they will be brought forth.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Purity is to Allah from the matters they fabricate.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
Except the chosen bondmen of Allah.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
Therefore you and all what you worship. (The disbelievers and their deities.)\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mmmcml{%
You cannot make anyone rebel against Him.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
Except the one who will go into the blazing fire.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
And the angels say, “Each one of us has an appointed known position.”\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
“And indeed we, with our wings spread, await the command.”\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
“And indeed we are those who say His purity.”\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
And indeed the disbelievers used to say, –\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
“If we had some advice from the earlier generations,” –\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
“We would certainly be the chosen bondmen of Allah.”\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
They therefore denied it, so they will soon come to know.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
And indeed Our Word has already gone forth for Our bondmen who were sent.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
That undoubtedly, only they will be helped.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
And surely, only Our army will be victorious.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
Therefore turn away from them for some time.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
And watch them, for they will soon see.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
So are they being impatient for Our punishment?\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
So when it does descend in their courtyards – so what an evil morning it will be for those who were warned!\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
And turn away from them for some time.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
And wait, for they will soon see.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Purity is to your Lord, the Lord of Honour, from all what they say.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And peace is upon the Noble Messengers.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And all praise is to Allah, the Lord Of The Creation.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Saad* – By oath of the renowned Qur’an, (Alphabet of the Arabic language; Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
In fact, the disbelievers are in false pride and opposition.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
Many a generation We did destroy before them – thereupon they cried out whereas it is not the time to escape!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
And they were surprised that a Herald of Warning came to them from among themselves; and the disbelievers said, “He is a magician, a great liar!”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
“Has he made all the Gods into One God? This is really something very strange!”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
And their leaders went about, “Leave him and cling steadfastly to your Gods! Indeed he has a hidden objective in this!”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
“We never heard of this even in Christianity, the latest religion; this is clearly a newly fabricated matter.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
“Is the Qur’an which is sent to him, among us?” In fact they are in a doubt concerning My Book; in fact, they have not yet tasted My punishment.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or do they hold the treasures of the mercy of your Lord, the Almighty, the Great Bestower?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Is the kingdom of the heavens and the earth and all that is between them, for them? So would they not just ascend using ropes?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
This is just one of the disgraced armies, that will be routed there and then.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Before them, the people of Nooh had denied, and the tribe of A’ad, and Firaun who used to crucify.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
And the tribe of Thamud, and the people of Lut, and the People of the Woods; these are the groups.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
None of them was such that it did not deny the Noble Messengers, therefore My punishment became inevitable.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
They await just one Scream, which no one can avert.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
And they said, “Our Lord! Give us our share quickly, before the Day of Reckoning.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Have patience upon what they say, and remember Our bondman Dawud, the one blessed with favours; he is indeed most inclined (towards His Lord).\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
Indeed We subjected the hills to say the praise with him, at night and at morn.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
And birds gathered together; they were all obedient to him.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
And We strengthened his kingdom and gave him wisdom and just speech.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
And did the news of the two disputants reach you? When they scaled over the wall into Dawud’s mosque.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
When they entered upon David, so he feared them – they said, “Do not fear! We are two disputants, one of whom has wronged the other, therefore judge fairly between us and do not judge unjustly – and show us the right way.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
“This is my brother; he has ninety nine ewes and I have one ewe; and he now says ‘Give that one also to me’ – and he is very demanding in speech.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
Said Dawud, “He is indeed being unjust to you in that he demands to add your ewe to his ewes; and indeed most partners wrong one another, except those who believe and do good deeds – and they are very few!” Thereupon Dawud realised that We had tested him, so he sought forgiveness from his Lord, and fell prostrate and inclined (towards his Lord). (Command of Prostration \# 10)\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
We therefore forgave him this; and indeed for him in Our presence are, surely, proximity and an excellent abode.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
“O Dawud! We have indeed appointed you as a Viceroy in the earth, therefore judge between mankind with the truth, and do not follow desire for it will lead you astray from Allah’s path; indeed for those who stray away from Allah’s path is a severe punishment, because they forgot the Day of Reckoning.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
And We have not created the heaven and the earth and all that is between them without purpose; this is what the disbelievers assume; therefore ruin is for the disbelievers, by the fire.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Shall We make those who believe and do good deeds equal to those who spread turmoil in the earth? Or shall We equate the pious with the disobedient?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
This is a Book which We have sent down upon you, a blessed Book, for them to ponder upon its verses, and for men of intellect to accept advice.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmm{%
And We bestowed Sulaiman to Dawud; what an excellent bondman! He is indeed most inclined.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmi{%
When fast footed steeds were presented to him at evening.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmii{%
Therefore Sulaiman said, “I cherish the love of these horses*, out of remembrance of my Lord”; he then ordered them to be raced until they vanished in a curtain out of sight. (To be used in holy war.)\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
He then ordered, “Bring them back to me”; and he began caressing their shins and necks.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
And We indeed tested Sulaiman, and placed a dead body on his throne – he therefore inclined towards His Lord.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said, “My Lord! Forgive me and bestow upon me a kingdom, which shall not befit anyone after me; indeed only You are the Great Bestower.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
We therefore gave the wind under his control, moving steadily by his command wherever he wished.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
And made the demons subservient to him, all builders and divers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
And other demons bound in chains.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmix{%
“This is Our bestowal – you may therefore bestow favours or withhold them – you will not be questioned.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And indeed for him in Our presence are, surely, proximity and an excellent abode.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
And remember Our bondman Ayyub (Job); when he cried out* to his Lord, “The devil has struck me with hardship and pain.” (After seven years of patience.)\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
We said to him, “Strike the earth with your foot; this cool spring is for bathing and drinking.” (A spring of gushed forth when he struck the earth – this was a miracle.)\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We bestowed his household to him and one more similar to it – as a mercy from Us, and as a remembrance for the people of intellect.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
And We said, “Take a broom in your hand and strike her with it, and do not break your vow”; We indeed found him patiently enduring; what an excellent bondman! He is indeed most inclined.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And remember Our bondmen Ibrahim, and Ishaq, and Yaqub – the men of power and knowledge.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
We indeed gave them distinction with a genuine affair – the remembrance of the (everlasting) abode.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
And in Our sight, they are indeed the chosen ones, the beloved.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And remember Ismail and Yasa’a (Elisha) and Zul-Kifl; and they are all excellent.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is an advice; and indeed for the pious is an excellent abode.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
Everlasting Gardens – all its gates are open for them.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
Reclining on pillows, in it they ask for fruits and drinks in plenty.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
And with them are the pure spouses, who do not set gaze upon men except their husbands, of single age.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
This is the promise being given to you, for the Day of Reckoning.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
Indeed this is Our sustenance, which will never end.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
This is for the virtuous; and indeed for the rebellious is a wretched destination.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell; which they shall enter; what an evil resting-place!\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
This is for the criminals – so that they may taste it – boiling hot water and pus.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
And similar other punishments in pairs.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
“Here is another group that was with you, falling along with you”; they will answer, “Do not give them plenty of open space; they surely have to enter the fire – let them also be confined!”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
The followers will say, “In fact, for you! May you not get open space! It is you who brought this calamity upon us!” So what a wretched destination.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They say, “Our Lord! Whoever has brought this calamity upon us – double the punishment of the fire for him!”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they say, “What is the matter with us that we do not see the men whom we thought were evil?”\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
“Did we mock at them or did our eyes turn away from them?”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Indeed this is really true – the people of the hell quarrelling among themselves.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “I am purely a Herald of Warning – and there is no God except Allah, the One, the All Dominant.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
“Lord of the heavens and the earth and all that is between them – the Almighty, the Oft Forgiving.”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say, “That is a great tidings.”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
“You are neglectful of it!”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
“What did I know of the heavenly world, when the angels had disputed.”\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
“I receive only the divine revelations, that I am purely a clear Herald of Warning.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
(Remember) When your Lord said to the angels, “I will create a human from clay.” –\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
“So when I have perfected him and breathed into him a spirit from Myself, (you all) fall down before him in prostration.”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
So all the angels prostrated, every one, without exception.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
Except Iblis; he was proud and was, from the beginning, a disbeliever.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
Said Allah, “O Iblis! What prevented you from prostrating before one whom I have created with My hands*? Have you become proud or were you haughty from the beginning?” (Used as a metaphor).\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
Said Iblis, “I am better than him; You made me from fire, and You have created him from clay!”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
He said, “Therefore exit from heaven, for you have been outcast.” (To disrespect the Prophets – peace and blessings be upon them – is blasphemy.)\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
“And indeed My curse is upon you till the Day of Judgement.”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
He said, “My Lord! Therefore give me respite till the day when all will be raised.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmml{%
Said Allah, “You are therefore among those given respite.”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmli{%
“Until the time of the known day.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
He said, “Therefore, by oath of Your honour, I will surely mislead all of them.”\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
“Except Your chosen bondmen among them.”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
Said Allah, “So this is the truth; and I speak only the truth.” –\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
“That I will fill hell with you and with those among them who follow you, all together.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say (O dear Prophet Mohammed – peace and blessings be upon him) “I do not ask any fee from you for the Qur’an, and I am not a fabricator.”\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
“It is not but an advice for the entire world.”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
“And you will come to know of its tidings, after a while.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of the Book is from Allah, the Most Honourable, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
We have indeed divinely revealed the Book to you (O dear Prophet Mohammed – peace and blessings be upon him) with the truth, therefore worship Allah, as His sincere bondman.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Pay heed! Worship is for Allah only; and those who have taken others as their supporters beside Him say; “We worship* them only so that they get us closer to Allah”; Allah will surely judge between them regarding the matter in which they dispute; indeed Allah does not guide one who is a big liar, extremely ungrateful. (*The pagans regarded their idols as smaller Gods and worshipped them. So did the Christians. This does not apply to Muslims who only respect their elders, and ask for their blessings.)\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
Were Allah to create a son* for Himself, He would have chosen any one from His creation! Purity is to Him! He is Allah, the One, the All Dominant. (*Which is impossible.)\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
It is He Who created the heavens and the earth with the truth; He envelops the night over day and envelops the day over night, and He has subjected the sun and the moon; each one runs for its appointed term; pay heed! He only is the Most Honourable, the Oft Forgiving.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
It is He Who created you from a single being, and then from the same being created its spouse, and sent down for you eight pairs of animals; He creates you in your mothers’ wombs, from one sort to another, in a triple darkness; such is Allah, your Lord – for Him only is the kingship; there is no God except Him; so where are you being turned away?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If you become ungrateful, then (know that) indeed Allah is Independent of you; and He does not like the ungratefulness of His bondmen; and if you give thanks, He is pleased with it for you; and no burdened soul will bear another soul’s burden; you have then to return towards your Lord – He will therefore inform you of what you used to do; undoubtedly, He knows what lies within the hearts.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
And when some hardship strikes man, he prays to his Lord, inclined only towards Him – then when Allah grants him a favour from Himself, he forgets why he had prayed to Him earlier, and sets up equals to Allah in order to mislead from Allah’s way; proclaim, “Revel in your disbelief for some days; you are indeed of the people of the fire.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Will he, whose night hours pass in obedience while prostrating and standing, fearing the Hereafter and hoping for the mercy of his Lord, ever be equal to the disobedient? Proclaim, “Are the knowledgeable and the ignorant equal?” It is only the men of intellect who heed advice.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “O my slaves who have accepted faith! Fear your Lord; for those who do good deeds in this world is goodness (in return); and Allah’s earth is spacious; it is the steadfast who will be paid their full reward, without account.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say, “I am commanded that I must worship Allah as His sincere bondman.” (And so must you too.)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
“And I am commanded that I be the first to submit.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say, “Were I to disobey my Lord, I too would fear the punishment of the great Day (of Resurrection).”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Proclaim, “I worship only Allah, as His sincere bondman.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
“Therefore you can worship what you want besides Him!” Say, “The worst losers are those who will lose themselves and their household on the Day of Resurrection; pay heed! This is the plain loss!”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
Above them are mountains of fire and beneath them are mountains of fire; Allah scares His bondmen with this; “O My bondmen! Fear Me!”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
And those who stayed away from the worship of idols, and inclined towards Allah – for them are glad tidings; therefore give glad tidings to My bondmen. –\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
Those who heed attentively and follow the best from it; it is these whom Allah has guided, and it is these who have intelligence.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
So will the one upon whom the Word of punishment has proved true, ever be equal to those who are forgiven? So will you guide and save the one who deserves the fire? (Because the hearts of some disbelievers are sealed).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But for those who fear their Lord, are the high chambers with more high chambers built above them – rivers flowing beneath them; a promise of Allah; Allah does not renege on His promise.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Did you not see that it is Allah Who sent down water from the sky, and then with it made springs in the earth, and then with it produces crops of various colours, and then it dries up and you see it has become yellow, and He then fragments them into small pieces; indeed in this is a reminder for people of intellect.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
So will he whose bosom Allah has opened up for Islam – he is therefore upon a light from his Lord – ever be equal to one who is stone hearted? Therefore ruin is for those whose hearts are hardened towards the remembrance of Allah; they are in open error.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah has sent down the best of Books (the Holy Qur’an), which is consistent throughout, the one with paired statements; the hairs on the skins of those who fear their Lord, stand on end with it; then their skins and their hearts soften, inclined towards the remembrance of Allah; this is the guidance of Allah, He may guide whomever He wills with it; and whomever Allah sends astray, there is no guide for him.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
So will he who will not have a shield except his own face against the wretched punishment on the Day of Resurrection, ever be equal to one who is forgiven? And it will be said to the unjust, “Taste what you have earned!”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those before them had denied, therefore the punishment came to them from a place they did not know.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
So Allah made them taste humiliation in the life of this world; and indeed the punishment of the Hereafter is the greatest; if only they knew!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
And We have indeed illustrated examples of all kinds in this Qur’an, so that they may ponder.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
The Qur’an in Arabic, having no deviation at all, so that they may be pious.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah illustrates an example – “A man having several wicked masters as partners, and another man belonging wholly to just one master; are the two equal in comparison?” All praise is to Allah; in fact, most among them do not know.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
Indeed you (O dear Prophet Mohammed – peace and blessings be upon him) will taste death, and they (the disbelievers) too will die.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
Then you will dispute before your Lord on the Day of Resurrection.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
So who is more unjust than one who fabricates a lie against Allah, and denies the truth when it comes to him? Is not the destination of disbelievers in hell?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And those who brought this truth and those who testify for it – these are the pious.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
For them is whatever they wish, before their Lord; this is the reward of the virtuous.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
So that Allah may relieve them of their worst deeds, and reward them for the best deeds they had done.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Is not Allah Sufficient for His slave? And they threaten you with others beside Him! And whomever Allah sends astray – there is no guide for him.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And no one can mislead whomever Allah guides; is not Allah the Most Honourable, the Avenger?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
And if you ask them, “Who has created the heavens and the earth?”, they will surely say, “Allah”; say, “What is your opinion regarding those whom you worship other than Allah – if Allah wills to cause me some hardship, so will they avert the hardship sent by Him? Or if He wills to have mercy upon me, so will they restrain His mercy?” Proclaim, “Allah is Sufficient for me; the people who trust must rely only upon Him.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Proclaim, “O my people! Keep on with your works in your positions, I am doing mine; so you will soon come to know.” –\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
“To whom will come a punishment that will disgrace, and upon whom descends the punishment that never ends.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
We have indeed sent down this Book to you with the truth, in order to guide mankind; so whoever attains guidance has attained it is for his own good, and whoever strays, has strayed for his own harm; and you are not at all responsible for them.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmc{%
It is Allah Who gives death* to living beings at the time of their demise, and to those who do not die, during their sleep; so He restrains the soul on which the decree of death has been passed, and leaves the other till the appointed term; indeed in this are signs for people who reflect. (*Death is of 2 types – passing to the next world, and sleeping.)\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmci{%
What! Have they chosen intercessors against Allah? Proclaim, “What! Even if they do not own anything nor have any intelligence?”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Proclaim, “To Allah only* belongs all the intercession! For Him only is the kingship of the heavens and the earth; and then it is towards you have to return.” (*Allah does not intercede – He gives the permission to intercede with Him, to whomever He wills.)\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
And when Allah the One God is mentioned, the hearts of those who do not believe in the Hereafter get constricted; and when others (false deities) besides Him are mentioned, they rejoice!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Invoke (O dear Prophet Mohammed – peace and blessings be upon him), “O Allah! The Creator of the heavens and the earth, the All Knowing of all the hidden and the open, You will judge between Your bondmen, regarding the matters in which they differed.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
And if the unjust owned all that is in the earth, and another one in addition to it, they would surely give it in exchange for freedom from the wretched punishment on the Day of Resurrection; and a matter which they had never imagined, appeared to them from their Lord.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
And the evils they earned appeared to them, and the thing they used to mock at descended upon them.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
So when some hardship reaches man, he prays to Us; then later when We bestow a favour upon him, he says, “I obtained this only because of some knowledge”; in fact it is a test, but most of them do not have any knowledge.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Those before them also said the same, so their earnings did not benefit them at all.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
Therefore the evils of their earnings befell them; and those who are unjust among them – soon the evils of the earnings will befall them, and they cannot escape.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Do they not know that Allah eases the sustenance for whomever He wills, and restricts it? Indeed in this are signs for the People who Believe.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “O my* slaves, who have wronged themselves, do not lose hope in Allah’s mercy; indeed Allah forgives all sins; indeed He only is the Oft Forgiving, the Most Merciful.” (All Muslims are truly the slaves of Prophet Mohammed – peace and blessings be upon him.)\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
“And incline towards your Lord and submit to Him, before the punishment comes you and then you may not be helped.”\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
“And follow this, the best among all, which has been sent down towards you from your Lord, before the punishment comes suddenly upon you whilst you are unaware.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
So that no soul may say, “Alas! The failures that I committed regarding Allah – and indeed I used to mock!”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
Or (so that no soul) may say, “If Allah had shown me the right path, I would then be among the pious!”\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
Or (so that no soul) may say when it beholds the punishment, “If only I may be sent back, so that I may do good deeds!”\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
It will be said to him, “Surely yes, why not?* My signs did come to you, so you denied them and you were haughty and you were a disbeliever.” (They will be mocked at.)\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
And you will see on the Day of Resurrection the fabricators of lies against Allah, with their faces blackened; is not the destination of the haughty in hell?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
And Allah will rescue the pious, to their place of salvation; neither will the punishment touch them, nor shall they grieve.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is Creator of all things; and He only is the Controller of all things.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
For Him only are the keys of the heavens and the earth; and those who denied the signs of Allah – it is they who are the losers.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him) “So do you instruct me to worship (deities) other than Allah? You ignorant fools!”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
And it was indeed revealed to you and to those before you; that, “O listener! If you ascribe a partner to Allah, all your deeds will go to waste and you will surely be a loser.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
But rather worship only Allah, and be among the thankful!\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
And they did not realise the importance of Allah as was His right; and on the Day of Resurrection, He will compress the lands and the heavens will be rolled up by His power; Purity and Supremacy are to Him, from all what they ascribe as partners.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
And the Trumpet will be blown, so everyone in the heavens and everyone in the earth will fall unconscious, except whomever* Allah wills; it will then be blown again, thereupon they will get up staring! (*Prophet Moosa and / or some angels).\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the earth will shine bright by the light of its Lord, and the Book will be established, and the Prophets and this Noble Prophet and the witnesses upon them from this nation will be brought, and it will be judged between them with the truth, and they will not be wronged.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
And every soul will be repaid for its deeds in full, and He knows very well what they used to do.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
And the disbelievers will be herded towards hell in groups; to the extent that when they reach it, its gates will be opened, and its guards will say to them, “Did not the Noble Messengers come to you from amongst you, who used to recite to you the verses of your Lord and warn you of confronting this Day?” They will say, “Yes indeed, why not?” But the Word of punishment proved true upon the disbelievers.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It will be said, “Enter the gates of hell to remain in it forever”; so what a wretched destination for the haughty!\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
And the mounts of those who feared their Lord will be led towards Paradise, in groups; to the extent that when they reach it, its gates will be opened and its guards will say to them, “Peace be upon you! You have done well! Therefore enter Paradise, to abide in it forever.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
And they will say, “All praise is to Allah, Who has made His promise to us come true, and has bequeathed us this land, to stay in Paradise wherever we wish!” So what an excellent reward for the performers!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And you will see the angels gathered around the Throne, saying the Purity of their Lord, with praise; and a true judgement will be delivered between the people, and it will be said, “All praise is to Allah, the Lord Of The Creation!”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha-Meem. (Alphabets of the Arabic Language – Allah, and to whomever he reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The revelation of the Book is from Allah, the Most Honourable, the All Knowing.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
The Forgiver of sin, and the Most Acceptor of Repentance, the Severe in Punishing, the Greatly Rewarding; there is no God except Him; towards Him only is the return.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None except the disbelievers dispute the signs of Allah, therefore do not let their free movements in the land deceive you.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
Before them, the people of Nooh and the groups after them had denied; and every nation intended to apprehend its Noble Messenger, and they fought along with falsehood to avert the truth, so I seized them; so how did My punishment turn out?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
And this is how the Word of your Lord has proved true upon the disbelievers that they are people of the hell.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those* who bear the Throne, and those who are around it, say the Purity of their Lord while praising Him, and they believe in Him and seek forgiveness for the believers; “O Our Lord! Your mercy and knowledge encompass all things, therefore forgive those who repented and followed Your path, and save them from the punishment of hell.” (* The angels.)\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
“O Our Lord! And admit them into the Gardens of everlasting stay which you have promised them, and those who are virtuous among their forefathers and their wives and their offspring; indeed You only are the Most Honourable, the Wise.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
“And save them from the evil consequences of sins; and whomever You save from the evil consequences of sins on that Day – so You have indeed had mercy upon him; and this only is the greatest success.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
The disbelievers will indeed be called out to – “Indeed Allah’s disgust with you is greater than your own abhorrence of yourselves, whereas you used to deny when you were called towards the faith!”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They will say, “O Our Lord! Twice You have given us death and twice You have given us life* – we now confess to our sins – so is there a way out of the fire?” (From nothingness to life in this world, to death and then Resurrection.)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
“This has occurred because when Allah the One was prayed to, you used to disbelieve; and when a partner was ascribed with Him, you used to believe; so the command is only for Allah, the Supreme, the Great.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
It is He Who shows you His signs, and sends down sustenance from the sky for you; and none accept guidance except those who incline (towards Him).\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
Therefore worship Allah, as His sincere bondmen even if the disbelievers get annoyed.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
Bestower of High Ranks, Owner of the Throne; it is He Who instils the spirit of faith into the one He wills among His bondmen, in order that he may warn of the Day of Meeting. –\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
A day when they will be fully exposed; nothing from their affairs will be hidden from Allah; “For whom is the kingship this day? For Allah, the One, the All Dominant.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
This day each soul will be repaid for what it has earned; no one will be wronged this day; indeed Allah is Swift At Taking Account.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
And warn them of the day of impending calamity, when hearts will rise up to the throats filled with grief; and the disbelievers will have neither any friend nor any intercessor who will be obeyed. (Intercession will be accepted only for the Muslims, not for the disbelievers)\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
Allah well knows the covert glance and all what lies hidden in the hearts.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
And Allah renders the true judgement; and those whom they worship instead of Him do not judge at all; indeed Allah only, is the All Hearing, the All Seeing.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
So did they not travel in the land in order to see what sort of fate befell those before them? Their strength and the signs they left behind in the earth, exceeded them – so Allah seized them on account of their sins, and they had no one to save them from Allah.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
This occurred because their Noble Messengers came to them with clear signs, thereupon they used to disbelieve, so Allah seized them; indeed Allah is All Powerful, Severe in Punishment.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
And indeed We sent Moosa with Our signs and a clear proof.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
Towards Firaun and Haman and Qaroon – in response they said, “(He is) a magician, a big liar!”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
So when he brought the truth from Our presence to them, they said, “Kill the sons of those who believe in him, and keep their women alive”; and the evil scheme of the disbelievers only keeps wandering astray.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
And said Firaun, “Allow me to kill Moosa and let him pray to his Lord; I fear that he will change your religion or cause chaos in the land!”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
Said Moosa, “I seek the refuge of mine and your Lord, from every haughty person who does not believe in the Day of Reckoning.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
And said a Muslim man from the people of Firaun, who used to hide his faith, “What! You want to kill a man just because he says, ‘Allah is my Lord’ whereas he has indeed brought clear signs to you from your Lord? And supposedly if he is speaking wrongly, then the calamity of wrongful speech is upon him; and if he is truthful, then part of what he promises you will reach you; indeed Allah does not guide any transgressor, excessive liar.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
“O my people! You now rule the earth, dominant; so who will save us from Allah’s punishment if it comes upon us?” Said Firaun, “I only explain to you what I think is correct, and I show you only the right path.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
And the believer said, “O my people! I fear for you a day similar to that of the earlier groups!”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
“Like the tradition of the people of Nooh, and Aad, and Thamud and others after them; and Allah does not will injustice upon bondmen.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
“O my people! I fear for you a day on which will be a great outcry!”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
“A day when you will turn back fleeing; none can save you from Allah; and whomever Allah sends astray, there is no guide for him.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
“And indeed Yusuf came to you with clear signs before this, thereupon you remained doubtful concerning what he had brought; to the extent that when he died, you said, ‘Allah will surely not send any Noble Messenger after him’”; this is how Allah sends astray whoever transgresses, is doubtful. –\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
Those who dispute regarding the signs of Allah without any proof having come to them; how very disgusting this is, in the sight of Allah and in the sight of the believers! This is how Allah seals the entire heart of every haughty, rebellious person.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
And said Firaun, “O Haman! Build a high palace for me, in order that I may reach the routes.” –\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
“The routes of the heavens, in order to glance at the God of Moosa – and indeed I think he is a liar”; this is how the evil deeds of Firaun were made seeming good to him, and he was stopped from the path; and the evil scheme of Firaun was destined to be ruined.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
And the believer said, “O my people! Follow me, I shall show you the way of righteousness.”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
“O my people! The life of this world is just a brief usage, and indeed the next abode is one of everlasting stay.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
“Whoever commits an evil deed will not be repaid except to the same extent; and whoever does good deeds, whether a man or a woman, and is a Muslim, will be admitted into Paradise, in which they will receive sustenance without account.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
“And O my people! What is the matter with me that I call you towards salvation whereas you call me towards hell?”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
“You call me to disbelieve in Allah and ascribe such as partners to Him, regarding whom I do not have any knowledge – whereas I call you towards the Most Honourable, the Oft Forgiving!”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
“So it is self evident that what you call me towards has no benefit being prayed to, either in this world or in the Hereafter, and that our return is towards Allah, and that the transgressors only are the people of the fire.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
“And soon the time will come when you will remember what I now say to you; and I entrust my tasks to Allah; indeed Allah sees the bondmen.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
Therefore Allah saved him from the evils of their scheming, and an evil punishment enveloped the people of Firaun. –\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
The fire – upon which they are presented morning and evening; and when the Last Day is established – “Put the people of Firaun into the most severe punishment.” (Punishment in the grave is proven by this verse.)\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
And when they will quarrel amongst themselves in the fire, those who were weak will say to those who sought greatness, “We were your followers, so will you reduce from us some of the punishment of the fire?”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who were proud will say, “We are all in the fire – indeed Allah has already passed the judgement among the bondmen.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those who are in the fire said to its guards, “Pray to your Lord to decrease the punishment upon us for one day.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They said, “Is it not that your Noble Messengers used to come to you with clear signs?” They said, “Why not, surely yes!” They said, “Then you yourselves pray”; and the prayer of the disbelievers is nothing but astray.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Indeed We will surely help Our Noble Messengers, and the believers, in the life of this world and on the day when the witnesses will be standing.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
The day on which the unjust will not gain any benefit from their excuses, and for them is the curse, and for them is the wretched home.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
And indeed We gave Moosa the guidance, and bequeathed the Book to the Descendants of Israel.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
A guidance and an advice for the people of intellect.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
Therefore be patient (O dear Prophet Mohammed – peace and blessings be upon him), undoubtedly Allah’s promise is true, and seek forgiveness for the sins of your own people, and praising your Lord, proclaim His Purity morning and evening.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Those who dispute concerning the signs of Allah without any proof having come to them – in their hearts is nothing but a craving for greatness which they shall never achieve; therefore seek the refuge of Allah; indeed He only is the All Hearing, the All Seeing.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
Certainly the creation of the heavens and the earth is far greater than the creation of men, but most people do not know.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
And the blind and the sighted are not equal – and neither are the believers who perform good deeds and the wicked equal; how very little do you ponder!\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
Indeed the Last Day will surely come, there is no doubt in it – but most people do not accept faith.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
And your Lord proclaimed, “Pray to Me, I will accept; indeed those who stay conceited towards worshipping Me, will enter hell in disgrace."\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
It is Allah Who created night for you so that you may gain rest in it, and the day giving sight; indeed Allah is Most Munificent towards mankind, but most people do not give thanks.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
Such is Allah, your Lord, the Creator of all things; there is no God except Him; so where are you reverting?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
This is how those who deny the signs of Allah go reverting.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
It is Allah Who made for you the earth your resting place and the sky a canopy, and moulded you so gave you the best shape, and gave you pure things for sustenance; such is Allah, your Lord; so Most Auspicious is Allah, the Lord Of The Creation.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
It is He, the Alive – there is no God except Him; therefore worship Him as His sincere bondmen; all praise is to Allah, the Lord Of The Creation.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “I have been forbidden to worship those whom you worship besides Allah whilst clear proofs have come to me from my Lord; and I have been commanded to submit to the Lord Of The Creation.”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
It is He Who created you from clay, then from a drop of liquid, then from a clot of blood, and then brings you forth as a child, then keeps you alive for you to reach adulthood and then to become old; and some among you pass away earlier, and for you to reach an appointed term, and so that you may understand.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
It is He Who gives life and death; so whenever He wills a thing, He only says to it “Be” – it thereupon happens!\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Did you not see those who dispute concerning the signs of Allah? Where are they being diverted?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who denied the Book and what We sent with Our Noble Messengers; so they will soon come to know. –\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When around their necks will be shackles and chains; they will be dragged. –\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
In boiling water; they will then be ignited* in the fire. (Like fuel – see verse 2:24)\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
It will then be said to them, “Where are the partners you used to appoint?” –\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
“As rivals to Allah?”; they will say, “We have lost them – in fact we never used to worship anything before!”; this is how Allah sends the disbelievers astray.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
“This is the recompense of your being happy upon falsehood in the earth, and the recompense of your conceit.”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
“Enter the gates of hell, to remain in it forever”; so what a wretched destination for the haughty!\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
Therefore be patient (O dear Prophet Mohammed – peace and blessings be upon him), undoubtedly Allah’s promise is true; and whether We show some of what We promise them, or cause you to pass away before it – in any case they will return to Us.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
Indeed We sent many Noble Messengers before you, so We have related to you the affairs of some among them, and not related the affairs of some; and no Noble Messenger has the right to bring any sign except with the command of Allah; so the time when the command of Allah comes, the true judgement will be delivered and there will the people of falsehood be ruined.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
It is Allah Who created the animals for you, in order for you to ride some of them, and some to eat.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
And in them are numerous benefits for you, and for you to reach your hearts’ desires while riding them – and you ride upon them and upon the ships.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He shows you His signs; so which sign of Allah will you deny?\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Did they not travel in the land to see what sort of fate befell those before them? They were more than these in number, and they exceeded them in strength and the signs they left behind in the earth – so what benefit did they get from what they earned?\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
So when their Noble Messengers came to them with clear signs, they remained happy over the worldly knowledge they possessed, and upon them only reverted what they used to mock at!\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
So when they saw Our punishment, they said, “We accept faith in the One Allah, and reject those whom we ascribed with Him.”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
So their accepting of faith did not benefit them when they saw Our punishment; the tradition of Allah which has passed among His bondmen; and there were the disbelievers ruined.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha-Meem. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
This (Qur’an) is sent down from the Most Gracious, the Most Merciful.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Book the verses of which are explained in detail, the Qur’an in Arabic for people of intellect.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
Giving glad tidings and heralding warning; so most of them turned away, therefore they cannot listen (to the truth).\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
And they say, “Our hearts are covered against the affair you call us to, and there is deafness in our ears, and there is a barrier between us and you – therefore mind your own business, we are minding ours.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Physically I am a human like you – I receive the divine revelation that your God is only One God, therefore be upright towards Him and seek forgiveness from Him”; and woe is to the polytheists. –\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
Those who do not give the obligatory charity, and who deny the Hereafter.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
Indeed for those who believed and did good deeds, is a limitless reward.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say “What! You disbelieve in Him Who created the earth in two days, and you appoint equals to Him? He is the Lord Of The Creation!”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
And in it He placed mountains as anchors from above it, and blessings in it, and appointed the sustenance for those who dwell in it – all this in four days; a proper answer to those who question.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
He then inclined towards the heavens and it was smoke – thereupon He said to it and to the earth, “Both of you present yourselves, willingly or with reluctance”; they said, “We present ourselves, with zeal.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
He then established them into seven heavens in two days, and to each heaven He sent the command of its affairs; and We decorated the lower heaven with lamps; and for its protection; this is the command set by the Most Honourable, the All Knowing.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
Then if they turn away say, “I warn you of a thunderbolt like the thunderbolt which came upon A’ad and Thamud.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
When their Noble Messengers approached them from front and from behind saying, ``Do not worship any one except Allah"; they said, ``If our Lord willed, He would surely have sent down angels – we therefore deny whatever you have been sent with.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
So regarding the A’ad, they were haughty in the land without right, and they said, “Who is more powerful than us?” Did they not realise that Allah, Who created them, is more powerful than them? And they used to deny Our signs.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
We therefore sent a violent thunderstorm towards them in their days of misfortune, in order to make them taste a disgraceful punishment in the life of this world; and indeed the punishment of the Hereafter is more disgracing, and they will not be helped.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
And regarding the Thamud, We showed them the right path – so they chose to be blind above being guided, therefore the thunderbolt of the disgraceful punishment overcame them – the recompense of their deeds.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
And We rescued those who accepted faith and were pious.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
And on the day when the enemies of Allah are herded towards the fire, the earlier groups will be restrained till the latter join them.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
To the extent that when they reach it, their ears and their eyes and their skins will testify against them for what they used to do.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
And they will say to their skins, “Why did you testify against us?"; they will say, “Allah has made us talk, Who has given all things the power of speech, and it is He Who created you the first time, and it is to Him that you have to return.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
And where could you hide from Him, so that your ears and your eyes and your skins may not testify against you? But you had assumed that Allah does not know most of your deeds!\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
And this is the assumption you had regarding your Lord, which has ruined you, so you are now among those who have been defeated.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
Then if they are patient, even then the fire is their home; and if they plead, none will listen to their pleading.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
And We appointed companions for them, who made what is before them and what is after them seem good to them, and the Word proved true upon them along with the groups of jinns and men who passed away before them; they were indeed losers.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
And the disbelievers said, “Do not listen to this Qur’an and engulf it in noise – perhaps you may be victorious this way.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
So We will indeed make the disbelievers taste the severe punishment, and indeed We will repay them for their worst deeds.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
This is the recompense of Allah’s enemies – the fire; they have to stay in it forever; the penalty for denying Our signs.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
And the disbelievers said, “Our Lord! Show us both – among jinns and men – who misled us, for us to put them beneath our feet so that they be the lowest of the low.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Indeed those who said, “Allah is our Lord” and remained firm upon it – upon them descend the angels, (saying), “Do not fear nor grieve, and be happy for the Paradise which you are promised.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
“We are your friends in the life of this world and in the Hereafter; in it for you is all that you may wish for, and for you is all what you ask.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
“The hospitality of the Oft Forgiving, Most Merciful.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And whose speech is better than one who calls towards his Lord and does righteous deeds, and says, “I am a Muslim.”?\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
And the good deed and the evil deed will never be equal; O listener! Repel the evil deed with a good one, thereupon the one between whom and you was enmity, will become like a close friend.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
And none receive this great treasure except those who are patient; and none receives this except one who is extremely fortunate.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
And O listener! If a distracting thought from the devil reaches you, seek the refuge of Allah; indeed He is the All Hearing, the All Knowing.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And the night, and the day, and the sun, and the moon are among His signs; do not prostrate for the sun or the moon, but prostrate for Allah Who has created them, if you are His bondmen.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
So if these (disbelievers) be haughty, so (in any case) those (the angels) who are with your Lord say His Purity night and day, and they do not get weary. (Command of prostration \# 11)\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And among His signs is that you see the earth lying neglected, so when We sent down water on it, it freshened up and grew forth; indeed He Who gave it life, will revive the dead; indeed He is Able to do all things.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Indeed those who distort Our verses are not hidden from Us; so is one who is cast into the fire better, or one who comes in safety on the Day of Resurrection? Do whatever you wish! He is indeed seeing your deeds.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Indeed those who denied the Remembrance when it came to them – they are truly ruined; and indeed it is an honourable Book.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
Falsehood cannot approach it – neither from its front nor from its back; it is sent down by the Wise, the Most Praiseworthy.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
You will not be told except what was said to the Noble Messengers before you; that “Your Lord is the Owner of Forgiveness, and the Owner of Painful Punishment.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
And if We had made it as a Qur’an in a foreign language they would have certainly said, “Why were its verses not explained in detail?” What! The Book in a foreign language, and the Prophet an Arab?! Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “It is a guidance and a cure for the believers”; and there is deafness in the ears of those who do not believe, and it is blindness upon them; as if they are being called from a place far away!\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
And We indeed gave the Book to Moosa, so a dispute was created regarding it; and were it not for a Word that had already gone forth from your Lord, the judgement would have been immediately passed upon them; and indeed they are in an intriguing doubt regarding it.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whoever does good deeds, so it is for his own good, and whoever commits evil, so it is for his own harm; and your Lord does not at all oppress the bondmen.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
The knowledge of the Last Day is directed towards Him; and no fruit comes out from its cover, and nor does any female conceive or give birth, but with His knowledge; and on the day when He will call out to them, “Where are My partners?” They will say, “We have told you that none among us can testify.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
And they have lost what they used to worship before, and be sure, they do not have a place to escape.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man does not weary of seeking goodness; and if some misfortune reaches him, he loses hope, gets disappointed.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And if We make him taste Our mercy after the hardship which befell him, he will say, “This is mine! And I do not think that the Last Day will ever be established – and even if I am returned to my Lord, with Him is only goodness for me”; so We shall indeed inform the disbelievers of what they did; and We shall indeed make them taste a solid punishment.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
And when We favour man, he turns away and goes back afar; and when some hardship reaches him, he comes with a vast prayer!\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “What is your opinion – if this Qur’an is from Allah and then you deny it – so who is more astray than whoever is in extreme opposition?”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
We shall now show them Our signs in all the directions and within their own selves until it becomes clear to them that it is certainly the truth; is not your Lord sufficient as a Witness over all things?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Pay heed! They are certainly doubtful regarding the meeting with their Lord; pay heed! He encompasses all things!\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha-Meem. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
A’in-Seen-Qaf. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
This is how Allah the Most Honourable, the All Knowing sends the divine revelation to you (O dear Prophet Mohammed – peace and blessings be upon him) and to those before you.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
To Him only belongs all whatever is in the heavens and all whatever is in the earth; and He is the Supreme, the Greatest.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
The heavens nearly split apart from above – and the angels say the Purity of their Lord while praising Him, and seek forgiveness for those on earth; pay heed! Indeed Allah only is the Oft Forgiving, the Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
And Allah is watching those who have chosen supporters besides Him; and you are not responsible for them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
And this is how We have divinely revealed to you the Qur’an in Arabic, for you to warn the people of the mother of all towns – Mecca – and those around it, and to warn of the Day of Assembling of which there is no doubt; a group is in Paradise, and another group is in hell.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
And had Allah willed, He could have made them all upon one religion, but He admits whomever He wills into His mercy; and the unjust do not have any friend nor any supporter.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
What! Have they appointed supporters other than Allah? So (know that) Allah only is the Supporter, and He will revive the dead; and He is Able to do all things.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
“The final decision for the matters in which you differ rests with Allah; such is my Lord – I rely on Him; and towards Him do I incline.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
The Maker of the heavens and the earth; He has created pairs for you from yourselves and pairs from the animals; He spreads your generation; nothing is like Him; and He only is the All Hearing, the All Seeing.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
For Him only are the keys of the heavens and the earth; He increases the sustenance for whomever He wills and restricts it; indeed He is the All Knowing.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He has kept for you the same path of religion which He commanded Nooh, and what We divinely reveal to you (O dear Prophet Mohammed – peace and blessings be upon him), and what We had commanded to Ibrahim and Moosa and Eisa that, “Keep the religion proper, and do not create divisions in it”; the polytheists find the matter what you call them to as intolerable; Allah chooses for His proximity whomever He wills, and guides towards Himself whoever inclines (towards Him).\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
And they did not cause divisions except after the knowledge had come to them, because of jealousy among themselves; and were it not for a Word that had already gone forth from your Lord, the judgement would have been passed upon them long ago; and indeed those who inherited the Book after them are in an intriguing doubt regarding it.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
For this reason, call them (to Islam); and remain firm, as you are commanded to; and do not follow their desires; and say, “I accept faith in whichever Book Allah has sent down; and I am commanded to judge fairly between you; Allah is the Lord of all – ours and yours; for us are our deeds and for you are your misdeeds; there is no debate between us and you; Allah will gather all of us together; and towards Him is the return.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
And those who fight regarding Allah after the Muslims have accepted His call, their reasoning does not hold at all before their Lord, and upon them is wrath, and for them is a severe punishment.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
It is Allah Who has sent down the Book with the truth, and the Scales of Justice; and what do you know – possibly the Last Day could really be near!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those who do not believe in it are impatient for it, and those who believe in it fear it and know that indeed it is the truth; pay heed! Those who doubt the Last Day are certainly in extreme error.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Allah is Benevolent upon His bondmen – He bestows sustenance to whomever He wills; and He only is the All Powerful, the Most Honourable.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whoever aspires for the yield of the Hereafter – We increase its yield for him; and whoever aspires for the yield of this world – We give him part of it, and he has no portion in the Hereafter.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Or do they have associate deities who have appointed for them a religion, which Allah has not permitted? And were it not for a Word that had already been decided, the judgement would have been passed between them here itself; and indeed for the unjust is a painful punishment.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
You will see the unjust getting terrified of their own deeds, and (evil of) their deeds will certainly befall them; and (that) those who accepted faith and performed good deeds are in blossoming Gardens of Paradise; for them is whatever they wish from their Lord; this only is the great munificence (of Allah).\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
This is what Allah gives the glad tidings of to His bondmen who accept faith and do good deeds; say (O dear Prophet Mohammed – peace and blessings be upon him) “I do not ask any fee from you upon this, except the love between close ones”; and whoever performs a good deed – We further increase the goodness in it for him; indeed Allah is Oft Forgiving, Most Appreciative.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
What! They dare say that, “He has fabricated a lie against Allah”? And if Allah wills, He can seal your heart by His mercy and protection*; and Allah wipes out falsehood and proves the truth by His Words; indeed He knows what lies within the hearts. (* So that you may not be agonised by what they do).\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
And it is He Who accepts repentance from His bondmen, and pardons sins*, and knows all your deeds. (Repentance for the cardinal sins, while lesser sins are wiped out by good deeds.)\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And He accepts the prayers of those who accept faith and do good deeds, and gives them a greater reward by His munificence; and for the disbelievers is a severe punishment.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
And had Allah increased the sustenance for all His slaves, they would have surely caused turmoil in the land, but He sends it down by a proper assessment as He wills; indeed He is Well Aware of, Seeing His bondmen.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
And it is He Who sends down the rain when they have despaired, and spreads out His mercy; and He is the Benefactor, the Most Praiseworthy.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And among His signs is the creation of the heavens and the earth, and the moving creatures dispersed in it; and He is Able to gather them whenever He wills.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
And whatever calamity befalls you, is because of what your hands have earned – and there is a great deal He pardons!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
And you cannot escape in the earth; and you have neither a friend nor any supporter against Allah.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And among His signs are the ships sailing on the sea, like hills.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If He wills, He can calm the winds so the ships remain still on the sea surface; indeed in this are signs for every greatly enduring, grateful person.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He can ruin them due to peoples’ sins and He can forgive a great deal.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
And for those who dispute regarding Our signs to realise; that they do not have a place to escape to.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
Whatever you have received is only for usage in the life of this world, and that which is with Allah is much better and more lasting – for those who believe and rely upon their Lord.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And (for) those who avoid cardinal sins and indecencies, and forgive (even) when they are angry.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
And those who obeyed the command of their Lord and kept the prayer established; and whose affairs are with mutual consultation; and who spend in Our cause from what We have bestowed upon them.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
And those who take revenge when rebellion harms them.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The retribution of a harmful deed is the harm equal to it; so whoever forgives and makes amends, so his reward is upon Allah; indeed He does not befriend the unjust.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
And there is no way of reproach against those who take revenge after being wronged.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
Reproach is only against those who oppress people, and wrongfully spread rebellion in the land; for them is a painful punishment.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
And indeed whoever patiently endured and forgave – then indeed these are acts of great courage.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
And whomever Allah sends astray, there is no friend for him against Allah; and you will see the unjust when they behold the punishment saying, “Is there a way to return?”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And you will see them being presented upon the fire, cowering with disgrace watching with concealed eyes; and the believers will say, “Indeed ruined are those who have lost themselves and their families on the Day of Resurrection”; pay heed! Indeed the unjust are in a punishment that will never end.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
And they had no friends to help them against Allah; and there is no way for one whom Allah sends astray.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Obey your Lord before the advent of a Day from Allah, which cannot be averted; you will not have any refuge on that day, nor will you be able to deny.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
So if they turn away from you, We have not sent you as a guardian over them; upon you is nothing but to convey (the message); and when We make man taste some mercy from Us, he rejoices upon it; and if some harm reaches them because of what their own hands have sent before, thereupon man is ungrateful!\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
For Allah only is the kingship of the heavens and the earth; He creates whatever He wills; He may bestow daughters to whomever He wills, and sons to whomever He wills.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or may mix them, the sons and daughters; and may make barren whomever He wills; indeed He is All Knowing, Able.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
And it is not for any human that Allah may speak to him except as a divine revelation or while the human is on this side of the veil of greatness, or that He sends an angel to reveal by His permission, whatever He wills; indeed He is Supreme, Wise.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
And this is how We sent the divine revelation to you (O dear Prophet Mohammed – peace and blessings be upon him) – a life giving thing, by Our command; neither did you know the Book nor the detailed commands of religion, but We have made this Qur’an a light by which We guide whomever We will from Our bondmen; and indeed you surely do guide to the Straight Path.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The path of Allah – the One to Whom only belongs all whatever is in the heavens and all whatever is in the earth; pay heed! Towards Allah only do all matters return.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha-Meem. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By oath of the clear Qur’an.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
We have indeed sent it as a Qur’an in the Arabic language, so that you may understand.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
And the Qur’an is undoubtedly, in the Original Book with Us, surely the exalted, full of wisdom.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
So shall We divert the advice away from you, because you are a nation that exceeds the limits?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
And how many Prophets We did send among the earlier people!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
And whenever any Prophet came to them, they only mocked at him.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
We therefore destroyed the people who were more forceful than these, and the example of the earlier ones has already gone by.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
And if you ask them, “Who has created the heavens and the earth?”, they will surely say, “They are created by the Most Honourable, the All Knowing.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
The One Who made the earth a bed you, and made roads for you in it, so that you may be guided.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
And Who sent down water from the sky with a proper measure, so We revived a dead city with it; this is how you will be taken out.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
And the One Who created all pairs, and made the ships and cattle as rides for you.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
So that you may properly mount their backs, and may remember your Lord’s favour when you have mounted them, and say, “Purity is to Him, Who has given this ride in our control, and we did not have the strength for it.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
“And indeed we have to return to our Lord.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
And from* His bondmen, they appointed a portion for Him; man is indeed an open ingrate. (* Appointed some of His creation as His sons and daughters).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Has He chosen daughters for Himself from His creation, and selected only sons for you?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
And if one of them is given the glad tidings of what he professes regarding the Most Gracious, his face blackens and he is mournful!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
And (do they chose for Him) one who is brought up among ornaments, and cannot express herself clearly in debate?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they appoint the angels, who are the bondmen of the Most Gracious, as females; were they present at the time of the angels’ creation? Their declaration will be now recorded and they will be questioned.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
And they say, “If the Most Gracious had willed, we would not have worshipped them!” They do not know its truth at all; they only make guesses.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or have We given them some Book before this, to which they hold fast?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Rather they said, “We found our forefathers upon a religion, and we are following their footsteps.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
And similarly, whenever We sent a Herald of Warning before you (O dear Prophet Mohammed – peace and blessings be upon him) into any town, its wealthy people said, “We found our forefathers upon a religion, and we are behind their footsteps.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
The prophet said, “What! Even if I bring to you a path better than what you found your forefathers following?”; they said, “We do not believe in whatever you have been sent with.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So We took revenge from them – therefore see what sort of fate befell those who denied!\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
And when Ibrahim said to his father and his people, “I have no relation whatsoever with your deities.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
“Except Him Who has created me, for He will soon direct me.” (To my place of migration.)\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And Ibrahim kept this declaration among his progeny, in order that they may desist.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
In fact I gave them and their forefathers the usage of this world until the truth and the Noble Messenger who conveyed the message clearly, came to them.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
And when the truth came to them they said, “This is magic, and we disbelieve in it.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
And they said, “Why was the Qur’an not sent down upon some chieftain of these two great towns?” (The chiefs of Mecca and Taif).\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Are they the distributors of your Lord’s mercy? We have distributed among them their comforts in the life of this world, and gave high status to some over others so that they mock at each other; and the mercy of your Lord is better than all what they hoard.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
And were it not for that all people be on one religion, We would have made for the disbelievers of the Most Gracious, roofs and stairs of silver which they would climb.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
And doors of silver for their houses and couches of silver upon which they would recline.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
And diverse adornments; and all this is usage only of the life of this world; and the Hereafter with your Lord, is for the pious.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
And whoever is averse to the Remembrance of the Most Gracious, We appoint a devil upon him, who stays with him.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
And indeed those devils prevent them from the Straight Path, and they think they are on guidance!\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
To the extent that when the disbeliever will be brought to Us, he will say to his devil, “Alas – if only there was the distance* of east and west, between you and me!” – so what an evil companion** he is! (* Had I not listened to you. **They will be bound together in chains.)\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
(It will be said to them) “And you will not benefit from them this day, whereas you are unjust – for you are all partners in the punishment.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
So will you make the deaf listen or show the path to the blind, and to those who are in open error? (The disbelievers whose hearts are sealed, are deaf and blind to the truth).\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
So if We take you away, We shall then indeed take revenge from them.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
Or show you what We have promised them – We therefore have complete control over them.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
Therefore hold fast to what We have divinely revealed to you; indeed you are upon the Straight Path. (The Holy Prophets can never go astray).\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
And it is undoubtedly an honour for you and your people; and you will soon be questioned.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
And ask them – did any of the Noble Messengers We sent before you, appoint any other Gods except the Most Gracious, whom they used to worship?\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
And indeed We sent Moosa along with Our signs towards Firaun and his chieftains – he therefore said, “Indeed I am a Noble Messenger of the Lord of the Creation.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
So when he brought Our signs to them, they started mocking at them!\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
And all the signs We showed them were always greater than the earlier ones; and We seized them with calamities, so that they may return.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
And they said, “O you magician! Pray for us to your Lord, by the means of His covenant which is with you; we will certainly come to guidance.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
So when We averted the calamity from them, they immediately broke the promise!\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And said Firaun, “O my people! Is not the kingdom of Egypt for me, and these rivers that flow beneath me? So do you not see?”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
“Or that I am better than him, for he is lowly – and he does not seem to talk plainly.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
“So why was he not bestowed with armlets of gold? Or angels should have come with him staying at his side!”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
So when he had brainwashed his people, they followed him; indeed they were a disobedient nation.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
So when they made Us wrathful, We took revenge from them – We therefore drowned all of them.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
So We made them a bygone fable and a lesson for the latter generations.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
And when the example of the son of Maryam is given, your people laugh at it!\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
And they say, “Are our deities better or he?” They did not say this to you except to unjustly argue; in fact they are a quarrelsome people.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He is purely a bondman (of Ours), whom We have favoured upon, and We made him an extraordinary example for the Descendants of Israel.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
And if We willed, We could have established angels on the earth instead of you.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
And indeed Eisa is a sign* of the Last Day, therefore do not ever doubt in the Last Day, and obey Me**; this is the Straight Path. (* The advent of Prophet Eisa to earth for the second time. ** By obeying the Noble Messenger.)\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
And do not ever let the devil stop you; he is indeed your open enemy.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
And when Eisa came to them with clear signs, he said, “I have come to you with wisdom, and to explain to you some of the matters regarding which you dispute; therefore fear Allah, and obey me.”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
“Allah is indeed my Lord, and yours – therefore worship Him; this is the Straight Path.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
Then the groups differed amongst themselves; therefore ruin is for the unjust by the punishment of an agonising day.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
What are they waiting for – except the Last Day, that it may suddenly come upon them while they are unaware?\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
Close friends will turn into enemies of one another on that Day, except the pious.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
To such will be said, “O My bondmen! This day there shall be no fear upon you, nor any grief.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
Those who believed in Our signs, and were Muslims.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
“Enter Paradise – you and your wives – and you will be honoured guests.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
“Rounds of golden cups and wine will be presented upon them; and in it is whatever the hearts wish for, and what pleases the eye; and you will stay in it forever.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
“And this is the Paradise which is bequeathed to you, because of your deeds.”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
“For you are many fruits in it, for you to eat therefrom.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
Indeed the criminals will stay in the punishment of hell forever.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
And it will never be lightened upon them, and they will remain in it devastated.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
And We did not oppress them at all, but they themselves were unjust.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
And they will cry out, “O Malik*, ask your Lord to finish us!” He will answer, “Rather you are to stay (forever).” (*The guard of hell)\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
Indeed We have brought the Truth to you, but most of you detest the Truth.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Do they assume that they have made their work thorough? So We shall make Our work thorough.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Do they fancy that We do not listen to their whispers and their counselling? Why not, We surely do! And Our angels are with them, writing down.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “If supposedly, the Most Gracious had an offspring* – I would be the first to worship!” (*Which is impossible)\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Purity is to the Lord of the heavens and the earth, the Lord of the Throne, from all what they fabricate.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
Therefore leave them to utter vile speech and to play, until they confront the day which they are promised.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
And only He is the God of the heavenly creation and the God of the earthly creation; and He only is the Wise, the All Knowing.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
And Most Auspicious is He, for Whom is the kingship of the heavens and the earth and all that is between them; and only with Him is the knowledge of the Last Day; and towards Him you are to return.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
And those whom they worship besides Allah do not have the right of intercession – the right of intercession is only for those who testify to the Truth and have knowledge.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
And if you ask them as to Who created them, they will surely answer “Allah” – so where are they reverting?\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
And by oath of the saying of My Prophet “O my Lord! These people do not accept faith!”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
Therefore excuse them and proclaim, “Peace”; for they will soon come to know.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha-Meem. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By oath of this clear Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
We have indeed sent it down in a blessed night – indeed it is We Who warn.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
During it are distributed all the works of wisdom.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
By a command from Us – indeed it is We Who send.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
A mercy from your Lord; indeed He only is the All Hearing, the All Knowing.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
The Lord of the heavens and the earth and all that is between them; if you people believe.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no worship except for Him – He gives life and causes death; your Lord and the Lord of your forefathers.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Rather they are in doubt, playing.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
So you await the day when the sky will bring forth a visible smoke. –\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
Which will envelop the people; this is a painful punishment.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
Thereupon they will say, “O our Lord! Remove the punishment from us – we now accept faith.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
How is it possible for them to accept guidance, whereas a Noble Messenger who speaks clearly has already come to them?\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
Whereas they had then turned away from him and said, “He is a madman, tutored!”?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
We now remove the punishment for some days – so you will again commit the same.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
The day when We will seize with the greatest seizure – We will indeed take revenge.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
And before them We indeed tried the people of Firaun, and an Honourable Noble Messenger came to them.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
Who said, “Give the bondmen of Allah into my custody; I am indeed a trustworthy Noble Messenger for you.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
And saying, “And do not rebel against Allah; I have brought a clear proof to you.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
“And I take the refuge of my Lord and yours, against your stoning me.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
“And if you do not believe in me, then have no relation with me.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
He therefore prayed to his Lord, “These are a guilty nation!”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
We commanded him, “Journey with My bondmen in a part of the night – you will be pursued.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
“And leave the sea as it is, parted in several places; indeed that army will be drowned.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How many gardens and water-springs they left behind!\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
And fields and grand palaces!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
And favours amongst which they were rejoicing!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
That is what We did; and We made another nation their heirs.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
So the heavens and the earth did not weep for them, and they were not given respite.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
And indeed We rescued the Descendants of Israel from a disgraceful torture.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
From Firaun; he was indeed proud, among the transgressors.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
And We knowingly chose them, among all others of their time.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And We gave them signs in which lay clear favours.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
Indeed these disbelievers proclaim; –\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
“There is nothing except our dying just once, and we will not be raised.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
“Therefore bring back our forefathers, if you are truthful!”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better, or the people of Tubba? And those who were before them? We destroyed them; they were indeed criminals.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
And We did not create the heavens and the earth, and all that is between them, just for play.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We did not create them except with the truth, but most of them do not know.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
Indeed the Day of Decision is the appointment for all of them.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
The day on which, no friends will benefit each other at all, nor will they be helped. (Except those who are pious – see verse 43:67)\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
Except those upon whom Allah has mercy; indeed He only is the Most Honourable, the Most Merciful.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
Indeed the tree of Zaqqum, –\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
Is the food of the sinners.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like molten copper; it churns in their bellies.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
Like the churning of boiling water.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
“Seize him, and forcibly drag him right to the blazing fire.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
“Then pour on his head the punishment of boiling water.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
Saying “Taste it! Indeed you only are the most honourable, the dignified!”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
“Indeed this is what you used to doubt about.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Indeed the pious are in a place of peace.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
In Gardens and water-springs.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
They will be dressed in fine silk and embroidery, facing one another (on thrones).\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
So it is; and We have wedded them to maidens with gorgeous eyes.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
In it they will ask for all kinds of fruit, with safety.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
They will not taste death again in it, except their former death; and Allah has saved them from the punishment of fire.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
By the munificence of your Lord; this is the great success.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
And We have made this Qur’an easy in your language, for them to understand.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
Therefore wait (O dear Prophet Mohammed – peace and blessings be upon him) – they too are waiting.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha; Meem. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The sending down of the Book is from Allah, the Most Honourable, the Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Indeed in the heavens and the earth are signs for believers.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
And in your creation, and all the creatures He scatters in the earth – in them are signs for the people who are certain.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
And in the alternation of night and day, and in the means of sustenance – water – which Allah sends down from the sky whereby He gave life to the earth after its death, and in the movement of the winds – (in all these) are signs for people of intellect.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
These are the verses of Allah which We recite to you with the truth; so forsaking Allah and His signs, what will they believe in?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Ruin is for every great slanderer, excessive sinner.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
Who hears the verses of Allah which are recited to him, then remains stubborn, proud, as if he did not hear them; therefore give him the glad tidings of a painful punishment.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he comes to know about any of the verses, he mocks at it; for them is a disgraceful punishment.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
Hell is after them; and what they have earned will not benefit them at all, nor those whom they have chosen as supporters besides Allah; and for them is a terrible punishment.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This is the (true) guidance; and for those who disbelieve in the verses of their Lord is the severest of painful punishments.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
It is Allah Who has subjected the sea for you so that ships may sail upon it by His command, and for you to seek His munificence, and so that you may give thanks.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And has subjected for you all whatever is in the heavens and in the earth, by His command; indeed in this are signs for people who ponder.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Tell the believers to ignore those who do not expect the days of Allah, in order that Allah may give a nation the reward of what they used to earn.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whoever does a good deed, so it is for his own good; and whoever commits evil, does for his own harm; and you will then be returned towards your Lord.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
And indeed We gave the Descendants of Israel the Book, and the rule, and the Prophethood, and gave good things for sustenance and gave them superiority over all others of their time.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
And We gave them clear proofs in the command; so they did not differ except after the knowledge had come to them – due to jealousy among themselves; indeed your Lord will judge between them on the Day of Resurrection concerning the matter in which they differ.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
We then placed you (O dear prophet Mohammed – peace and blessings be upon him) upon the clear path of the command, therefore continue following it and do not listen to the desires of the ignorant.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Indeed they cannot benefit you at all against Allah; and indeed the unjust are the friends of each other; and Allah is the Friend of the pious.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
This is an enlightenment for mankind, and a guidance and mercy for the people of faith.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Do those who commit evil assume that We will make them equal to those who believe and do good deeds, therefore both becoming equal in life and death? What an evil judgement they impose!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
And Allah has created the heavens and the earth with the truth, and so that every soul is repaid for what it has earned, and they will not be wronged.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Just look at him who makes his desire as his God, and Allah has sent him astray despite his having knowledge, and set a seal upon his ears and his heart, and a covering upon his eyes; so who will guide him after Allah? So do you not ponder?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
And they said, “There is nothing except our life of this world – we die and we live – and nothing destroys us except the passage of time”; and they do not have any knowledge of it; they only make guesses.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our clear verses are recited to them, their only argument is, “Bring back our forefathers, if you are truthful!”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “It is Allah Who gives you life, then will give you death, then will gather you all on the Day of Resurrection in which there is no doubt, but most people do not know.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmd{%
And to Allah only belongs the kingship of the heavens and the earth; and when the Last Day is established – on that day the followers of falsehood will suffer loss.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
And you will see every group down on its knees; every group will be called towards its book of deeds; “This day you will be repaid for what you did.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
“This Book of Ours speaks against you with the truth; indeed We had been recording all what you did.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
So those who believed and did good deeds – their Lord will admit them into His mercy; this is the clear triumph.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
And to those who disbelieved, it will be said “Was it not that Our verses were recited to you? In response you were haughty and were a guilty people.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
“And when it was said, ‘Indeed Allah’s promise is true and there is no doubt regarding the Last Day”, you used to say, ‘We do not know what the Last Day is – we think it is nothing except an imagination, and we are not convinced.’”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
And the evils of their deeds appeared to them, and the punishment they used to mock at encompassed them.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
And it will be said, “This day We shall forsake you, the way you had forgotten the confronting of this day of yours – and your destination is the fire, and you do not have any supporters.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
“This is because you mocked at the signs of Allah, and the worldly life deceived you”; so this day they are not to be removed from the fire, nor will anyone seek amends from them.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
So all praise is for Allah only, the Lord of the heavens and the Lord of the earth, the Lord of the Creation!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
And for Him only is the Greatness, in the heavens and in the earth; and He only is the Most Honourable, the Wise.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha-Meem. (Alphabets of the Arabic language – Allah, and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The sending down of this Book is from Allah the Most Honourable, the Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We did not create the heavens and the earth and all that is between them except with the truth, and for a fixed term; and the disbelievers have turned away from what they are warned!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Proclaim, (O dear Prophet Mohammed – peace and blessings be upon him), “What is your opinion – regarding those whom you worship other than Allah – show me which part of the earth they have created, or do they own any portion of the heavens? Bring to me a Book preceding this (Qur’an), or some remnants of knowledge, if you are truthful.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
And who is more astray than one who worships those, instead of Allah, who cannot listen to their prayer until* the Day of Resurrection, and who do not even know of their worship! (Will never listen.)\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And on the day when people are gathered, they will become their enemies, and will reject their worshippers. (The idols will give testimony against the polytheists.)\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
And when Our clear verses are recited to them, the disbelievers say regarding the Truth that has come to them, “This is an obvious magic!”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
What! They dare say, “He has fabricated it”? Say (O dear Prophet Mohammed – peace and blessings be upon him), “If I have fabricated it, then (I know that) you have no power to support me against Allah; He well knows the matters you are involved in; He is Sufficient as a Witness between me and you; and He only is the Oft Forgiving, the Most Merciful.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say, “I am not something new* among the Noble Messengers, nor do I know (on my own) what will happen to me** or with you; I only follow that which is divinely revealed to me, and I am purely a Herald of clear warning. (* I am like the earlier ones. ** My knowledge comes due to divine revelations.)\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say, “What is your opinion – if the Qur’an is from Allah and you have rejected faith in it, and a witness among the Descendants of Israel has already testified upon this and accepted faith, while you became arrogant? Indeed Allah does not guide the unjust.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
And the disbelievers said regarding the Muslims, “If there were any good in it, the Muslims would not have surpassed us in achieving it!”; and since they did not receive guidance with it, they will now say, “This is an old slander.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
And whereas before this exists the Book of Moosa, a guide and a mercy; and this is a Book giving testimony, in the Arabic language, to warn the unjust; and to give glad tidings to the virtuous.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Indeed those who said, “Allah is our Lord”, and then remained steadfast – upon them is neither any fear nor shall they grieve.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
They are the People of Paradise, abiding in it forever; the reward of their deeds.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
And We have commanded man to be good towards parents; his mother bore him with hardship, and delivered him with hardship; and carrying him and weaning him is for thirty months; until when he* reached maturity and became forty years of age, he said, “My Lord! Inspire me to be thankful for the favours you bestowed upon me and my parents, and that I may perform the deeds pleasing to You, and keep merit among my offspring; I have inclined towards you and I am a Muslim.” (* This verse was revealed concerning S. Abu Bakr – the first caliph, R. A. A)\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
These are the ones whose good deeds We will accept, and overlook their shortfalls – among the People of Paradise; a true promise which is being given to them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
And the one who said to his parents, “Uff – I am fed up with both of you! What! You promise me that I will be raised again whereas generations have passed away before me?” And they both seek Allah’s help and say to him, “May you be ruined, accept faith! Indeed Allah’s promise is true”; he therefore answers, “This is nothing except stories of former people.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
It is these upon whom the Word has proved true, among the nations that passed away before them, of jinns and men; indeed they were losers.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
And for all persons are ranks according to their deeds; and so that He may repay them in full for their deeds, and they will not be wronged.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
And on the day when the disbelievers will be presented upon the fire; it will be said to them, “You have wasted your portion of the good things in the life of this world and enjoyed them; so this day you will be repaid with the disgraceful punishment, the recompense of your wrongfully priding yourself in the land, and because you used to disobey.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
And remember the fellowman of the tribe of A’ad; when he warned his nation in the Ahqaf* – and indeed Heralds of warning passed away before and after him – that, “Do not worship anyone except Allah; indeed I fear the punishment of a Great Day upon you. (* A country among sand dunes.)\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said, “Have you come to us in order to turn us away from our Gods? Therefore bring upon us what you promise us, if you are truthful.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said, “Its knowledge is only with Allah; and I convey to you the messages of my Lord, but I perceive that you are an ignorant nation.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
So when they saw the punishment coming towards their valleys, spread like a cloud on the horizon, they said, “That is a cloud which will shower rain upon us”; said Hud “In fact this is what you were being impatient for; a windstorm carrying a painful punishment.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
“That destroys all things by the command of its Lord” – so at morning none could be seen except their empty houses; this is the sort of punishment We mete out to the guilty.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And We had indeed given them the means which We have not given you, and made ears and eyes and hearts for them; so their ears and eyes and hearts did not benefit them at all because they used to deny the signs of Allah, and the punishment they used to mock at encompassed them.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
And We indeed destroyed townships surrounding you, and brought several signs so that they may desist.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
So why did they – the ones whom they had chosen as Gods as a means of attaining Allah’s proximity – not help them? In fact the disbelievers lost them; and this is just their slander and fabrication.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
And when We sent a number of jinns towards you (O dear Prophet Mohammed – peace and blessings be upon him), listening attentively to the Qur’an; so when they presented themselves there, they said to each other, “Listen quietly!”; and when the recitation finished, they turned back to their people, giving them warning.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said, “O our people! We have indeed heard a Book, sent down after Moosa, which confirms the Books preceding it, and guides towards the Truth and the Straight Path.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
“O our people! Listen to Allah’s caller and accept faith in Him, so that He may forgive you some of your sins and save you from the painful punishment.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
“And whoever does not listen to Allah’s caller cannot escape in the earth, and he has no supporters against Allah; they are in open error.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Have they not realised that Allah, Who did not tire in creating the heavens and the earth and in creating them, is Able to revive the dead? Surely yes, why not? Indeed He is Able to do all things.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
And on the day when the disbelievers are presented upon the fire; it will be said, “Is this not a reality?” They will answer, “By oath of our Lord, surely yes, why not?”; it will be said, “Therefore taste the punishment, the recompense of your disbelief.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
Therefore patiently endure (O dear Prophet Mohammed – peace and blessings be upon him) like the courageous Noble Messengers had endured, and do not be impatient for them; on the day when they see what they are promised, it will be as if they had not stayed on earth except part of a day; this is to be conveyed; will anyone be destroyed, except the disobedient?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Allah has destroyed the deeds of those who disbelieved and prevented from Allah’s way.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
And those who accepted faith and did good deeds and believed in what has been sent down upon Mohammed (peace and blessings be upon him) – and that is the truth from their Lord – Allah has relieved them of some of their evils and refined their condition.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
This is because the disbelievers followed falsehood and the believers followed the Truth which is from their Lord; this is how Allah illustrates the examples of people to them.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
So when you confront the disbelievers, strike at their necks; until when you have slain them in plenty, tie them up firmly; then after that, you may either release them as a favour or take ransom, until the war lays down its ordeal; this is it; and had Allah willed He Himself could have taken revenge from them, but this is to test some of you with others; and Allah will surely never waste the deeds of those who were killed in His way.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will soon guide them (towards Paradise) and make them succeed.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
And He will admit them into Paradise – they have been made familiar with it.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O People who Believe! If you help the religion of Allah, He will help you and will stabilise you.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
And for those who disbelieve – may they be ruined, and may Allah destroy all their deeds!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
This is because they disliked what Allah has sent down – He has therefore squandered all their deeds.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
So did they not travel in the land to see what sort of fate befell those who preceded them? Allah poured ruin upon them; and for the disbelievers are several like it.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
This is because Allah is the Supporter of the believers, whereas the disbelievers do not have any supporter.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Allah will indeed admit those who believed and did good deeds into Gardens beneath which rivers flow; and the disbelievers enjoy, and they eat like the cattle eat, and their destination is in the fire.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
And many a township existed which was stronger than your town (O dear Prophet Mohammed – peace and blessings be upon him) – those who removed you from your town – We destroyed them, so they do not have a supporter!\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
So will one who is upon on a clear proof from his Lord, ever be like any of those whose evil deeds are made to appear good to them and they follow their own desires?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
A description of the Garden which is promised to the pious; in it are rivers of water which shall never pollute; and rivers of milk the taste of which shall never change; and rivers of wine delicious to drink; and rivers of purified honey; and in it for them are fruits of all kinds, and the forgiveness of their Lord; so will such ever be equal to those who are to stay in the fire for ever and who will be given boiling water to drink so that it tears their guts apart?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
And among them are some who listen to what you say; until when they go away from you, they say to those who have been given knowledge, “What did he say now?”; they are those whose hearts Allah has sealed, and they follow their own desires.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
And those who attained the right path – Allah increases the guidance for them and bestows their piety to them.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
So what are they waiting for, except that the Last Day suddenly come upon them? For its signs have already appeared; so when it does come, of what use is their realising it?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
Therefore know (O dear Prophet Mohammed – peace and blessings be upon him) that there is none worthy of worship except Allah, and seek the forgiveness of sins of your close ones and for the common believing men and women; and Allah knows your movements during the day and your resting during the night.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
And the Muslims say, “Why was not a chapter sent down?” So when a positive chapter was sent down, and war was commanded in it, you will see those in whose hearts is a disease looking at you with the dazed looks of a dying man; so it would be better for them. –\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
To obey and speak good; so when the manifest command came – it would have been better for them if they had remained faithful to Allah.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
So do you* portray that if you get governance, you would spread chaos in the land and sever your relations? (* The hypocrites)\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
It is these whom Allah has cursed, so He made them deaf to the Truth and blinded their eyes.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
So do they not ponder the Qur’an deeply, or are there locks on some of their hearts?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Indeed those who turn back after the guidance had become clear to them – Satan has deceived them; and made them optimistic of living for ages.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
This is because they said to those who dislike what Allah has sent down, “We will obey you regarding one matter*”; and Allah knows their secrets. (* To fight against the Holy Prophet).\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
So how (dreadful) will it be when the angels remove their souls, striking at their faces and their backs!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
This is because they followed the matter which displeases Allah, and they disliked what pleases Him – He therefore squandered away all their deeds.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
What! Do they, in whose hearts is a disease, fancy that Allah will not expose concealed enmities?\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
And if We will, We can show them to you so that you may recognise them by their faces; and you will surely recognise them by the way they talk; and Allah knows your deeds.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
And We shall indeed test you until We make known the warriors and the steadfast among you – and to test your proclamations.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Indeed those who disbelieved and prevented others from Allah’s way, and opposed the Noble Messenger after the guidance had become clear to them – they cannot harm Allah in the least; and soon He will squander away their deeds.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
O People who Believe! Obey Allah and obey the Noble Messenger, and do not render your deeds void.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Indeed those who disbelieved and prevented others from Allah’s way, and then died as disbelievers – so Allah will never forgive them.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
Therefore do not relax, nor call towards truce by yourself; and it is you who will dominate; and Allah is with you, and He will never cause a loss in your deeds.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The worldly life is just a sport and pastime; and if you accept faith and be pious, He will bestow your rewards to you, and not at all ask you for your wealth.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
Were He to ask it from you, and ask in plenty, you would be miserly, and the miserliness would expose the filth within your hearts.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Yes, undoubtedly it is you who are being called, that you may spend in Allah’s way; so some among you act miserly; and whoever is miserly, is being a miser upon himself; and Allah is the Independent (Wealthy – Not requiring anything), whereas you all are needy; and if you renege, He will replace you with other people – and they will not be like you.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen We have indeed, for your sake (O dear Prophet Mohammed – peace and blessings be upon him), bestowed a clear victory.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
So that Allah may forgive, for your sake, the sins of those before you and those after you, and complete His favours upon you, and to show you the Straight Path.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
And so that Allah may provide you a great help.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
It is He Who instilled peace in the hearts of the believers, so that it may increase their strength of conviction; and to Allah only belong the armies of the heavens and the earth; and Allah is All Knowing, Wise.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
In order to admit the believing men and believing women into Gardens beneath which rivers flow, in which they will abide, and to relieve them of their misdeeds; and this, in Allah’s sight, is the greatest success.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
And to punish the hypocrite men and hypocrite women, and the polytheist men and polytheist women, who think evilly about Allah; upon them only is the evil cycle of misfortune; and Allah has wreaked anger upon them, and has cursed them, and has prepared hell for them; and what an evil destination.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
And to Allah only belong the armies of the heavens and the earth; and Allah is Most Honourable, Wise.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
We have indeed sent you (O dear Prophet Mohammed – peace and blessings be upon him) as a present witness and a Herald of glad tidings and warnings. (The Holy Prophet is a witness from Allah.)\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
In order that you, O people, may accept faith in Allah and His Noble Messenger, and honour and revere the Noble Messenger; and may say the Purity of Allah, morning and evening. (To honour the Holy Prophet – peace and blessings be upon him – is part of faith. To disrespect him is blasphemy.)\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Those who swear allegiance to you (O dear Prophet Mohammed – peace and blessings be upon him), do indeed in fact swear allegiance to Allah; Allah's Hand* of Power is above their hands; so whoever breaches his oath, has breached his own greater promise; and whoever fulfils the covenant he has with Allah – so very soon Allah will bestow upon him a great reward. (Used as a metaphor.)\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
The ignorant ones who had stayed behind will now say to you, “Our wealth and our families prevented us from going by keeping us pre-occupied, therefore seek forgiveness for us”; they utter with their tongues what is not in their hearts; say, “So does anyone have any control over you against Allah, if He wills to harm you or provide you benefit? In fact Allah is Aware of what you do.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
“Rather you had assumed that the Noble Messenger and the Muslims will never return to their homes, and you thought this as good within your hearts, whereas you had thought evilly; and you were a people about to be ruined.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
And whoever does not accept faith in Allah and His Noble Messenger – We have indeed kept prepared a blazing fire for disbelievers.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
And for Allah only is the kingship of the heavens and the earth; He may forgive whomever He wills, and punish whomever He wills; and Allah is Oft Forgiving, Most Merciful.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
Those who had stayed behind will now say, “When you go to receive the war booty, let us also go with you”; they wish to change the Words of Allah; say “You shall never come with us – this is already decreed by Allah”; so they will now say, “But rather you envy us”; in fact they never understood except a little.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say to the ignorant who stayed behind, “You will soon be called against a nation of great military strength – to fight against them or that they become Muslims; so if you obey, Allah will give you an excellent reward; and if you turn away, the way you had turned away before, He will mete out a painful punishment to you.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
There is no reproach upon the blind, nor reproach against the lame, nor reproach upon the sick; and whoever obeys Allah and His Noble Messenger – Allah will admit him into Gardens beneath which rivers flow; and whoever turns away – He will mete out a painful punishment to him.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Indeed Allah was truly pleased with the believers when they swore allegiance to you beneath the tree – so He knew what was in their hearts – He therefore sent down peace upon them, and rewarded them with an imminent victory.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
And plenty of war booty, to take; and Allah is Most Honourable, Wise.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah has promised you plenty of booty which you will take, and has bestowed this to you quickly, and restrained peoples’ hands from you; and in order that it may be a sign for the believers, and to guide you on the Straight Path.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And one more, not within your capacity, is within Allah’s hold; and Allah is Able to do all things.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
And if the disbelievers were to fight you, they will turn away and flee, and then they will not find any supporter nor any aide.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
The tradition of Allah, ongoing since before; and you will not find the tradition of Allah changing.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
And it is He Who restrained their hands from you, and your hands from them in the valley of Mecca, after having given you control over them; and Allah sees all what you do.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
It was these who disbelieved and prevented you from the Sacred Mosque, and stopped the sacrificial animals from reaching their place; and were it not for some Muslim men and Muslim women, whom you do not know – lest you may crush them and unintentionally incur some violation due to them – Allah would have permitted you to slay them; this relief for them, is so that Allah may admit into His mercy whomever He wills; and had they been separated, We would have indeed punished the disbelievers among them with a painful punishment.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
Whereas the disbelievers had set up in their hearts an obstinacy – the same obstinacy of the days of ignorance – so Allah sent down His solace upon His Noble Messenger and upon the believers, and decreed upon them the words of piety, and they were more deserving and suitable for it; and Allah is the All Knowing.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Allah has indeed made the truthful dream of His Noble Messenger, come true; indeed you will all enter the Sacred Mosque, if Allah wills, in safety – with your heads shaven or hair cut short – without fear; so He knows what you do not know, and has therefore ordained another imminent victory before this.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
It is He Who has sent His Noble Messenger with the guidance and the true religion, in order to make it prevail over all other religions; and Allah is sufficient as a Witness. (The Holy Prophet is a light from Allah.)\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Mohammed (peace and blessings be upon him) is the Noble Messenger of Allah; and his companions are stern with the disbelievers and merciful among themselves – you will see them bowing and falling in prostration, seeking Allah’s munificence and His pleasure; their signs are on their faces, from the effects of their prostration; this trait of theirs is mentioned in the Taurat; and their trait is mentioned in the Injeel; like a cultivation that sprouted its shoot, then strengthened it, then thickened and then stood firm upon its stem, pleasing the farmer – in order to enrage the disbelievers with them; Allah has promised forgiveness and a great reward to those among them who have faith and do good deeds.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O People who Believe! Do not advance ahead of Allah and His Noble Messenger, and fear Allah; indeed Allah is All Hearing, All Knowing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
O People who Believe! Do not raise your voices higher than the voice of the Prophet, nor speak to him loudly the way you shout to one another, lest your deeds go to waste whilst you are unaware. (Faith will go waste due to the slightest disrespect towards the Holy Prophet – peace and blessings be upon him. To honour him is part of faith. To disrespect him is blasphemy.)\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Indeed those who suppress their voices in the presence of Allah’s Noble Messenger, are the ones whose hearts Allah has tested for piety; for them is forgiveness, and a great reward.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Indeed most of those who call you from outside the chambers do not have sense.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
And had they been patient until you yourself came out to them, it would be better for them; and Allah is Oft Forgiving, Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
O People who Believe! If any miscreant brings you some tidings, verify it, lest you unknowingly cause suffering to some people, and then remain repenting for what you did.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that Allah’s Noble Messenger is among you; in most of the affairs, were he to listen to you, you would surely fall into hardship, but Allah has made faith dear to you and has instilled it in your hearts, and has made disbelief and rebellion and disobedience abhorred by you; it is people like these who are on guidance.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
The munificence and favour of Allah; and Allah is All Knowing, Wise.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
And if two groups of Muslims fight against each other, reconcile them; and if one of them oppresses the other, fight against the oppressor till it returns to the command of Allah; then if it returns, reconcile between them with justice, and be fair; indeed Allah loves the equitable.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The Muslims are brothers to each other, therefore make peace between your two brothers and fear Allah, so that you may gain mercy. (The entire Muslim nation is a single brotherhood, without any distinction for caste, creed or colour.)\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O People who Believe! Men must not ridicule other men for it could be that the ridiculed are better than the mockers, nor must the women ridicule other women for the ridiculed women may be better than the mockers; and do not insult one another, nor assign evil nicknames; how base it is to be called a sinner after being a Muslim! And whoever does not repent – then it is they who are unjust.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O People who Believe! Avoid excessive assumptions; indeed assumption sometimes becomes a sin, and do not seek faults, and do not slander one another; would any one among you like to eat the flesh of his dead brother? So you will hate that! And fear Allah; indeed Allah is Most Acceptor of Repentance, Most Merciful.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O mankind! We have indeed created you from one man and one woman, and have made you into various nations and tribes so that you may know one another; indeed the more honourable among you, in the sight of Allah, is one who is more pious among you; indeed Allah is All Knowing, All Aware. (Piety is the basis of honour in Allah’s sight.)\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The ignorant said, “We have accepted faith”; say, (O dear Prophet Mohammed – peace and blessings be upon him), “You have surely not accepted faith, but you should say ‘We have submitted’, for faith has not yet entered your hearts; and if you obey* Allah and His Noble Messenger, He will not reduce the reward of any of your deeds; indeed Allah is Oft Forgiving, Most Merciful.” (* By accepting faith and then obeying the commands).\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
The true believers are only those who accepted faith in Allah and His Noble Messenger and then did not have any doubt, and fought with their wealth and their lives in Allah’s way; it is they who are the truthful.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Are you teaching Allah your own religion? Whereas Allah knows all whatever is in the heavens and all whatever is in the earth; and Allah knows all things.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They portray that they are doing a great favour to you (O dear Prophet Mohammed – peace and blessings be upon him) by having become Muslims; say, “Do not think that you have done me a favour by accepting Islam; in fact Allah has bestowed a favour upon you, for He guided you to Islam, if you are truthful.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
Indeed Allah knows all the hidden of the heavens and the earth; and Allah is seeing your deeds.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf; by oath of the Glorious Qur’an.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
Rather they were shocked that a Herald of Warning came to them from among themselves, so the disbelievers said, “This is something really strange.”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
“When we are dead and have turned to dust, will we be raised again? That return is impossible!”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We know all what the earth decreases from them; and with Us is a Book that retains.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
In fact they denied the Truth when it came to them, so they are now in a dilemma.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
So did they not see the sky above them – how We have made it and beautified it, and there are no cracks in it?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And (how) We have spread the earth, and placed mountains as anchors in it, and have grown all kinds of beautiful pairs in it?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
A perception and an understanding, for every bondman who inclines.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We sent down the auspicious water from the sky, therefore producing gardens with it, and the grain that is harvested.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
And high date-palms with lush fruit.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
As sustenance for the bondmen; and with it We revived a dead city; this is how you will be raised.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
Before these, the people of Nooh had denied, and so did the dwellers of Rass and the Thamud.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
And the tribe of A’ad, and Firaun, and the fellowmen of Lut.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
And the Dwellers of the Woods, and the people of Tubb’a; each one of them one denied the Noble Messengers, so My promised punishment proved true.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
So did We tire by creating the first time? Rather they doubt being created again.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
And indeed We have created man and We know what his soul instils in him; and We are nearer to him than the hearts artery.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
When the two receiving angels receive from him, one seated on the right and one on the left.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
He does not utter a single word, without a ready recorder seated next to him.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And the hardship of death came with the truth; “This is what you were escaping from!”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the Trumpet was blown; “This is the Day of the promised punishment.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And every soul came, along with a herder and a witness.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
“You were indeed neglectful of this, so We have removed the veil for you, and your eyesight is sharp this day.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And his accompanying angel said, “This is the record of your deeds, available with me.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
It will be said to the angels, “Both of you fling every excessive ungrateful, stubborn person into hell.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
“The one who excessively prevented from virtue, the transgressor, the doubtful.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
“The one who appointed another God along with Allah – so both of you fling him into the severe punishment.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His accompanying devil said, “Our Lord! I did not cause him to rebel, but he himself was in extreme error.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
He will say, “Do not dispute before Me – I had already warned you of the punishment.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
“With Me, the decree does not change, and nor do I oppress the bondmen.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
The day when We will ask hell, “Are you filled up?” and it will answer, “Are there some more?”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And Paradise will be brought close to the pious, not far away from them.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
This is what you are promised – for every repenting, careful person.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
Who fears the Most Gracious without seeing, and came with a heart that inclines.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
It will be said to him, “Enter it in peace; this is the day of eternity.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
In it for them is all that they may desire, and with Us is more than it.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
And many a generation We did destroy before them, who exceeded them in strength, therefore venturing in the cities! Is there a place to escape?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Indeed in this is an advice for anyone who keeps a heart, or listens attentively.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
And We have indeed created the heavens and the earth, and all what is between them, in six days; and fatigue did not even approach Us.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
Therefore (O dear prophet Mohammed – peace and blessings be upon him) patiently bear upon what they say, and praising your Lord say His Purity before the sun rises and before the sun sets.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And say His Purity during the night, and after the customary prayers.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And listen attentively on the day when an announcer will proclaim from a place nearby.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
The day when all will hear the Scream with the truth; this is the day of coming out of the graves.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
Indeed it is We Who give life, and give death, and towards Us only is the return.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
On the day when the earth will split for them, so they will come out in haste; this is the gathering – easy for Us.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We well know what they say (O dear Prophet Mohammed – peace and blessings be upon him), and you are not one to use force over them; therefore advise him with the Qur’an, whoever fears My threat.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By oath of those which carry away while dispersing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
Then by oath of those which carry the burdens.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
Then by oath of those which move with ease.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
Then by oath of those which distribute by the command.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
Undoubtedly, the promise you are given is surely true.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
And undoubtedly justice will surely be done.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
And by oath of the decorated heaven.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
You are indeed in different opinions regarding this Qur’an.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
Only those who are destined to revert, are reverted from it.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Slain be those who mould from their imaginations.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
Those who have forgotten in a state of intoxication.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask, “When will be the Day of Judgement?”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
It will be on the day when they will be roasted in the fire.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
And it will be said to them, “Taste your own roasting; this is what you were impatient for.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
Indeed the pious are among Gardens and water springs.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
Accepting the rewards given by their Lord; they were indeed virtuous before this.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
They used to sleep only a little during the night.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
And used to seek forgiveness before dawn.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
And the beggar and the destitute had a share in their wealth.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
And in the earth are signs for those who are certain.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
And in your own selves; so can you not perceive?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in the heaven lies your sustenance, and the promise you are given.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
So by oath of the Lord of the heavens and the earth, this Qur’an is the Truth, in the same language that you speak.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Did the news of Ibrahim’s honourable guests reach you (O dear Prophet Mohammed – peace and blessings be upon him)?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they came to him and said, “Peace”; he answered, “Peace”; and thought, “These people are not familiar.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he went to his home – so he brought a healthy calf.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
He then presented it before them and said, “Do you not eat?”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
He therefore inwardly sensed fear of them; they said, “Do not fear!”; and they gave him the glad tidings of a knowledgeable son.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
So his wife came screaming, and striking her forehead cried, “What! For a barren old woman?”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said, “This is how your Lord has decreed; indeed He only is the Wise, the All Knowing.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
Said Ibrahim, “What is your task, O the sent angels?”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said, “We have been sent towards a guilty nation.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
“To throw upon them stones of baked clay.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
“That are kept marked, with your Lord, for the transgressors.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
So We removed the people who had faith, from that town.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
We therefore found just one house over there that was Muslim.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And We kept a sign remaining in it, for those who fear the painful punishment.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And in Moosa, when We sent him with a clear proof towards Firaun.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
In response, he turned away along with his army and said, “He is a magician or a madman.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
We therefore seized him and his army and threw them into the sea, while he was blaming himself.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in the tribe of A’ad, when we sent a dry windstorm upon them.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
It left out nothing in its path, but which it split up into fragments.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in the tribe of Thamud when it was told to them, “Enjoy for a while.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
In response they rebelled against their Lord’s command, so the thunderbolt seized them whilst they were watching.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
So they were neither able to stand up, nor were they able to take revenge.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
And before them, We destroyed the people of Nooh; they were indeed a sinning nation.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
And We have built the heaven with hands (the Divine Power), and it is We Who give the expanse.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And We made the earth a base, so how well do We lay out!\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And We created all things in pairs, so that you may ponder.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
“Therefore rush towards Allah; indeed I am from Him, a clear Herald of Warning towards you.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
“And do not appoint other deities along with Allah; indeed I am from Him, a clear Herald of Warning towards you.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Similarly, whenever a Noble Messenger came to those before them they always said, “He is a magician or a madman.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
What! Have they willed this utterance to one another? In fact they are a rebellious people.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
Therefore turn away from them (O dear Prophet Mohammed – peace and blessings be upon him), – so there is no blame upon you.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
And advise, for advice benefits the Muslims.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
And I created the jinns and men, only for them to worship Me.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I do not ask any sustenance from them, nor wish that they give Me food.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Indeed it is Allah, Who is the Greatest Sustainer, the Strong, the Able.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
And indeed for these unjust is also a turn of punishment, like that of their companions – so they must not ask Me to hasten.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
So ruin is for disbelievers, from their day – which they are promised.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By oath of (mount) Tur.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
And by oath of a passage, written –\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
On an open record.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
And by oath of the Inhabited House.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
And the lofty roof.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
And the sea set aflame.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
Indeed your Lord’s punishment will surely take place.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
No one can avert it.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
A day on which the heavens will shake with a visible shaking.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
And the mountains will move with a visible movement.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
So on that day, ruin is for those who deny.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
Those who are playing in pursuits.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
A day when they will be pushed, forcibly shoved towards the fire of hell.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
“This is the fire, which you used to deny!”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
“So is this magic, or are you unable to see?”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
“Enter it – now whether you patiently bear it or are impatient – it is the same for you; for you is a recompense only for what you used to do.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
Indeed the pious are in Gardens and peace.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
Delighted at the bestowal of their Lord; and their Lord has saved them from the fire.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
“Eat and drink with pleasure, a reward for what you used to do.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
Reclining on thrones, in rows; and We have wedded them to maidens with gorgeous eyes.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
And those who accepted faith, and whose descendants followed them with faith – We have joined their descendants with them, and have not reduced anything for them from their deeds; every soul is trapped in its own deeds.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We aided them with fruit and meat, whatever they desire.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
In it, they accept cups from each other, in which is neither any lewdness nor any sin.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
And their boy servants shall go around them, as if they were pearls, safely hidden.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
And one of them turned towards the other, questioning.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
Saying, “Indeed before this, we were in our houses, worried.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
“So Allah did us a great favour, and saved us from the punishment of the flame.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
“Indeed we used to worship Him in our previous life; indeed He only is the Benign, the Most Merciful.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
Therefore (O dear Prophet Mohammed – peace and blessings be upon him), enlighten, for by the munificence of your Lord, you are neither a soothsayer nor a madman.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or they allege, “He is a poet – we await a calamity of the times to befall him.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Proclaim, “Go on waiting – I too am waiting along with you.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Is this what their senses tell them, or are they a rebellious people?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
What! They say, “He has invented the Qur'an”? Rather they do not have faith.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
So let them bring a single discourse like it, if they are truthful.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Have they not been created from some source, or are they themselves the creators?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or did they create the heavens and the earth? Rather they are not certain.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or do they have the treasures of your Lord, or are they the authority?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or do they have any stairs, climbing upon which they eavesdrop? So their eavesdropper should bring some clear proof!\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
What! The daughters for Him, and the sons for you?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or do you (O dear Prophet Mohammed – peace and blessings be upon him) ask any fee from them, so they are burdened with the penalty?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or is the hidden with them, by which they pass judgements?\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or are they planning a conspiracy? So the conspiracy will befall only upon the disbelievers.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or do they have a God besides Allah? Purity is to Allah from their ascribing of partners to Him.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
And were they to see a portion of the sky falling, they will say, “It is a heap of clouds.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
Therefore leave them, until they confront their day, in which they will be stunned.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
A day on which their scheming will not benefit them at all, nor will they be helped.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
And indeed for the unjust is another punishment before this, but most of them do not know. (Punishment in the grave is proven by this verse.)\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
And be patient upon your Lord’s command, (O dear Prophet Mohammed – peace and blessings be upon him), for you are indeed in Our sight; and proclaim the Purity of your Lord while praising Him, whenever you stand.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
And proclaim His Purity during the night, and when the stars turn back.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By oath of the beloved shining star Mohammed (peace and blessings be upon him), when he returned from the Ascent.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
Your companion did not err, nor did he go astray.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
And he does not say anything by his own desire.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
It is but a divine revelation, which is revealed to him.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
He has been taught by the Extremely Powerful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
The Strong; then the Spectacle inclined towards him.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
And he was on the horizon of the highest heaven.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Then the Spectacle became closer, and came down in full view.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
So the distance between the Spectacle and the beloved was only two arms’ length, or even less. (The Heavenly Journey of Prophet Mohammed – peace and blessings be upon him – was with body and soul.)\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
So Allah divinely revealed to His bondman, whatever He divinely revealed.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
The heart did not deny, what it saw. (The Holy Prophet was bestowed with seeing Allah – see also preceding verses 8, 9, 10.)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
What! So do you dispute with him regarding what he saw?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
And indeed he did see the Spectacle again.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
Near the lote-tree of the last boundary.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
Close to which is the Everlasting Paradise.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
When the lote-tree was being enveloped, by whatever around it.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
The sight did not shift, nor did it cross the limits.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
Indeed he saw the supreme signs of his Lord.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
So did you observe the idols Lat and Uzza?\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
And subsequently the third, the Manat?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
What! For you the son, and for Him the daughter?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
Then that is surely a very unjust distribution!\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
They are nothing but some names that you have coined, you and your forefathers – Allah has not sent any proof for them; they follow only guesses and their own desires; whereas the guidance from their Lord has come to them.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
What! Will man get whatever he dreams of?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
So (know that) Allah only is the Owner of all – the Hereafter and this world.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
And many an angel is in the heavens, whose intercession does not benefit the least unless Allah gives permission for whomever He wills, and whom He likes.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Indeed those who do not believe in the Hereafter, coin the names of angels like those of females.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
And they do not have any knowledge of it; they just follow assumption; and indeed assumption does not serve any purpose in place of the Truth.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
Therefore turn away from whoever has turned away from Our remembrance and has desired only the life of this world.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
This is the extent of their knowledge; indeed your Lord well knows one who has strayed from His path, and He well knows one who has attained guidance.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
And to Allah only belongs all whatever is in the heavens and all whatever is in the earth, in order to repay those who do evil for what they have done, and give an excellent reward to those who do good.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
Those who avoid the cardinal sins and lewdness, except that they approached it and refrained; indeed your Lord’s mercy is limitless; He knows you very well – since He has created you from clay, and when you were foetuses in your mothers’ wombs; therefore do not, on your own, claim yourselves to be clean; He well knows who are the pious.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
So did you observe him who turned away?\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
And he gave a little, then refrained?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Does he have knowledge of the hidden, so he can foresee?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Did not the news reach him, of that which is mentioned in the Books of Moosa?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
And of Ibrahim, who was most obedient?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
That no burdened soul bears another soul’s burden?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
And that man will not obtain anything except what he strove for?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
And that his effort will soon be scrutinised?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
Then he will be fully repaid for it?\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
And that the end is only towards your Lord?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
And that it is He Who made (you) laugh and made (you) cry?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
And that it is He Who gave death and gave life?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
And that it is He Who has created the two pairs, male and female?\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
From a drop of liquid, when it is added?\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
And that only upon Him is the next revival?\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
And that it is He Who has given wealth and contentment?\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
And that He only is the Lord of the star Sirius?\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
And that it is He Who earlier destroyed the tribe of Aad?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
And destroyed the tribe of Thamud, not sparing anyone?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
And before them, the people of Nooh? Indeed they were more unjust and more rebellious than these!\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And that it is He Who threw down the upturned townships?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
So they were covered with whatever covered them?\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
So O listener! Which favour of your Lord will you doubt?\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
He (Prophet Mohammed – peace and blessings be upon him) is a Herald of Warning, like the former Heralds of Warning.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The approaching event has come near.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
None except Allah can avert it.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
So are you surprised at this fact?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
And you laugh, and do not weep!\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
And you are lost in play!\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
Therefore prostrate for Allah, and worship Him. (Command of Prostration \# 12)\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Last Day came near, and the moon split apart.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
And when they see a sign, they turn away and say, “Just a customary magic!”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
And they denied and followed their own desires, whereas each matter has been decided!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
And indeed the news which had a lot of deterrence, came to them.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
The pinnacle of wisdom – so how will the Heralds of warning provide any benefit?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
Therefore turn away from them; on the day when the announcer will call towards a severe unknown matter –\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
They will come out from the graves with eyes lowered, as if they were spread locusts.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
Rushing towards the caller; the disbelievers will say, “This is a tough day.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
Before these, the people of Nooh denied and they belied Our bondman and said, “He is a madman” and rebuffed him.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
He therefore prayed to his Lord, “I am overpowered, therefore avenge me.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
We therefore opened the gates of heaven, with water flowing furiously.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
And caused springs to gush out from the earth, so that the two waters met totalling a quantity that had been destined.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We carried Nooh upon a ship of wooden planks and nails.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
Sailing in front of Our sight; as a reward for the sake of one who was rejected.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And We left it as a sign – so is there one who would ponder?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
So how did My punishment turn out, and My threats?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
And We have indeed made the Qur’an easy to memorise, so is there one who would remember?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
The tribe of A’ad denied – so how did My punishment turn out, and My warnings?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
We indeed sent towards them a severe windstorm, on a day the ill luck of which lasted upon them forever.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
Smashing down men as if they were uprooted trunks of date palms.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
So how did My punishment turn out, and My warnings?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
And We have indeed made the Qur’an easy to memorise, so is there one who would remember?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
The tribe of Thamud denied the Noble Messengers.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
So they said, “What! Shall we follow a man from among us? If we do, we are indeed astray, and insane!”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
“What! Of all the men among us, the remembrance has come down upon him? In fact, he is a mischievous, great liar.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
It was said to Saleh, “They will soon realise tomorrow who is the mischievous great liar.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
“We shall send a she-camel to test them, therefore O Saleh, wait and have patience.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
“And inform them that the water is to be shared between them; only those may come whose turn it is.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
In response they called their companion – he therefore caught and hamstrung the she-camel.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
So how did My punishment turn out, and My warnings?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
Indeed We sent upon them a single Scream – thereupon they became like the barrier builder’s residual dry trampled hay.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
And We have indeed made the Qur’an easy to memorise, so is there one who would remember?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The people of Lut denied the Noble Messengers.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
Indeed We sent a shower of stones upon them, except the family of Lut; We rescued them before dawn.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
As a reward from Us; this is how We reward one who gives thanks.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
And indeed he had warned them of Our seizure – in response they doubted the warnings.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
And they tried to persuade him regarding his guests – We therefore blinded their eyes, “So taste My punishment, and My warnings.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
And indeed, the everlasting punishment overcame them early in the morning.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
“So taste My punishment, and My warnings!”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
And We have indeed made the Qur’an easy to memorise, so is there one who would remember?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
And indeed the Noble Messengers came to the people of Firaun.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
They denied all Our signs, We therefore seized them – the seizure of the Most Honourable, the All Powerful.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your disbelievers better than they were, or have you been given exemption in the Books?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or they say, “We shall all take revenge as a group.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
The group will soon be routed, and will turn their backs to flee.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
In fact their promise is upon the Last Day – and the Last Day is very severe and very bitter!\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Indeed the criminals are astray and insane.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
On the day when they are dragged upon their faces in the fire – “Taste the heat of hell.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
We have indeed created all things by a proper measure.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our command is only a fleeting one – like the batting of an eyelid.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
And We have indeed destroyed your kind, so is there one who would ponder?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
And all what they did is in the Books.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
And every small and great thing is recorded.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Indeed the pious are amidst Gardens and springs.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
Seated in an assembly of the Truth, in the presence of Allah, the Omnipotent King.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen Allah, the Most Gracious\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
Has taught the Qur’an to His beloved Prophet (Mohammed – peace and blessings be upon him).\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
Has created Prophet Mohammed (peace and blessings be upon him) as the soul of mankind.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
Has taught him the knowledge of the past and the future.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon are scheduled.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
And the plants and the trees prostrate (for Him).\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
And Allah has raised the sky; and He has set the balance.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
In order that you may not corrupt the balance.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
And establish the measures justly, nor decrease the due weight.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And He appointed the earth for the creatures.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
In which are fruits, and covered dates.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
And grain covered with husk, and fragrant flowers.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man from clay like that of earthenware.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
And created jinn from the flame of fire.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
Lord of both the Easts, and Lord of both the Wests!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He has set flowing two seas that appear to meet.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
Whereas there is a barrier between them so they cannot encroach upon one another.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
Pearls and coral-stone come forth from them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
To Him only belong the sailing ships, raised above the sea like hills.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
For everything on the earth is extinction.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
And everlasting is the Entity of your Lord, the Most Majestic and the Most Honourable.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
All those who are in the heavens and the earth seek only from Him; every day is an enterprise for Him.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
Disposing all works quickly We tend towards your account, O you two large groups!\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O the groups of jinns and men, if you can cross the boundaries of the heavens and the earth, then cross them; wherever you may go, His is the kingdom!\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
Flames of smokeless fire and black smoke without flames, will be let loose on you, so you will not be able to retaliate.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
And when the heaven will split, it will appear like a rose painted red.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
On that day no sinner will be questioned about his sins, from men or from jinns.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The criminals will be recognised from their faces, so will be caught by their forelocks and feet, and thrown into hell.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is hell, which the criminals deny.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
They shall keep going back and forth between it and the extremely hot boiling water.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
And for one who fears to stand before his Lord, are two Gardens.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
Having numerous branches.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
In the two Gardens flow two springs.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
In which are fruits of all kinds, each of two varieties.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
Reclining upon thrones that are lined with brocade, with the fruit of both Gardens close enough to be picked from under.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
Upon thrones are the women who do not gaze at men except their husbands, and before them, are untouched by any man or jinn.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
They are like rubies and coral-stone.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
What is the reward of virtue except virtue (in return)?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And besides them, there are two more Gardens.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Densely covered with foliage, appearing dark.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
In the Gardens are two springs, overflowing with abundance.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
In them are fruits (of all kinds), and dates and pomegranate.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
In them are women of good behaviour and gorgeous faces.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
They are houris (maidens of Paradise), hidden from view, in pavilions.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
Untouched by any man or jinn, before them.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining on green cushions and beautiful decorated carpets.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
So O men and jinns! Which favour of your Lord will you deny?\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Most Auspicious is the name of your Lord, the Most Majestic and the Most Honourable.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the forthcoming event does occur.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
Then none will be able to deny its occurrence.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
The event will be abasing some, and exalting some.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
When the earth will tremble, shivering.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
And the mountains will be crushed, blown to bits.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
So they will become like fine dust, scattered in a shaft of light.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
And you will become divided into three categories.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
So those on the right – how (fortunate) are those on the right!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And those on the left – how (wretched) are those on the left!\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And those who surpassed have indeed excelled.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
It is they who are the close ones.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
They are in Gardens of peace.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A large group from the earlier generations.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
And a few from the latter.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
On studded thrones.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
Reclining on them, facing each other.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
Surrounded by immortal boys.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
Carrying bowls and pitchers – and cups filled with wine flowing before them.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
Their heads shall not ache with it, nor shall they lose their senses.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
And fruits that they may like.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmm{%
And meat of birds that they may wish.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And gorgeous eyed fair maidens.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
Like pearls safely hidden.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
The reward for what they did.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
They will not hear any useless speech in it, or any sin.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
Except the saying, “Peace, peace.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
And those on the right – how (fortunate) are those on the right!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
Among thorn-less lote-trees.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
And clusters of banana plants.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
And in everlasting shade.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
And in perpetually flowing water.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
And plenty of fruits.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
That will neither finish, nor ever be stopped.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And raised couches.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
We have indeed developed these women with an excellent development.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
So made them as maidens.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
The beloved of their husbands, of one age.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
For those on the right.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A large group from the earlier generations.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
And a large group from the latter.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
And those on the left – how (wretched) are those on the left!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
In scorching wind and boiling hot water.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
And in the shadow of a burning smoke.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
Which is neither cool nor is for respect.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
Indeed they were among favours before this.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
And were stubborn upon the great sin (of disbelief).\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
And they used to say, “When we are dead and have turned into dust and bones, will we surely be raised again?”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
“And also our forefathers?”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Proclaim, “Without doubt all – the former and the latter.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
“They will all be gathered together – on the appointed time of the known day.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
Then indeed you, the astray, the deniers –\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
You will indeed eat from the Zaqqum tree.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
Then will fill your bellies with it.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
And upon it, you will drink the hot boiling water.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
Drinking the way thirsty camels drink.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
This is their reception on the Day of Justice.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
It is We Who created you, so why do you not accept the truth?\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
So what is your opinion regarding the semen you discharge?\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Do you make a human out of it, or is it We Who create?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
It is We Who have ordained death among you, and We have not been beaten –\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
In the matter of exchanging you for others, and to transform you into what you do not know.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
And you have indeed learnt about the first creation, so why do you not ponder?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
So what is your opinion regarding what you sow?\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Is it you who cultivate it, or is it We Who develop it?\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
If We will We can make it like dry trampled hay, so you would keep crying out.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
That, “We have indeed been penalised!”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
“In fact, we were unfortunate!”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
So what is your opinion regarding the water that you drink?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Is it you who caused it to descend from the cloud, or is it We Who cause it to descend?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We will We can make it bitter, so why do you not give thanks?\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmml{%
So what is your opinion regarding the fire which you kindle?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Is it you who grew its tree, or is it We Who create?\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We have made it as a reminder of hell and as a utility for travellers in the jungle.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Therefore (O dear Prophet Mohammed – peace and blessings be upon him) proclaim the Purity of the name of your Lord, the Greatest.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
So I swear by the setting places of the stars.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
And that is indeed a tremendous oath, if you understand.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
This is indeed the noble Qur’an.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
Kept in a secure Book.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
None may touch it, except with ablution.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
Sent down by the Lord Of The Creation.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
So is this the matter regarding which you laze?\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
And you make its denial your share?\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
So why was it not, when the soul reaches up to the throat, –\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
Whereas you watch at that moment!\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
And We are nearer to him than you are, but you cannot see.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
So why is it not, that if you are not to be repaid, –\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
That you bring it back, if you are truthful?\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
Then if the dying one is of those having proximity, –\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
Then is relief, and flowers – and Gardens of peace.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he is of those on the right, –\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
Then upon you is the greetings of peace (O dear Prophet Mohammed – peace and blessings be upon him), from those on the right.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
And if he is from the deniers, the astray, –\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
Then his reception is the hot boiling water.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
And a hurling into the blazing fire.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
This is indeed an utmost certainty.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
Therefore (O dear Prophet Mohammed – peace and blessings be upon him) proclaim the Purity of the name of your Lord, the Greatest.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen All whatever is in the heavens and in the earth proclaims the Purity of Allah; and He only is the Most Honourable, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
For Him only is the kingship of the heavens and the earth; He gives life and causes death; and He is Able to do all things.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He only is the First and He only the Last, and He only is the Evident and He only the Concealed; and it is He Who knows all things.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
It is He Who created the heavens and the earth in six days, then ascended the Throne (of Control), in a manner befitting His Majesty; He knows all what goes into the earth and all what comes out of it, and all what descends from the sky and all that rises in it; and He is with you, wherever you may be; and Allah is seeing your deeds.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
For Him only is the kingship of the heavens and the earth; and towards Allah only is the return of all matters.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He brings the night in a part of the day, and brings the day in a part of the night; and He knows what lies within the hearts.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Accept faith in Allah and His Noble Messenger, and spend in His cause from what He has made you the heirs of; so for those among you who accepted faith and spent in His cause, is a great reward.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
And what is the matter with you, that you should not accept faith in Allah? Whereas this Noble Messenger is calling you to believe in your Lord, and Allah has indeed already taken a covenant from you, if you believe.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
It is He Who sends down clear verses upon His chosen bondman, in order to take you out from the realms of darkness towards light; and indeed Allah is Most Compassionate, Most Merciful upon you.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And what is the matter with you that you should not spend in Allah’s cause, whereas Allah is the Inheritor of all that is in the heavens and in the earth? Those among you who spent and fought before the conquest of Mecca are not equal to others; they are greater in rank than those who spent and fought after the conquest; and Allah has promised Paradise to all of them; and Allah well knows what you do.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who will lend a handsome loan to Allah so that He may double it for him? And for such is an honourable reward.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
The day when you will see the believing men and believing women, that their light runs before them and on their right – it being said to them, “This day, the best tidings for you are the Gardens beneath which rivers flow – abide in it forever; this is the greatest success.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
The day when hypocrite men and hypocrite women will say to the Muslims, “Look mercifully towards us, so that we may gain some of your light!”; it will be said to them, “Turn back, search light over there!”; so they will turn around, whereupon a wall will be erected between them, in which is a gate; inside the gate is mercy, and on the outer side is the punishment.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
The hypocrites will call out to the Muslims, “Were we not with you?”; they will answer, “Yes you were, why not? But you had put your souls into trial, and you used to await misfortune for the Muslims, and you doubted, and false hopes deceived you until Allah’s command came – and the big cheat had made you conceited towards the command of Allah.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
“So this day no ransom is to be taken from you nor from the declared disbelievers; your destination is the fire; that is your companion; and what a wretched outcome!”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Has not the time come for the believers to surrender their hearts to Allah’s remembrance and to this truth that has come down? And do not be like those who were earlier given the Book(s) and when a long term passed over them, their hearts became hardened; and many of them are sinners.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that it is Allah Who revives the earth after its death; We have indeed illustrated the signs for you, for you to understand.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Indeed the charity-giving men and women, and those who lend an excellent loan to Allah – for them is double, and for them is an honourable reward.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
And those who believe in Allah and all His Noble Messengers, are the truly sincere; and are witness upon others, before their Lord; for them is their reward, and their light; and those who disbelieved and denied Our signs, are the people of hell.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the life of this world is nothing but play and pastime, and adornment, and boasting amongst yourselves, and the desire to surpass each other in wealth and children; like the rain the produce of which pleased the farmer, then dried so you see it yellow, and then turned into dry trampled hay; and in the Hereafter is a severe punishment, and the forgiveness from Allah and His pleasure; and the life of this world is nothing but counterfeit wealth.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Rush towards the forgiveness of your Lord and a Paradise wide as the expanse of the heavens and the earth – made for those who believe in Allah and all His Noble Messengers; this is Allah’s munificence, He may bestow it to whomever He wills; and Allah is Extremely Munificent.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
There is no misfortune that reaches in the earth or in your selves but is mentioned in a Book, before We initiate it; indeed this is easy for Allah.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
So that you may not be saddened upon losing something, nor rejoice upon what you are given; and Allah does not like any boastful, conceited person.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
Those who practice miserliness, and exhort others to miserliness; and whoever turns away, then (know that) Allah is the Independent, the Most Praiseworthy.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
Indeed We sent Our Noble Messengers with proofs, and sent down the Book and the Balance of Justice along with them, so that people may stay upon justice; and We sent down iron having severe heat and benefits for mankind, and so that Allah may see him, who without seeing aides Him and His Noble Messengers; indeed Allah is Almighty, Dominant.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
And indeed We sent Nooh and Ibrahim, and placed Prophethood and the Book among their descendants, so some among them took to guidance; and many of them are sinners.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
We then sent Our other Noble Messengers after them following their footsteps, and after them We sent Eisa, the son of Maryam, and bestowed the Injeel to him; and We instilled compassion and mercy in the hearts of his followers; and they invented monasticism which We had not ordained upon them only to seek Allah’s pleasure, then did not properly abide by it as it should have been rightfully abided; We therefore gave the believers among them their reward; and many of them are sinners.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O People who Believe (in the earlier Noble Messengers)! Fear Allah and accept faith in this Noble Messenger of His – He will bestow two portions of His mercy to you and will create a light for you to walk in it, and will forgive you; and Allah is Oft Forgiving, Most Merciful.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
This is so that the disbelievers among People given the Book(s) may know that they do not have any control over Allah’s munificence, and that the munificence is in Allah’s Hand (control) – He bestows to whomever He wills; and Allah is Extremely Munificent.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Allah has indeed heard the speech of the woman who is arguing with you (O dear Prophet Mohammed – peace and blessings be upon him) concerning her husband, and is complaining to Allah; and Allah hears the conversation of you both; indeed Allah is All Hearing, All Knowing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Those among you who have proclaimed their wives as their mothers – so their wives are not their mothers; their mothers are only those that gave them birth; and undoubtedly they utter evil and a blatant lie; and indeed Allah is Most Pardoning, Oft Forgiving.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
And those among you who have proclaimed their wives as their mothers and then wish to revert to the matter upon which they had uttered such an enormous word, must then free a slave before they touch one another; this is what you are advised; and Allah is Aware of your deeds.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
So one who cannot find a slave, must then fast for two successive months before they touch one another; and one who cannot even fast, must then feed sixty needy ones; this is in order that you keep faith in Allah and His Noble Messenger; and these are the limits of Allah; and for the disbelievers is a painful punishment.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Indeed those who oppose Allah and His Noble Messenger have been humiliated, like those before them who were humiliated, and We have indeed sent down clear verses; and for the disbelievers is a disgraceful punishment.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
The day when Allah will raise all of them together and inform them of their misdeeds; Allah has kept count of them, whereas they have forgotten them; and all things are present before Allah.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
O listener! Did you not see that Allah knows all whatever is in the heavens and all whatever is in the earth? Wherever there is any discussion among three He is the fourth present with them, and among five He is the sixth, and there is no discussion among fewer or more except that He is with them wherever they may be; and then on the Day of Resurrection He will inform them of all what they did; indeed Allah knows all things.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Did you not see those who were forbidden from conspiracy, yet they do what was forbidden, and consult each other for sinning, and for exceeding limits, and for disobeying the Noble Messenger? And when they come in your presence, they greet you with words not chosen by Allah for respectfully greeting you, and they inwardly say, “Why does not Allah punish us for what we say?”; hell is sufficient for them; they will sink into it; and what a wretched outcome!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O People who Believe! When you consult each other, do not consult for sinning, nor for exceeding limits, nor for disobeying the Noble Messenger – and consult for righteousness and piety; and fear Allah, towards Whom you will be raised.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
The evil consultation is only from the devil in order that he may upset the believers, whereas he cannot harm them in the least without Allah’s command; and only upon Allah must the Muslims rely.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O People who Believe! When you are told to give room in the assemblies, then do give room – Allah will give you room (in His mercy); and when it is said, “Stand up in reverence”, then do stand up – Allah will raise the believers among you, and those given knowledge, to high ranks; and Allah is Aware of your deeds.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O People who Believe! When you wish to humbly consult with the Noble Messenger, give some charity before you consult; that is much better and much purer for you; so if you do not have the means, then (know that) Allah is Oft Forgiving, Most Merciful.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Were you afraid to offer charity before you consult? So when you did not do this, and Allah has inclined towards you with His mercy, keep the prayers established and pay the obligatory charity and obey Allah and His Noble Messenger; and Allah is Aware of your deeds.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Did you not see those who befriended those upon whom is Allah’s wrath? They are neither of you nor of these – and they swear a false oath, whereas they know.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah has kept prepared a severe punishment for them; indeed they commit extremely evil deeds.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They use their oaths as a shield therefore preventing from Allah’s way – so for them is a disgraceful punishment.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Their wealth and their children will be of no use to them before Allah; they are the people of hell; they are to remain in it forever.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
The day when Allah will raise them all, they will swear in His presence the way they now swear in front of you, and they will assume that they have achieved something; pay heed! Indeed it is they who are the liars.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
The devil has overpowered them, so they forgot the remembrance of Allah; they are the devil’s group; pay heed! Indeed it is the devil’s group who are the losers.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Indeed those who oppose Allah and His Noble Messenger, are among the most despicable.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah has already decreed that, “I will indeed be victorious, and My Noble Messengers”; indeed Allah is Almighty, the Most Honourable.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
You will not find the people who believe in Allah and the Last Day, befriending those who oppose Allah and His Noble Messenger, even if they are their fathers or their sons or their brothers or their tribesmen; it is these upon whose hearts Allah has ingrained faith, and has aided them with a Spirit from Himself; and He will admit them into Gardens beneath which rivers flow, abiding in them forever; Allah is pleased with them, and they are pleased with Him; this is Allah’s group; pay heed! Indeed it is Allah’s group who are the successful.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen All whatever is in the heavens and all whatever is in the earth proclaims the Purity of Allah; and He only is the Most Honourable, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
It is He Who expelled the disbelievers among the People given the Book(s) from their homes, for their first gathering; you did not expect them to leave, whereas they assumed that their fortresses would save them from Allah, so Allah’s command came to them from a place they had not imagined; and He instilled awe in their hearts, so they ruin their own houses by their own hands and at the hands of the Muslims; therefore learn a lesson, O those who can perceive!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
And had Allah not decreed exile for them, He would have surely punished them in this world; and for them in the Hereafter is the punishment of the fire.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
This is because they remained opposed to Allah and His Noble Messenger; and whoever remains opposed to Allah, (and His Noble Messenger) – then indeed Allah’s punishment is severe.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
The trees you had cut down or left standing on their roots was all by Allah’s permission, and in order to disgrace the sinners.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
And from them, the booty which Allah gave to His Noble Messenger – so you had not raced your horses or camels against them, but it is Allah Who gives whomever He wills within the control of His Noble Messengers; and Allah is Able to do all things.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
The booty which Allah gave to His Noble Messenger from the people of the townships, is for Allah and His Noble Messenger, and for the relatives, and the orphans, and the needy and the travellers – so that it does not become the wealth of the rich among you; and accept whatever the Noble Messenger gives you; and refrain from whatever he forbids you; and fear Allah; indeed Allah’s punishment is severe.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
And (the booty is) also for the poor migrants who were expelled from their homes and their wealth, seeking Allah’s munificence and His pleasure, and aiding Allah and His Noble Messenger; it is they who are the truthful.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
And those who accepted this city as their home and accepted faith before them, befriend those who migrated towards them, and in their breasts do not find any need for what they have been given, and prefer the migrants above themselves even if they themselves are in dire need; and whoever is saved from the greed of his soul – it is they who are the successful.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And those who came after them say, “O our Lord! Forgive us, and our brothers who accepted faith before us, and do not keep any malice in our hearts towards the believers – O our Lord! Indeed You only are the Most Compassionate, Most Merciful.”.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Did you not see the hypocrites, that they say to their disbelieving brothers among the People given the Book(s), “If you are expelled, then we will definitely go out with you, and we will not listen to anyone in your matters, and if you are fought against we will surely help you”; and Allah testifies that they are indeed liars.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
If they are expelled, the hypocrites will not go out with them; and if they are fought against they will not help them; and even if they were to help them, they would turn their backs and flee; and then they will not be helped.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Indeed in their hearts is a greater fear of you than that of Allah; this is because they are a people who do not understand.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They will not fight you even if they all come together, except in barricaded cities or from behind walls; they are severe fighters among themselves; you will assume them to be one, whereas their hearts are divided; this is because they are a people who do not have any sense.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
Like the example of those who were before them not long ago – they tasted the evil result of their deeds; and for them is a painful punishment.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
The example of the devil – when he said to man “Disbelieve”; so when he has rejected faith, he says, “I am unconcerned with you – indeed I fear Allah, the Lord of The Creation.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
So the fate of them both is that they are both in the fire, to remain in it forever; and this is the proper punishment for the unjust.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O People who Believe! Fear Allah, and every soul must see what it has sent ahead for tomorrow; and fear Allah; indeed Allah is Aware of your deeds.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And do not be like those who forgot Allah – He therefore put them into hardship making them forget themselves; it is they who are the sinners.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
The People of hell and the People of Paradise are not equal; it is only the People of Paradise who have succeeded.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
Had We sent down this Qur’an upon a mountain, you would have then surely seen it bowed down, blown to bits by the fear of Allah; and We illustrate such examples for people, for them to ponder.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
It is Allah, except Whom there is no God; the Knowing of all – the hidden and the evident; He only is the Most Gracious, the Most Merciful.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
It is Allah, except Whom there is no God; the King, the Pure, the Giver of Peace, the Bestower of Safety, the Protector, the Most Honourable, the Compeller, the Proud; Purity is to Allah from all what they ascribe as partners (to Him)!\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
It is Allah only, Who is the Creator, the Initiator, the Designer of all – His only are all the good names; all whatever is in the heavens and in the earth proclaims His Purity; and He only is the Most Honourable, the Wise.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O People who Believe! Do not befriend My and your enemy – you reveal secrets to them out of friendship whereas they disbelieve in the truth which has come to you! It is they who remove the Noble Messenger and you from your homes, upon your believing in Allah, your Lord; if you have come out to fight for My cause, and to gain My pleasure, then do not befriend them; you send them secret messages of friendship – and I well know all what you hide and all what you disclose; and whoever among you does it, has indeed strayed away from the right path.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
If they gain dominance over you they will be your enemies, and will extend their hands and their tongues towards you with evil, and they wish that in some way you turn disbelievers.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
Neither your relations nor your offspring will in the least benefit you, on the Day of Resurrection; He will separate you from them; and Allah is seeing your deeds.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
Indeed in Ibrahim, and those along with him, lay a good example for you follow – when they said to their people, “Indeed we are unconcerned with you and all what you worship besides Allah; we reject you, and between us and you has surfaced enmity and hatred for ever until you accept faith in the One Allah” – except the saying of Ibrahim to his father, “I will surely seek forgiveness for you, and I do not possess any power to benefit you against Allah”; “O our Lord! We have relied only upon You, and towards You only we have inclined and only towards You is the return”.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
“O our Lord! Do not put us into the trial of the disbelievers, and forgive us, O our Lord! Indeed You only are the Most Honourable, the Wise.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
Indeed in them lay a good example for you to follow – for one who looks forward to (meeting) Allah and the Last Day; and whoever turns away – then (know that) indeed Allah only is the Independent, the Most Praiseworthy.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
It is likely that Allah may create friendship between you and those among them who are now your enemies; and Allah is All Able; and Allah is Oft Forgiving, Most Merciful.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah does not forbid you from those who did not fight against you because of religion and did not drive you out from your homes, that you should be kind towards them and deal with them fairly; indeed the equitable are the beloved of Allah.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
Allah forbids you only from those who fought against you because of religion or drove you out from your homes or helped others to drive you out, that you should befriend them; and whoever befriends them – it is they who are the unjust.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O People who Believe! When Muslim women leave the lands of disbelief and migrate towards you, examine them; Allah knows more about their faith; so if you judge the women to be believers, do not send them back to the disbelievers; neither are they lawful for the disbelievers, nor are the disbelievers lawful for them; and give their disbelieving husbands what they had spent; and there is no sin upon you to marry them if you give them their bridal money; and do not continue the marriage with disbelieving women – and ask for what you had spent, and the disbelievers may ask for what they had spent; this is Allah’s command; He judges between you; and Allah is All Knowing, Wise.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if some women go away from the Muslims to the disbelievers – then when you punish the disbelievers, give from the war booty to the Muslims who lost their wives the amount they had spent; and fear Allah in Whom you believe.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O dear Prophet (Mohammed – peace and blessings be upon him)! If Muslim women come humbly to you to take oath of allegiance that they will neither ascribe any partner to Allah, nor steal, nor commit adultery, nor kill their children, nor bring the lie that they carry between their hands and feet, nor disobey you in any rightful matter – then accept their allegiance and seek forgiveness from Allah for them; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O People who Believe! Do not befriend the people upon whom is Allah’s wrath – they have lost hope in the Hereafter the way the disbelievers have lost hope in the people of the graves.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen All whatever is in the heavens and all whatever is in the earth proclaims the Purity of Allah; and He only is the Most Honourable, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O People who Believe! Why do you preach what you do not practice?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
How despicable it is in the sight of Allah that you may preach what you do not practice.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Indeed Allah likes those who fight in His cause, positioned in rows, as if they were an edifice fortified.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And remember when Moosa said to his people, “O my people! Why do you trouble me, whereas you know that I am Allah’s Noble Messenger towards you?” So when they deviated, Allah deviated their hearts; and Allah does not guide the sinning people.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And remember when Eisa the son of Maryam said, “O Descendants of Israel! Indeed I am Allah’s Noble Messenger towards you, confirming the Book Torah which was before me, and heralding glad tidings of the Noble Messenger who will come after me – his name is Ahmed (the Praised One)”; so when Ahmed came to them with clear proofs, they said, “This is an obvious magic.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who is more unjust than one who fabricates a lie against Allah whereas he is being called towards Islam? And Allah does not guide the unjust people.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
They wish to put out Allah’s light with their mouths, whereas Allah will perfect His light even if the disbelievers get annoyed.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
It is He Who has sent His Noble Messenger with guidance and the religion of truth, in order that He may make it prevail over all other religions, even if the polytheists get annoyed.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O People who Believe! Shall I show you a trade that can save you from the painful punishment?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
Have faith in Allah and His Noble Messenger, and fight in Allah’s cause with your wealth and your lives; this is better for you, if you understand.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive you your sins and admit you into Gardens beneath which rivers flow, and superb dwellings in everlasting Gardens of Eden; this is the greatest success.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And He will give you another favour, which is dear to you – the help from Allah and an imminent victory; and O dear Prophet (Mohammed – peace and blessings be upon him), give glad tidings to the Muslims.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O People who Believe! Become the aides of Allah’s religion, the way Eisa the son of Maryam had said to the disciples, “Who will help me, inclining towards Allah?” The disciples said, “We are the aides of Allah’s religion” – so a group among the Descendants of Israel accepted faith and another group disbelieved; We therefore aided the believers against their enemies, so they were victorious.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen All whatever is in the heavens and all whatever is in the earth proclaims the Purity of Allah, the King, the Most Pure, the Most Honourable, the Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
It is He Who has sent among the unlettered people a Noble Messenger from themselves, who recites His verses to them and purifies them, and bestows them the knowledge of the Book and wisdom; and indeed before this, they were in open error.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
And he (the Holy Prophet) bestows knowledge to others along with them, who have not yet joined them; and He only is the Most Honourable, the Wise.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
This is Allah’s munificence, which He may give to whomever He wills; and Allah is Extremely Munificent.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The example of those who were entrusted with the Taurat, and did not carry out its commands, is like the donkey carrying books; what a wretched example is of the people who denied the signs of Allah; and Allah does not guide the unjust.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say “O Jews! If you assume that you are Allah’s friends, others are not, then wish for death if you are truthful!”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
And they will never wish for it because of the misdeeds their hands have sent ahead; and Allah well knows the unjust.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Indeed death which you run away from will surely confront you, then you will be returned to Him Who knows all the hidden and the visible – He will then inform you of what you did.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O People who Believe! When the call for prayer is given on (Friday) the day of congregation, rush towards the remembrance of Allah and stop buying and selling; this is better for you if you understand.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
And when the prayer ends, spread out in the land and seek Allah’s munificence, and profusely remember Allah, in the hope of attaining success.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
And when they see some trade or sport, they move towards it and leave you standing delivering the sermon; proclaim, “That which is with Allah, is better than sport and trade; and the sustenance of Allah is the best.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come in your presence (O dear Prophet Mohammed – peace and blessings be upon him) they say, “We testify that you surely are Allah’s Noble Messenger”; and Allah knows that you indeed are His Noble Messenger, and Allah testifies that the hypocrites are indeed liars.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They have taken their oaths as a shield, thereby prevented others from Allah’s way; indeed they commit extremely evil deeds.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they accepted faith with their tongues then disbelieved with their hearts, therefore their hearts were sealed – so now they do not understand anything.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
And when you see them, their appearance would please you; and when they speak, you would listen carefully to their speech; like wooden blocks propped against the wall; they assume every cry to be against them; they are the enemy, so beware of them; may Allah slay them! Where are they reverting!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said to them, “Come! Allah’s Noble Messenger may seek forgiveness for you” – they turn heads away, and you will see them turning away in pride.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
It is the same for them, whether you seek forgiveness for them or do not seek forgiveness for them; Allah will never forgive them; indeed Allah does not guide the sinning people.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
It is they who say, “Do not spend upon those who are with Allah’s Noble Messenger until they get distraught”; whereas to Allah only belong the treasures of the heavens and the earth, but the hypocrites do not have sense.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say, “If we return to Medinah, then indeed the honourable group will soon expel the lowly one”; whereas all honour belongs to Allah and to His Noble Messenger and to the Muslims, but the hypocrites do not know.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O People who Believe! May not your wealth or your children cause you to neglect the remembrance of Allah; and whoever does this – so it is they who are in a loss.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
And spend from what We have provided you before death approaches any one of you and he then says, “My Lord! Why did you not give me respite for a little while, so I would have given charity and become of the virtuous?”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
And Allah will never give respite to any soul when its promise arrives; and Allah is Aware of your deeds.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen All whatever is in the heavens and all whatever is in the earth proclaims the Purity of Allah; His only is the kingship and His only is all praise; and He is Able to do all things.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
It is He Who has created you, so among you one is a disbeliever whereas another is a Muslim; and Allah is seeing your deeds.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He created the heavens and the earth with the truth, and fashioned you thereby making you in best shapes; and towards Him only is the return.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows all whatever is in the heavens and in the earth, and He knows all what you hide and all what you disclose; and Allah knows what lies within the hearts.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Did not the news of those who disbelieved before you reach you? So they tasted the evil outcome of their deeds, and for them is a painful punishment.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
This is because their Noble Messengers used to bring clear proofs to them, in response they said, “What! Will humans show us the way?”; they therefore became disbelievers and turned away, and Allah acted independently; and Allah is the Independent, the Most Praiseworthy.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
The disbelievers alleged that they will surely not be raised again; proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “Surely yes, why not? By oath of Lord, you will surely be raised again and you will then be informed of your misdeeds; and this is easy for Allah.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
Therefore accept faith in Allah and His Noble Messenger and the light which We have sent down; and Allah is Well Aware of what you do.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
The day when He will gather you, on the Day of Collective Assembly – that is the day when the loss of the losers will be laid bare; and whoever believes in Allah and does good deeds, Allah will relieve him of his sins and admit him into Gardens beneath which rivers flow, for them to abide in it forever; this is the greatest success.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
And those who disbelieved and denied Our signs, are the people of the fire – to remain in it forever; and what a wretched outcome!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No misfortune befalls except by Allah’s command; and Allah will guide the heart of whoever accepts faith in Him; and Allah knows all things.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
And obey Allah and obey His Noble Messenger; then if you turn away, know that the duty upon Our Noble Messenger is only to plainly convey.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah – there is none worthy of worship except Him; and only upon Allah must the Muslims rely.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O People who Believe! Some of your wives and children are your enemies, therefore be wary of them; and if you pardon and overlook and forgive, then indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your wealth and your children are just a test; and with Allah is a tremendous reward.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
Therefore fear Allah as much as possible, and heed the commands, and obey, and spend in Allah’s cause, for your own good; and whoever is rescued from the greed of his own soul – is they who will be successful.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If you lend an excellent loan to Allah, He will double it for you and forgive you; and Allah is Most Appreciative, Most Forbearing.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
The All Knowing of all things hidden and visible, the Most Honourable, the Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O dear Prophet (Mohammed – peace and blessings be upon him)! When you people divorce women, divorce them at the time of their completing the appointed period, and keep count of the appointed period; and fear Allah, your Lord; do not expel them from their houses during the appointed period nor should they leave on their own, unless they bring about some matter of blatant lewdness; and these are the limits of Allah; and whoever crosses Allah’s limits has indeed wronged himself; do you not know, it is likely that Allah may send some new decree after this?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
So when they are about to reach their appointed term, hold them back with kindness or separate them with kindness, and make two just men among you as witnesses, and establish the testimony for Allah; with this is advised whoever believes in Allah and the Last Day; and whoever fears Allah – Allah will create for him a way of deliverance.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
And will provide him sustenance from a place he had never expected; and whoever relies on Allah – then Allah is Sufficient for him; indeed Allah will accomplish His command; indeed Allah has set a proper measure for all things.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
And for those of your women who have no hope of menstruation, if you doubt, the appointed period is three months – and also for those who have not yet had menstruation; and the appointed period for the pregnant women is up to the time they deliver their burden; and whoever fears Allah – Allah will create ease for him in his affairs.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
This is Allah’s command that He has sent down towards you; and whoever fears Allah – Allah will relieve his sins and bestow upon him a great reward.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Accommodate them where you also reside, according to your means, and do not harass them to make it difficult upon them; and if they are pregnant, give them the provision till they deliver their burden; then if they suckle the child for you, pay them its due; and consult with each other in a reasonable manner; and if you create hardship for one another, the child will get another breast feeding nurse.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Whoever has the capacity must give provisions according to his means; and the one whose sustenance is restricted upon him, must give provisions from what Allah has given him; Allah does not burden any soul except according to what He has given it; Allah will soon, after the hardship, create ease.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
And many a town existed that rebelled against the command of its Lord and His Noble Messengers, so We took a severe account from it – and struck them with a dreadful punishment.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
They therefore tasted the evil outcome of their deeds, and the outcome of their deeds was a loss.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah has kept prepared a severe punishment for them – therefore fear Allah, O men of intellect! O People who Believe! Allah has sent down a Remembrance (or an honour) for you. (The Holy Prophet is a Remembrance from Allah.)\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
The Noble Messenger who recites the clear verses of Allah to you, so that he may take those who accept faith and do good deeds, away from the realms of darkness towards light; and whoever accepts faith in Allah and does good deeds, Allah will admit him into Gardens beneath which rivers flow, to abide in them for ever and ever; indeed Allah has kept an excellent sustenance for him.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
It is Allah Who has created the seven heavens, and seven earthly worlds like them; the command descends within them, so that you may know that Allah is Able to do all things, and that Allah’s knowledge encompasses everything.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O dear Prophet (Mohammed – peace and blessings be upon him)! Why do you forbid for yourself the things that Allah has made lawful for you? You wish to please some of your wives; and Allah is Oft Forgiving, Most Merciful.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Allah has ordained expiation for your oaths; and Allah is your Master; and Allah is the All Knowing, the Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
And when the Holy Prophet confided a matter to one of his wives; so when she disclosed it and Allah conveyed this to the Holy Prophet, he told her part of it and held back a part; so when the Holy Prophet informed her about it, she said, “Who informed you?”; he said, “The All Knowing, the All Aware has informed me.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If you both, the wives of the Holy Prophet, incline towards Allah, for indeed your hearts have deviated a little; and if you come together against him (the Holy Prophet – peace and blessings be upon him) then indeed Allah is his Supporter, and Jibreel and the virtuous believers are also his aides; and in addition the angels are also his aides. (Allah has created several supporters for the believers.)\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
It is likely that, if he divorces you, his Lord will give him wives better than you in your place -widows and maidens who are obedient, believing, respectful, penitent, serving and fasting.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
O People who Believe! Save yourselves and your families from the fire, the fuel of which is men and stones – appointed over it are the extremely strict angels, who do not refuse the command of Allah and carry out whatever they are commanded.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
“O disbelievers! Do not feign excuses this day; you will only be repaid what you used to do.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
O People who Believe! Incline towards Allah in a repentance that becomes a guidance for the future; it is likely that your Lord will relieve you of your sins and admit you into Gardens beneath which rivers flow – on the day when Allah will not humble the Prophet and the believers along with him; their light will be running ahead of them and on their right; they will say, “Our Lord! Perfect our light for us, and forgive us; indeed You are Able to do all things.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O dear Prophet (Mohammed – peace and blessings be upon him), wage holy war against the disbelievers and the hypocrites, and be strict with them; and their destination is hell; and what a wretched outcome!\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah illustrates the example of the disbelievers – the wife of Nooh and the wife of Lut; they were bonded in marriage to two of Our bondmen deserving Our proximity – they then betrayed them so they did not benefit them the least against Allah and it was declared, “Both of you women enter the fire, along with others who enter.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
And Allah illustrates an example of the Muslims – the wife of Firaun; when she prayed, “My Lord! Build a house for me near You, in Paradise, and deliver me from Firaun and his works, and rescue me from the unjust people.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And the example of Maryam the daughter of Imran, who guarded her chastity – We therefore breathed into her a Spirit from Ourselves – and she testified for the Words of her Lord and His Books, and was among the obedient.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Most Auspicious is He in Whose control is the entire kingship; and He is Able to do all things.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
The One Who created death and life to test you – who among you has the better deeds; and He only is the Most Honourable, the Oft Forgiving.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
The One Who created the seven heavens atop each other; do you see any discrepancy in the creation of the Most Gracious? Therefore lift your gaze – do you see any cracks?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then lift your gaze again, your gaze will return towards you, unsuccessful and weak.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
And indeed We have beautified the lower heaven with lamps, and have made them weapons against the devils, and have kept prepared for them the punishment of the blazing fire.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
And for those who disbelieved in their Lord, is the punishment of hell; and what a wretched outcome!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
They will hear it hissing when they will be thrown into it, and it is boiling.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
As if about to explode with rage; whenever a group is thrown into it, the guardians of hell will ask them, “Did not a Herald of Warning come to you?”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They will say, “Yes, why not – indeed a Herald of Warning did come to us – in response we denied and said ‘Allah has not sent down anything – you are not except in a great error’.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
And they will say, “Had we listened or understood, we would not have been among the people of hell.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
So now they admit their sins! Therefore accursed be the people of hell!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
Indeed for those who fear their Lord without seeing is forgiveness, and a great reward.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
And whether you speak softly or proclaim it aloud; He indeed knows what lies within the hearts!\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
What! Will He Who has created not know? Whereas He knows every detail, the All Aware!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
It is He Who subjected the earth for you, therefore tread its paths and eat from Allah’s sustenance; and towards Him is the resurrection.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Have you become unafraid of the One Who controls the heavens, that He will not cause you to sink into the earth when it trembles?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Or have you become unafraid of the One Who controls the heavens, that He will not send a torrent of stones upon you? So now you will realise, how My warning turned out!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
And indeed those before them had denied – therefore how did My rejection turn out!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
And did they not see the birds above them, spreading and closing their wings? None except the Most Gracious holds them up; indeed He sees all things.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Or which army do you have that will help you against the Most Gracious? The disbelievers are in nothing except an illusion.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Or who is such that will give you sustenance if Allah stops His sustenance? In fact they persist in rebellion and hatred.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
So is one who walks inverted upon his face more rightly guided, or one who walks upright on the Straight Path?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “It is He Who created you, and made ears and eyes and hearts for you; very little thanks do you offer!”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say, “It is He Who has spread you out in the earth, and towards Him you will be raised.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
And they say, “When will this promise come, if you are truthful?”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Proclaim, “Surely Allah has its knowledge; and I am only a Herald of plain warning.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
So when they will see it close, the faces of the disbelievers will become ghastly, and it will be declared, “This is what you were demanding.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “What is your opinion –Allah may either destroy me and those with me, or have mercy on us – so who is such that will protect the disbelievers from the painful punishment?”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Proclaim, “He only is the Most Gracious – we have accepted faith in Him and have relied only upon Him; so you will now realise who is in open error.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say, “What is your opinion – if in the morning all your water were to sink into the earth, then who is such who can bring you water flowing before you?”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nuun* – by oath of the pen and by oath of what is written by it. (Alphabet of the Arabic language; Allah and to whomever He reveals, know their precise meanings.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
You are not insane, by the munificence of your Lord.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
And indeed for you is an unlimited reward.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
And indeed you possess an exemplary character.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
So very soon, you will see and they too will realise –\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
- That who among you was insane.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Indeed your Lord well knows those who have strayed from His path, and He well knows those who are upon guidance.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
Therefore do not listen to the deniers.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
They wish that in some way you may yield, so they too might soften their stand.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
Nor ever listen to any excessive oath maker, ignoble person.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
The excessively insulting one, spreader of spite.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
One who excessively forbids the good, transgressor, sinner.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
Foul mouthed, and in addition to all this, of improper lineage.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
Because he* has some wealth and sons. (Walid bin Mugaira, who cursed the Holy Prophet.)\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When Our verses are recited to him, he says, “These are stories of earlier people.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
We will soon singe his pig-nose.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
We have indeed tested them the way We had tested the owners of the garden when they swore that they would reap its harvest the next morning.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
And they did not say, “If Allah wills”.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
So an envoy from your Lord completed his round upon the garden, whilst they were sleeping.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
So in the morning it became as if harvested.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
They then called out to each other at daybreak.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
That, “Go to your fields at early morn, if you want to harvest.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So they went off, while whispering to one another.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
“Make sure that no needy person enters your garden this day.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And they left at early morn, assuming they were in control of their purpose.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
Then when they saw it, they said, “We have indeed strayed.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
“In fact, we are unfortunate.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
The best among them said, “Did I not tell you, ‘Why do you not proclaim His purity?’”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said, “Purity is to our Lord – we have indeed been unjust.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
So they came towards each other, blaming.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said, “Woe to us – we were indeed rebellious.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
“Hopefully, our Lord will give us a better replacement than this – we now incline towards our Lord.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the punishment; and indeed the punishment of the Hereafter is the greatest, if only they knew!\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Indeed for the pious, with their Lord, are Gardens of Serenity.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
Shall We equate the Muslims to the guilty?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What is the matter with you? What sort of a judgement you impose!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Is there a Book for you, from which you read?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
- That for you in it is whatever you like?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or is it that you have a covenant from Us, right up to the Day of Judgement, that you will get all what you claim?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them, who among them is a guarantor for it?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or is it that they have partners in worship? So they should bring their appointed partners, if they are truthful.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
On the day when the Shin* will be exposed and they will be called to prostrate themselves, they will be unable. (Used as a metaphor)\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
With lowered eyes, disgrace overcoming them; and indeed they used to be called to prostrate themselves whilst they were healthy.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
Therefore leave the one who denies this matter, to Me; We shall soon steadily take them away, from a place they do not know.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
And I will give them respite; indeed My plan is very solid.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or is it that you (O dear Prophet Mohammed – peace and blessings be upon him) ask any fee from them, so they are burdened with the penalty?\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or that they possess the hidden, so they are writing it?\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
Therefore wait for your Lord’s command, and do not be like the one of the fish; who cried out when he was distraught. (Prophet Yunus – peace be upon him.)\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Were it not for his Lord’s favour that reached him, he would have surely been cast onto the desolate land, reproached.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
His Lord therefore chose him and made him among those deserving His proximity.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
And indeed the disbelievers seem as if they would topple you with their evil gaze when they hear the Qur’an, and they say, “He is indeed insane.”\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
Whereas it is not but an advice to the entire creation!\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The true event!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
How tremendous is the true event!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
And what have you understood, how tremendous the true event is!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
The tribes of Thamud and A’ad denied the event of great dismay. (The Day of Resurrection)\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
So regarding the Thamud, they were destroyed by a terrible scream.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
And as for A’ad, they were destroyed by a severe thundering windstorm.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
He forced it upon them with strength, consecutively for seven nights and eight days – so you would see those people overthrown in it, like trunks of date palms fallen down.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
So do you see any survivor among them?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
And Firaun, and those before him, and the dwellings that were inverted and thrown, had brought error.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
They therefore disobeyed the Noble Messengers of their Lord – so He seized them with an intense seizure.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
Indeed when the water swelled up, We boarded you onto the ship.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
In order to make it a remembrance for you, and in order that the ears that store may remember.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
So when the Trumpet will be blown, with a sudden single blow.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
And the earth and the mountains will be lifted up and crushed with a single crush.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
So that is the day when the forthcoming event will occur.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
And the heaven will split asunder – so on that day it will be unstable.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
And the angels will be on its sides; and on that day, eight angels will carry the Throne of your Lord above them.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
On that day all of you will be brought forth, so none among you wishing to hide will be able to hide.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
So whoever is given his book in his right hand – he will say, “Take, read my account!”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
“I was certain that I will confront my account.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
He is therefore in the desired serenity.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
In a lofty Garden –\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
The fruit clusters of which are hanging down.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
“Eat and drink with pleasure – the reward of what you sent ahead, in the past days.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
And whoever is given his book in his left hand – he will say, “Alas, if only my account were not given to me!”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
“And had never come to know my account!”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
“Alas, if only it had been just death.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
“My wealth did not in the least benefit me.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
“All my power has vanished.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
It will be said, “Seize him, and shackle him.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
“Then hurl him into the blazing fire.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
“Then bind him inside a chain which is seventy arm-lengths.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
“Indeed he refused to accept faith in Allah, the Greatest.”\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
“And did not urge to feed the needy.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
“So he does not have any friend here this day.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
“Nor any food except the pus discharged from the people of hell.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
“Which none except the guilty shall eat.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
So by oath of the things you see.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
And by oath of those you do not see.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
This Qur’an is the speech of Allah with a gracious Noble Messenger.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
And it is not the speech of a poet; how little do you believe!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor is it the speech of a soothsayer; how little do you ponder!\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
Sent down by the Lord Of The Creation.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
And had he fabricated just one matter upon Us –\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We would have definitely taken revenge from him.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
Then would have cut off his heart’s artery.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
Then none among you would be his saviour.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
And indeed this Qur’an is an advice for the pious.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
And indeed We know that some among you are deniers.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
And indeed it is a despair for the disbelievers.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
And indeed it is a certain Truth.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
Therefore (O dear Prophet Mohammed – peace and blessings be upon him), proclaim the purity of your Lord, the Greatest.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A requester seeks the punishment that will take place –\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
- Upon the disbelievers – the punishment that none can avert.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
From Allah, the Lord of all pinnacles.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
The angels and Jibreel, ascend towards Him – the punishment will befall on a day which spans fifty thousand years.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
Therefore patiently endure, in the best manner (O dear Prophet Mohammed – peace and blessings be upon him).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
They deem it to be remote.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
Whereas We see it impending.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
The day when the sky will be like molten silver.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
And the hills will be light as wool.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
And no friend will ask concerning his friend.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
They will be seeing them; the guilty will wish if only he could redeem himself from the punishment of that day, by offering his sons.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
And his wife and his brother.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
And the family in which he was.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
And all those who are in the earth – then only if the redemption saves him!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
Never! That is indeed a blazing fire.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
A fire that melts the hide.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
It calls out to him who reverted and turned away.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
And accumulated wealth and hoarded it.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Indeed man is created very impatient, greedy.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
Very nervous when touched by misfortune.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
And refraining, when good reaches him.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
Except those who establish prayer.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
Those who are regular in their prayers.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
And those in whose wealth exists a recognised right,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
For those who beg, and for the needy who cannot even ask.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
And those who believe the Day of Judgement to be true.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
And those who fear the punishment of their Lord.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
Indeed the punishment of their Lord is not a thing to be unafraid of!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
And those who protect their private organs (from adultery).\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
Except with their wives and the bondwomen in their possession, for there is no reproach on them.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
So those who desire more than this – it is they who are the transgressors.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
And those who protect the property entrusted to them, and their agreements.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
And those who are firm upon their testimonies.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
And those who protect their prayers.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
It is these who will be honoured in Gardens.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
So what is the matter with these disbelievers, that they stare at you (O dear Prophet Mohammed – peace and blessings be upon him)?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
From the right and the left, in groups?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Does every man among them aspire to be admitted into the Garden of serenity?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
Never! We have indeed created them from a thing they know.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
So I swear by the Lord of every East and every West, that We are indeed Able.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
To replace them by those better than them; and none can escape from Us.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
Therefore leave them, involved in their indecencies and play, till they confront their day which they are promised.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
A day when they will come out of the graves in haste, as if rushing towards their goals.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
With lowered eyes, disgrace overcoming them; this is the day, which they had been promised.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen Indeed We sent Nooh towards his people saying that, “Warn your people before the painful punishment comes upon them.”\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said, “O my people! I am indeed a Herald of clear warnings to you.”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
“That you must worship Allah and fear Him, and obey me.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
“He will forgive you some of your sins, and give you respite up to an appointed term; indeed the promise of Allah cannot be averted when it arrives; if only you knew.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said, “My Lord! I invited my people night and day.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
“So for them, my calling them increased their fleeing away.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
“And whenever I called them, so that You may forgive them, they always thrust their fingers into their ears, and covered themselves with their clothes, and remained stubborn and were extremely haughty.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
“I then called them openly.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
“Then I also told them publicly and also spoke to them softly in private.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
“I therefore told them, ‘Seek forgiveness from your Lord; He is indeed Most Forgiving.’\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
‘He will send down abundant rain for you from the sky.’\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
‘And will aid you with wealth and sons, and will create gardens for you and cause rivers to flow for you.’\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
‘What is the matter with you, that you do not desire honour from Allah?’\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
‘Whereas it is He Who created you in different stages?’\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
‘Do you not see how Allah has created the seven heavens atop each other?’\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
‘And in them, has illuminated the moon, and made the sun a lamp?’\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
‘And it is Allah Who made you grow like vegetation from the earth.’\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
‘And He will then take you back to it, and again remove you from it.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
‘And it is Allah Who made the earth a bed for you.’\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
‘So that you may tread the wide roads in it.’”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Prayed Nooh, “O my Lord! They have disobeyed me, and they follow the one whose wealth and children increase nothing for him except ruin.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
“And they carried out a very sinister scheme.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
“And they said, ‘Do not ever abandon your Gods – and never abandon Wadd, or Suwa – or Yaghuth or Yauq or Nasr.’”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
“And they have misled a large number; and (I pray that) You increase nothing for the unjust except error.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
Because of their sins they were drowned and then put into the fire; so they did not find any supporter for themselves against Allah. (Punishment in the grave is proven by this verse.)\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And prayed Nooh, “O my Lord! Do not leave any of the disbelievers dwelling in the land.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
“Indeed, if You spare them, they will mislead your bondmen – and their descendants, if any, will be none except the wicked, very ungrateful.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
“O my Lord! Forgive me, and my parents, and the believers who are in my house, and all other Muslim men and Muslim women; and do not increase anything for the unjust except ruin.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “I have received the divine revelation that some jinns attentively listened to my recitation, so they said, ‘We have heard a unique Qur’an.’\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
‘That guides to the path of goodness, we have therefore accepted faith in it; and we shall never ascribe anyone as a partner to our Lord.’\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
‘And that our Lord’s Majesty is Supreme – He has neither chosen a wife nor a child.’\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
‘And that the fool among us used to utter false exaggerations against Allah.’\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
‘Whereas we thought that men and jinns would never fabricate a lie against Allah!’\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
‘And indeed some men among humans used to take the protection of some men among jinns, so it further increased their haughtiness.’\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
‘And that they assumed, like you humans assume, that Allah would not send any Noble Messenger.’\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
‘And we reached the sky, so we found it strongly guarded and filled with comets.’\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
‘And that we sometimes used to sit in some places in the sky, to listen; so whoever now listens finds a fiery comet waiting for him.’\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
‘And we do not know whether harm is intended for those on the earth, or whether their Lord intends goodness for them.’\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
‘And among us some are virtuous and some are the other type; we are split into several branches.’\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
‘And we are certain that we cannot defeat Allah in the earth, nor can we run out of His grasp.’\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
‘And that when we heard the guidance, we accepted faith in it; so whoever accepts faith in his Lord, has no fear – neither of any loss nor of any injustice.’\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
‘And that some among us are Muslims and some are the unjust; and whoever has accepted Islam – it is they who have thought rightly.’\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
‘And as for the unjust – they are the fuel of hell.’”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
And proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “I have received the divine revelation that ‘Had they remained upright on the straight path, We would have given them abundant water.’\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
‘In order to test them with it; and whoever turns away from the remembrance of his Lord – He will put him in a punishment that keeps on increasing.’\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
‘And that the mosques are for Allah only – therefore do not worship anyone along with Allah.’\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
‘And that when Allah’s bondman stood up to worship Him, the jinns had almost crowded upon him.’”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “I worship only Allah, and I do not ascribe any partner to Him.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “I am not the master of any harm or benefit for you.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say, “No one will ever save me from Allah, and other than Him, I will not find any refuge.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
“I only convey the commands from Allah, and His messages; and whoever disobeys the commands of Allah and His Noble Messenger – then indeed for him is the fire of hell, in which they will remain for ever and ever.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
Till the time when they will see what they are promised – so they will now come to know whose aide is weak, and who is lesser in number.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say (O dear Prophet Mohammed – peace and blessings be upon him), “I do not know whether what you are promised is close or if my Lord will postpone it for a while.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
The All Knowing of all the hidden does not give anyone the control over His secrets.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
Except to His chosen Noble Messengers – so He appoints guards in front and behind him. (Allah gave the knowledge of the hidden to the Holy Prophet – peace and blessings be upon him.)\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
In order to see that they have conveyed the messages of their Lord – and His knowledge encompasses all whatever they have, and He has kept all things accounted for.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O the One Wrapped in piety! (Prophet Mohammed – peace and blessings be upon him)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Stand up for worship during the night, except for some part of it.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
For half the night, or reduce some from it.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
Or increase a little upon it, and recite the Qur’an slowly in stages.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
Indeed We shall soon ordain a heavy responsibility upon you.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Indeed getting up in the night is tougher, and the words flow with strength.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
Indeed you have a lot of matters during the day.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
And remember the name of your Lord and, leaving others, devote yourself solely to Him.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
Lord of the East and Lord of the West – there is no God except Him, therefore make Him your sole Trustee of affairs.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And patiently endure upon what the disbelievers say, and leave them for good.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
And leave them to Me – these wealthy deniers – and give them some respite.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
Indeed We have heavy fetters and a blazing fire.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
And food that chokes, and a painful punishment.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
On a day when the earth and the mountains will tremble, and the mountains turn into dunes of flowing sand.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
We have indeed sent a Noble Messenger towards you, a present witness over you – the way We had sent a Noble Messenger towards Firaun.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
In response Firaun disobeyed the Noble Messenger, so We seized him with a severe seizure.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
So how will you save yourselves, if you disbelieve, on a day that will turn children old?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
The heaven will split asunder with its grief; the promise of Allah will surely occur.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
This is indeed an advice; so whoever wishes may take the path towards his Lord.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Indeed your Lord knows that you stand up in prayer, sometimes almost two-thirds of the night, and sometimes half the night or sometimes a third of it – and also a group of those along with you; Allah keeps measure of the night and day; He knows that you, O Muslims, will not be able to measure the night, so He has inclined towards you with mercy – therefore recite from the Qur’an as much as is easy for you; He knows that soon some of you will fall ill, and some will travel in the land seeking the munificence of Allah, and some will be fighting in Allah’s cause; therefore recite from the Qur’an as much as is easy for you, and establish prayer and pay the obligatory charity, and lend an excellent loan to Allah; and whatever good you send ahead for yourselves, you will find it with Allah, better and having a great reward; and seek forgiveness from Allah; indeed Allah is Oft Forgiving, Most Merciful.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O the Cloaked One! (Prophet Mohammed – peace and blessings be upon him)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Rise up and warn!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
And proclaim the Purity of your Lord.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
And keep your clothes clean.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
And stay away from idols.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
And do not favour others in order to receive more.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
And for the sake of your Lord, patiently endure.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
So when the Trumpet will be blown.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
So that is a tough day.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
Not easy upon the disbelievers.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave him to Me, the one whom I created single.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
And gave him vast wealth.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
And gave him sons present before him.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
And made several preparations for him.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
Yet he desires that I should give more.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
Never! For he is an enemy to Our signs!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
Soon I shall mount him on Saood, the hill of fire.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
Indeed he thought, and inwardly decided.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
So accursed be he, how evilly did he decide!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
Again accursed be he, how evilly did he decide!\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
He then dared to lift his gaze.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
Then frowned and grimaced.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
Then he turned away, and was haughty.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
And said, “This is nothing but magic learnt from earlier men.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
“This is nothing but the speech of a man.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
I will soon fling him into hell.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
And what have you understood, what hell is!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It neither leaves, nor spares.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
It strips away the hide of man.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Above it are nineteen guards.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
We have not appointed the guards of hell, except angels; and did not keep this number except to test the disbelievers – in order that the People given the Book(s) may be convinced, and to increase the faith of the believers – and so that the People given the Book(s) and the Muslims may not have any doubt – and so that those in whose hearts is a disease and the disbelievers, may say, “What does Allah mean by this amazing example?” This is how Allah sends astray whomever He wills, and guides whomever He wills; and no one knows the armies of Allah except Him; and this is not but an advice to man.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
Yes, never!* By oath of the moon. (Hell will never spare the disbelievers).\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
And by oath of the night when it turns back.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
And by oath of the morning, when it spreads light.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
Indeed hell is one of the greatest entities.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
Warn the men.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
For the one among you who wishes to come forward or stay back.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every soul is mortgaged for its own deeds.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
Except those on the right side.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
In Gardens, they seek answers,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
- From the guilty.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
“What took you into the hell?”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They said, “We never used to offer the prayer.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
“Nor used to feed the needy.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
“And used to dwell on evil matters with those who think evilly.”\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
“And used to deny the Day of Justice.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
“Till death overcame us.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
So the intercession of the intercessors will not benefit them. (The disbelievers will not have any intercessor.)\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
So what is the matter with them that they turn away from the advice?\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
As if they were startled donkeys –\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
Fleeing away from a lion.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Rather each one of them desires that he should be given open Books.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
Never! In fact they do not fear the Hereafter.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
Yes indeed, this is an advice.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
So whoever wills may heed advice from it.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
And what advice will they heed, except if Allah wills? Only He deserves to be feared, and His only is the greatness of forgiving.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen I swear by the Day of Resurrection.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
And by oath of the soul that reproaches itself.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Does man assume that We will never assemble his bones?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Surely yes, why not? We can properly make all his phalanxes.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
In fact man wishes to commit evil in front of Him!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He asks, “When will be the Day of Resurrection?”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
So when the eyes will be blinded by light.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
And the moon will be eclipsed.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
And the sun and the moon will be united.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
On that day man will cry out, “Where shall I flee?”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
Never! There is no refuge!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
On that day, the station is only towards your Lord.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
On that day, man will be informed of all what he sent ahead and left behind.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
In fact, man himself is keeping an eye on his state of affairs!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
And even if he presents all the excuses he has, none will be listened to.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
O dear Prophet (Mohammed – peace and blessings be upon him), do not cause your tongue to move along with the Qur’an in order to learn it faster.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
Indeed assembling the Qur’an and reading it are upon Us.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
So when We have read it, you should thereupon follow what is read.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
Then indeed, to explain its details to you is upon Us.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
None except you, O disbelievers – you love what you have, the fleeting one.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
And you have forsaken the Hereafter.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
On that day, some faces will shine with freshness.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
Looking toward their Lord.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And on that day some faces will be ghastly.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
Knowing that they will be subjected to a torment that breaks the backs.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
Yes indeed, when the soul will reach up to the throat.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
And they will say, “Is there any one – any magician?”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
And he will realise that this is the parting.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
And one shin will curl up with the other shin.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
On that day, the herding will be only towards your Lord.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
Neither did he believe it to be true, nor did he offer the prayer.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
But he denied and turned away.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
Then he went back to his home in pride.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Your ruin has come close, still closer.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
Again your ruin has come close, still closer.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Does man assume that he will be let loose?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not just a drop of the semen that is discharged?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
He then became a clot – so Allah created him, then made him proper.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
So created from him a pair, the male and female.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
So will He, Who has done all this, not be able to revive the dead?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Indeed there has been a time for man, when even his name did not exist anywhere.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
Indeed We have created man from mixed semen; in order to test him – We therefore made him hearing, knowing.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
We have indeed shown him the way – whether he is grateful or ingrate.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
We have indeed kept prepared chains, and shackles and a blazing fire for the disbelievers.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
Indeed the virtuous will drink from a cup, containing a mixture of Kafoor.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
The Kafoor is a spring, from which the chosen bondmen of Allah will drink, causing it to flow wherever they wish inside their palaces.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
They fulfil their pledges, and fear a day the evil of which is widespread.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
And out of His love, they give food to the needy, the orphan and the prisoner.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
They say to them, “We give you food, only for the sake of Allah – we do not seek any reward or thanks from you.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
“Indeed we fear from our Lord a day which is extremely bitter, most severe.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
So Allah saved them from the evil of that day, and gave them freshness and joy.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
And gave them Paradise and silk clothes, as a reward for their patience.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
Reclining in it, upon thrones; they will not see the hot sunshine in it, nor the bitter cold.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
And its shade will cover them, and its fruit clusters brought down low for them.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
Rounds of silver cups and silver beakers, looking like glass, will be presented upon them.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
Glass made from silver, which the servers have filled up to the measure.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
And in Paradise they will be given to drink cups, filled with a mixture of ginger.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
Which is a spring in Paradise called Salsabeel.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
Immortal youths shall surround them, waiting upon them; when you see them, you would think they are scattered pearls.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
And when you look towards it, you will see serenity and a great kingdom.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
In it they adorn clothes of fine green silk and gold embroidery; and they are given silver bracelets to wear; and their Lord gave them pure wine to drink.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
It will be said to them, “This is your reward – indeed your efforts have been appreciated.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
Indeed We have sent down the Qur’an upon you, in stages.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
Therefore stay patient upon your Lord’s command, and do not listen to any of the sinners or ingrates among them.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And remember the name of your Lord morning and evening.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
And prostrate for Him in a part of the night, and proclaim His purity into the long night.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Indeed these people love what they have, the fleeting one, and have forsaken the immensely important day behind them.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
It is We Who created them, and strengthened their skeleton; and We can replace them with others like them, whenever We will.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
This is indeed an advice; so whoever wishes may take the path towards his Lord.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
And what will you wish, except if Allah wills; indeed Allah is All Knowing, Wise.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He admits into His mercy, whomever He wills; and for the unjust He has kept prepared a painful punishment.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By oath of those that are sent, one after the other. (The verses of the Holy Qur’an or the angels or the winds).\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
Then by oath of those that push with a strong gust.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
Then by oath of those that lift and carry.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
Then by those that clearly differentiate the right and wrong.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
And then by those that instil Remembrance into the hearts.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
To complete the argument or to warn.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Indeed what you are promised, will surely befall.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
So when the lights of the stars are put out.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
And when the sky is split apart.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
And when the mountains are made into dust and blown away.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
And when the time of the Noble Messengers arrives.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
For which day were they appointed?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
For the Day of Decision.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what do you know, what the Day of Decision is!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Ruin is for the deniers on that day!\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy the earlier people?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
We shall then send the latter after them.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
This is how We deal with the guilty.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Ruin is for the deniers on that day!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you from an abject fluid?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
We then kept it in a safe place.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
For a known calculated term.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
We then calculated; so how excellently do We control!\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Ruin is for the deniers on that day!\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Did We not make the earth a storehouse?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
For the living and the dead among you?\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
And We placed high mountains as anchors in it and gave you sweet water to drink.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Ruin is for the deniers on that day!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
“Move towards what you used to deny!”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
“Move towards the shadow of the smoke having three branches.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
“Which neither gives shade, nor saves from the flame.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
Indeed hell throws up sparks like huge castles.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
Seeming like yellow camels.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Ruin is for the deniers on that day!\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
This is a day in which they will not be able to speak.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
Nor will they be given permission to present excuses.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Ruin is for the deniers on that day!\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
This is the Day of Decision; We have gathered you and all the earlier men.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
If you now have any conspiracy, carry it out on Me.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Ruin is for the deniers on that day!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Indeed the pious are in shade and springs.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
And among fruits whichever they may desire.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
“Eat and drink with pleasure, the reward of your deeds.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
This is how We reward the virtuous.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Ruin is for the deniers on that day!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
“Eat and enjoy for a while – indeed you are guilty.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Ruin is for the deniers on that day!\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
And when it is said to them, “Offer the prayer” – they do not!\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Ruin is for the deniers on that day!\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
So after this, in what matter will they believe?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen What are they questioning each other about?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
About the great tidings!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
Regarding which they hold different views.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
Surely yes, they will soon come to know!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Again surely yes, they will soon come to know!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Did We not make the earth a bed?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
And the mountains as pegs?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And it is We who created you in pairs.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
And made your sleep a rest.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
And made the night a cover.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
And made the day for seeking livelihood.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And built seven strong roofs above you.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
And have kept a very bright lamp in it.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
And then sent down hard rain from the water bearing clouds.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
In order to produce grain and plants with it.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
And dense gardens.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Indeed the Day of Decision is a time fixed.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
The day when the Trumpet will be blown – you will therefore come forth in multitudes.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
And the heaven will be opened – it therefore becomes like gates.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
And the mountains will be moved – they will therefore become like mirages.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Indeed hell is lying in ambush.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
The destination of the rebellious.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
They will remain in it for ages.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
They will neither taste anything cool in it, nor anything to drink.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
Except hot boiling water and hot pus discharged from the people of hell.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
The reward to each is according to what he is.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
Indeed they had no fear of the account.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
And they denied Our signs to the extreme.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
And We have kept recorded everything in a Book, accounted for.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
Therefore taste it now – We shall not increase anything for you except the punishment.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Indeed the place of success is for the pious.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
Gardens and grapes.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
And maidens of a single age.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
And an overflowing cup.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
In which they shall neither hear lewd talk, nor any lie.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
A reward from your Lord – a grossly sufficient bestowal.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
Lord of the heavens and the earth, and all whatever is between them – the Most Gracious – with Whom no one will have the right to talk.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
The day when Jibreel and all the angels will stand in rows; none will be able to speak except one whom the Most Gracious commands and who spoke rightly. (Prophet Mohammed – peace and blessings be upon him – will be the first to be granted permission to intercede.)\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is the True Day; therefore whoever wills may take the path towards his Lord.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
We warn you of a punishment that has come near; a day on which man will see what his own hands have sent ahead, and the disbeliever will say, “Alas – if only I were dust!”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By oath of those who harshly pull out the soul. (Of the disbeliever)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
And who softly release the soul. (Of the believer)\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
And who glide with ease.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
And who quickly present themselves.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
And who plan the implementation.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
On the day when the trembling one will tremble. (The disbelievers will certainly taste the punishment.)\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
And the following event will come after it.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
Many a heart will flutter on that day!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
Unable to lift their gaze.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
The disbelievers say, “Will we really return to our former state?”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
“When we have become decayed bones?”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They said, “So this return is an obvious loss!”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
So that is not but a single shout.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
So they will immediately be in an open plain.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Did the news of Moosa reach you?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
When his Lord called him in the holy valley of Tuwa.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
That “Go to Firaun – he has rebelled.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
“Tell him ‘Do you have the inclination to become pure?’\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
‘And I may guide you to your Lord, so that you may fear.’”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
So Moosa showed him a magnificent sign.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
In response, he denied and disobeyed.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
He then turned away, striving in his effort.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
So he gathered the people, and proclaimed.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
And then said, “I am your most supreme lord.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
Allah therefore seized him, in the punishment of this world and the Hereafter.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Indeed in this is a lesson for one who fears.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
Do you think that it is harder to create you or the heavens? Allah has created it.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He raised its roof and made it proper.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
And He made its night dark, and started its light.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And after it spread out the earth.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
And from it produced its water and its pasture.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And solidified the mountains.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
In order to benefit you and your cattle.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
So when the greatest universal disaster arrives,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
On that day man will recall all what he strove for.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
And hell will be made visible to all those who can see.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
So for one who rebelled,\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
And preferred the worldly life,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
Then indeed hell only is his destination.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
And for one who feared to stand before his Lord and restrained his soul from desire,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
Then indeed Paradise only is his destination.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They (the disbelievers) ask you regarding the Last Day, as to when is its appointed time.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
What concern do you have regarding its explanation? (You are not bound to tell them)\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
Towards your Lord only is its conclusion.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
You are but a Herald of Warning, for one who fears it.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
The day when they will see it, it will seem as if they had not stayed on earth except for an evening or its morning.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen He frowned and turned away.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
Because the blind man had come in his august presence.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
And what do you know, he may be of the pure!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
Or that he may accept advice, so the advice may benefit him.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
For him who does not care,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
So you are after him!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
And you have nothing to lose if he does not become pure.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
And for him who came to you striving,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
And whereas he fears,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
So you leave him, and are engrossed elsewhere!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
Not this way – this is the advice.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
So whoever wishes may remember it.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
On honourable pages.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
Exalted, pure.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
Written by the hands of emissaries.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
Who are noble, virtuous.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
May man be slain – how ungrateful he is!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
From what did He create him?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
From a drop of liquid; He created him and then set several measures for him.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
Then eased the way for him.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
Then gave him death, so had him put in the grave.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
Then, when He willed, He brought him out. (As during the night of Holy Prophet’s ascension, when all the Prophets gathered behind him in the Al Aqsa mosque in Jerusalem. Or when Allah will raise everyone on the Day of Resurrection.)\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
Not one – he has not yet completed what he was commanded.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
So man must look at his food.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
That We watered it in abundance.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
Then We split the earth properly.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
Thereby produced grain in it.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
And grapes and fodder,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
And olives and date palms,\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
And dense gardens,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
And fruits and grass,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
In order to benefit you and your cattle.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
So when the deafening Shout arrives,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
On that day man will run away from his brother.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
And from his mother and father,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
And from his wife and sons.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
On that day, each one has just one issue, which is enough for him.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Many a face will be glittering on that day.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
Laughing, rejoicing.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
And many a face will be covered with dust on that day.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
Blackness overcoming them.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
It is they, the disbelievers, the sinners.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sunlight is rolled up.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
And when the stars fall down.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
And when the mountains are driven.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
And when milch camels roam abandoned.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
And when wild animals are herded together.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
And when the seas are set afire.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
And when the souls are paired.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
And when the girl-child who was buried alive is asked.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
Upon what sin was she killed for.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
And when the Records of Account are laid bare.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
And when the heaven is torn away.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
And when hell is further enflamed.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
And when Paradise is brought near.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
Every soul will then come know what it has brought.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
So by oath of those that revolve. (The planets.)\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
Who move straight and stop.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
And by oath of the night when it turns back.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
And by oath of the morning when it takes birth.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
This is indeed the recitation of an honoured Noble Messenger. (Angel Jibreel – peace and blessings be upon him.)\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
The mighty, the honoured in the presence of the Lord of the Throne.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
The one who is obeyed, and trustworthy. (Other angels obey angel Jibreel).\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
And your companion is not insane.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
And indeed he saw him on the clear horizon. (Prophet Mohammed saw Angel Jibreel in his true shape – peace and blessings be upon them).\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
And this Prophet is not miserly upon the hidden. (Allah gave the knowledge of the hidden to the Holy Prophet – peace and blessings be upon him.)\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
And the Qur’an is not the recitation of Satan the outcast.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
So where are you going?\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
That is but an advice to the entire creation!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
For the one among you who wishes to become upright.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
And what will you wish, except if Allah wills – the Lord of the Creation.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the heaven splits open.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
And when the stars fall down.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
And when the oceans are swept away.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
And when the graves are overturned.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
Every soul will come to know what it has sent ahead and what it left behind.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O man! What has deceived you away from your Lord, the Most Beneficent?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
The One Who created you, then moulded you, then made you proper?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
He moulded you into whatever shape He willed.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
Not at all – but rather you deny the establishment of Justice.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
And indeed there are some guardians over you.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
The honourable recorders.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
Knowing all what you may do.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Indeed the virtuous are in serenity.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
And indeed the sinners are in hell.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
They will enter it on the Day of Justice.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
And will not be able to hide from it.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
And what do you know – of what sort is the Day of Justice!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what do you know – of what sort is the Day of Justice!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
The day on which no soul will have the authority over any other soul; and on that day, the entire command belongs to Allah.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Ruin is for the defrauders. (Those who measure less.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
Those who when they take the measure from others, take it in full!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
Whereas when they give others after measuring or weighing, they give them less!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
What! Do they not expect that they will be raised?\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
(To be raised) for a Great Day?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
The day when everyone will stand before the Lord Of The Creation.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
Indeed, the record of the disbelievers is in the lowest place, the Sijjeen.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
And what do you know, how (wretched) the Sijjeen is!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
The record is a sealed text.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Ruin is for the deniers on that day!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
Those who deny the Day of Justice.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
And none will deny it, except every transgressor, rebel.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
When you recite Our verses to him, he says, “Stories of earlier men!”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
Not at all – but rather their earnings have heaped rust upon their hearts.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
Yes indeed – they will be deprived of seeing their Lord on that day.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Then indeed they have to enter hell.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
It will then be said, “This is what you used to deny.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
Indeed the record of the virtuous is in the highest place, the Illiyin.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
And what do you know what the Illiyoon are!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
The record is a sealed text.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
Which is witnessed by the close ones.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Indeed the virtuous are in serenity.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
On thrones, watching.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
You will recognise the freshness of serenity on their faces.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They will be given pure wine to drink, which is kept preserved, sealed.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
Its seal is upon musk; and for this should those who crave be eager.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
And it is mixed with Tasneem.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
The spring from which drink the ones close to Allah.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Indeed the guilty used to laugh at the believers.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
And when the believers used to pass by, they used to gesture at each other with their eyes.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
And whilst returning to their homes, they used to return rejoicing.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
And upon seeing the Muslims, they used to say, “Indeed they have gone astray.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
Whereas they have not at all been sent as guardians over them.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
So this day it is the believers who laugh at the disbelievers.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
On high thrones, watching.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Did not the disbelievers get repaid for what they used to do?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the heaven breaks apart.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
And it listens to the command of its Lord – and that befits it.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
And when the earth is spread out.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
And it unburdens itself of all that is in it, and becomes empty.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
And it listens to the command of its Lord – and that befits it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O man, indeed you have to surely run towards your Lord, and to meet him.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
So whoever is given his record of deeds in his right hand –\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
Soon an easy account will be taken from him.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
And he will return to his family rejoicing.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
And whoever is given his record of deeds behind his back –\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
Soon he will pray for death.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
And will go into the blazing fire.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
Indeed he used to rejoice in his home.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
He assumed that he does not have to return.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
Surely yes, why not? Indeed his Lord is seeing him.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
So by oath of the late evening’s light.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
And by oath of the night and all that gathers in it.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
And by oath of the moon when it is full.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
You will surely go up level by level.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
What is the matter with them that they do not accept faith?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
And when the Qur’an is recited to them, they do not fall prostrate? (Command of Prostration \# 13)\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
In fact the disbelievers keep denying.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
And Allah well knows what they conceal in their hearts.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
Therefore give them the glad tidings of a painful punishment.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
Except those who believed and did good deeds – for them is a reward that will never end.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By oath of the heaven which contains the constellations.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
And by oath of the Promised Day.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
And by oath of the day that is a witness and by oath of a day in which the people present themselves.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
Accursed be the People of the Ditch!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
The people of the fuelled blazing fire.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
When they were sitting at its edge.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
And they themselves are witnesses to what they were doing to the Muslims!\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
And what did they dislike from the Muslims, except that the Muslims accepted faith in Allah the Most Honourable, the Most Praiseworthy?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
To Him only belongs the kingship of the heavens and the earth; and Allah is a Witness over all things.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Indeed those who troubled the Muslim men and Muslim women, and then did not repent – for them is the punishment of hell, and for them is the punishment of fire.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
Indeed those who believed and did good deeds – for them are Gardens beneath which rivers flow; this is the great success.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Indeed the seizure of your Lord is very severe.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
Indeed it is He Who initiates and redoes.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He only is the Oft Forgiving, the Beloved of His bondmen.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Master of the Honourable Throne.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
Always doing whatever He wills.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Did the story of the armies reach you?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
(The armies of) Firaun and the tribe of Thamud.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
In fact the disbelievers are in denial.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
And Allah is after them, has them surrounded.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
In fact it (what they deny) is the Noble Qur’an.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
In the Preserved Tablet.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By oath of the heaven, and by oath of the nightly arriver.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
And have you understood what the nightly arriver is?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
The very brightly shining star!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
There is not a soul that does not have a guardian over it.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
So man must consider from what he has been created.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
Created from a gushing fluid.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
That is issued from between the backs and the ribs.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Indeed Allah is Able to return him.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
A day when the secrets will be examined.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
So man will neither have any strength nor any aide.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By oath of the sky from which comes down the rain.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
And by oath of the earth which flourishes with it.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
Indeed the Qur’an is a decisive Word.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
And is not a matter of amusement.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
Indeed the disbelievers carry out their evil schemes.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
And I secretly plan.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
Therefore give them some respite – give them some time.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Proclaim the Purity of your Lord, the Supreme.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
The One Who created, and then made proper.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
And the One Who kept proper measure and then guided.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
The One Who produced pasture.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
Then made it dry and dark.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We shall now make you read (O dear Prophet Mohammed – peace and blessings be upon him), so you will not forget.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
Except what Allah wills; indeed He knows all the evident and all the concealed.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
And We shall create the means of ease for you.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
Therefore advise, if advising is beneficial.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
Soon whoever fears will heed advice.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
And the most wicked will stay away from it.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
The one who will enter the biggest fire.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
Then he neither dies in it, nor lives.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
Indeed successful is the one who became pure.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
And who mentioned the name of his Lord, then offered prayer.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
But rather you prefer the life of this world!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
Whereas the Hereafter is better and everlasting.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
Indeed this is in the former scriptures.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
In the Books of Ibrahim and Moosa.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Certainly the news of the calamity that will overwhelm has come to you!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
Many a face will be disgraced on that day.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
Labouring, striving hard.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
(Yet) Going into the blazing fire.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
Made to drink water from the boiling hot spring.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
There is no food for them except thorns of fire.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
Which neither give strength nor satisfy the hunger.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
Many a face will be in serenity on that day.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
Rejoicing over their efforts.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
In a high Garden.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
In which they will not hear any lewd speech.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
In it is a flowing spring.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
In which are high thrones.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
And chosen goblets.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
And arranged carpets.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
And linen spread out.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
So do they not see the camel – how it has been created?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And the heaven – how it has been raised?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And the mountains – how they have been established?\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And the earth – how it has been spread out?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
Therefore advise; indeed you are a proclaimer of advice. (The Holy Prophet is a Remembrance from Allah.)\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
You are not at all a guardian over them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
Except whoever turns away and disbelieves –\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
So Allah will mete out to him the greatest punishment.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Indeed only towards Us is their return\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
Then indeed only upon Us is their reckoning.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By oath of the (particular) dawn.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
And by oath of ten nights.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
And by oath of the even and the odd.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
And by oath of the night when it recedes\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Why is there an oath in this, for the intelligent?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Did you not see how did your Lord deal with (the tribe of) Aad?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
(And) the tall giants of Iram?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
Like whom no one else was born in the cities.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And the tribe of Thamud, who hewed rocks in the valley.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And with Firaun, who used to crucify.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
Those who rebelled in the cities,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
And who then spread a lot of turmoil in them.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
Therefore your Lord struck them hard with the means of punishment.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
Indeed nothing is hidden from the sight of your Lord.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
So man, whenever his Lord tests him by giving him honour and favours – thereupon he says, “My Lord has honoured me.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
And if He tests him and restricts his livelihood – thereupon he says, “My Lord has degraded me!”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
Not at all – but rather you do not honour the orphan.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
And do not urge one another to feed the needy.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
And you readily devour the inheritance with greed.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
And you harbour intense love for wealth.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
Most certainly – when the earth is smashed and blown to bits.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
And when the command of your Lord comes – and the angels row by row,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
And when hell is brought that day – on that day will man reflect, but where is the time now to think?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say, “Alas – if only I had sent some good deeds ahead, during my lifetime!”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
So on that day, no one punishes like He does!\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
And no one binds like He does!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
O the contented soul!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
Return towards your Lord – you being pleased with Him, and He pleased with you!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
Then enter the ranks of My chosen bondmen!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
And come into My Paradise!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen I swear by this city (Mecca) –\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
For you (O dear Prophet Mohammed – peace and blessings be upon him) are in this city.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And by oath of your forefather Ibrahim, and by you – his illustrious son!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
We have indeed created man surrounded by hardships.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Does man think that no one will ever have power over him?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He says, “I destroyed vast wealth.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Does man think that no one saw him?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Did We not make two eyes for him?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
And a tongue and two lips?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And did We not guide him to the two elevated things?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
So he did not quickly enter the steep valley.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
And what have you understood, what the valley is!\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
The freeing of a slave!\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
Or the feeding on a day of hunger.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
Of a related orphan,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
Or of a homeless needy person!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
And moreover to be of those who accepted faith, and who urged patience to one another and who urged graciousness to one another.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
These are the people of the right.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
And those who denied Our signs, are the people of the left.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
Upon them is a fire, in which they are imprisoned, closed and shut above them.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By oath of the sun and its light\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
And by oath of the moon when it follows the sun\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
And by oath of the day when it reveals it\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
And by oath of the night when it hides it\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
And by oath of the heaven and by oath of Him Who made it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
And by oath of the earth and by oath of Him Who spread it.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
And by oath of the soul and by oath of Him Who made it proper.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
And inspired in it the knowledge of its sins and its piety.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
Indeed successful is the one who made it pure.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
And indeed failed is the one who covered it in sin.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
The tribe of Thamud denied with rebellion.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
When the most wicked among them stood up in defiance.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
So the Noble Messenger of Allah said to them, “Stay away from the she camel of Allah, and from its turn to drink.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
In response they belied him, and hamstrung the she camel – so Allah put ruin over them because of their sins and flattened their dwellings.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
And He does not fear its coming behind (to take vengeance).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By oath of the night when it covers\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
And by oath of the day when it shines\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
And by oath of the One Who created the male and the female.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
Indeed your efforts differ.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
So for one who gave and practised piety\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
And believed the best matter to be true\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
So We will very soon provide him ease.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
And for him who hoarded wealth and remained carefree,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
And denied the best matter,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
So We will very soon provide him hardship.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
His wealth will not avail him when he falls into ruin.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Indeed guiding is upon Us.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
And indeed the Hereafter and this world both belong to Us.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
I therefore warn you of the fire that is ablaze.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
None except the most wicked will enter it.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
The one who denied and turned away.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
He will be far away from the most pious. (The first Caliph S. Abu Bakr Siddiq)\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
Who gives his wealth in order to be pure.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
And no one has done a favour to him, for which he should be compensated.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
He desires only to please his Lord, the Supreme.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
And indeed, soon he will be very pleased.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By oath of the late morning,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
And by oath of the night when it covers,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Your Lord has not forsaken you nor does He dislike you!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
And indeed the latter is better for you than the former.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
And indeed your Lord will soon give you so much that you will be pleased. (Allah seeks to please the Holy Prophet – peace and blessings be upon him.)\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find you an orphan, so provided you shelter?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
And found you deeply engrossed in His love, so directed you?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
And found you in need, so made you prosperous?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Therefore do not oppress the orphan.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
And do not rebuke the beggar.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
And abundantly proclaim the favours of your Lord.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Did We not widen your bosom?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
And relieve you of the burden –\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
Which had broken your back?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And We have exalted your remembrance for you.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
So indeed with hardship is ease.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
Indeed with hardship is ease.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
So when you finish the prayer, strive in supplication.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
And incline towards your Lord.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By oath of the fig and of the olive,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
And by oath of Mount Sinai,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
And by oath of this secure land,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
We have indeed created man in the best shape.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
We then turned him towards all the lowest of the low states.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
Except those who accepted faith and did good deeds – for them is a never ending reward.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
So after this, what causes you to deny the judgement?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not Allah the Greatest Judge upon all judges?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Read with the name of your Lord Who created,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
Created man from a clot.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Read, and your Lord only is the Most Beneficent,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
The One Who taught to write with the pen.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
The One Who taught man all what he did not know.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
Yes indeed, man is surely rebellious.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
As he considers himself independent!\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Indeed towards your Lord only is the return.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
What is your opinion – regarding him who forbids –\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
A bondman when he offers the prayer?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
What is your opinion – if he were upon guidance,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
He would enjoin piety, so how good it would be!\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
What is your opinion – if he denies and turns away, how wretched will be his state!\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Did he not realise that Allah is watching?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
Yes certainly, if he does not desist, We will seize him by the forelock.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
A forelock that lies, is sinful.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
So let him now call his gang!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We will now call the guards!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
Yes indeed; do not listen to him – and prostrate, and become close to Us. (Command of Prostration \# 14)\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen We have indeed sent down the Qur’an in the Night of Destiny.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
And what have you understood, what the Night of Destiny is!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Destiny is better than a thousand months.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
In it descend the angels and Jibreel, by the command of their Lord – for all works.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
It is peace until the rising of dawn.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen The disbelieving People of the Book(s) and the polytheists would not have left their religion until the clear proof came to them.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
(The clear proof is) the Noble Messenger from Allah, who reads the pure pages.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
In which are written proper affairs.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
Nor did the People of the Book(s) get divided until after the clear proof came to them.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
And they were ordered only to worship Allah, believing purely in Him – devoted solely (to Him), and to establish the prayer and to pay the obligatory charity – and this is the straight religion.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Indeed all disbelievers, the People of the Book(s) and the polytheists, are in the fire of hell – they will remain in it for ever; it is they who are the worst among the creation.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
Indeed those who accepted faith and did good deeds – it is they who are the best among the creation.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their reward is – with their Lord – everlasting Gardens of Eden beneath which rivers flow, in which they will abide for ever and ever; Allah is pleased with them and they are pleased with Him; this is for one who fears his Lord.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth is shaken with its appointed tremor.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
And the earth throws out its burdens.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
And man says, “What has happened to it?”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
On that day earth will narrate its news,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
Because your Lord sent a command to it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
On that day men will return towards their Lord, in different groups, in order to be shown their deeds.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
So whoever does a good deed equal to the weight of the minutest particle, will see it.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
And whoever does an evil deed equal to the weight of the minutest particle, will see it.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By oath of those that sprint, breathing heavily. (The horses used in Holy War.)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
Striking stones with their hooves, sparking fire.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
And by oath of those who raid at dawn.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
So thereupon raising dust.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
Then penetrate to the centre of the enemy army.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Indeed man is very ungrateful towards his Lord.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
And indeed he himself is a witness to it.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And indeed he loves wealth to the extreme.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
So does he not know? When those in the graves are raised,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
And all what lies in the breasts is opened –\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
On that day their Lord surely knows all about them!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The event that terrifies the hearts!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the event that terrifies the hearts?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
And what have you understood, what the event that terrifies the hearts is!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
The day when men will be like scattered moths.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
And mountains will be like flying wool.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
So for one whose scales prove heavy,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
He is therefore in the desired bliss.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
And for one whose scales prove light,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
He is in the lap of one that abases.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
And what have you understood, what the one that abases is!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
A flaming fire!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen The craving for excess wealth kept you people neglectful.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
Until you confronted the graves.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
Yes certainly, you will soon realise!\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Again, yes certainly, you will soon realise!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
Yes certainly, if you had believed with certainty, you would not have craved for wealth.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
Indeed you will see hell.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
Again, indeed you will see it with certainty.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then, on that day, you will surely be questioned regarding the favours.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By oath of this era of yours (O dear Prophet Mohammed – peace and blessings be upon him).\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Indeed man is surely in a loss.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
Except those who accepted faith, and did good deeds and urged one another to the truth – and urged one another to have patience.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Ruin is for every open slanderer, backbiter.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
Who accumulated wealth and hoarded it, counting.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
Does he think that his wealth will prolong his stay on earth forever?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
Never! He will certainly be thrown into the Crushing One.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
And what have you understood what the Crushing One is!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
The fire of Allah, that is ablaze.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
Which will climb on to the hearts.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
Indeed it will be shut over them.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
In extended columns.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen O dear Prophet (Mohammed – peace and blessings be upon him), did you not see how did your Lord deal with the People of the Elephant?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not put their scheme into ruin?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And send flocks of birds upon them,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
Which hit them with stones of baked clay,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
So He made them like the leftover devoured leaves of farms?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen Because of giving alliances to the Quraish.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
(We) gave them alliances during both their travels of winter and summer.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
So they must worship the Lord of this House. (The Ka’aba)\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
The One Who gave them food in hunger, and bestowed them safety from a great fear.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Just look at him, who belies the religion!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
So it is he, who pushes away the orphan,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
And does not urge to feed the needy.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
So ruin is to those offerers of prayer –\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
Those who are neglectful of their prayer.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
Those who make a display (of their deeds).\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
And do not let others ask for small utilities.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen We have indeed bestowed the Kausar* upon you (O dear prophet Mohammed – peace and blessings be upon him). (*Infinite excellent qualities / the greatest number of followers / the sweet pond on the Day of Resurrection)\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
So offer the prayers for your Lord, and perform the sacrifice.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
Indeed it is your enemy who is bereft of all goodness.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Proclaim, (O dear prophet Mohammed – peace and blessings be upon him), “O disbelievers!”\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
Neither do I worship what you worship.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
Nor do you worship Whom I worship.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
And neither will I ever worship what you worship.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
Nor will you worship Whom I worship.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
For you is your religion, and for me is mine.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When the help and victory of Allah come,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
And you see people entering the religion of Allah in multitudes,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
Then proclaim the Purity of your Lord while praising Him, and seek forgiveness from Him; indeed He is the Most Acceptor of Repentance.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen May both the hands of Abu Lahab be destroyed – and they are destroyed!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth did not benefit him in the least, nor did whatever he earned.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
He will soon enter the flaming fire.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
And so will his wife; carrying a bundle of firewood on her head.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
A rope made from palm fibre around her neck!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “He is Allah, He is One.”\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
“Allah is the Un-wanting.” (Perfect, does not require anything.)\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
“He has no offspring, nor is He born from anything.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
“And there is none equal to Him.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “I take refuge of the One Who creates the Daybreak.”\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
“From the evil of His entire creation.”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
“And from the evil of the matter that darkens when it sets.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
“And from the evil of the witches who blow into knots.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
“And from the evil of the envier when he is envious of me.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Proclaim (O dear Prophet Mohammed – peace and blessings be upon him), “I take refuge of the One Who is the Lord of all mankind.”\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
“The King of all mankind.”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
“The God of all mankind.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
“From the evil of the one who instils evil thoughts in the hearts – and stays hidden.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
“Those who instil evil thoughts into the hearts of men.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
“Among the jinns and men.”\qt@no{(6)}}%
%% End of file `qurantext-enii.translation.def'
