\qt@newcmd\qurantrans@en@i{%
In the name of Allah, the Merciful, the Compassionate\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ii{%
Praise be to Allah, the Lord of the entire universe.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@iii{%
The Merciful, the Compassionate\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@iv{%
The Master of the Day of Recompense.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@v{%
You alone do we worship, and You alone do we turn for help\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@vi{%
Direct us on to the Straight Way,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@vii{%
The way of those whom You have favoured, who did not incur Your wrath, who are not astray.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif. Lam. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ix{%
This is the Book of Allah: there is no doubt about it. It is guidance to Godfearing people,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@x{%
who believe in the unseen, establish the Salats and expend (in Our way) out of what We have bestowed on them;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@xi{%
who believe in the Book We have sent down to you (i.e. the Qur'an) and in the Books sent down before you, and firmly believe in the Hereafter.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@xii{%
Such people are on the right way from their Lord and such are truly successful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@xiii{%
As for those who have rejected (these things), it is all the same to them whether you warn them or do not warn them: they are not going to believe.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah has sealed up their hearts and ears and a covering has fallen over their eyes, and they have incurred the severest punishment.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@xv{%
Then there are some who say, ``We believe in Allah and the Last Day", whereas they do not believe at all.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@xvi{%
They thus try to deceive Allah and the Believers, but they succeed in deceiving none except themselves and they realize it not.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is a disease which Allah has increased all the more and a painful doom is in store for them for the lie they utter.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@xviii{%
Whenever it is said to them, ``Spread not disorder on the earth", their reply is, ``We only seek to put things aright".\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@xix{%
Beware! they do spread disorder but they realize it not.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@xx{%
And when it is said to them, ``Believe sincerely as the other people have believed", they reply, ``Should we believe as fools have believed?" Beware! they themselves are the fools, but they know it not.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@xxi{%
When they meet those who believe, they say, ``We, too, are believers", but when they privily meet their evil geniuses, they say, ``Indeed we are with you: we are only mocking at these people".\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@xxii{%
(Little do they realize that) Allah is mocking at them. He gives them rope enough, and they wander on and on blindly in their mischief and rebellion.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@xxiii{%
These are the people who have bartered away Guidance for error, but this is a profitless bargain that they have made, and they are not at all on the right way.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their condition may be described in a parable: a man kindled a fire and when it illuminated all around him, Allah took away the light from their eyes and left them in utter darkness, where they could not see anything.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@xxv{%
They are deaf; they are dumb; they are blind so they will not return (to the right way).\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or (still another parable may be cited to depict their condition): heavy rain is falling from the sky, accompanied by pitch darkness, thunder and lightning. When they hear the thunderclap, they thrust their fingers into their ears for fear of death, but Allah is encircling the disbelievers on all sides.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning terrifies them as if it were going to snatch away their eyesight from them. When they see light, they move on a little further and When it becomes dark for them, they stand still. Had Allah so willed, He could have deprived them totally of their hearing and their sight. Most surely Allah has power over everything.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@xxviii{%
O Mankind, submit to your Lord Who created you and those who were before you; in this way only you may expect to save yourselves.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@xxix{%
It is He Who has made the earth a bed for you and the sky a canopy; and it is He Who sends down rain from above for the growth of every kind of food products for your sustenance. So, when you know this, you should not set up equals to rank with Allah.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@xxx{%
And if you be in doubt whether the Book We have sent down to Our Servant is from Us or not, then produce, at least, one Surah like this. You may call all your associates to assist you and avail yourselves of the help of any one other than Allah. If you are genuine in your doubt, do this.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@xxxi{%
But if you do not do this, and you can never do this, then fear the Fire which has been prepared for the disbelievers and which shall have men and stones for fuel.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@xxxii{%
And give good news (O Muhammad), to those who believe in this Book and do good deeds (in accordance with its teachings). For them there will be gardens underneath which canals flow. Their fruits will so resemble the fruits on the Earth that every time they will be provided with fruits, they will say, ``Such fruits were provided to us before on the Earth. `` And there will be pure spouses for them and therein they will live for ever.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Well, Allah is not ashamed to cite the similitude of a gnat or of something even more insignificant than this. As for those who believe, they come to know from the same similitude that it is the Revelation from their Lord; but those who disbelieve, say, ``What does Allah mean by such similitudes?" Allah leads astray many and guides many to the right way by the same thing. And He leads astray only those who disobey Allah;\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@xxxiv{%
who break Allah's covenant after ratifying it; who cut asunder what Allah has ordered to be joined, and who produce chaos on the Earth. These are the people who are indeed the losers.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@xxxv{%
How is it that you adopt the attitude of disbelief towards Allah when the fact is that you were lifeless and He gave you life, and He will take away life from you and will again restore you to life: then you shall ultimately return to Him.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@xxxvi{%
He it is Who created for you all that there is on the Earth; He then turned to the sky and ordered it into seven heavens. And He has full knowledge of everything.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@xxxvii{%
Just recall the time when your Lord said to the angels, ``I am going to appoint a vicegerent on the Earth." They humbly enquired, ``Are you going to appoint such a one as will cause disorder and shed blood on the Earth? We are already engaged in hymning Your praise, and hallowing Your name".\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@xxxviii{%
Allah replied, ``I know what you do not know." After this he taught Adam the names of all things. Then He set these before the angels and asked, ``Tell Me the names of these things, if you are right (in thinking that the appointment of a vicegerent will cause disorder)".\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@xxxix{%
They replied, ``Glory be to You. You alone are free from defect. We possess only that much knowledge which You have given us. Indeed You alone are All-Knowing and All-Wise."\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@xl{%
Then Allah said to Adam, ``Tell them the names of these things." When Adam told them the names of all those things, Allah declared, ``Did I not tell you that I know those truths about the Earth and the Heavens which are hidden from you? I know what you disclose and what you hide."\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@xli{%
Then We commanded the angels, ``Bow yourselves to Adam. ``All bowed but Iblis refused to do so; he waxed proud and joined the defiers.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@xlii{%
Then We said, ``O Adam, you and your wife, both dwell in the Garden and eat to your hearts' content where from you will, but do not go near this tree; otherwise you shall become transgressors"\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@xliii{%
After a time Satan tempted them with that tree to disobey. Our Command and brought them out of the state they were in, and We decreed, ``Now, go down all of you from here; you are enemies of one another. Henceforth you shall dwell and provide for yourselves on the Earth for a specified period."\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@xliv{%
At that time Adam learnt appropriate words from his Lord and repented, and his Lord accepted his repentance, for He is very Relenting and very Merciful.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@xlv{%
We said, ``Now go down, all of you from here. Henceforth there shall come to you Guidance from Me now and again: whoever will follow it shall have neither fear nor sorrow\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@xlvi{%
and whoever will refuse to accept it and defy Our Revelations they shall be doomed to the Fire wherein they shall remain for ever.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@xlvii{%
O children of Israel! Just recall to mind My favour wherewith I blessed you fulfil your covenant with Me and I shall fulfil My covenant with you, and fear Me alone.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in the Book I have now sent down; as it confirms the Scriptures you already possess, be not the first to reject it; barter not away My Revelations for paltry worldly gain, and guard yourselves against My wrath\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@xlix{%
Confound not the Truth with falsehood nor conceal it knowingly.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@l{%
Establish the Salat, pay the Zakat and bow down before Me along with those who bow down.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@li{%
How is it that you enjoin others to follow the Right Way, but forget it yourselves, though you read the Scriptures? Have you no sense at all?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@lii{%
Seek help with the Salat and fortitude: no doubt, Salat is a hard task but not for those obedient servants,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@liii{%
who realize that ultimately they shall meet their Lord and shall return to Him.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@liv{%
O Children of Israel! Just recall to mind My favour that bestowed upon you, and remember that I exalted you above all the peoples of the world.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@lv{%
And guard yourselves against the Day when no one shall avail anyone anything; nor shall intercession be accepted from anyone; nor shall anyone be acquitted for any (amount of) ransom; nor shall the guilty ones be helped from any quarter.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@lvi{%
Recall the time when We delivered you from the slavery of Pharaoh's people. They had inflicted a dreadful torment on you: they killed your sons and let your daughters live. And in this there was a hard trial for you from your your Lord.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@lvii{%
Remember the time when We parted the sea to make way for you and let you pass safely through it and then drowned Pharaoh's people before your very eyes.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@lviii{%
Call to mind that when We invited Moses for a fixed term of forty nights and days, you took to calf worship in his absence. Though you had committed a wicked transgression,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@lix{%
yet We pardoned you even after that so that you might become grateful.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@lx{%
Remember that (at that very time, when you were committing this gross iniquity) We gave Moses the Book and the criterion of right and wrong so that you might be guided aright.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@lxi{%
Remember that when Moses (returned with the Divine Gift, he) said to his people, ``O my people, you have wronged yourselves grievously by taking the calf for worship. Therefore, turn to your Creator. in penitence and slay the guilty ones among you. This is best for you in the sight of your Creator." At that time your Creator accepted your repentance because He is Relenting 'and Merciful.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@lxii{%
Remember when you said, ``O Moses, we are not going to believe you until we see with our own eyes Allah (talking to you)". At that very time a thunderbolt struck you while you were looking on and you fell lifeless.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We raised you to life so that you might become grateful for this favour.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@lxiv{%
(Remember that) We caused the cloud to overshadow you and provided you with manna and salva for your food, saying, ``Eat of the clean and pure things We have bestowed upon you" (In spite of this, your forefathers violated Our commands:) however, they did not harm Us but harmed only themselves.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@lxv{%
Then call to mind the time when We said, ``Go into the town' before you and eat to your hearts' content therein, wherefrom you will, but enter the gate bowing down with humility, repeating 'hittatun'; We will forgive your sins and increase the reward of the righteous".\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@lxvi{%
But the transgressors perverted the words said to them entirely into a different thing. So We sent down upon the transgressors a severe torment from the sky: that was the punishment for the disobedience they were showing.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@lxvii{%
Remember that when Moses prayed for water for his people, We answered, ``Strike the rock with your staff": whereupon twelve springs gushed forth from it; the people of every clan came to know their drinking place. (Then they were enjoined:) ``Eat and drink of what Allah has provided and do not spread disorder on the earth."\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@lxviii{%
Remember: You grumbled: ``O Moses, we cannot endure one and the same sort of food. Pray your Lord to bring for us the products of the earth green herbs, vegetables, corn, garlic, onions, pulses and the like." Moses replied: ``What! would you exchange that which is meaner for that which is nobler? Well, go and live in a town and you will get there what you demand." By and by, they became so degraded that disgrace and humiliation, misery and wretchedness were stamped upon them and they incurred Allah's wrath. That was because they began to reject the Revelations of Allah and kill His Messengers without any just cause; that was the consequence of their disobedience and their persistent transgression against the Law.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@lxix{%
Rest assured that whosoever from among the Muslims or the Jews or the Christians or the Sabaeans believes in Allah and the Last Day, and performs good deeds, he will have his reward with his Lord and he will have no cause for fear and grief.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@lxx{%
Call to mind the time when We raised above you the Tur and made a covenant with you, saying, ``Hold fast to the Book which We are giving you and bear in mind the commands and precepts contained therein. It is expected that this will lead you on to the paths of virtue and piety."\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@lxxi{%
But even after that you forsook the Covenant: nevertheless Allah did not withhold His grace and mercy from you; otherwise you would have been utterly ruined long before this.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@lxxii{%
And you know well the story of those among you who broke Sabbath. We said to them, ``Be apes despised and hated by all.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@lxxiii{%
Thus We made their end a warning to the people of their time and succeeding generations, and an admonition for God-fearing people.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@lxxiv{%
Then call to mind the other event: when Moses said to his people, ``Allah commands you to sacrifice a cow," they replied, ``Do you mean to have a jest with us?" He answered, ``I crave Allah's protection from behaving like ignorant people."\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@lxxv{%
Then they said, ``Please make a request to your Lord to give us some details of the cow." Moses answered, ``Allah says that the cow should neither be old nor immature but of middle age. Do, therefore, as you are bidden."\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@lxxvi{%
But they further asked, ``Please request your Lord to make it clear to us of what colour she should be." Moses answered, ``He says that she should be of yellow colour, so deep and bright as to delight the beholders."\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@lxxvii{%
Again they said, ``Pray your Lord to specify for us the kind of cow that is required; for cows (of this type) look alike to us. We shall then find her, if God so wills."\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@lxxviii{%
Moses answered, ``Allah says that she should be a cow which has not been yoked nor has ploughed the land nor watered the fields; which is sound and whole, without belemish. `` Then they cried out, ``Now you have given an accurate description. `` Then they sacrificed her but they did not appear to be doing this willingly.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@lxxix{%
You should also recall to mind another incident: You slew a man and began to dispute about the murder and accuse one another of it, but Allah had decreed that what you were trying to hide should be disclosed.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@lxxx{%
So We commanded, ``Strike the corpse of the murdered man with a part of the sacrificed cow. See how Allah brings the dead to life and shows you His Signs, so that you may understand".\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@lxxxi{%
But even after seeing these Signs your hearts hardened and became as hard as rocks; nay, even harder than rocks. For there are some rocks out of which springs gush forth, and others which split open, and water issues out of them; then there are some which tumble down for fear of Allah. And Allah is not unaware of what you are doing.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@lxxxii{%
O Muslims, do you then expect that these people will accept your invitation and become believers? whereas there have always been among them some who have been hearing the Word of God, understanding it well and then perverting and tampering with it knowingly.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
When they meet those who believe in Muhammad, they say, ``We also believe in him." But when they meet one another in private, they say, ``Have you got no sense that you disclose to them those things which Allah has revealed to you so that they might bring them as a proof against you before your Lord?\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Do they really not know that Allah is fully aware of what they hide and what they disclose?\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@lxxxv{%
Then there are among them some un-lettered people who have no knowledge of the Book but depend upon empty hopes and are guided by mere conjecture and guess-work.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
So woe to their learned people, who write the law with their own hands and then say to the people, ``This is from Allah," so that they might gain some paltry worldly end. (They do not see that) this writing of their hands will bring woe to them and what they gain thereby will lead to their ruin.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
They also say, ``The fire of Hell is not going to touch us, and even if it does at all, it will be only for a few days". Say, ``Have you obtained a promise from Allah which He would not break? Or, do you attribute to Allah things you do not know? Why will not the fire of Hell touch you?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Whoever earns evil and becomes engrossed in sin shall be doomed to Hell and abide therein for ever.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@lxxxix{%
Only those people who believe and do good deeds, will be the dwellers of the Garden and live there for ever.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@xc{%
Remember that We made a solemn covenant with the children of Israel to this effect: worship none save Allah: be good to your parents, to your relatives, to the orphans and to the helpless; speak aright with the people: establish the Salat and pay the Zakat. But with the exception of a few, you all slid back from it and are paying no heed to it even now.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@xci{%
Remember also that We made another solemn covenant with you: you shall not shed blood among yourselves nor expel one another from your homes. And you confirmed it and you are a witness to it.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@xcii{%
But inspite of this, you are killing your brethren and driving them out from their homes and making unjust and aggressive alliances against one another. And when they come to you as captives, you trade on their ransoms whereas their expulsion itself was unlawful for you. Do you then believe in one part of the Scriptures and disbelieve in the other? What other punishment do such people from among you deserve except an ignominious life in this world and the most grievous doom on the Day of Resurrection? Allah is not unaware of what you are doing.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@xciii{%
These are the people who have preferred the worldly life to the life in the Hereafter. Therefore their torment shall not be lightened nor shall help be given to them (from any quarter).\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@xciv{%
And We gave Moses the Book and sent after him a train of Messengers in succession. Then We sent Jesus, son of Mary, with clear Signs and supported him with the Holy Spirit. Then how is it that whenever a Messenger came to you wish that which did not suit your lusts, you grew rebellious against him, and repudiated some and slew others.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@xcv{%
They say, ``Our hearts are secure." Nay, the fact is that Allah has cursed them for their disbelief; so they are little disposed to believe.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@xcvi{%
And how are they behaving now towards a Book which has come to them from Allah? Inspite of the fact that it confirms the Scriptures which they already possessed. and, inspite of the fact that, before it came, they used to pray for a signal victory over the disbelievers, they rejected it when it came, although they recognized it. May Allah's curse be upon such disbelievers!\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@xcvii{%
What a mean thing it is with which they delude their minds. They reject the Guidance which Allah has sent down merely because of their grudge why Allah has in His bounty sent it to whom He chose from amongst His servants. They have thus incurred wrath after wrath, and for such disbelievers there is a disgraceful doom.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@xcviii{%
When it is said to them, ``Believe in that which Allah has sent down," they say, ``We believe only in that which has been sent to us", and reject everything else, though it is the Truth and confirms what is with them. Well, ask them, ``If you sincerely believed in what was sent down to you, why did you kill the Messengers of Allah (who were sent to you from amongst yourselves)?\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@xcix{%
(More than that:) Moses came to you with clear Signs, yet no sooner was he away from you than you transgressed and took the calf for worship.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@c{%
Recall also to mind the Covenant We made with you while We raised the Tur over you: `Follow strictly the precepts We are giving you and give ear to Our Commandments.' Your forefathers replied, ``We have heard but we will not obey." They were so prone to unbelief that they cherished the calf in their hearts. Tell them (O Muhammad). ``If indeed you are believers, yours is a strange Faith that enjoins you to do such evil things."\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@ci{%
Say to them, ``If the abode of the Hereafter with Allah is exclusively reserved for you and not for the rest of mankind, then you should long for death, if you arc sincere in your claim."\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@cii{%
Believe it that they will never wish for it, for (they are fully aware of the consequences of) what they have sent before them for the Hereafter. And Allah knows well the mentality of the transgressors.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ciii{%
You will find that, of all mankind, they are the greediest for life, nay, they are even greedier than the mushriks. Each one of them longs to have a life Of a thousand years, but a long life can, by no means, remove them away from the scourge, for Allah is watching whatever they are doing.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@civ{%
Say to them, ``Whoever is enemy to Gabriel, should understand that he has, by Allah's command, revealed to your heart the Qur'an which confirms what was revealed before it, and brings Guidance and glad tidings to the Believers.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@cv{%
(If their enmity to Gabriel is due to this, let them understand that) whoever is enemy to Allah, His Angels, His Messengers, Gabriel and Michael, Allah is enemy to such disbelievers."\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@cvi{%
We have sent down to you Revelations that clearly expound the Truth, and none but the disobedient reject them.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@cvii{%
Has it not always been so that every time they made a covenant, some of them set it aside? Nay, most of them never believe in it sincerely.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@cviii{%
And whenever a Messenger came to them from Allah, confirming that Scripture which they already possessed, some from among the people of the Book threw the Book of Allah behind their backs as though they knew nothing about it.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@cix{%
(Instead of this,) they began to follow that (magic) to which the devils falsely attributed (the greatness of) the kingdom of Solomon. In fact Solomon was never involved in any practice of disbelief, but the satans, who taught magic to the people were themselves guilty of disbelief. They were after that thing which was sent to Harut and Marut, the two angels at Babylon. Whenever these two angels taught black art to anyone, they would always give a clear warning beforehand, saying, ``We are merely a trial for you; so you should not commit blasphemy. But in spite of this warning, those people used to learn from the angels the art which caused division between husband and wife. Although it was obvious that they could not do any harm to anyone by means of this magic without Allah's permission, yet they learnt that art which could not be profitable even for them but was actually harmful. Moreover, they knew it full well that anyone, who purchased that art, would have no share in the Hereafter. What a vile commodity it was for which they sold off their souls, if they had but known it!\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@cx{%
Had they believed in Allah and practised piety, they would have received a far better reward from AIIah, if they had but known it.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@cxi{%
O Believers, do not say. ``Ra 'ina" but say, ``Unzurna `` and listen a to what is said; for the disbelievers deserve a painful punishment.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@cxii{%
The people who have rejected the message of Truth, be they the people of the Book or the mushriks, would never like that any good be sent down to you from your Lord, but Allah chooses for His mercy whom He wills, and Allah is Most Bountiful.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@cxiii{%
We bring a better verse or at least the like of it for whatever we abrogate or cause it to be forgotten.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@cxiv{%
Do you not know that Allah has full power over everything? Do you not know that the sovereignty of the heavens and the earth belongs to Allah alone and that you have neither any protector nor helper beside Him?\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@cxv{%
Would you then ask your Prophet such questions as were asked of Moses in former times? In fact, anyone, who changes the way of belief for that of disbelief, has surely swerved from the Right way.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many of the people of the Book desire to turn you anyhow back to unbelief. They wish this out of the envy of their hearts though the Truth has become quite clear to them. Yet, you should show forbearance and forgiveness to them' till Allah Himself enforces His judgement.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@cxvii{%
(Rest assured that) Allah has full power over everything: establish the Salat and pay the Zakat. you will find with Allah whatever good you send forward for your future; Allah is watching everything you do.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cxviii{%
They say, ``None shall enter Paradise unless he be a Jew or according to the Christians) a Christian." These are their wishful fancies. Say to them, ``Bring your proof, if you are right in your claim."\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cxix{%
The fact is that no one has any special claim to Paradise; whoever surrenders himself to Allah in obedience and follows the Right Way, shall get his reward from his Lord: there shall be neither fear nor grief for such people.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cxx{%
The Jews say that the Christians have nothing (of the Truth) and the Christians say that the Jews have nothing of it, though both read the Scripture. And those who have no knowledge of the Scripture also make similar claims. Allah will surely give His judgement on the Day of Resurrection in all the matters in which they differ.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who could be a greater wrongdoer than the one who forbids the mention of Allah's name in places of worship and strives for their ruin? Such people do not deserve to enter the places of worship, and, if they enter at all, they should do so in fear; for there is ignominy for them in this world and an awful punishment in the Hereafter.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cxxii{%
The East and the West, all belong to Allah: you will face Allah in whichsoever direction you turn your face: Allah is All-Embracing and All-Knowing.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cxxiii{%
They say ``Allah has adopted a son." Allah is above such things. As a matter of fact, whatever is in the heavens and on the earth belongs to Him and all are obedient to Him.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cxxiv{%
He is the Creator of the heavens and the earth: when He decrees a thing, He merely says, ``Be," and there it is.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cxxv{%
The ignorant people say, ``Why does not Allah Himself talk to us or why does not a Sign come to us?" The people before them also talked like this, for all (who swerve from the Right Path) have the same mentality. We have already shown clear Signs to those who believe;\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cxxvi{%
(what greater Sign could there be than that) We have sent you with the knowledge of the Truth and made you a bearer of good tidings and a Warner? Now, you are not responsible and answerable for those who are bent upon going to Hell.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cxxvii{%
The Jews and the Christians will never be satisfied with you, O Muhammad, until you follow their way. Tell them plainly, ``The right way is shown by Allah." And if, after all the' knowledge you have received, you were to yield to their desires, you shall find neither any friend nor helper to protect you from Allah's wrath.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cxxviii{%
There are those, even among the people of the Scripture, who read the Book as it should be read and believe in it sincerely; as for those who reject it, they are indeed the losers.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cxxix{%
O children of Israel, remember that special favour I bestowed upon you, and that I exalted you above all the communities of the world.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cxxx{%
And dread the Day when no one shall avail anyone in any way; nor shall any ransom be accepted from anyone; nor shall intercession profit any body; nor shall the offenders be helped from any quarter.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cxxxi{%
Recall to mind that when his Lord put Abraham to test in certain things and he fulfilled all of them, He said, ``I am going to make you the leader of mankind." Abraham humbly asked, ``Does this promise apply to my descendants also?" He replied, ``My promise does not apply to the transgressors."\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And remember that We made this House (the Ka'bah) the centre and sanctuary for mankind and enjoined the people to dedicate to worship the place where Abraham used to stand for prayer, and We urged Abraham and Ismail to keep My House pure for those who would go round it and those who would retire to it for devotion and prayer and for those who would bow down and prostrate themselves there in worhsip.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And remember that Abraham prayed, ``Lord, make this city a city of peace and security, and provide with every kind of fruit those of its people, who believe in Allah and the Last Day'. Allah answered, ``As for the disbelievers, I will also provide them with the necessities of life in this world, though in the Next World I will drag them to the torment of Hell, and that is the worst abode."\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And remember that when Abraham and Ishmael were raising the walls of the House, they prayed, ``Lord, accept this service from us; You are All-Hearing and All-Knowing.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cxxxv{%
Lord, make us Your Muslims (submissive servants) and also raise from our offspring a community which should be Muslim (submissive to Your Will). Show us the ways of Your worship and forbear our shortcomings: You are Forgiving and Merciful.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
Lord, raise up from among them a Messenger who shall recite Your Revelations to them and teach them the Book and Wisdom and purify their lives. You art All-Powerful and AllWise".\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
Now, who else can have aversion to the way of Abraham but the one who has debased himself with folly and ignorance? Abraham was the man whom We chose for Our service in this world, and in the Next World he shall be among the righteous.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said to him, ``Surrender," he promptly responded, ``I have surrendered to the Lord of the Universe (and become a Muslim)."\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cxxxix{%
He also enjoined on his children to follow the same way. Jacob also did the same and his last will to his sons was, ``O my children, Allah has chosen the same way of life for you. Hence remain Muslims up to your last breath."\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cxl{%
Were you present at the time when Jacob was on the point of death? He asked his children, ``Whom will you worship after me?" They all answered, ``We will worship the same One Allah Whom you, your forefathers Abraham. Ismail and Isaac acknowledged as their Allah and to Him we all surrender as Muslims."\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cxli{%
They were a people who passed away; they shall receive the reward of what they earned and you shall have the reward of what you will earn; and you will not be questioned as to what they did.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cxlii{%
The Jews say, ``Become Jews and you will be rightly guided"; the Christians say, ``Become Christians and you will have the true guidance." Say to them, ``Nay, we turn away from every other way and accept the way of Abraham, and Abraham did not associate other gods with Allah."\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cxliii{%
O Muslims, say to them, ``We believe in Allah and the Guidance which has been sent down to us and which was sent to Abraham, Ismail, Isaac and Jacob and his descendants and which was given by their Lord to Moses and Jesus and to all other Prophets. We do not discriminate against any of them and we have completely surrendered to Allah as Muslims."\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cxliv{%
Then if they believe the way you have believed, they have the right guidance, and if they turn away from this, it will become obvious that they are obdurate. Therefore, rest assured that AIIah will suffice to defend you against them: He hears everything and knows every thing.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cxlv{%
Say, ``Take Allah's colour, and who can give a better colour than Allah? Therefore, we worship and submit to Him alone. ``\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cxlvi{%
O Prophet, say to them, ``Do you argue with us concerning AIIah, whereas He is our Lord and also your Lord? We shall be accountable to Him for our deeds and you for yours; so we have dedicated our worship to Him alone.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or do you say that Abraham, Ismail, Isaac, Jacob and his children were all Jews or Christians? Ask them, ``Do you know more than Allah does? And who is more unjust than the one who hides the testimony which Allah has entrusted to him? Allah is not unaware of what you are doing.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cxlviii{%
They were a people who have passed away and they shall be repaid for what they earned and you for what you earn: you will not be questioned as to what they did. ``\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cxlix{%
Of course, the foolish people will say, ``What has turned them abruptly away from the giblah towards which they formerly used to turn their faces in prayer?" Tell them, O Messenger, `'East and West all belong to Allah; He shows the Right Way to anyone He wills."\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cl{%
Thus have We made you a Community of the ``Golden Mean" so that you may be witnesses in regard to mankind and the Messenger may be a witness in regard to you. We had appointed the former giblah towards which you used to turn your face merely to test who would follow the Messenger and who would turn back. It was indeed a hard test but not for those who had been blessed with Guidance from Allah. Allah will not let go to waste this faith of yours; rest assured that He is full of pity and mercy for mankind.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cli{%
We have seen you (O Muhammad), turning your face over and over again towards Heaven. Now, therefore, We turn you towards the giblah that you like best: so turn your face towards the Masjid Haram. Henceforth, wheresoever you may be, turn your face at prayer towards it. The people who were given the Book know it well that the commandment (about the change of giblah) is in fact from their Lord, and is based on the Truth, but Allah is not unaware of what they are doing (in spite of this)\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@clii{%
Even though you may show every kind of sign to the people of the Book, they will not adopt your giblah, nor are you going to adopt their giblah; nor will any of them adopt the giblah of the other; therefore if, after the knowledge you have received, you follow their desires, you will certainly be counted among the transgressors.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cliii{%
As for those to whom We gave the Book, they recognise the place (which has now been made giblah), as clearly as they recognise their own children. But some of them are knowingly concealing the truth.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cliv{%
This is in fact a Commandment from your Lord; so you should not have any doubt concerning this.\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@clv{%
Everyone has a direction towards which he turns in Prayer: so try to excel one another in good works. Allah will find you wheresoever you be, for nothing is out of Allah's reach.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@clvi{%
At whatever place you may be, turn your face towards Masjid Haram (at Prayer time) for this is, in fact, a Commandment of your Lord, and Allah is not unaware of what you do.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@clvii{%
At whatever place you may be, you must turn your face towards the Masjid Haram, and wherever you may be, you must turn your face towards the same at prayer so that people might not find an argument against you. As for the unjust people, they will never stop talking; so do not fear them but fear Me -- (Do this) so that I may complete My favour upon you and you may find the way to real success,\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@clviii{%
just as (you have found from this: that) We sent the Messenger to you from among you, who recites to you Our Revelations; who purifies your lives; who instructs you in the Book and in Wisdom and teaches you those things that you did not know.\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@clix{%
So remember Me and I will remember you, and give thanks to Me and be not ungrateful.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@clx{%
O Believers, seek help with fortitude and Salat, for Allah is with those who show fortitude.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@clxi{%
And do not say of those who are slain in the way of Allah, ``they are dead." In fact, they are alive but you do not perceive that life.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@clxii{%
We will surely put you to trial by involving you in fear and hunger and by causing loss of property, life and earnings. And give good tidings to those who remain steadfast in these trials:\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@clxiii{%
when a misfortune comes to them, they say, ``We are Allah's and we shall certainly return to Him,''\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@clxiv{%
Their Lord will bestow great blessings and mercy upon them; such are the people who are rightly guided.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@clxv{%
Indeed Safa and Marwah are among the emblems of Allah: it is, therefore, no sin for him, who performs Hajj or `Umrah to the House of AIIah, to run between the two hills; and Allah knows and appreciates him who does any good with a willing heart.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@clxvi{%
Indeed Allah curses, and the cursers, too, curse those who conceal the clear teachings and guidance We have sent down, after We have made these plain in the Book for the guidance of all mankind.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@clxvii{%
I, however, will forgive those of them who repent of it, mend their ways and make own what they were concealing: for I am very generous in accepting repentance and showing mercy.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@clxviii{%
Those who adopted the way of disbelief and died as disbelievers, are accursed of Allah and of angels and of all mankind: they shall remain accursed for ever.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@clxix{%
Their punishment shall not be lightened, nor shall they be reprieved.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@clxx{%
Your Deity is Allah alone: there is no deity save the All-Beneficent and All-Merciful Allah.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@clxxi{%
(If they want a sign for the perception of this Reality) surety there are countless signs for those who use their common sense; they can see alternation of the night and day, in the ships that sail the ocean laden with cargoes beneficial to mankind, and in the rain-water which Allah sends down from the sky and thereby gives life to the earth after its death and spreads over it all kinds of animate creatures, in the blowing of the winds and in the clouds which obediently wait for orders between the sky and the earth.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@clxxii{%
(In spite of such clear signs of the Oneness of Allah), there are people who set up equals and rivals with Allah and adore them with the adoration due to Allah. whereas the Believers adore Allah most ardently. Would that these transgressors could realize now what they will realize, when they will see the chastisement before them that power and authority wholly belong to Allah and that Allah is severe in punishment!\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@clxxiii{%
When He will inflict punishment, those very leaders and guides whom they followed in the world will disown them. But punishment they shall get and all their bonds shall be cut off.\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@clxxiv{%
Then those who followed them will say, ``Would that we were given another chance to return to the world: then we will disown them just as they have disowned us today." Thus will Allah bring before them the deeds they did in the world in such a manner as to make them wring their hands in regret but they shall be unable to come out of the Fire.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@clxxv{%
O people, eat of what is lawful and clean in the earth and do not follow the ways of Satan, for he is your avowed enemy.\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@clxxvi{%
He enjoins you to commit vice and indecency and induces you to attribute to Allah's name things you do not know to be from Him.\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@clxxvii{%
When it is said to them, ``Follow the Commands that Allah has sent down," they reply, ``We will follow only what we found our forefathers practising., Well, will they go on following their forefathers even though they did not use common sense and did not find the right way?\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@clxxviii{%
The mental condition of those who rejected the way of Allah may be likened to that of the cattle whom the shepherd calls but they hear nothing except the sound of shouts and cries. They are deaf, they are dumb, they are blind; therefore they do not understand anything.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@clxxix{%
O Believers, if you are true worshippers of Allah alone, eat without hesitation of the good and clean things wherewith We have provided you and be grateful to Allah.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@clxxx{%
Allah has only forbidden you to eat what dies of itself, and blood and swine flesh and what has been consecrated to any other name than of Allah. But one will incur no sin if, forced by absolute necessity, he eats of any of these forbidden things, provided he has no intention of transgressing the law and does not take more than what is absolutely indispensable: for Allah is very Forgiving and very Merciful.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Indeed those, who conceal the Commands that Allah has sent down in His Book and barter them away for paltry worldly gains, fill their bellies with fire. Allah will not speak to them on the Day of Resurrection, nor will He regard them as pure; ``a there is a painful torment for them.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@clxxxii{%
They are the people who have bartered away Guidance for error and Allah's pardon for His punishment. How audacious they are: they are ready even to endure the fire of Hell.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
This was inspite of the fact that Allah had sent down the Book with the Truth but the people who sought differences in the Book swerved far away from the Truth in their disputes.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
It is no virtue. That you turn your faces towards the east or the west, but virtue is that one should sincerely believe in Allah and the Last Day and the Angels and the Book and the Prophets and, out of His love, spend of one's choice wealth for relatives and orphans, for the needy and the wayfarer, for beggars and for the ransom of slaves, and establish the Salat and pay the Zakat. And the virtuous are those who keep their pledges when they make them and show fortitude in hardships and adversity and in the struggle between the Truth and falsehood; such are the truthful people and such are the pious.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O Believers, the lawn of retribution has been prescribed for you in cases of murder; if a free man commits a murder, the free man shall he punished for it and a slave for a slave: likewise if a woman is guilty of murder the same shall he accountable for it. But in case the injured brother is willing to show leniency to the murderer, the blood money should he decided in accordance with the common law and the murderer should pay it in a genuine way. This is an allowance and mercy from your Lord. Now there shall be a painful torment for anyone who transgresses the limits after this. O men of understanding.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
There is security of life for you in the law of retribution. It is expected that you will refrain from breaking this law.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
It has been prescribed for you that when death approaches one of you and he is leaving some property behind him, he should bequeath it equitably for his parents and relatives: it is an obligation on those who fear AIIah.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
Then if those, who heard the will, change it, they themselves shall bear the sin of this. Allah hears everything and knows everything.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@clxxxix{%
If, however. one apprehends genuinely that the testator had intentionally or unintentionally done some injustice, and then alters the will to set things right between the parties concerned, in that case he does not incur any sin. Allah is Forgiving and Merciful.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@cxc{%
O Believers, the Fast has been made obligatory on you just as it was prescribed for the followers of the Prophets before you. It is expected that this will produce piety in you.\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@cxci{%
The Fast is to be observed for a fixed number of days. If, however, anyone of you be sick or on a journey, he should fast the same number of other days. As for those who can fast (but do not), the expiation of this shall be the feeding of one needy person for one fast day, and whoso does more than this with a willing heart does it for his own good. But if you understand the thing, it is better for you to observe the Fast.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@cxcii{%
Ramadan is the month in which the Qur'an was sent down: this Book is a perfect guidance for mankind and consists of clear teachings which show the right way and are a criterion of Truth and falsehood. Therefore from now on whoever witnesses it, it is obligatory on hire to fast the whole month, but if one be ill or on a journey, he should make up for the same number by fasting on other days. Allah desires to show leniency to you and does not desire to show any hardship. ``therefore this method is being shown to you so that you may complete the number of Fast days and glorify Allah for the Guidance He has shown to you and be grateful to Him.\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@cxciii{%
And if My servants ask you, O Prophet. concerning Me, tell them that I am quite near to them. I hear and answer the prayer of the suppliant, when he calls to Me. So let them respond to My call and believe in Me. Convey this to them, O Prophet; perhaps they may be guided aright.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@cxciv{%
It has been made lawful for you to go to your wives during the nights of the fast days. They are as a garment to you and you are as a garment to them. Though Allah knew that you were secretly dishonest to yourselves, He has pardoned your guilt and forgiven you. NOW you are permitted to have intercourse with your wives and enjoy what Allah has made lawful for you. You are also pemitted to eat and drink during the nights of the Fast months. until you can discern the white streak of dawn from the blackness of night. `` Then (abstain from all these things and) complete your fast till night-fall. But you should not have intercourse with your wives while you confine yourselves to mosques. These are the bounds set by Allah; so do nut go near them. In this way Allah makes His Commands clear to mankind. It is expected that they will guard themselves against wrong ways.\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@cxcv{%
Do not usurp one another's property by unjust means nor offer it to the judges so that you may devour knowingly and unjustly a portion of the goods of others.\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask you about the phases of the moon. Say, ``These are signs for the people to reckon dates and fix the periods for hajj." Also tell them, ``It is no virtue to enter your houses from their backs during the Hajj days); real virtue is that one should refrain from incurring the displeasure of Allah; so enter your houses by their proper doors. and fear Allah so that you may gain (true) success.\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@cxcvii{%
And fight in the way of Allah with those who fight against you but do not commit aggression because AIIah does not like aggressors.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@cxcviii{%
Fight against them wherever they confront you in combat and drive them out from where they drove you out. Though killing is bad. persecution is worse than killing Do not fight against them near the Masjid Haram unless they attack you there.\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@cxcix{%
And if they attack you first (even in that sacred area), strike them (without any hesitation); this is the due punishment for such disbelievers. If, however, they desist from fighting (you should also do likewise), and know that Allah is Forgiving and Merciful.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@cc{%
Go on fighting with them till there is no more a state of tribulation and Allah's way is established instead. Then if they desist from it, there should be no more hostility except against those who had been guilty of cruelty and brutality.\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@cci{%
A prohibited month is to be respected, if the same is respected (by the enemy), and likewise there is the law of just retribution for the violation of all prohibited things. Therefore, if anyone transgresses a prohibition by attacking you, you may do likewise, but always fear AIIah and bear in mind that Allah is with those who desist from breaking Allah's bounds.\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@ccii{%
Spend your wealth in the Way of Allah and do not cast yourselves into ruin with your own hands. Do all things gracefully, for Allah loves those who do all things with excellence\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@cciii{%
When you make up your mind to perform Hajj and `Umrah, accomplish these to please Allah. But if you are hemmed in somewhere, then offer to Allah whatever sacrifice you can afford. And do not shave your heads until the sacrifice reaches its place. But whoever among you is sick or has an ailment of the head and has his head shaved shall atone for this either by fasting or by alms-giving or by offering a sacrifice However, when you are secure (and you reach Makkah before the Hajj season begins), whoever takes advantage of this opportunity to perform `Umrah shall offer the sacrifice that he can afford. But if he cannot afford a sacrifice, he shall fast three days during the Hajj season and seven days after reaching home, that is, ten days in all. This concession is only for those whose homes are not near the Masjid Haram, refrain from transgressing these Commandments of Allah and know it well that Allah is very severe in punishment.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@cciv{%
The months for Hajj are well known to all; whoever makes up his mind to perform Hajj during these fixed months, let him totally abstain from all sorts of sexual indulgence, wickedness and wrangling during the Hajj and remember that Allah knows whatever good you do. Take necessary provisions for Hajj, and piety is the best of all provisions: so refrain from disobeying Me, O men of understanding!\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@ccv{%
And there is nothing wrong if you also seek the bounty of your Lord during the pilgrimage. Moreover, when you return from 'Arafat, stay at Mash'aril-Haram (Muzdalifah) and remember Allah. And remember Him just as He has enjoined you, for you had gone astray before this.\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then return from where others return and ask Allah's forgiveness. Most surely He is Forgiving and Merciful.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@ccvii{%
And when you have performed your Hajj rites, remember Allah as you had been remembering your own forefathers, or even with greater zeal. (Even those who remember Allah do it in different ways). Some say, ``Our Lord, give us all the good things here in this world. `` Such people shall have no share in the Hereafter.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@ccviii{%
Then there are others who say, ``Our Lord, give us what is good in this world and also what is good in the Hereafter and save us from the torment of Fire."\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@ccix{%
Such people shall have their due share (in both the worlds) according to what they earn. And Allah is swift at settling accounts.\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@ccx{%
So pass these few appointed days in remembering Allah; then there is nothing wrong if one hastens on (from Mina) after two days or stays there (a day) longer, `` provided that he spends these days it piety. Do not disobey Him and remember that One Day you shall be mustered before Him.\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@ccxi{%
There is a certain type of man who charms you in this worldly life with his glib talk. He calls Allah to witness again and again that he cherishes good intentions in his heart, whereas, in fact, he is the deadliest opponent of the Truth.\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@ccxii{%
When he gets power he directs all his efforts towards spreading mischief in the land, destroying harvests and killing the human race whereas Allah (Whom he makes his witness) does not like mischief.\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@ccxiii{%
And when it is said to him, ``Fear Allah," vanity seizes him and makes him adhere to the sin. Hell is the proper place for such a person and it is a very bad dwelling indeed.\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@ccxiv{%
On the other side, there is another type of man who devotes his whole life to please Allah, and Allah is gracious to such of His servants.\qt@no{(207)}}%
\qt@newcmd\qurantrans@en@ccxv{%
O Believers, enter completely into Islam and do not follow in" the footsteps of Satan, for he is your avowed enemy.\qt@no{(208)}}%
\qt@newcmd\qurantrans@en@ccxvi{%
If you lapse back after receiving the clear teachings that have come to you, know it well that Allah is All-Powerful, All-Wise.\qt@no{(209)}}%
\qt@newcmd\qurantrans@en@ccxvii{%
(If people do not follow the right way even after receiving such clear admonitions), do they await that Allah Himself should come down to them in the canopies of clouds with a retinue of angels, and seal their doom Ultimately every thing shall be presented before Allah (for judgement).\qt@no{(210)}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the children of Israel how many a clear sign We have shown to them: (also ask them) what a severe chastisement Allah inflicts on the community that, after receiving Allah's favour exchanges it (for wretchdness).\qt@no{(211)}}%
\qt@newcmd\qurantrans@en@ccxix{%
This worldly life has been made very charming and alluring for those who have adopted the way of disbelief. So they mock at those who have adopted the way of belief, but (they forget that) the pious people will rank above them on the Day of Resurrection. As to the wordly provisions, Allah has full authority and power to bestow these without measure on anyone He wills.\qt@no{(212)}}%
\qt@newcmd\qurantrans@en@ccxx{%
In the beginning all the people followed the same way. (Afterwards there came a change and differences arose). Then Allah sent Prophets to give good tidings to those who followed the Right Way and warnings to those who swerved from it. And He sent down with them the Book based on the Truth so that it should judge between the people concerning their differences. (Differences arose not because people were not given the knowledge of the Truth in the beginning, nay), differences arose between those very people who had been given clear teachings, and (for no other reasons than that) they wanted to tyrannize over one another. So Allah, by His leave, guided those who believed in the Prophets to the Truth about which they had differed; AIIah guides whomever He pleases to the Right Way.\qt@no{(213)}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Do you think that you will enter Paradise without undergoing such trials as were experienced by the believers before you? They met with adversity and affliction and were so shaken by trials that the Prophet of the time and his followers cried out: ``When will Allah's help come"? (Then they were comforted with the good tidings): ``Yes, Allah's help is near."\qt@no{(214)}}%
\qt@newcmd\qurantrans@en@ccxxii{%
The people ask, ``What should we spend?" Tell them, ``Whatever you spend, spend for your parents, your relatives, orphans, the needy and the wayfarer; and whatever good you do, Allah has knowledge of it.\qt@no{(215)}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
You have been enjoined to go to war, and you dislike it; it may be that you dislike a thing and the same is good for you, and you love a thing and the same is bad for you: Allah knows but you do not.\qt@no{(216)}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask you (O Muhammad) concerning warfare in the prohibited month. Say, ``Fighting is a heinous offence in this month, but in the sight of Allah it is far worse to hinder people from the Way of Allah and to deny Him and to prevent His worshippers from visiting the Masjidal-Haram, and to expel the dwellers of the sacred place from it; and persecution is far worse than bloodshed. As for them, they will go on fighting with you till they succeed in turning you away from your Faith, if they can. But (note it well that) whosoever renounces his Faith and dies a renegade, all his works shall be fruitless both in this world and in the Hereafter. All such people deserve the Fire and shall abide in Hell for ever.\qt@no{(217)}}%
\qt@newcmd\qurantrans@en@ccxxv{%
In contrast to them, those, who have believed And left their homes in the way of Allah and exerted their utmost in His cause, rightly look forward to His mercy: and Allah is Forgiving and full of mercy.\qt@no{(218)}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask you about drinking and gambling. Say, ``There is great harm in both, though there is some benefit also for the people. But the harm of the sin thereof is far greater than their benefit. ``\qt@no{(219)}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
And they ask ``What ought we to spend (in the way of Allah)"? Say ``Spend whatever you can spare." Thus Allah makes His commands clear to you so that you may think about the good of both this world and the Hereafter. They ask you about the right way of dealing with orphans. Say ``The right way is that which is for their good." Then there is no harm if you live a common life with them for they are after all your own brethren. Allah knows well the one who means harm and also the one who means good. If Allah had willed He would have been hard upon you in this matter for He is All-Powerful but He is at the same time AlI-Wise.\qt@no{(220)}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
Do not marry mushrik women unless they believe; a slave woman who believes is better than a free woman who does not believe, even though the latter may appear very attractive to you. (Likewise) do not wed your women to mushrik men unless they believe; a slave man who believes is better than a free man who does not, even though he may be very pleasing to you. These mushrik people invite you to the Fire while Allah by His grace invites you to the Garden and His pardon, and He makes His revelations plain to the people so that they should learn a lesson and follow the admonition.\qt@no{(221)}}%
\qt@newcmd\qurantrans@en@ccxxix{%
They ask about the monthly course. Say, ``It is a state of impurity; so keep apart from women during their monthly course and do not go near them until they are clean. When they have cleansed themselves, then you may go to them in the manner Allah has enjoined you." Most surely Allah loves those people who refrain from evil and keep themselves pure and clean.\qt@no{(222)}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your wives are your tilth: so you may go to your tilth as you please, but you should take care of your future and refrain from the displeasure of Allah. Know it well that One Day you shall meet Him. (O Prophet!) bear good tidings to the Believers.\qt@no{(223)}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
Do not use Allah's name for such oaths which are taken to keep back from virtue, piety and the welfare of mankind:\qt@no{(224)}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah hears everything you utter and knows everything. Allah does not call you to Account for unintentional and meaningless oaths, but will surely take you to task for oaths taken deliberately and in earnest: Allah is Forgiving and Forbearing.\qt@no{(225)}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
Those who take an oath to keep apart from their wives are given four months (for a final decision), Then if they resume their relations, Allah is Forgiving and Merciful.\qt@no{(226)}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
And if they resolve on divorce, (let them remember that Allah hears everything and knows everything.\qt@no{(227)}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
Divorced women shall keep themselves in waiting for three menstrual courses and it is unlawful for them, if they believe in Allah and the Last Day, to hide whatever Allah might have created in their wombs. Should their husbands desire reconciliation during this time they are entitled to take them back into wedlock. Women have the same rights against their men as men have against them; but men have a degree above them. Allah is All- Powerful, All-Wise.\qt@no{(228)}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
Divorce may be pronounced twice; then either the wife be kept honourably or parted with gracefully. And it is not lawful for you to take back anything out of what you have given them. There is, however, an exception to this; if you fear that they might not be able to keep within the limits imposed by Allah, there is no harm if both agree mutually that the wife should obtain divorce by giving something as compensation to the husband. These are the bounds set by Allah; therefore do not violate them, for those who violate the bounds of AIIah are the tansgressors.\qt@no{(229)}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
And if the husband divorces his wife (for the third time), she shall not remain his lawful wife after this (absolute) divorce, unless she marries another husband and the second husband divorces her. (In that case) there is no harm if they re-marry, provided that the woman and her first husband are convinced that they will be able to keep within the bounds fixed by Allah. And these are Allah's bounds, which He makes clear for the guidance of those who know (the consequences of transgression).\qt@no{(230)}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
And when you have divorced your wives and they are about to complete their prescribed term, then either retain them gracefully or release them generously. It is transgression to retain them merely for harassment; and whoever' does that indeed wrongs his own self. Do not play with Allah's Commandments, and remember that Allah has blessed you with a great favour. He admonishes you to show due respect to the Book and the Wisdom He has sent to you. Fear Allah and know that He is fully aware of everything.\qt@no{(231)}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
When you have divorced your wives absolutely and they have completed their prescribed term, then you should not prevent them from marrying their prospective husbands, if they mutually agree to marry each other in a lawful way. You are enjoined not to commit such an offence, if you sincerely believe in Allah and the Last Day. It is most decent and pure for you to desist from this; Allah knows and you do not know.\qt@no{(232)}}%
\qt@newcmd\qurantrans@en@ccxl{%
The (divorced) mothers shall suckle their children for two whole years, if the fathers desire the suckling to be completed. In that case the father of the child shall, in the fair known way, be responsible for their food and clothing. But none should be burdened with more than one can bear: neither the mother should be pressed unjustly (to accept unfair terms) just because she is the mother nor should the father be burdened just because he is the father. And the same responsibility for the maintenance of the mother devolves upon the father of the child and his heir. There is no harm if they wean the child by mutual consent and consultation. Moreover, there is no harm if you choose to give your children a suckle by a wet nurse, provided that you pay her fairly. Fear Allah and know it well that whatever you do is in the sight of Allah.\qt@no{(233)}}%
\qt@newcmd\qurantrans@en@ccxli{%
If those of you, who die, leave wives behind, they should abstain (from marriage) for four months and ten days. Then when their waiting term expires, they are free to do whatever they choose for themselves, provided that it is decent; you shall not be answerable for this; Allah is fully aware of what you do.\qt@no{(234)}}%
\qt@newcmd\qurantrans@en@ccxlii{%
It is no offence if you make indirect proposal of marriage to widows during their waiting term or keep it concealed in your hearts: for Allah knows that you will naturally think of them. But be careful not to make any secret engagement. If you have to do anything, do it in an honourable way. And you should not settle anything finally about the marriage until the waiting term expires. Understand it well that Allah even knows what is hidden in your hearts; so fear Him. Also know that Allah is Lenient and Forgiving.\qt@no{(235)}}%
\qt@newcmd\qurantrans@en@ccxliii{%
It is no sin if you divorce your wives while you have not yet touched them or fixed any dower for them. In such a case, pay them something anyhow. A rich man should pay fairly according to his means and a poor man according to his resources, for this is an obligation on the righteous people.\qt@no{(236)}}%
\qt@newcmd\qurantrans@en@ccxliv{%
In case you fixed a dower for them and then divorced them before you touched them, you should pay half of the fixed dower. But there is no harm if the woman agrees to forego it or the man, in whose hands is the marriage tie, is generous enough (to pay the dower in full). And if you (men) act generously, it is akin to piety. Do not forget to show generosity in your dealings with one another for Allah sees what you do.\qt@no{(237)}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Take great care of your Prayers, especially of a Prayer that has excellent qualities of Salat and stand before Allah like devoted servants.\qt@no{(238)}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
Even if you are in danger, you must offer your Prayers anyhow on foot or on horseback. And when you have peace again, remember Allah in the manner He has taught you, which you did not know before.\qt@no{(239)}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
Those of you, who shall die and leave wives behind them, should make a will to the effect that they should be provided with a year's maintenance and should not be turned out of their homes. But if they leave their homes of their own accord, you shall not be answerable for whatever they choose for themselves in a fair way; Allah is All-Powerful, All-Wise.\qt@no{(240)}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
Likewise, the divorced women should also be given something in accordance with the known fair standard. This is an obligation upon the God-fearing people.\qt@no{(241)}}%
\qt@newcmd\qurantrans@en@ccxlix{%
Thus Allah makes clear His commandments for you: it is expected that you will use your common sense.\qt@no{(242)}}%
\qt@newcmd\qurantrans@en@ccl{%
Have you ever reflected upon the case of those who fled their homes for fear of death, and they were thousands in number? So Allah said to them, ``Die"; then He again gave them life. Indeed Allah is bountiful to mankind, but most of the people are ungrateful.\qt@no{(243)}}%
\qt@newcmd\qurantrans@en@ccli{%
O Muslims, fight in the way of Allah and know that Allah hears everything and knows everything.\qt@no{(244)}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is there among you who will lend to Allah a good loan that He may return it after multiplying it manifold? Allah alone can decrease and increase (wealth) and to Him you shall all return.\qt@no{(245)}}%
\qt@newcmd\qurantrans@en@ccliii{%
Have you also reflected upon the matter concerning the chiefs of the Israelites after (the death of) Moses? They said to their Prophet, ``Appoint a king for us so that we may fight in the way of Allah." The Prophet asked them, ``Might it be that you will not fight, if fighting is prescribed for you?" They replied, ``How can it be that we would refuse to fight in the way of Allah when we have been turned out of our homes and separated from our children?" But (in spite of this assurance) when they were enjoined to fight, they all, except a few of them, turned their backs. And Allah knows each and everyone of these transgressors.\qt@no{(246)}}%
\qt@newcmd\qurantrans@en@ccliv{%
Their Prophet said to them, ``Allah has appointed Saul to be king over you." Hearing this, they replied, ``How has he been entitled to become king over us? We have a better right to kingship than he, for he does not even possess enough riches." The Prophet replied, ``Allah has preferred him to you and blessed him with abundant powers of mind and body. And Allah has the power to give His kingdom to whomever He wills: Allah is All-Embracing, All-Knowing."\qt@no{(247)}}%
\qt@newcmd\qurantrans@en@cclv{%
Their Prophet further informed them, ``The sign of his appointment as king from Allah is that during his reign you will get back the Ark, wherein are the means of your peace of mind from your Lord, and which contains the sacred relics of the family of Moses and Aaron, and which is being borne at this time by the angels. Herein is a great Sign for you, if you are true believers."\qt@no{(248)}}%
\qt@newcmd\qurantrans@en@cclvi{%
And when Saul marched out with his army, he warned: ``Allah is going to put you to a test by the side of a river: whoso drinks of its water shall cease to be my companion: he alone shall be~my companion who does not quench his thirst with its water: one may, however, take except a few, drank their fill of it. Afterwards when Saul, and those who had believed with him, crossed the river and advanced forward, the former said to Saul, ``We have no power left this day to fight against Goliath and his hosts." But those who believed that one Day they shall meet Allah, declared, ``lt has often been that a small host has, by Allah's grace, overcome a big host: for Allah is with those who show fortitude."\qt@no{(249)}}%
\qt@newcmd\qurantrans@en@cclvii{%
Accordingly, when they marched forward to fight with Goliath and his hosts, they prayed, ``Our Lord, bless us with fortitude, make firm our foothold and give us victory over the unbelieving host."\qt@no{(250)}}%
\qt@newcmd\qurantrans@en@cclviii{%
Consequently, by Allah's grace, they routed the unbelievers, and David killed Goliath; and Allah gave him kingship and wisdom and taught him whatever other things He willed. And if Allah had not been repelling one set of people by means of another, the earth would have been filled with chaos. But Allah is bountiful to the world (and so repels chaos in this way).\qt@no{(251)}}%
\qt@newcmd\qurantrans@en@cclix{%
These are Allah's revelations, which We are conveying to you accurately. And O Muhammad, most surely you are of those who have been sent as Messengers.\qt@no{(252)}}%
\qt@newcmd\qurantrans@en@cclx{%
Of these Messengers (whom We sent for the guidance of mankind), We raised some above the others in rank. Among them was one with whom Allah Himself had direct talks. There were others whom He raised high in rank in other ways. Likewise We gave clear signs to Jesus, son of Mary, and supported him with the Holy Spirit. Had Allah so willed the people who had seen clear signs would not have fought against one another after the Prophets. But (it was not Allah's will to prevent people forcibly from differences: so) they disagreed; then some of them accepted the Truth and others rejected it. If Allah had so willed they would have never fought against one another, but Allah does whatever He pleases (to fulfil His designs.\qt@no{(253)}}%
\qt@newcmd\qurantrans@en@cclxi{%
O Believers, spend of the wealth We have bestowed upon you (in Our way) before the Day comes when there shall be no buying and no selling: when neither friendship nor intercession will be of any avail. Those, who adopt the way of disbelief are indeed the wrongdoers. '\qt@no{(254)}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah: the Everlasting, the Sustainer of the whole Universe; there is no god but He. He does neither slumber nor sleep. Whatsoever is in the heavens and in the earth is His. Who is there that can intercede with Him except by His own permission.? He knows what is before the people and also what is hidden from them. And they cannot comprehend anything of His knowledge save whatever He Himself pleases to reveal. His Kingdom spreads over the heavens and the earth and the guarding of these does not weary Him. He alone is the Supreme and the Exalted.\qt@no{(255)}}%
\qt@newcmd\qurantrans@en@cclxiii{%
There is no compulsion and coercion in regard to religion. The right thing has been made distinct from the wrong thing: now whoever rejects taghut and believes in Allah has taken a firm support that never gives way.\qt@no{(256)}}%
\qt@newcmd\qurantrans@en@cclxiv{%
And Allah (Whose support he takes) hears everything and knows everything. Allah is the Helper and Protector of those who believe in Him: He brings them out of the depths of darkness into the light. As for the disbelievers, they have taghut as their patron, who drives them out of light into the depths of darkness. These are the people who are doomed to the Fire, wherein they shall live for ever.\qt@no{(257)}}%
\qt@newcmd\qurantrans@en@cclxv{%
Have you not considered the case of the person who had an argument with Abraham as to `Whom Abraham acknowledged as his Lord?' The dispute arose because Allah had given him the kingship, (which had made him arrogant). When Abraham said, ``My Lord is He Who gives life and causes death," he answered, ``I give life and cause death." Then Abraham said, ``Well, Allah brings the sun from the east: just bring it from the west." At this the disbeliever was confounded: (yet he did not believe), for Allah does not show guidance to unjust people.\qt@no{(258)}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or take the case of the one who passed by a township that had fallen down upon its roofs. He exclaimed, ``How shall Allah bring back to life this township that has become dead?" At this Allah caused him to die and he lay dead for a hundred years. Then Allah brought him back to life and asked him, ``How long have you lain here?" He answered. ``I might have lain here for a day or a few hours." Allah said, ``Nay, you have been lying here in this state for a hundred years: now, just have a look at your food and your drink; they have not become spoiled in the least. Then have a look at your ass, (and see that his very bones have become rotten) and We have done this in order to make you a Sign for the people. Look, how We raise up the skeleton and set the bones (of the ass) and cover them with flesh and (put breath of life into them)." And when the Reality became manifest to him, he said, ``I know that Allah has power over everything."\qt@no{(259)}}%
\qt@newcmd\qurantrans@en@cclxvii{%
Call to mind the other event also, when Abraham said, ``My Lord, show me how Thou bringest the dead back to life?" He said ``Have you no faith in this?" Abraham humbly replied, ``I do believe but I ask this to reassure my heart." Allah said, ``Well, take four birds and tame them with yourself and then (cut them into pieces) and place a piece of each of them on each hill. Then call them and they will come running to you; know this for certain that Allah is All-Powerful, All-Wise."\qt@no{(260)}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The charity of those who expend their wealth in the way of Allah may be likened to a grain of corn, which produces seven ears and each ear yields a hundred grains. Likewise Allah develops manifold the charity of anyone He pleases, for He is All-Embracing, All-Wise.\qt@no{(261)}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those people who expend their wealth in the way of Allah, and then do not follow up their charity with reminders of their generosity nor injure the feelings of the recipient, shall get their reward from their Lord; they will have no fear and no sorrow of any kind.\qt@no{(262)}}%
\qt@newcmd\qurantrans@en@cclxx{%
A kind word and forbearance is better than that charity which is followed up by insult or injury. Allah is Self-Sufficient and Forbearing.\qt@no{(263)}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O Believers, do not spoil your charity by taunts and injury to the recipients like the one who practises charity to be seen by men, while he neither believes in Allah nor in the Last Day. His charity may be likened to the rainfall on a rock which had only a thin layer of soil upon it. When heavy rain fell on it, the whole of the soil washed away and the rock was left bare Such people do not gain the reward they imagine they have earned by their seeming charity; Allah does not show the Right Way to the ungrateful.\qt@no{(264)}}%
\qt@newcmd\qurantrans@en@cclxxii{%
In contrast to them, the charity of those, who expend their wealth sincerely with the sole desire of pleasing Allah, may be likened to a garden on a plateau. If heavy rain falls, it yields its produce twofold: and even if there is no heavy rain but only a light shower, that too, is sufficient for it: whatever you do is in the sight of Allah.\qt@no{(265)}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would anyone of you wish that he should have a green garden of palm trees and vines, watered by canals and laden with all sorts of fruit and then it should be consumed by a fiery whirlwind at the very time when he himself has grown very old and his small children are too feeble to earn anything? Thus Allah makes His revelations clear and plain to you that you may ponder over them.\qt@no{(266)}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O Believers, expend in Allah's Way the best portion of the wealth you have earned and of that We have produced for you from the earth, and do not pick out for charity those worthless things which you yourselves would only accept in disdain by connivance, if they were offered to you. Understand it well that Allah does not stand in need of anything whatsoever and has all the praise-worthy attributes.\qt@no{(267)}}%
\qt@newcmd\qurantrans@en@cclxxv{%
Satan holds out to you the threat of poverty and prompts you to adopt a shameless niggardly conduct, but Allah holds out from Himself the promise of pardon and bounty: Allah is All-Embracing, All-Knowing.\qt@no{(268)}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He bestows wisdom upon anyone He wills, and he who is given wisdom is in fact given great wealth, but only those who have common sense learn lessons from these things.\qt@no{(269)}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
Surely Allah knows whatever you may have spent and whatever vow you may have made, and the wrong-doers (who spend in the way of Satan) shall have no helpers.\qt@no{(270)}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If you practise charity publicly, it is good; but if you give charity secretly to the needy, it is much better for you, for this will expiate many of your sins. Anyhow, Allah is well aware of whatever you do.\qt@no{(271)}}%
\qt@newcmd\qurantrans@en@cclxxix{%
O Prophet, you are not responsible for their guidance; Allah Himself shows guidance to anyone He pleases. And whatever wealth you spend in charity, it is for your own good. As you spend of your wealth to win Allah's pleasure, you will be given full reward for whatever you spend and you will not be deprived in the least of your rightful due.\qt@no{(272)}}%
\qt@newcmd\qurantrans@en@cclxxx{%
Those who are engaged so much in the cause of Allah that they cannot move about in the land to earn their livelihood and are, therefore, in straitened circumstances, specially deserve help. An ignorant person would suppose them to be well off because of their self-respect; you can know their real condition from their faces, for they are not the ones who would beg of people with importunity. And Allah will surely know whatever you will spend on them.\qt@no{(273)}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who spend their wealth secretly and openly by day and night, will have their reward with their Lord, and they have nothing to fear nor grieve.\qt@no{(274)}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
But those who devour interest become like the one whom Satan has bewitched and maddened by his touch. They have been condemned to this condition because they say, ``Trade is just like interest", whereas Allah has made trade lawful and interest unlawful. Henceforth, if one abstains from taking interest after receiving this admonition from his Lord, no legal action will be taken against him regarding the interest he had devoured before; his case shall ultimately go to Allah. But if one repeats the same crime after this,. he shall go to Hell, where he shall abide for ever.\qt@no{(275)}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah deprives interest of all blessing and develops charity; and Allah does not like an ungrateful, sinful person.\qt@no{(276)}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
As to those who believe and do good deeds, establish the Salat and pay the Zakat, they will most surely have their reward with their Lord and they will have nothing to fear nor to grieve.\qt@no{(277)}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O Believers, fear Allah and give up that interest which is still due to you, if you are true Believers;\qt@no{(278)}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
but if you do not do so, then you are warned of the declaration of war against you by Allah and His Messenger. If, however, you repent even now (and forego interest), you are entitled to your principal; do no wrong, and no wrong will be done to you.\qt@no{(279)}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
If your debtor be in straitened circumstances, give him time till his monetary condition becomes better. But if you remit the debt by way of charity, it would be better for you, if you only knew it.\qt@no{(280)}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
Guard against the disgrace and misery of the day when you shall return to Allah: there everyone shall be paid in full, for the good or evil one has earned and none shall be wronged.\qt@no{(281)}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O Believers, when you contract a debt for a fixed; term, you should put it in writing. Let a scribe write with equity the document for the parties. The scribe whom Allah has given the gift of literacy should not refuse to write. Let him write and let the one under obligation (the debtor) dictate, and he should fear Allah, his Lord, and should not diminish from or add anything to the terms which have been settled. But if the borrower be of low understanding or weak or unable to dictate (for any reason), then let the guardian of his interests dictate it with equity. And let two men from among you bear witness to all such documents. But if two men be not available, there should be one man and two women to bear witness so that if one of the women forgets (anything), the other may remind her. The witnesses should be from among such people whom you approve of as witnesses. When the witnesses are asked to testify, they should not refuse to do so. Do not neglect to reduce to writing your transaction for a specified term, whether it be big or small. Allah considers this more just for you, for it facilitates the establishment of evidence and lessens doubts and suspicions. Of course, there is no harm if you do not put in writing the common transactions you conclude daily on the spot, but in case of commercial transactions you should have witnesses. The scribe and the witnesses should not be harassed: if you do so, you shall be guilty of sin. You should guard against the wrath of Allah; He gives you the knowledge of the right way for Allah has the knowledge of everything.\qt@no{(282)}}%
\qt@newcmd\qurantrans@en@ccxc{%
If you are on a journey and cannot find a scribe to write the document, then transact your business on the security of a pledge in hand. And, if any one transacts a piece of business with another merely on trust, then the one who is trusted should fulfil his trust and fear Allah, his Lord And never conceal evidence for he who conceals it, has a sinful heart: Allah knows everything that you do.\qt@no{(283)}}%
\qt@newcmd\qurantrans@en@ccxci{%
To Allah belongs whatever is in the heavens and the earth. `` Allah will call you to account for what is in your minds whether you disclose it or hide it. He, however, had full authority to pardon or punish anyone He pleases, for Allah has complete power over everything.\qt@no{(284)}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Messenger has believed in the Guidance which has been sent down to him from his Lord, and those who believe in the Messenger have also sincerely accepted the same. They all believe in Allah, His Angels, His Books and Messengers. And they say, ``We do not discriminate against any of His Messengers. We have heard the Message and submitted to it. Our Lord, we look up to You for forgiveness, for to You we shall all return."\qt@no{(285)}}%
\qt@newcmd\qurantrans@en@ccxciii{%
Allah does not burden any human being with a responsibility heavier than he can bear. Everyone will enjoy the fruit of the good that one has earned and shall suffer for the evil that one has committed. (O Believers, pray like this to Allah: ``Our Lord, take us not to task if we forget and lapse into error inadvertently. Lord! lay not on us the kind of burdens that You had lain on the people before us. Lord, lay not on us the kind of burden that we have not the strength to bear. Be kind to us, forgive us and show mercy to us. You are our Protector: help us against the disbelievers."\qt@no{(286)}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alif, Lam, Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah, the Ever-Living, the Self-Subsisting, Who sustains the entire order of the universe - there is no God but He.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
He has revealed this Book to you, setting forth the truth and confirming the earlier Books, and earlier He revealed the Torah and Gospel\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
for the guidance of mankind; and He has also revealed the Criterion (to distinguish truth from falsehood). A severe chastisement lies in store for those who deny the signs of Allah. Allah is All-Mighty; He is the Lord of Retribution.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Nothing in the earth and in the heavens is hidden from Allah.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@ccxcix{%
It is He Who fashions you in the wombs as He wills. There is no God but He; the All-Mighty, the All-Wise.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@ccc{%
It is He Who has revealed the Book to you. Some of its verses are absolutely clear and lucid, and these are the core of the Book. Others are ambiguous. Those in whose hearts there is perversity, always go about the part which is ambiguous, seeking mischief and seeking to arrive at its meaning arbitrarily, although none knows their true meaning except Allah. On the contrary, those firmly rooted in knowledge say: 'We believe in it; it is all from our Lord alone.' No one derives true admonition from anything except the men of understanding.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@ccci{%
They pray to Allah: 'Our Lord! Do not let our hearts swerve towards crookedness after You have guided us to the right way, and. bestow upon us Your mercy. Surely You, only You, are the Munificent Giver!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@cccii{%
Our Lord! You surely will gather mankind together one Day, a Day about (the coming of which) there is no doubt. Surely Allah never goes against His promise.'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@ccciii{%
Those who disbelieve, neither their wealth nor their offspring will avail them at all against Allah, and it is they who will be the fuel of the Fire\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@ccciv{%
(To them shall happen) the like of what happened to the people of Pharaoh, and those before them. They rejected Our signs, so Allah seized them for their sins. Allah indeed is severe in punishment.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@cccv{%
Tell those who disbelieved: 'You shall soon be overpowered and mustered to Hell - and that is an evil resting place!'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@cccvi{%
You have already come across an instructive sign in the two hosts that encountered each other in battle (at Badr): one host fighting in the way of Allah, and the other that of unbelievers. They saw with their own eyes that one host was twice the number of the other. But (the result of the battle has proved that) Allah succours with His victory whomsoever He wills. In this there is surely a lesson for all who have eyes to see.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@cccvii{%
Men are naturally tempted by the lure of women, children, treasures of gold and silver, horses of mark, cattle and plantations. These are the enjoyments in the life of this world; but with Allah lies a goodly abode to return to.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say: 'Shall I tell you of things better than these? For the God-fearing there are, with their Lord, gardens beneath which rivers flow; there they will abide for ever, will have spouses of stainless purity as companions, and will enjoy the good pleasure of Allah.' Allah thoroughly observes His servants.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@cccix{%
These are the ones who pray: 'Our Lord! We do indeed believe, so forgive us our sins and keep us safe from the chastisement of the Fire';\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@cccx{%
men who are steadfast, truthful, obedient, spend (in the way of Allah) and implore the forgiveness of Allah before daybreak.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@cccxi{%
Allah Himself bears witness that there is no God but He; and likewise do the angels and the men possessed of knowledge bear witness in truth and justice that there is no God but He, the All-Mighty, the All-Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@cccxii{%
The true religion with Allah is Islam. The People of the Book adopted many different ways rather than follow the true way of Islam even after the knowledge of truth had reached them, and this merely to commit excesses against one another. Let him who refuses to follow the ordinances and directives of Allah know that Allah is swift in His reckoning.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@cccxiii{%
And if they remonstrate with you, tell them: 'I have submitted my whole being to Allah, and so have those who follow me.' And ask the People of the Book as well as those who follow no heavenly Scripture: 'Have you also submitted (to Allah)?' If they have submitted to Him, they are indeed on the right way but if they deviate from submitting to Allah, then your duty is merely to deliver the message. Allah observes the affairs of His servants.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Give those who refuse to follow the directives of Allah, who slay the Prophets unjustly, and who slay those who enjoin justice, give them glad tidings of a grievous chastisement.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@cccxv{%
These are the people whose works have gone to waste in this world and in the World to Come. They have none to help them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Have you not noticed those who have been given a portion of the Book? Whenever their learned men are summoned to the Book of Allah to judge the differences between them, a party of them turns away in aversion.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@cccxvii{%
This is because they say: 'The fire of Hell shall not touch us except for a limited number of days.' The false beliefs which they have forged have deluded them in their faith.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@cccxviii{%
How, then, will they fare when We shall gather them all together to witness the Day about (the coming of) which there is no doubt, and when every human being shall be repaid in full for what he has done, and none shall be wronged?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say: 'O Allah, Lord of all dominion! You give dominion to whom You will, and take away dominion from whom You will, and You exalt whom You will, and abase whom You will. In Your Hand is all good. Surely You are All-Power-ful.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@cccxx{%
You cause the night to pass into the day and the day to pass into the night. You bring forth the living out of the dead, and You bring the dead out of the living, and You give sustenance to whom You will beyond all reckoning.'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@cccxxi{%
The believers may not take the unbelievers for their allies in preference to those who believe. Whoever does this has nothing to do with Allah unless he does so in order to protect himself from their wrong-doing. Allah warns you to beware of Him for it is to Allah that you will return.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say: 'Whether you conceal what is in your hearts or disclose it, Allah knows it. Allah knows what is in the heavens and in the earth and He has power over everything.'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
The Day is approaching when every soul shall find itself confronted with whatever good it has done and whatever evil it has wrought. It will then wish there is a wide space between it and the Day! Allah warns you to beware of Him; He is most tender towards His servants.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
(O Messenger!) Tell people: 'If you indeed love Allah, follow me, and Allah will love you and will forgive you your sins. Allah is All-Forgiving, All-Compassionate.'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say: 'Obey Allah and obey the Messenger.' If they turn away from this then know that Allah does not love those who refuse to obey Him and His Messenger.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Truly Allah chose Adam and Noah and the descendants of Abraham and of 'Imran above all mankind.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
(for His messengership) - a people alike and the seed of one another. Allah is All-Hearing, All-Knowing.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
(He also heard) when the woman of 'Imran said: 'O Lord! Behold, unto You do I vow that the child in my womb is to be devoted to Your exclusive service. Accept it, then, from me. Surely You alone are All-Hearing, All-Knowing.'\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@cccxxix{%
But when she gave birth to a female child, she said: 'O Lord! I have given birth to a female' - and Allah knew full well what she had given birth to - 'and a female is not the same as a male. I have named her Mary and commit her and her offspring to You for protection from Satan, the accursed.'\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@cccxxx{%
Thereupon her Lord graciously accepted Mary and vouchsafed to her a goodly growth and placed her in the care of Zechariah. Whenever Zechariah visited her in the sanctuary, he found her provided with food. He asked her: 'O Mary, how did this come to you?' She said: 'It is from Allah. Allah provides sustenance to whom He wills beyond all reckoning.'\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
Then Zechariah prayed to his Lord: 'O Lord! Grant me from Yourself out of Your grace the gift of a goodly offspring, for indeed You alone heed all Prayers.'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
As he stood praying in the sanctuary, the angels called out to him: 'Allah gives you good tidings of John (Yahya), who shall confirm a command of Allah, shall be outstanding among men, utterly chaste, and a Prophet from among the righteous.'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
Zechariah exclaimed: 'My Lord! How shall I have a son when old age has overtaken me and my wife is barren?' He said: Thus shall it be; Allah does what He wills.'\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
Zechariah said: 'O my Lord! Appoint a sign for me.' The angel said: 'The sign for you shall be that you shall not speak to men for three days except by gesture. Remember your Lord and extol His glory by night and by day.'\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
Then came the time when the angels said: 'O Mary! Behold, Allah has chosen you, and made you pure, and exalted you above all the women in the world.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
O Mary! Remain devout to your Lord, and prostrate yourself in worship, and bow with those who bow (before Him).'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
(O Muhammad!) We reveal to you this account from a realm which lies beyond the reach of your perception for you were not with them when they drew lots with their pens about who should be Mary's guardian, and you were not with them when they disputed about it.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
And when the angels said: 'O Mary! Allah gives you the glad tidings of a command from Him: his name shall be Messiah, Jesus, the son of Mary. He shall be highly honoured in this world and in the Next, and shall be one of those near stationed to Allah.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
And he shall speak to men in the cradle and also later when he grows to maturity and shall indeed be among the righteous.'\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said: 'O my Lord! How shall I have a son when no man has ever touched me?' The angel answered: Thus shall it be. Allah creates whatever He wills. When He decides something, He merely says: ``Be" and it is.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@cccxli{%
And He will teach him the Book, the Wisdom, the Torah, the Gospel,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@cccxlii{%
and he will be a Messenger to the Children of Israel.' (And when he came to them he said): 'I have come to you with a sign from your Lord. I will make for you from clay the likeness of a bird and then I will breathe into it and by the leave of Allah it will become a bird. I will also heal the blind and the leper, and by the leave of Allah bring the dead to life. I will also inform you of what things you eat and what you treasure up in your houses. Surely this is a sign for you if you are true believ-ers.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@cccxliii{%
And I have come to confirm the truth of whatever there still remains of the Torah, and to make lawful to you some of the things which had been forbidden to you. have come to you with a sign from your Lord; so have fear of Allah and obey me.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@cccxliv{%
Surely, Allah is my Lord and your Lord; so serve Him alone. This is the straight way.'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@cccxlv{%
And when Jesus perceived their leaning towards unbelief, he asked: 'Who will be my helpers in the way of Allah?' The disciples said: 'We are the helpers of Allah. We believe in Allah, and be our witness that we have submitted ourselves exclusively to Allah.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
Our Lord! We believe in the com-mandment You have revealed and we obey the Messenger; make us, then, one of those who bear witness (to the Truth).'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
Then they schemed (against the Messiah), and Allah countered their schemes by schemes of His own. Allah is the best of schemers.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
(And it was part of His scheme) when Allah said: 'O Jesus! I will recall you and raise you up to Me and will purify you (of the company) of those who disbelieve, and will set your followers above the unbelievers till the Day of Resurrection. Then to Me you shall return, and I will judge between you regarding what you differed.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@cccxlix{%
As for those who disbelieved, I shall punish them with a terrible chastisement in this world and in the Next; and they shall find none to help them.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@cccl{%
But those who believe and do righteous deeds, He will reward them in full. Allah does not love the unjust.'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@cccli{%
What We recite to you consists of signs and wise admonition.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@ccclii{%
Surely, in the sight of Allah, the similitude of the creation of Jesus is as the creation of Adam whom He created out of dust, and then said: 'Be', and he was.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@cccliii{%
This is the truth from your Lord; be not, then, among those who doubt.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@cccliv{%
Tell whoever disputes with you on this matter after true knowledge has come to you: 'Come! Let us summon our sons and your sons, and our women and your women, and ourselves and yourselves, and then let us pray together and invoke the curse of Allah on those who lie.'\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@ccclv{%
This is the true story. There is no God but Allah, and assuredly Allah is All-Mighty, All-Wise.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@ccclvi{%
And if they turn their backs, truly Allah knows those who cause mischief.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say: 'People of the Book! Come to a word common between us and you: that we shall serve none but Allah and shall associate none with Him in His divinity and that some of us will not take others as lords beside Allah.' And if they turn their backs (from accepting this call), tell them: 'Bear witness that we are the ones who have submitted ourselves exclusively to Allah.'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@ccclviii{%
People of the Book! Why do you dispute with us about Abraham even though the Torah and the Gospel were not revealed until after the time of Abraham? Do you not understand?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@ccclix{%
Behold, you are those who have disputed greatly concerning matters which you knew; why are you now disputing about matters that you know nothing about? Allah knows it whereas you do not know.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@ccclx{%
Abraham was neither a Jew nor a Christian; he was a Muslim, wholly devoted to God. And he certainly was not amongst those who associate others with Allah in His divinity.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Surely the people who have the best claim to a relationship with Abraham are those who followed him in the past, and presently this Prophet and those who believe in him; Allah is the guardian of the men of faith.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@ccclxii{%
A party of the People of the Book would fain lead you astray, whereas in truth they lead none astray except themselves, but they do not realize it.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
O People of the Book! Why do you reject the signs of Allah even though you yourselves witness them?\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
People of the Book! Why do you confound Truth with falsehood, and why do you conceal the Truth knowingly?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@ccclxv{%
A party of the People of the Book said: 'Believe in the morning what has been revealed to those who believe, and then deny it in the evening that they may thus retract (from their faith).'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
They also say among themselves: 'Do not follow anyone except him who follows your faith.' Say: 'Surely true guidance is Allah's. It is His favour that anyone should be given the like of what you have been given in the past, and that others should have been given firm evidence to proffer against you before your Lord.' Say: 'Surely bounty is in the Hand of Allah; He gives it to whom He wills. Allah is All-Embracing, All-Knowing.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He singles out for His mercy whomever He wills, Allah is possessed of abounding bounty.'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
And among the People of the Book there are some who would restore you even if you were to entrust a treasure of gold, and of them there are some whom were you to entrust with one gold piece, will not restore it unless you stand over them. That is because they say: 'We will not be taken to task for whatever we may do to non-Jews (ummls). Thus they falsely fix a lie upon Allah, and do so wittingly.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@ccclxix{%
But Allah loves only those who fulfil their covenant and fear Allah. Truly Allah loves the God-fearing.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@ccclxx{%
There shall be no share in the Life to Come for those who sell away the covenant of Allah and their oaths for a trivial gain. On the Day of Resurrection Allah will neither address them, look at them, nor will He purify them. A painful chastisement lies ahead of them.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And there is a party among them who twist their tongues while reciting the Book to make you think that it is part of the Book when in fact it is not. They say: 'It is from Allah', when in fact it is not from Allah. They falsely fix a lie upon Allah, and do so wittingly.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It does not befit a man that Allah should grant him His Book and sound judgement and prophet-hood, and thereafter he should say to men: 'Become servants to me apart from Allah.' He would rather say: 'Become dedicated men of Allah, in accord with the dictates of the Book you have been teaching and studying.'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
He will never enjoin you to take the angels or Prophets for your lords. Will he enjoin upon you unbelief when you have submitted yourselves to Allah?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
And recall when Allah took a covenant from the Prophets: 'This is the Book and the Wisdom which I have given you. But should a Prophet come to you confirming that which is already with you, you shall believe in him and shall help him. So saying, Allah asked: 'Do you agree and accept to take up the burden of the covenant?' They answered: 'We agree,' He said: 'Then bear wirness; and I will be with you among the witness.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
Then whosoever shall turn away from this covenant they are the transgressors.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
Do they now seek a religion other than prescribed by Allah even though all that is in the heavens and the earth is in submission to Him - willing or unwillingly - and to Him all shall return?\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say: 'We believe in Allah and what was revealed to us and what was revealed to Abraham and Ishmael and to Issac and Jacob and his descendents, and the teachings which Allah gave to Moses and Jesus and to other Prophets. We make no distinction between any of them and to Him do we submit.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
And whoever seeks a way other than this way a submission (Islam), will find that it will not be accepted from him and in the Life to come he will be among the losers.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How can Allah guide people who once believed, after they received clear signs and affirmed that the Messenger was a true one, lapsed into disbelief. Allah does not guide the wrong-doers.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
The recom- pense for their wrong-doing is that the curse of Allah and of the angels and of all men shall upon them.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
Thus shall they abide. Neither shall their chastisement be granted nor shall they be granted any respite.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
But those who repent and mend their ways shall be excepted for indeed Allah is Forgiving, All-Compassionate.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Those who relieved and have har-dened in their disbelief after once believing, their (pretence to) repentance shall not be accepted. Indeed such men have altogether strayed.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
Truly those who disbelieved and died as unbelievers, not even an earth full of gold will be accepted from them as ransom. For such people there is painful chastisement; and none shall come to their help.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
You shall not attain righteousness until you spend out of what you love (in the way of Allah). Allah knows whatever you spend.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food (that is lawful in the Law revealed to Muhammad) was lawful to the Children of Israel, except what Israel made unlawful to themselves before the revelation of the Torah. Tell them: 'Bring the Torah and recite any passage of it if you are truthful.'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
Those who falsely fix lies upon Allah despite this are the wrong-doers.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say: 'Whatever Allah has said is true. Follow, then, the way of Abraham in total devotion to Allah. He was not one of those who associate others with Allah in His divinity.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
Behold, the first House (of Prayer) established for mankind is the one at Bakkah: it is full of blessing and a centre of guidance for the whole world.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@cccxc{%
In it there are clear signs and the station of Abraham; whoever enters it becomes secure. Pilgrimage to the House is a duty owed to Allah by all who can make their way to it. As for those who refuse to follow His command, surely Allah does not stand in need of anything.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say: 'People of the Book! Why do you reject the signs of Allah when Allah is witness to all that you do?'\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say: 'People of the Book! Why do you hinder one who believes from the way of Allah, seeking that he follow a crooked way, even though you yourselves are witness to its being the right way?' Allah is not heedless of what you do.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@cccxciii{%
Believers! Were you to obey a party of those who were given the Book, they might cause you to renounce the Truth after you have attained to faith.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@cccxciv{%
How can you disbelieve when you are the ones to whom the signs of Allah are recited and amidst you is His Messenger? Whoever holds fast to Allah will certainly be guided to the straight way.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@cccxcv{%
Believers! Fear Allah as He should be feared, and see that you do not die save in the state of submission to Allah.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
Hold fast together to the cable of Allah and be not divided. Remember the blessing that Allah bestowed upon you: you were once enemies then He brought your hearts together, so that through His blessing you became brothers. You stood on the brink of a pit of fire and He delivered you from it. Thus Allah makes His signs clear to you that you may be guided to the right way.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
And from among you there must be a party who invite people to all that is good and enjoin the doing of all that is right and forbid the doing of all that is wrong. It is they who will attain true success.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
Do not be like those who fell into factions and differed among themselves after clear signs had come to them. A mighty chastisement awaits them on the Day when some faces will turn bright and ther faces will turn dark. Those whose faces have turned dark will be told: 'Did you fall into unbelief after you had been blessed with belief? Taste, then, chastise- ment for your unbelief.' And those whose faces have turned bright, they will be in the mercy of Allah, and therein they shall abide. These are the mes sages of Allah which We recite to you in truth, and Allah desires no wrong to the people of the world. To Allah belongs all that is in the heavens and the earth, and to Allah are all matters referred for decision.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On the Day when some faces will turn bright and ther faces will turn dark. Those whose faces have turned dark will be told: 'Did you fall into unbelief after you had been blessed with belief? Taste, then, chastisement for your unbelief.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@cd{%
And those whose faces have turned bright, they will be in the mercy of Allah, and therein they shall abide.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@cdi{%
These are the mes sages of Allah which We recite to you in truth, and Allah desires no wrong to the people of the world.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@cdii{%
To Allah belongs all that is in the heavens and the earth, and to Allah are all matters referred for decision.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@cdiii{%
You are now the best people brought forth for (the guidance and reform of) mankind. You enjoin what is right and forbid what is wrong and believe in Allah. Had the People of the Book believed it were better for them. Some of them are believers but most of them are transgressors.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will not be able to harm you except for a little hurt, and if they fight against you they will turn their backs (in flight), and then they will not be succoured.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cdv{%
Wherever they were, they were covered with ignominy, except when they were protected by either a covenant with Allah or a covenant with men. They are laden with the burden of Allah's wrath, and humiliation is stuck upon them - and all this because they rejected the signs of Allah and slayed the Prophets without right, and because they disobeyed and transgressed.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cdvi{%
Yet all are not alike: among the People of the Book there are upright people who recite the messages of Allah in the watches of the night and prostrate themselves in worship.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cdvii{%
They believe in Allah and in the Last Day and enjoin what is right and forbid what is wrong, and hasten to excel each other in doing good. These are among the righteous.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cdviii{%
Whatever good they do shall not go unappreciated, and Allah fully knows those who are pious.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cdix{%
As for those who denied the Truth, neither their possessions nor their children will avail them against Allah. They are the people of the Fire, and therein they shall abide.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cdx{%
The example of what they spend in the life of this world is like that of a wind accompanied with frost which smites the harvest of a people who wronged themselves, and lays it to waste. It is not Allah who wronged them; rather it is they who wrong themselves.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cdxi{%
Believers! Do not take for intimate friends those who are not of your kind. They spare no effort to injure you. Indeed they love all that distresses you. Their hatred is clearly manifest in what they say, and what their breasts conceal is even greater. Now We have made Our messages clear to you, if only you can understand (the danger of their intimacy).\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cdxii{%
Lo! It is you who love them but they do not love you even though you believe in the whole of the (heavenly) Book. When they meet you they say: 'We believe', but when they are by themselves they bite their fingers in rage at you. Say: 'Perish in your rage.' Allah knows even what lies hidden in their breasts.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If anything good happens to you they are grieved; if any misfortune befalls you they rejoice at it. But if you remain steadfast and mindful of Allah their designs will not cause you harm. Allah surely encompasses all that they do.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cdxiv{%
(O Messenger! Remind the Muslims of the occasion) when you went forth from your home at early dawn (to the battlefield of Uhud) and placed the believers in battle arrays. Allah is All-Hearing, All-Knowing.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cdxv{%
And recall when two groups from among you were inclined to flag although Allah was their protector; it is in Allah that the believers should put their trust.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cdxvi{%
For sure Allah helped you at Badr when you were utterly weak. Beware, then, of Allah; perhaps you will be thankful.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cdxvii{%
And recall when you said to the believers: 'Will it not suffice you that your Lord will aid you by sending down three thousand angels?\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cdxviii{%
If you are steadfast and mindful of God, even though the enemy should suddenly fall upon you, your Lord will help you even with five thousand marked angels.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cdxix{%
Allah has reminded you of this only as a glad tiding to you and so as to let your hearts be at rest. Help can only come from Allah, the All-Mighty, the All-Wise.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cdxx{%
And Allah provided this aid to you in order to cut off a part of those who disbelieved and frustrate them so that they retreat in utter disappointment.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cdxxi{%
(O Messenger!) It is not for you to decide whether He will accept their repentance or chastise them, for they surely are wrongdoers.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cdxxii{%
Whatever is in the heavens and the earth belongs to Allah. He forgives whom He wills, and chastises whom He wills: Allah is indeed All-Forgiving, Most-Compassionate.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
Believers! Do not swallow interest, doubled and redoubled, and be mindful of Allah so that you may attain true success.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And have fear of the Fire which awaits those who deny the Truth.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey Allah and the Messenger, that you may be shown mercy. And hasten to the for-giveness of your Lord and to a Paradise as vast as the heavens and the earth, prepared for the God-fearing who spend in the way of Allah both in plenty and hardship, who restrain their anger, and forgive others. Allah loves such good-doers."\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And hasten to the for-giveness of your Lord and to a Paradise as vast as the heavens and the earth, prepared for the God-fearing.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
who spend in the way of Allah both in plenty and hardship, who restrain their anger, and forgive others. Allah loves such good-doers."\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
These are the ones who, when they commit any indecency and wrong against themselves, instantly remember Allah and implore forgiveness for their sins - for who will forgive sins save Allah? - and who do not wilfully persist in the wrong they did.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cdxxix{%
They shall be recompensed by forgiveness from their Lord and by gardens beneath which rivers flow; there they shall abide. How good is the reward of those who labour!\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Many eras have passed before you. Go about, then, in the land and behold the end of those who gave the lie to (the directives and ordinances of Allah).\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This is a plain exposition for men, and a guidance and admonition for the Godfearing.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
Do not, then, either lose heart or grieve: for you shall surely gain the upper hand if you are true men of faith.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If a wound has befallen you a similar wound has already befallen the people who are opposed to you. We make such movements to men in turn so that Allah might mark out those who are the true men of faith and select from among you those who do really bear witness (to the Truth): for Allah does not love the wrong-doers,\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
and makes men go through trials in order that He might purge the believers and blot out those who deny the Truth.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Did you think that you would enter Paradise even though Allah has not yet seen who among you strove hard in His way and remained steadfast?\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
You previously longed for death (in the way of Allah): now you have faced it, observing it with your own eyes.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad is no more than a Messenger, and Messengers have passed away before him. If, then, he were to die or be slain will you turn about on your heels? Whoever turns about on his heels can in no way harm Allah. As for the grateful ones, Allah will soon reward them.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
It is not given to any soul to die except with the leave of Allah, and at an appointed time. And he who desires his reward in this world, We shall grant him the reward of this world; and he who desires the reward of the Other World, We shall grant him the reward of the Other World. And soon shall We reward the ones who are grateful.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
Many were the Prophets on whose side a large number of God-devoted men fought: they neither lost heart for all they had to suffer in the way of Allah nor did they weaken nor did they abase themselves. Allah loves such steadfast ones.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cdxl{%
And all they said was this: 'Our Lord! Forgive us our sins, and our excesses, and set our feet firm, and succour us against those who deny the Truth.'\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@cdxli{%
Thereupon Allah granted them the reward of this world as well as a better reward of the World to Come. Allah loves those who do good.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@cdxlii{%
Believers! If you follow those who deny the Truth, they will drive you back on your heels, and you will turn about, losers.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@cdxliii{%
But Allah is your Protector, and He is the best of helpers.\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@cdxliv{%
We will cast terror into the hearts of those who have denied the Truth since they have associated others with Allah in His divinity - something for which He has sent down no sanction. The Fire is their abode; how bad the resting place of the wrong-doers will be!\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@cdxlv{%
Allah surely fulfilled His promise (of succour) when you were slaying them by His leave until the moment when you flagged and quarrelled among yourselves about the matter, and acted against the order of (the Prophet). Soon He showed you what you had intensely desired - for some among you sought this world and some of you sought the Next. Thereupon, in order to put you to a test He turned you away from your foes. Still He pardoned you after that for Allah is Bounteous to those who believe.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
Recall when you were fleeing without casting even a side glance at anyone, and the Messenger was calling out to you from the rear. Then Allah requited you by inflicting grief after grief upon you so as to instruct you neither to grieve for the losses you might suffer nor for the afflictions that might befall you. Allah knows all that you do.\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then, after inflict-ing this grief, He sent down an inner peace upon you - a sleep which overtook some of you. Those who were concerned merely about themselves, entertaining false notions about Allah - the notions of the Age of Ignorance - asked: 'Have we any say in the matter?' Tell them: 'Truly, all power of decision rests solely with Allah.' Indeed, they conceal in their hearts what they would not reveal to you, saying: 'If we had any power of decision, we would not have been slain here.' Say: 'Even if you had been in your houses, those for whom slaying had been appointed would have gone forth to the places where they were to be slain.' And all this happened so that Allah might test your secret thoughts and purge your hearts of all impurities. Allah knows well what is in the breasts of men.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Surely those of them who turned their backs on the day when the two armies met (at Uhud) did so because Satan made them slip because of some of their lapses. But Allah has pardoned them; He is All-Forgiving, All-Forbearing.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@cdxlix{%
Believers, do not behave like those who disbelieved and say to their brothers (who meet some mishap) in the course of their journey for fighting: 'Had they remained with us, they would not have died nor been slain.' Allah makes such thoughts the cause of deep regrets in their hearts. For in truth it is Allah alone who grants life and deals death. Allah sees all that you do.\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@cdl{%
And were you to be slain or to die in the way of Allah, then surely Allah's forgiveness and mercy are better than all the goods they amass.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@cdli{%
And were you to die or be slain, it is to Allah that you will all be mustered.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@cdlii{%
It was thanks to Allah's mercy that you were gentle to them. Had you been rough, hard-hearted, they would surely have scattered away from you. So pardon them, and pray for their forgiveness, and take counsel from them in matters of importance. And when you are resolved on a course of action place your trust in Allah; surely Allah loves those who put their trust (in Him).\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah helps you none shall prevail over you; if He forsakes you then who can help you? It is in Allah that the believers should put their trust.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not for a Prophet to defraud; and whoever defrauds shall bring with him the fruits of his fraud on the Day of Resurrection, when every human being shall be paid in full what he has earned, and shall not be wronged.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@cdlv{%
Is he who follows the good pleasure of Allah like him who is laden with Allah's wrath and whose abode is Hell? How evil that is for a resting-place!\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They vary greatly in rank in the sight of Allah, and Allah sees what they do.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Surely Allah conferred a great favour on the believers when He raised from among them a Messenger to recite to them His signs, and to purify them, and to teach them the Book and Wisdom. For before that they were in manifest error.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@cdlviii{%
And how come when a calamity befell you, you began to ask: 'How has this come about?' even though the enemy has suffered at your hands (in the Battle of Badr) double what you have suffered! Say: This calamity has been brought about by yourselves. Surely Allah is Ail-Powerful.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@cdlix{%
What befell you on the day when the two hosts met was by the leave of Allah, and in order that He might mark out those who believe\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@cdlx{%
and those who are hypocrites. And when these hypocrites were asked: 'Come and fight in the wayof Allah', or (at least) 'defend yourselves', they answered: 'If we but knew that there would be fighting, we would certainly have followed. They were nearer then to infidelity than to faith. They utter from their mouths what is not in their hearts. Allah knows well what they conceal.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@cdlxi{%
These are the ones who stayed away, saying about their brothers: 'Had they followed us, they would not have been slain.' Say: 'If you speak the truth then avert death when it comes to you.'\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@cdlxii{%
Think not of those slain in the way of Allah as dead. Indeed they are living, and with their Lord they have their sustenance,\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
rejoicing in what Allah has bestowed upon them out of His bounty, jubilant that neither fear nor grief shall come upon the believers left behind in the world who have not yet joined them.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They rejoice at the favours and bounties of Allah, and at the awareness that Allah will not cause the reward of the believers to be lost.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@cdlxv{%
There were those who responded to the call of Allah and the Messenger after injury had smitten them - for all those who do good and fear Allah there is a mighty reward.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
When people said to them: 'Behold, a host has gathered around you and you should fear them', it only increased their faith and they answered: 'Allah is Sufficient for us; and what an excellent Guardian He is!'\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So they returned with a mighty favour and a great bounty from Allah having suffered no harm. They followed the good pleasure of Allah, and Allah is the Lord of great bounty.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
It was Satan who suggested to you the fear of his allies. Do not fear them; fear Me, if you truly believe.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@cdlxix{%
Let not those who run towards disbelief grieve you; they shall not hurt Allah in the least. Allah will not provide for them any share in the Next Life. A mighty punishment awaits them.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Indeed those who have purchased unbelief in exchange for faith shall not hurt Allah in the least. Theirs shall be a painful chastisement.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
Do not let the, unbelievers imagine that the respite We give them is good for them. We give them respite so that they may grow in wickedness. A humiliating chastisement lies in store for them.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
Allah will not let the believers stay in the state they are: He will set the wicked apart from the good. Allah is not going to disclose to you what is hidden in the realm beyond the reach of perception, but He chooses from among His Messengers whom He wills (to intimate such knowledge). Believe, then, in Allah and in His Messengers; and if you believe and be come God-fearing, yours will be a great reward.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
Those who are niggardly about what Allah has granted them out of His bounty think that niggardli ness is good for them; it is bad for them. What they were niggardly about will turn into a halter round their necks on the Day of Resur-rection. To Allah belongs the inheritance of the heavens and the earth; and Allah is well aware of what you do.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Allah has heard the saying of those who said: 'Allah is poor, and we are rich. We shall record what they have said, and the fact of their slaying the Prophets unjustly, and we shall say to them: Taste now the torment of the Fire.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
That is in recompense for what you have done.' Allah does no wrong to His servants.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
To those who say: 'Allah has directed us that we accept none as Messenger until he makes an offering that the fire will consume', say: 'Other Messengers came to you before me with clear signs, and with the sign you have mentioned. So why did you slay them, if what you say is true?\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
Now, if they give the lie to you, then other Messengers who came bearing clear signs and scriptures and the illuminating Book were also given the lie before you.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Everyone is bound to taste death and you shall receive your full reward on the Day of Resurrection. Then, whoever is spared the Fire and is admitted to Paradise has indeed been successful. The life of this world is merely an illusory enjoyment.\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
(Believers!) You will certainly be put to test in respect of your properties and lives, and you will certainly hear many hurtful things from those who were granted the Book before you and those who have associated others with Allah in His divinity. If you remain patient and God-fearing this indeed is a matter of great resolution.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
And recall when Allah took a covenant from those who were given the Book: 'You shall explain it to men and not hide it. Then they cast the Book behind their backs, and sold it away for a trivial gain. Evil indeed is their bargain.\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Do not think that those who exult in their misdeeds and love to be praised for what indeed they have not done, do not think that they are secure from chastisement. A painful chastisement awaits them.\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
To Allah belongs the dominion of the heavens and the earth; and Allah is All-Powerful. indeed been successful. The life of this world is merely an illusory enjoyment.\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Surely in the creation of the heavens and the earth, and in the alternation of night and day, there are signs for men of understanding.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
those who remember Allah while standing, sitting or (reclining) on their backs, and reflect in the creation of the heavens and the earth, (saying): 'Our Lord! You have not created this in vain. Glory to You! Save us, then, from the chastisement of the Fire.\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
Our Lord! Whomever You cause to enter the Fire, him You indeed bring to disgrace, and there will be none to succour the wrong-doers.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
Our Lord! Indeed we heard a crier calling to the faith saying: ``Believe in your Lord"; so we did believe. Our Lord, forgive us our sins, and wipe out our evil deeds and make us die with the truly pious.'\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
'Our Lord, fulfil what You promised to us through Your Messengers, and disgrace us not on the Day of Resurrection; indeed You never go back on Your promise.\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
Their Lord answered the Prayer thus: ``I will not suffer the work of any of you, whether male or female, to go to waste; each of you is from the other. Those who emigrated and were driven out from their homesteads and were persecuted in My cause, and who fought and were slain, indeed I shall wipe out their evil deeds from them and shall certainly admit them to the gardens beneath which rivers flow." This is their reward with their Lord; and with Allah lies the best reward.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
(O Messenger!) Do not let the strutting about of the unbelievers in the land deceive you.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@cdxc{%
This is but a little enjoyment, then their destination is Hell -what an evil resting place!\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@cdxci{%
But those who fear their Lord: theirs shall be the gardens beneath which rivers flow and in which they will live forever: a hospitality from Allah Himself, And Allah's reward is best for the truly pious.\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And among the People of the Book some believe in Allah and what has been revealed to you, and what has been revealed to them. They humble themselves before Allah, and do not sell Allah's revelations for a small price. For these men their reward is with their Lord. Allah is swift in His reckoning.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@cdxciii{%
Believers, be steadfast, and vie in steadfastness, stand firm in your faith, and hold Allah in fear that you may attain true success.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O men! Fear your Lord Who created you from a single being and out of it created its mate; and out of the two spread many men and women. Fear Allah in Whose name you plead for rights, and heed the ties of kinship. Surely, Allah is ever watchful over you.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@cdxcv{%
Give orphans their property, and do not exchange the bad for the good, and do not eat up their property by mixing it with your own. This surely is a mighty sin.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
If you fear that you might not treat the orphans justly, then marry the women that seem good to you: two, or three, or four. If you fear that you will not be able to treat them justly, then marry (only) one, or marry from among those whom your right hands possess. This will make it more likely that you will avoid injustice.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
Give women their bridal-due in good cheer (considering it a duty); but if they willingly remit any part of it, consume it with good pleasure.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
Do not entrust your properties - which Allah hasmade a means of support for you - to the weak of understanding, but maintain and clothe them out of it, and say to them a kind word of admonition.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@cdxcix{%
Test the orphans until they reach the age of marriage, and then if you find them mature of mind hand over to them their property, and do not eat it up by either spending extravagantly or in haste, fearing that they would grow up (and claim it). If the guardian of the orphan is rich let him abstain entirely (from his ward's property); and if he is poor, let him partake of it in a fair measure. When you hand over their property to them let there be witnesses on their behalf. Allah is sufficient to take account (of your deeds).\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@d{%
Just as there is a share for men in what their parents and kinsfolk leave behind, so there is a share for women in what their parents and kinsfolk leave behind - be it little or much - a share ordained (by Allah).\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@di{%
If other near of kin orphans and needy are pre sent at the time of division of inheritance give them some thing of it and speak to them kindly.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dii{%
And let them fear, those who, if they would themselves leave behind helpless offspring, they would surely have been fearful on their account. Let them, then, fear Allah and make the right statement.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@diii{%
Behold, those who wrongfully devour the properties of orphans only fill their bellies with fire. Soon they will burn in the Blazing Flame.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@div{%
Allah thus commands you concerning your children: the share of the male is like that of two females. If (the heirs of the deceased are) more than two daughters, they shall have two-thirds of the inheritance; and if there is only one daughter, then she shall have half the inheritance. If the deceased has any offspring, each of his parents shall have a sixth of the inheritance; and if the deceased has no child and his parents alone inherit him, then one-third shall go to his mother; and if the deceased has brothers and sisters, then one-sixth shall go to his mother. All these shares are to be given after payment of the bequest he might have made or any debts outstanding against him. You do not know which of them, your parents or your children, are more beneficial to you. But these portions have been determined by Allah, for He indeed knows all, is cognizant of all beneficent considerations.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dv{%
And to you belongs half of whatever has been left behind by your wives if they die childless; but if they have any children then to you belongs a fourth of what they have left behind, after payment of the bequest they might have made or any debts outstanding against them. And to them belongs a fourth of what you leave behind, if you die childless; and if you have any child then to them belongs one-eighth of what you have left behind, after the payment of the bequest you might have made or any debts outstanding against you. And if the man or woman has no heir in the direct line, but has a brother or sister, then each of these shall inherit one-sixth; but if they are more than two, then they shall inherit one-third of the inheritance, after the payment of the bequest that might have been made or any debts outstanding against the deceased, providing that the bequest causes no injury. This is a commandment from Allah; Allah is All-Knowing, All-Forbearing.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dvi{%
These are the bounds set by Allah. Allah will make the man who obeys Allah and His Messenger enter the Gardens beneath which rivers flow. He will abide there for ever. That is the mighty triumph.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dvii{%
And he who disobeys Allah and His Messenger and transgresses the bounds set by Him - him shall Allah cause to enter the Fire. There he will abide. A humiliating chastisement awaits him.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dviii{%
As for those of your women who are guilty of immoral conduct, call upon four from amongst you to bear witness against them. And if four men do bear witness, confine those women to their houses until either death takes them away or Allah opens some way for them.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dix{%
Punish both of those among you who are guilty of this sin, then if they repent and mend their ways, leave them alone. For Allah is always ready to accept repentance. He is All-Compassionate.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dx{%
(And remember that) Allah's acceptance of repentance is only for those who commit evil out of ignorance and then soon repent. It is towards such persons that Allah turns graciously. Allah is All-Knowing, All-Wise.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dxi{%
But of no avail is repentance of those who do evil until death approaches any one of them and then he says: 'Now I repent.' Nor is the repentance of those who die in the state of unbelief of any avail to them. For them We have kept in readiness a painful chastisement.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dxii{%
Believers! It is not lawful for you to become heirs to women against their will. It is not lawful that you should put constraint upon them that you may take away anything of what you have given them; (you may not put constraint upon them) unless they are guilty of brazenly immoral conduct. Live with your wives in a good manner. If you dislike them in any manner, it may be that you dislike something in which Allah has placed much good for you.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dxiii{%
And if you decide to dispense with a wife in order to take another, do not take away anything of what you might have given the first one, even if you had given her a heap of gold. Would you take it back by slandering her and committing a manifest wrong?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dxiv{%
How can you take it away after each one has enjoyed the other, and they have taken a firm covenant from you?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dxv{%
Do not marry the women whom your fathers married, although what is past is past. This indeed was a shameful deed, a hateful thing, and an evil way.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden to you are your mothers, your daughters, your sisters, your father's sisters and your mother's sisters, your brother's daughters and your sister's daughters, your milk-mothers, your milk-sisters, the mothers of your wives, and the stepdaughters - who are your foster-children, born of your wives with whom you have consummated the marriage; but if you have not consummated the marriage with them, there will be no blame upon you (if you marry their daughters). It is also forbidden for you to take the wives of the sons who have sprung from your loins and to take two sisters together in marriage, although what is past is past. Surely Allah is All-Forgiving, All-Compassionate.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dxvii{%
And also forbidden to you are all married women (muhsanat) except those women whom your right hands have come to possess (as a result of war). This is Allah's decree and it is binding upon you. But it is lawful for you to seek out all women except these, offering them your wealth and the protection of wedlock rather than using them for the unfettered satisfaction of lust. And in exchange of what you enjoy by marrying them pay their bridal-due as an obligation. But there is no blame on you if you mutually agree to alter the settlement after it has been made. Surely Allah is All-Knowing, All-Wise.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dxviii{%
And those of you who cannot afford to marry free, believing women (muhsanat), then marry such believing women whom your right hands possess. Allah knows all about your faith. All of you belong to one another. Marry them, then, with the leave of their guardians, and give them their bridal-due in a fair manner that they may live in the protection of wedlock rather than be either mere objects of unfettered lust or given to secret love affairs. Then if they become guilty of immoral conduct after they have entered into wedlock, they shall be liable to half the penalty to which free women (muhsanat) are liable. This relaxation is for those of you who fear to fall into sin by remaining unmarried. But if you persevere, it is better for you. Allah is All-Forgiving, All-Compassionate.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah wants to make all this clear to you, and to guide you to the ways which the righteous have followed in the past. He will turn graciously towards you. Allah is All-Knowing, All-Wise.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dxx{%
And Allah indeed wants to turn graciously towards you; but those who follow their lusts would want you to drift far away from the right way.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dxxi{%
Allah wants to lighten your burdens, for man was created weak.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dxxii{%
Believers! Do not devour one another's possessions wrongfully; rather than that, let there be trading by mutual consent. You shall not kill yourselves. Surely Allah is ever Compassionate to you.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dxxiii{%
And whoever does this by way of transgression and injustice him shall We surely cast into the Fire; that indeed is quite easy for Allah.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dxxiv{%
But if you avoid the major sins which you have been forbidden, We shall remit your (trivial) offences, and cause you to enter an honourable abode.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dxxv{%
Do not covet what Allah has conferred more abundantly on some of you than others. Men shall have a share according to what they have earned, and women shall have a share according to what they have earned. Do ask of Allah His bounty. Allah has full knowledge of everything.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dxxvi{%
And to everyone We have appointed rightful heirs to what the parents and near of kin might leave behind. As to those with whom you have made a solemn covenant, give them their share. Allah watches over all things.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are the protec-tors and maintainers of women because Allah has made one of them excel over the other, and because they spend out of their possessions (to support them). Thus righteous women are obedient and guard the rights of men in their absence under Allah's protection. As for women of whom you fear rebellion, admonish them, and remain apart from them in beds, and beat them. Then if they obey you, do not seek ways to harm them. Allah is Exalted, Great.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dxxviii{%
If you fear a breach between the two, appoint an arbitrator from his people and an arbitrator from her people. If they both want to set things right, Allah will bring about reconciliation between them. Allah knows all, is well aware of everything.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dxxix{%
Serve Allah and ascribe no partner to Him. Do good to your parents, to near of kin, to orphans, and to the needy, and to the neighbour who is of kin and to the neighbour who is a stranger, and to the companion by your side, and to the wayfarer, and to those whom your right hands possess. Allah does not love the arrogant and the boastful,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dxxx{%
who are niggardly and bid others to be niggardly and conceal the bounty which Allah has bestowed upon them. We have kept in readiness a humiliating chastisement for such deniers (of Allah's bounty).\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dxxxi{%
Allah does not love those who spend out of their wealth to make a show of it to people when they believe neither in Allah nor in the Last Day. And he who has taken Satan for a companion has indeed taken for himself a very bad companion.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dxxxii{%
What harm would have befallen them if they had believed in Allah and the Last Day, and spent on charity what Allah had bestowed upon them as sustenance? For Allah indeed has full knowledge of them.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Indeed Allah wrongs none, not even as much as an atom's weight. Whenever a man does good, He multiplies it two-fold, and bestows out of His grace a mighty reward.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
Consider, then, when We shall bring forward witnesses from every community, and will bring you (O Muhammad!) as a witness against them all.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dxxxv{%
Those who disbelieved and disobeyed the Messenger will wish on that Day that the earth were levelled with them. They will not be able to conceal anything from Allah.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
Believers! Do not draw near to the Prayer while you are intoxicated until you know what you are saying nor while you are defiled - save when you are travelling - until you have washed yourselves. If you are either ill or travelling or have satisfied a want of nature or have had contact with women and can find no water, then betake yourselves to pure earth, passing with it lightly over your face and your hands. Surely Allah is All-Relenting, All-Forgiving.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Have you not seen those to whom a portion of the Book was given? They purchased error for themselves, and wish that you too lose the right way?\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
Allah knows your enemies better and Allah suffices as a protector and Allah suffices as a helper.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Among those who have become Jews there are some who alter the words from their context, and make a malicious play with their tongues and seek to revile the true faith. They say: 'We have heard and we disobey' (sami'na wa 'asayna), 'Do hear us, may you turn dumb' (isma' ghayr musma') and 'Hearken to us' (ra'ina). It would indeed have been better for them and more upright if they had said: 'We have heard and we obey' (sami'na wa ata'na) and: 'Do listen to us, and look at us (with kindness)' (wa isma' wa unzurna). But Allah has cursed them because of their disbelief. Scarcely do they believe.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dxl{%
O you who have been granted the Book! Do believe in what We have (now) revealed, which confirms the revelation which you already possess. Do this before We alter countenances, turning them backwards, or lay a curse upon them as We cursed the Sabbath-men. Bear in mind that Allah's command is done.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dxli{%
Surely Allah does not forgive that a partner be ascribed to Him, although He forgives any other sins for whomever He wills. He who associates anyone with Allah in His divinity has indeed forged a mighty lie and committed an awesome sin.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dxlii{%
Have you not seen those who boast of their righteousness, even though it is Allah Who grants righteousness to whomsoever He wills? They are not wronged even as much as the husk of a date-stone (if they do not receive righteousness).\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dxliii{%
See how they forge lies about Allah! This in itself is a manifest sin.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dxliv{%
Have you not seen those to whom a portion of the Book was given? They believe in baseless superstitions and taghut (false deities), and say about the unbelievers that they are better guided than those who believe.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dxlv{%
Such are the ones whom Allah has cursed; and he whom Allah curses has none to come to his help.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Have they any share in the dominion (of Allah)? Had that been so, they would never have granted people even as much as the speck on a date-stone.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Do they envy others for the bounty that Allah has bestowed upon them? (Let them bear in mind that) We bestowed upon the house of Abraham the Book and Wis-dom, and We bestowed upon them a mighty dominion,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dxlviii{%
whereupon some of them believed, and others turned away. (Those who turn away), Hell suffices for a blaze.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dxlix{%
Surely We shall cast those who reject Our signs into the Fire; and as often as their skins are burnt out, We shall give them other skins in exchange that they may fully taste the chastisement. Surely Allah is All-Mighty, All-Wise.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dl{%
And those who believe and do good deeds, We shall cause them to enter the Gardens beneath which rivers flow. There they shall abide for ever. There they shall have spouses purified and there We shall cause them to enter a shelter with plenteous shade.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dli{%
Allah commands you to deliver trusts to those worthy of them; and when you judge between people, to judge with justice. Excellent is the admonition Allah gives you. Allah is All-Hearing, All-Seeing.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dlii{%
Believers! Obey Allah and obey the Messenger, and those from among you who are invested with authority; and then if you were to dispute among yourselves about anything refer it to Allah and the Messenger if you indeed believe in Allah and the Last Day; that is better and more commendable in the end.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dliii{%
(O Messenger!) Have you not seen those who claim to believe in the Book which has been revealed to you and in the Books revealed before you, and yet desire to submit their disputes to the judgement of taghut (the Satanic authorities who decide independently of the Law of Allah), whereas they had been asked to reject it. And Satan seeks to make them drift far away from the right way.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dliv{%
When they are told: 'Come to that which Allah has revealed, and come to the Messenger', you will notice the hypocrites turning away from you in aversion.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dlv{%
But what happens when some misfortune visits them because of their own misdeeds? Then, they come to you swearing by Allah, saying: 'We wanted nothing but to do good and to bring about conciliation (between the two parties)'.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dlvi{%
As for them, Allah knows what is in their hearts. Leave them alone, admonish them, and say to them penetrating words about themselves.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dlvii{%
(And tell them that) We never sent a Messenger but that he should be obeyed by the leave of Allah. If whenever they wronged themselves they had come to you praying to Allah for forgiveness, and had the Messenger prayed for their forgiveness, they would indeed have found Allah All-Forgiving, All-Compassionate.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dlviii{%
But no, by your Lord, they cannot become true be-lievers until they seek your arbitration in all matters on which they disagree among themselves, and then find not the least vexation in their hearts over what you have decided, and accept it in willing submission.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dlix{%
Had We enjoined upon them: 'Slay yourselves', or 'Leave your habitations', very few of them would have done it; yet if they had done as they were admonished, it would have been better for them and would have strengthened them;\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dlx{%
whereupon We would indeed grant them from Us a mighty reward,\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dlxi{%
and guide them to a straight way.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dlxii{%
And he who obeys Allah and the Messenger -they shall be with those whom Allah has favoured -the Prophets, those steadfast in truthfulness, the martyrs, and the righteous." How excellent will they be for companions!\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dlxiii{%
That is a bounty from Allah, and Allah suffices to know the truth.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dlxiv{%
Believers! Always be on your guard against encounters. Then (as circumstance demands) either advance in detachments or advance in a body.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dlxv{%
Among you there is such who lags behind, then if some affliction strikes you, he says: 'Indeed Allah bestowed His favour upon me that I was not present with them.'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dlxvi{%
And if a bounty from Allah is given you, he says - and says as if there never was any affection between you and him - 'Oh, would that I had been with them, I would have come by a great gain.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dlxvii{%
Let those who seek the life of the Next World in exchange for the life of this world fight in the way of Allah. We shall grant a mighty reward to whoever fights in the way of Allah, whether he is slain or comes out victorious.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dlxviii{%
How is it that you do not fight in the way of Allah and in support of the helpless - men, women and children -who pray: 'Our Lord, bring us out of this land whose people are oppressors and appoint for us from Yourself, a protector, and appoint for us from Yourself a helper'?.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dlxix{%
Those who have faith fight in the way of Allah, while those who disbelieve fight in the way of taghut (Satan). Fight, then, against the fellows of Satan. Surely Satan's strategy is weak.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dlxx{%
Have you not seen those who were told: 'Restrain you hands, and establish the Prayer, and pay the Zakah'? But when fighting was enjoined upon them some of them feared men as one should fear Allah, or even more, and said: 'Our Lord, why have You ordained fighting for us? Why did You not grant us a little more respite?' Say to them: 'There is little enjoyment in this world. The World to Come is much better for the God-fearing. And you shall not be wronged even to the extent of the husk of a date-stone.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dlxxi{%
Wherever you might be, death will overtake you even though you be in massive towers. And when some good happens to them, they say: 'This is from Allah'; whereas when some misfortune befalls them, they say: 'This is because of you'. Say: 'All is from Allah.' What has happened to this people that they seem to understand nothing?\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever good happens to you is from Allah; and whatever misfortune smites you is because of your own action. We have sent you to mankind (O Muhammad!) as a Messenger, and Allah is sufficient as a witness.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
He who obeys the Messenger thereby obeys Allah; as for he who turns away, We have not sent you as a keeper over them!\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
They say (in your presence): 'We obey', but when they leave your presence a party of them meets by night to plan against what you have said. Allah takes note of all their plots. So, let them alone, and put your trust in Allah. Allah is sufficient as a guardian.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Do they not ponder about the Qur'an? Had it been from any other than Allah, they would surely have found in it much inconsistency.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
Whenever they come upon any news bearing upon either security or causing consternation they go about spreading it, whereas if they were to convey it to either the Messenger or to those from among them who are entrusted with authority, it would come to the knowledge of those who are competent to investigate it. But for Allah's bounty and mercy upon you, (weak as you were) all but a few of you would surely have followed Satan.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
(So, O Messenger!) Fight in the way of Allah -since you are responsible for none except yourself - and rouse the believers to fight, for Allah may well curb the might of the unbelievers. Indeed Allah is strongest in power and most terrible in chastisement.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
He who intercedes in a good cause shall share in its good result, and he who intercedes in an evil cause shall share in its burden. Allah watches over everything.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dlxxix{%
When you are greeted with a salutation then return it with a better one, or at least the same. Surely Allah takes good count of everything.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dlxxx{%
There is no god but Allah. He will certainly gather you all together on the Day of Resurrection - the Day regarding which there can be no doubt. Whose word can be truer than Allah's?\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
What has happened to you that you have two minds about the hypocrites even though Allah has reverted them, owing to the sins that they earned? Do you want to lead those to the right way whom Allah let go astray? And he whom Allah lets go astray, for him you can never find a way.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They wish that you should disbelieve just as they disbelieved so that you may all be alike. Do not, therefore, take from them allies until they emigrate in the way of Allah, but if they turn their backs (on emigration), seize them and slay them wherever you come upon them. Take none of them for your ally or helper, This is the verdict on those hypocritical confessors of faith who belong to a belligerent, non-Muslim nation and actually participate in acts of hostility against the Islamic state.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
unless it be such of them who seek refuge with a people who are joined with you by a covenant, or those who come to you because their hearts shrink from fighting either against you or against their own people. Had Allah so willed, He would certainly have given them power over you and they would have fought against you. If they leave you alone and do not fight against you and offer you peace,, then Allah does not permit you to harm them.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
You will also find others who wish to be secure from you, and secure from their people, but who, whenever they have any opportunity to cause mischief, plunge into it headlong. If such people neither leave you alone nor offer you peace nor restrain their hands from hurting you, then seize them and slay them wherever you come upon them. It is against these that We have granted you a clear sanction.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
It is not for a believer to slay another believer unless by mistake. And he who has slain a believer by mistake, his atonement is to set free from bondage a believing person and to pay blood-money to his heirs, unless they forgo it by way of charity. And if the slain belonged to a hostile people, but was a believer, then the atonement is to set free from bondage a believing person. And if the slain belonged to a (non-Muslim) people with whom you have a covenant, then the atonement is to pay the blood-money to his heirs, and to set free from bondage a believing person. But he who cannot (free a slave) should fast for two consecutive months. This is the penance ordained by Allah. Allah is All-Knowing, All-Wise.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
And he who slays a believer wilfully his reward is Hell, where he will abide. Allah's wrath is against him and He has cast His curse upon him, and has prepared for him a great chastisement.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
Believers! When you go forth in the way of Allah, discern (between friend and foe), and do not say to him who offers you the greeting of peace: 'You are not a believer.' If you seek the good of this worldly life, there lies with Allah abundant gain. After all, you too were such before, and then Allah was gracious to you. Discern, then, for Allah is well aware of what you do.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Those believers who sit at home, unless they do so out of a disabling injury, are not the equals of those who strive in the way of Allah with their possessions and their lives. Allah has exalted in rank those who strive with their possessions and their lives over those who sit at home; and though to each Allah has promised some good reward, He has preferred those who strive (in the way of Allah) over those who sit at home for a mighty reward.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
For them are ranks, forgiveness, and favours from Him. Allah is All-Forgiving, All-Compassionate.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dxc{%
While taking the souls of those who were engaged in wronging themselves, the angels asked: 'In what circumstances were you?' They replied: 'We were too weak and helpless in the land.' The angels said: 'Was not the earth of Allah wide enough for you to emigrate in it?' For such men their refuge is Hell - an evil destination indeed;\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dxci{%
except the men, women, and children who were indeed too feeble to be able to seek the means of escape and did not know where to go.-\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dxcii{%
maybe Allah shall pardon these, for Allah is All-Pardoning, All-Forgiving.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dxciii{%
He who emigrates in the way of Allah will find in the earth enough room for refuge and plentiful resources. And he who goes forth from his house as a migrant in the way of Allah and His Messenger, and whom death overtakes, his reward becomes incumbent on Allah. Surely Allah is All-Forgiving, All-Compassionate.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dxciv{%
When you go forth journeying in the land, there is no blame on you if you shorten the Prayer, (especially) if you fear that the unbelievers might cause you harm. Surely the unbelievers are your open enemies.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dxcv{%
(O Messenger!) If you are among the believers and rise (in the state of war) to lead the Prayer for them, let a party of them stand with you to worship, keeping their arms. When they have performed their prostration, let them go behind you, and let another party who have not prayed, pray with you, remaining on guard and keeping their arms, for the unbelievers love to see you heedless of your arms and your baggage so that they might swoop upon you in a surprise attack. But there shall be no blame upon you if you were to lay aside your arms if you are either troubled by rain or are sick; but remain on guard. Surely Allah has prepared a humiliating chastisement for the unbelievers.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dxcvi{%
When you have finished the Prayer, remember Allah -standing, and sitting, and reclining. And when you become secure, perform the regular Prayer. The Prayer is enjoined upon the believers at stated times.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dxcvii{%
Do not be faint of heart in pursuing these people: if you happen to suffer harm they too are suffering just as you are, while you may hope from Allah what they cannot hope for. Allah is All-Knowing, All- Wise.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dxcviii{%
(O Messenger!) We have revealed to you this Book with the Truth so that you may judge between people in accordance with what Allah has shown you. So do not dispute on behalf of the dishonest,\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dxcix{%
and seek forgiveness from Allah. Surely Allah is All-Forgiving, All-Compassionate.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dc{%
Do not plead for those who are dishonest to themselves; Allah does not love him who betrays trust and persists in sin.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dci{%
They can hide (their deeds) from men but they cannot hide (them) from Allah for He is with them even when they hold nightly counsels that are unpleasing to Allah. Allah encompasses all their doings.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcii{%
You pleaded on their behalf in this worldly life but who will plead with Allah on their behalf on the Day of Resurrection, or who will be their defender there?\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dciii{%
He who does either evil or wrongs himself, and then asks for the forgiveness of Allah, will find Allah All-Forgiving, All-Compassionate.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@dciv{%
He who commits a sin, commits it only to his detriment. Surely Allah is All-Knowing, All-Wise.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@dcv{%
But he who commits either a fault or a sin, and then casts it upon an innocent person, lays upon himself the burden of a false charge and a flagrant sin.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@dcvi{%
(O Messenger!) But for Allah's favour and mercy upon you, a party of them had resolved to mislead you, yet they only misled them selves, and could not have harmed you in any way. Allah revealed to you the Book and Wisdom, and He taught you what you knew not. Great indeed has been Allah's favour upon you.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@dcvii{%
Most of their secret conferrings are devoid of good, unless one secretly enjoins in charity, good deeds, and setting the affairs of men right. We shall grant who ever does that seeking to please Allah a great reward.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@dcviii{%
As for him who sets himself against the Messenger and follows a path other than that of the believers even after true guidance had become clear to him, We will let him go to the way he has turned to, and We will cast him into Hell - an evil destination.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@dcix{%
Truly it is only associating others with Allah in His divinity that Allah does not forgive, and forgives anything besides that to whomsoever He wills. Whoever associates others with Allah in His divinity has indeed strayed far away.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@dcx{%
Rather than call upon Him, they call upon goddesses, and call upon a rebellious Satan\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@dcxi{%
upon whom Allah has laid His curse. He said (to Allah): 'I will take to myself an appointed portion of Your servants\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@dcxii{%
and shall lead them astray, and shall engross them in vain desires, and I shall command them and they will cut off the ears of the cattle, and I shall command them and they will disfigure Allah's creation.' He who took Satan rather than Allah for his guardian has indeed suffered a man-ifest loss.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@dcxiii{%
Satan makes promises to them and fills them with vain hopes, but whatever he promises them is merely delusion.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@dcxiv{%
For these people, their abode shall be Hell and from there they shall find no way of escape.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@dcxv{%
But those who believe and do good, We shall cause them to enter the Gardens beneath which rivers flow. Here they will abide for ever. This is Allah's promise in truth and whose word is truer than Allah's?\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@dcxvi{%
It is neither your fancies nor the fancies of the People of the Book which matter. Whoever does evil shall reap its consequence and will find none to be his protector and helper against Allah.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@dcxvii{%
Whoever does good and believes -whether he is male or female - such shall enter the Garden, and they shall not be wronged in the slightest.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And whose way of life could be better than that of he who submits his whole being to Allah, does good, and follows exclusively the way of Abraham whom Allah took for a friend?\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@dcxix{%
Whatever is in the heavens and in the earth belongs to Allah; Allah en-compasses everything.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@dcxx{%
They ask you to pronounce laws concerning women, say: 'Allah pronounces to you concerning them, and reminds you of the injunctions which were recited to you in the Book about female orphans whom you do not give what has been ordained for them and whom you wish to marry (out of greed)', and the commandments relating to the children who are weak and helpless. Allah directs you to treat the orphans with justice. Allah is well aware of whatever good you do.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@dcxxi{%
If a woman fears either ill-treatment or aversion from her husband it is not wrong for the husband and wife to bring about reconciliation among themselves (by compromising on their rights), for settlement is better. Man's soul is always prone to selfishness, but if you do good and are God-fearing, then surely Allah is aware of the things you do.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@dcxxii{%
You will not be able to treat your wives with absolute justice not even when you keenly desire to do so. (It suffices in order to follow the Law of Allah that) you incline not wholly to one, leaving the other in suspense. If you act rightly and remain God-fearing, surely Allah is All-Forgiving, All-Compassionate.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
But if the two separate, out of His plenty Allah will make each dispense with the other. Indeed Allah is All-Bounteous, All-Wise.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
All that is in the heavens and all that is in the earth belongs to Allah. We enjoined upon those who were given the Book before you, and also yourselves, to have fear of Allah. But if you disbelieve, then bear in mind that all that is in the heavens and all that is in the earth belongs to Allah. Allah is Self-Sufficient, Most Praiseworthy.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@dcxxv{%
And to Allah belongs all that is in the heavens and all that is in the earth; and Allah suffices for help and protection.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If He wills, He has the full power to remove you, O mankind, and bring in others in your place.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
He who desires the reward of this world, let him know that with Allah is the reward of this world and also of the World to Come. Allah is All-Hearing, All-Seeing.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
Believers! Be upholders of justice, and bearers of witness to truth for the sake of Allah, even though it may either be against yourselves or against your parents and kinsmen, or the rich or the poor: for Allah is more concerned with their well-being than you are. Do not, then, follow your own desires lest you keep away from justice. If you twist or turn away from (the truth), know that Allah is well aware of all that you do.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@dcxxix{%
Believers! Believe in Allah and His Messenger and in the Book He has revealed to His Messenger, and in the Book He revealed before. And whoever disbelieves in Allah, in His angels, in His Books, in His Messengers and in the Last Day, has indeed strayed far away.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Allah will neither forgive nor show the right way to those who believed, and then disbelieved, then believed, and again disbelieved, and thenceforth became ever more intense in their disbelief.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Give tidings of painful chastisement to the hypocrites.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
who take the unbelievers for their allies in preference to the believers. Do they seek honour from them whereas honour altogether belongs to Allah alone?\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
Allah has enjoined upon you in the-Book that when you hear the signs of Allah being rejected and scoffed at, you will not sit with them until they engage in some other talk, or else you will become like them. Know well, Allah will gather the hypocrites and the unbe-lievers in Hell - all together.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
These hypocrites watch you closely: if victory is granted to you by Allah, they will say: 'Were we not with you?' And were the unbelievers to gain the upper hand, they will say: 'Did we not have mastery over you, and yet we protected you from the believers?' It is Allah Who will judge between you on the Day of Resurrection, and He will not allow the unbelievers, in any way, to gain advantage over the believers.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
Behold, the hypocrites seek to deceive Allah, but it is they who are being deluded by Him. When they rise to Prayer, they rise reluctantly, and only to be seen by men. They remember Allah but little.\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
They dangle between the one and the other (faith and disbelief), and belong neither to these nor to those completely. And he whom Allah lets go astray, for him you can find no way.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
Believers! Do not take the unbelievers as your allies in preference to the believers. Do you wish to offer Allah a clear proof of guilt against yourselves?\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
Surely the hypocrites shall be in the lowest depth of the Fire and you shall find none to come to their help,\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
except those who re-pent and mend their ways and hold fast to Allah and make their faith exclusive to Allah. Those people shall be numbered with the believers and Allah will certainly bestow on the believers a great reward.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@dcxl{%
Why should Allah deal chastisement to you if you are grateful to Him and believe? Allah is All-Appreciative, All-Knowing.\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah does not like speaking evil publicly unless one has been wronged. Allah is All-Hearing, All-Knowing.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@dcxlii{%
(Even though you have the right to speak evil if you are wronged), if you keep doing good -whether openly or secretly -or at least pardon the evil (then that is the attribute of Allah). Allah is All-Pardoning and He has all the power to chastise.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@dcxliii{%
There are those who disbelieve in Allah and His Messengers and seek to differentiate between Allah and His Messengers, and say: 'We believe in some and deny others, and seek to strike a way between the two.'\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@dcxliv{%
It is they, indeed they, who are, beyond all doubt, unbelievers; and for the unbelievers We have prepared a humiliating chastisement.\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@dcxlv{%
For those who believe in Allah and His Messengers, and do not differentiate between them, We shall certainly give them their reward. Allah is All-Forgiving, All-Compassionate\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The People of the Book now ask of you to have a Book come down on them from heaven; indeed they asked of Moses even greater things than this, for they said: 'Make us see Allah with our own eyes' - whereupon the thunderbolt suddenly smote them for their wickedness. Then they took to worshipping the calf after clear signs had come to them. Still, We forgave them, and conferred a manifest commandment upon Moses,\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
and We raised the Mount high above them and took from them a covenant (to obey the commandment), and ordered them: 'Enter the gate in the state of prostration.' And We said to them: 'Do not violate the law of the Sabbath', and took from them a firm covenant.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
(They have incurred Allah's wrath) for their breaking the covenant, and their rejection of the signs of Allah, and for slaying Prophets without right, and for saying: 'Our hearts are wrapped up in covers' -even though in fact Allah has sealed their hearts because of their unbelief, so that they scarcely believe\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@dcxlix{%
and for their going so far in unbelief as uttering against Mary a mighty calumny,\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@dcl{%
and their saying: 'We slew the Messiah, Jesus, son of Mary', the Messenger of Allah - whereas in fact they had neither slain him nor crucified him but the matter was made dubious to them - and those who differed about it too were in a state of doubt! They have no definite knowledge of it, but merely follow conjecture; and they surely slew him not,\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@dcli{%
but Allah raised him to Himself. Allah is All-Mighty, All-Wise.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@dclii{%
There are none among the People of the Book but will believe in him before his death, and he will be a witness against them on the Day of Resurrection.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@dcliii{%
Thus, We forbade them many clean things which had earlier been made lawful for them, for the wrong-doing of those who became Jews, for their barring many from the way of Allah,\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@dcliv{%
and for their taking interest which had been prohibited to them, and for their consuming the wealth of others wrongfully. And for the un believers among them We have prepared a painful chastisement.\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@dclv{%
Those among them who are firmly rooted in knowledge and the believers, such do believe in what has been revealed to you and what was revealed before you. (Those who truly believe) establish the Prayer and pay Zakah, those who firmly believe in Allah and in the Last Day, to them We shall indeed pay a great reward.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@dclvi{%
(O Muhammad!) We have revealed to you as We revealed to Noah and the Prophets after him, and We revealed to Abraham, Ishmael, Isaac, Jacob and the offspring of Jacob, and Jesus and Job, and Jonah, and Aaron and Solomon, and We gave to David Psalms.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@dclvii{%
We revealed to the Messengers We have already told you of, and to the Messengers We have not told you of; and to Moses Allah spoke directly.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@dclviii{%
These Messengers were sent as bearers of glad tidings and as warners so that after sending the Messengers people may have no plea against Allah. Allah is All-Mighty, All-Wise.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@dclix{%
(Whether people believe or not) Allah bears witness that whatever He has revealed to you, He has revealed with His knowledge, and the angels bear witness to it too, though the witness of Allah is sufficient.\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@dclx{%
Those who denied this truth and barred others from the way of Allah have indeed strayed far.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@dclxi{%
Likewise, Allah will neither forgive those who denied the truth and took to wrong-doing nor will He show them any other way.\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@dclxii{%
save that of Hell wherein they will abide. And that is easy for Allah.\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O men! Now that the Messenger has come to you bearing the Truth from your Lord, believe in him; it will be good for you. If you reject, know well that to Allah belongs all that is in the heavens and the earth. Allah is All-Knowing, All-Wise.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@dclxiv{%
People of the Book! Do not exceed the limits in your religion, and attribute to Allah nothing except the truth. The Messiah, Jesus, son of Mary, was only a Messenger of Allah, and His command that He conveyed unto Mary, and a spirit from Him (which led to Mary's conception). So believe in Allah and in His Messengers, and do not say: (Allah is a) trinity. Give up this assertion; it would be better for you. Allah is indeed just one God. Far be it from His glory that He should have a son. To Him belongs all that is in the heavens and in the earth. Allah is sufficient for a guardian.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@dclxv{%
The Messiah neither did disdain to be a servant of Allah nor do the angels who are stationed near to Him; and whoever disdains to serve Him, and waxes arrogant, Allah will certainly muster them all to Him.\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@dclxvi{%
He will grant those who have believed and done good deeds their rewards in full, and will give them more out of His bounty. He will bestow upon those who have been disdainful and arrogant a painful chastisement; and they will find for themselves neither a guardian nor a helper besides Allah.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O men! A proof has come to you from your Lord, and We have sent down unto you a clear light.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@dclxviii{%
Allah will surely admit those who believe in Him and hold fast to Him to His mercy and bounty, and will guide them on to a straight way to Himself.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@dclxix{%
People ask you to pronounce a ruling concerning inheritance from those who have left behind no lineal heirs (kalalah). Say: 'Allah pronounces for you the ruling: should a man die childless but have a sister, she shall have one half of what he has left behind; and should the sister die childless, his brother shall inherit her. And if the heirs are two sisters, they shall have two-thirds of what he has left behind. And if the heirs are sisters and brothers, then the male shall have the share of two females. Allah makes (His commandments) clear to you lest you go astray. Allah has full knowledge of everything.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen Believers! Honour your bonds! All grazing beasts of the flock are permitted to you except those which are recited to you hereinafter, but you are not allowed to hunt in the state of Ihram (a state of pilgrim sanctity). Indeed Allah decrees as He wills.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@dclxxi{%
Believers! Neither desecrate the symbols of (devotion to) Allah, nor the holy month, nor the animals of offering, nor the animals wearing collars indicating they are for sacrifice, nor ill-treat those who have set out for the Holy House seeking from their Lord His bounty and good pleasure. But once you are free from Pilgrimage obligations, you are free to hunt. Do not let your wrath against the people who have barred you from the Holy Mosque move you to commit undue transgressions; rather, help one another in acts of righteousness and piety, and do not help one another in sin and transgression. Fear Allah. Surely Allah is severe in retribution.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Forbidden to you are carrion, blood, the flesh of swine, the animal slaughtered in any name other than Allah's, the animal which has either been strangled, killed by blows, has died of a fall, by goring or that devoured by a beast of prey - unless it be that which you yourselves might have slaughtered while it was still alive - and that which was slaughtered at the altars. - You are also forbidden to seek knowledge of your fate by divining arrows. All these are sinful acts. This day the unbelievers have fully despaired of your religion. Do not fear them; but fear Me. This day I have perfected for you your religion, and have bestowed upon you My bounty in full measure, and have been pleased to assign for you Islam as your religion. (Follow, then, the lawful and unlawful bounds enjoined upon you.) As for he who is driven by hunger, without being wilfully inclined to sin, surely Allah is All-Forgiving, All-Compassionate.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask you what has been made lawful to them. Say: 'All clean things have been made lawful to you, and such hunting animals as you teach, training them to hunt, teaching them the knowledge Allah has given you - you may eat what they catch for you - but invoke the name of Allah on it. Have fear of Allah (in violating His Law). Allah is swift in His reckoning.'\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
This day all good things have been made lawful to you. The food of the People of the Book is permitted to you, and your food is permitted to them. And permitted to you are chaste women, be they either from among the believers or from among those who have received the Book before you, provided you become their protectors in wedlock after paying them their bridal-due, rather than go around committing fornication and taking them as secret-companions. The work of he who refuses to follow the way of faith will go waste, and he will be among the utter losers in the Hereafter.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@dclxxv{%
Believers! When you stand up for Prayer wash your faces and your hands up to the elbows, and wipe your heads, and wash your feet up to the ankles. And if you are in the state of ritual impurity, purify yourselves (by taking a bath). But if you are either ill, travelling, have satisfied a want of nature or have had contact with women and find no water then have recourse to clean earth and wipe your faces and your hands therewith. Allah does not want to lay any hardship upon you; rather He wants to purify you and complete His favours upon you so that you may give thanks.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
Remember Allah's favour upon you and His covenant which He made with you when you said: 'We have heard and we obey.' So do fear Allah. Allah has full knowledge even of that which is hidden in the breasts of people.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
Believers! Be upright bearers of witness for Allah, and do not let the enmity of any people move you to deviate from justice. Act justly, that is nearer to God-fearing. And fear Allah. Surely Allah is well aware of what you do.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
Allah has promised those who believe and do righteous deeds forgiveness from sins and a great reward.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@dclxxix{%
As for those who disbelieve and give the lie to Our signs, they are destined for the Blazing Flame.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@dclxxx{%
Believers! Remember Allah's favour upon you. When a certain people decided to stretch their hands against you, He restrained their hands from you. Do fear Allah. Men of faith should put their trust in Allah alone.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
Surely Allah took a covenant with the Children of Israel, and We raised up from them twelve of their leaders, and Allah said: 'Behold, I am with you; if you establish Prayer and pay Zakah and believe in My Prophets and help them, and lend Allah a good loan, I will certainly efface from you your evil deeds, and will surely cause you to enter the Gardens beneath which rivers flow. Whosoever of you disbelieves thereafter has indeed gone astray from the right way.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
Then, for their breach of the covenant We cast them away from Our mercy and caused their hearts to harden. (And now they are in such a state that) they pervert the words from their context and thus distort their meaning, and have forgotten a good portion of the teaching they were imparted, and regarding all except a few of them you continue to learn that they committed acts of treachery. Pardon them, then, and overlook their deeds. Surely Allah loves those who do good deeds.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
We also took a covenant from those who said: 'We are Christians'; but they forgot a good portion of the teaching they had been imparted with. Wherefore We aroused enmity and spite between them till the Day of Resurrection, and ultimately Allah will tell them what they had contrived.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
People of the Book! Now Our Messenger has come to you: he makes clear to you a good many things of the Book which you were wont to conceal, and also passes over many things. There has now come to you a light from Allah, and a clear Book.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
through which Allah shows to all who seek to please Him the paths leading to safety. He brings them out, by His leave, from darkness to light and directs them on to the straight way.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
Indeed those who said: 'Christ, the son of Mary, he is indeed God', disbelieved. Say (O Muhammad!): 'Who could have overruled Allah had He so willed to destroy Christ, the son of Mary, and his mother, and all those who are on earth?' For to Allah belongs the dominion of the heavens and the earth and all that is between them; He creates what He wills. Allah is All-Powerful.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
The Jews and the Christians say: 'We are Allah's children and His beloved ones.' Ask them: 'Why, then, does He chastise you for your sins?' You are the same as other men He has created. He forgives whom He wills and chastises whom He wills. And to Allah belongs the dominion of the heavens and the earth, and all that is between them. To Him is the eventual return.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
People of the Book! After a long interlude during which no Messengers have appeared there has come to you Our Messenger to elucidate the teaching of the true faith lest you say: 'No bearer of glad tidings and no warner has come to us.' For now there indeed has come to you a bearer of glad tidings and a warner, Allah is All-Power-ful.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
Remember when Moses said to his people: 'My people, remember Allah's favour upon you when He raised Prophets amongst you and appointed you rulers, and granted to you what He had not granted to anyone else in the world.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dcxc{%
My people! Enter the holy land which Allah has ordained for you; and do not turn back for then you will turn about losers.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dcxci{%
They answered: 'Moses, therein live a ferocious people: we will not enter unless they depart from it; but if they do depart from it then we will surely enter it.'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Two from among these who were frightened but upon whom Allah had bes-towed His favour said: 'Enter upon them through the gate - for if you do enter - you will be the victors. And put your trust in Allah if indeed you are men of faith.'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dcxciii{%
Nevertheless they said: 'O Moses! Never shall we enter it as long as they are there. Go forth, then, you and your Lord, and fight, both of you. As for us, we will sit here.'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dcxciv{%
Thereupon Moses said: 'My Lord! I have control over none but my own self and my brother; so distinguish between us and the transgressing people.'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dcxcv{%
Allah said: 'This land will now be forbidden to them for forty years and they will remain wandering about on the earth. Do not grieve over the condition of these transgressing people.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
Narrate to them in all truth the story of the two sons of Adam. When they made an offering and it was accepted from one of them and was not accepted from the other, the latter said: 'I will surely kill you.' Thereupon the former said: 'Allah accepts offerings only from the God-fearing.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
Even if you stretch forth your hand against me to kill, I will not stretch forth my hand to kill you. Surely, I fear Allah, the Lord of the entire universe.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
I would desire that you be laden with my sin and with your sin, and thus become among the inmates of the Fire. That indeed is the right recompense of the wrong-doers.'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dcxcix{%
At last his evil soul drove him to the murder of his brother, and he killed him, whereby he himself became one of the losers.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dcc{%
Thereupon Allah sent forth a raven who began to scratch the earth to show him how he might cover the corpse of his brother. So seeing he cried: 'Woe unto me! Was I unable even to be like this raven and find a way to cover the corpse of my brother? Then he became full of remorse at his doing.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dcci{%
Therefore We ordained for the Children of Israel that he who slays a soul unless it be (in punishment) for murder or for spreading mischief on earth shall be as if he had slain all mankind; and he who saves a life shall be as if he had given life to all mankind. And indeed again and again did Our Messengers come to them with clear directives; yet many of them continued to commit excesses on earth.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dccii{%
Those who wage war against Allah and His Messenger, and go about the earth spreading mischief -indeed their recompense is that they either be done to death, or be crucified, or have their hands and feet cut off from the opposite sides or be banished from the land. Such shall be their degradation in this world; and a mighty chastisement lies in store for them in the World to Come\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dcciii{%
except for those who repent before you have overpowered them. Know well that Allah is All-Forgiving, All-Compassionate.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dcciv{%
Believers! Fear Allah and seek the means to come near to Him, and strive hard in His way; maybe you will attain true success.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dccv{%
For those who disbelieved - even if they had all that is in the earth, and the like of it with it, and offered it all as ransom from chastisement on the Day of Resurrection, it will not be accepted of them - a painful chastisement lies in store for them.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will wish to come out of the Fire, but they will not. Theirs will be a long-lasting chastisement.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dccvii{%
As for the thief -male or female - cut off the hands of both. This is a recompense for what they have done, and an exemplary punishment from Allah. Allah is All-Mighty, All-Wise.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dccviii{%
But he who repents after he has committed wrong, and makes amends, Allah will graciously turn to him. Truly Allah is All-Forgiving, All-Compassionate.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dccix{%
Do you not know that to Allah belongs the dominion of the heavens and the earth? He chastises whom He wills and forgives whom He wills. Allah is All-Powerful.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger! Do not be grieved on account of those who vie with one another in disbelieving: even though they be those who say with their mouths: 'We believe' even though their hearts have no faith; or they be Jews who have their ears eagerly turned to falsehood and spy for other people who did not chance to come to you, who pervert the words of Allah, taking them out of their proper context in order to distort their meaning. They say to people: 'If such and such teaching is given to you, accept it; if you are not given that, then beware! You can be of no avail to him whom Allah wills to fall into error. Those are the ones whose hearts Allah does not want to purify. For them there is degradation in this world and a mighty chastisement in the Next.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dccxi{%
They are listeners of falsehood and greedy devourers of unlawful earnings. If they come to you you may either judge between them or turn away from them. And were you to turn away from them they shall not be able to harm you; and were you to judge between them judge with justice. Surely Allah loves the just.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dccxii{%
Yet how will they appoint you a judge when they have the Torah with them, wherein there is Allah's judgement - and still they turn away from it? The fact is, they are not believers.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dccxiii{%
Surely We revealed the Torah, wherein there is guidance and light. Thereby did Prophets - who had submitted themselves (to Allah) - judge for the Judaized folk; and so did the scholars and jurists. They judged by the Book of Allah for they had been entrusted to keep it, and bear witness to it. So (O Jews!) do not fear men but fear Me, and do not barter away My signs for a trivial gain. Those who do not judge by what Allah has revealed are indeed the unbelievers.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And therein We had ordained for them: 'A life for a life, and an eye for an eye, and a nose for a nose, and an ear for an ear, and a tooth for a tooth, and for all wounds, like for like. But whosoever forgoes it by way of charity, it will be for him an expiation. Those who do not judge by what Allah has revealed are indeed the wrong-doers.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dccxv{%
And We sent Jesus, the son of Mary, after those Prophets, confirming the truth of whatever there still remained of the Torah. And We gave him the Gospel, wherein is guidance and light, and which confirms the truth of whatever there still remained of the Torah, and a guidance and admonition for the God-fearing.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dccxvi{%
Let the followers of the Gospel judge by what Allah has revealed therein, and those who do not judge by what Allah has revealed are the transgressors.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dccxvii{%
Then We revealed the Book to you (O Muhammad!) with Truth, confirming whatever of the Book was revealed before, and protecting and guarding over it. Judge, then, in the affairs of men in accordance with the Law that Allah has revealed, and do not follow their desires in disregard of the Truth which has come to you. For each of you We have appointed a Law and a way of life. And had Allah so willed, He would surely have made you one single community; instead, (He gave each of you a Law and a way of life) in order to test you by what He gave you. Vie, then, one with another in good works. Unto Allah is the return of all of you; and He will then make you understand the truth concerning the matters on which you disagreed.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dccxviii{%
Therefore, judge bet-ween them (O Muhammad!) by what Allah has revealed and do not follow their desires, and beware lest they tempt you away from anything of what Allah has revealed to you. And if they turn away, then know well that Allah has indeed decided to afflict them for some of their sins. For surely many of them are transgressors.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dccxix{%
(If they turn away from the Law of Allah) do they desire judgement according to the Law of Ignorance? But for those who have certainty of belief whose judgement can be better than Allah's?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dccxx{%
Believers! Do not take the Jews and the Christians for your allies. They are the allies of each other. And among you he who takes them for allies, shall be regarded as one of them. Allah does not guide the wrong-doers.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dccxxi{%
Indeed you see those afflicted with the disease of hypocrisy race towards them, saying: 'We fear lest some misfortune overtakes us. And it may happen that Allah will either bring you a decisive victory or bring about something else from Himself? and then they will feel remorseful at their hypocrisy which they have kept concealed in their breasts -\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dccxxii{%
while those who believe will exclaim: 'Are these the self-same people who solemnly swore by Allah that they were with you?' All their acts have gone to waste and now they are the losers.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
Believers! If any of you should ever turn away from your faith, remember that Allah will raise up a people whom He loves, and who love Him; a people humble towards the believers, and firm towards the unbelievers; who will strive hard in the way of Allah and will not fear the reproach of the reproacher. This is the favour of Allah which He grants to whom He wills. Allah is vast in resources, All-Knowing.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Only Allah, His Messenger, and those who believe and who establish Prayer, pay Zakah, and bow (before Allah) are your allies.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dccxxv{%
All those who take Allah and His Messenger and those who believe as their allies, should remember that the party of Allah will be triumphant.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
Believers! Do not take for your allies those who make a mockery and sport of your faith, be they those given the Book before you or other unbelievers. Fear Allah if you indeed believe.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
And when you call for Prayer, they take it for a mockery and sport. That is because they are a people who do not understand.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say to them: 'People of the Book! Do you hate us for anything else except that we believe in Allah, and in the teaching which has been revealed to us and in the teaching which was revealed before? Indeed most of you are transgressors.'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Then say to them: 'Shall I tell you about those whose retribution with Allah is even worse? They are the ones whom Allah has cursed, and who incurred His wrath and some of whom were changed into apes and swine, and who served the false deities. Such have an even worse rank and have strayed farther away from the right path.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dccxxx{%
Whenever they come to you they say: 'We believe,' whereas, in fact, they come disbelieving, and go away disbelieving, and Allah knows all that they hide.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
You will see many of them hastening towards sin and transgression and devouring unlawful earnings. Indeed what they do is evil.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why is it that their scholars and jurists do not forbid them from sinful utterances and devouring unlawful earnings? Indeed they have been contriving evil.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
The Jews say: 'The Hand of Allah is fettered. It is their own hands which are fettered, and they stand cursed for the evil they have uttered. No! His Hands are outspread; He spends as He wills. Surely the message that has been revealed to you from your Lord has increased many of them in their in-surgence and unbelief, and so We have cast enmity and spite among them until the Day of Resurrection. And as often as they kindle the fire of war, Allah extinguishes it; and they go about trying to spread mischief on earth, whereas Allah does not love those who spread mischief.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
Had the People of the Book only believed and been God-fearing, We should surely have effaced from them their evil deeds, and caused them to enter Gardens of Bliss.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
Had the People of the Book observed the Torah and the Gospel, and all that had been revealed to them from their Lord, sustenance would have been showered over them from above and risen from beneath their feet. Some among them certainly keep to the right path; but many of them do things which are evil.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger! Deliver what has been revealed to you from your Lord, for if you fail to do that, you have not fulfilled the task of His messengership. Allah will certainly protect you from the evil of men. Surely Allah will not guide the unbelievers (to succeed against you).\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say to them: 'People of the Book! You have no solid ground to stand on unless you establish the Torah and the Gospel and all that had been revealed to you from your Lord. Indeed the message revealed to you from your Lord will aggravate insurgence and unbelief in many of them. So do not grieve for those who disbelieve.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
(Know well, none has an exclusive claim to the Truth.) For all those who believe in Allah and in the Last Day and do good deeds - be they either believers, Jews, Sabaeans or Christians - neither fear shall fall upon them, nor shall they have any reason to grieve.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
And We took a covenant from the Children of Israel and sent to them many Messengers. But whenever any Messenger brought to them something that did not suit their desires, they gave the lie to some of them and killed the others,\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dccxl{%
thinking that no harm would come from it. Thus they became blind and deaf (to the Truth). Thereafter Allah turned towards them in gracious forgiveness; but many of them became even more deaf and blind (to the Truth). Allah sees all that they do.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dccxli{%
And surely they disbelieved when they said: 'Christ, the son of Mary, is indeed God'; whereas Christ had said: 'Children of Israel! Serve Allah, Who is your Lord and my Lord.' Allah has forbidden Paradise to those who associate anything with Him in His divinity and their refuge shall be the Fire. No one will be able to help such wrong-doers.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dccxlii{%
Those who said: 'Allah is one of the Three', certainly they disbelieved, for there is no god save the One God. And if they do not give up this claim, all who have disbelieved among them shall be subjected to painful chastisement.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Will they not, then, turn to Allah in repentance, and ask for His forgiveness? Allah is All-Forgiving, All-Compassionate.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah, son of Mary, was no more than a Messenger before whom many Messengers have passed away; and his mother adhered wholly to truthfulness, and they both ate food (as other mortals do). See how We make Our signs clear to them; and see where they are turning away!\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say: 'Do you serve, beside Allah, that which has no power either to harm or benefit you, whereas Allah alone is All-Hearing, All-Knowing?'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say: 'People of the Book! Do not go beyond bounds in your religion at the cost of truth, and do not follow the caprices of the people who fell into error before, and caused others to go astray, and strayed far away from the right path.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Those of the Children of Israel who took to unbelief have been cursed by the tongue of David and Jesus, son of Mary, for they rebelled and exceeded the bounds of right.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They did not forbid each other from committing the abominable deeds they committed. Indeed what they did was evil.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dccxlix{%
And now you can see many of them taking the unbelievers (instead of the believers) for their allies. Indeed they have prepared evil for themselves. Allah is angry with them, and they shall abide in chastisement.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dccl{%
For had they truly believed in Allah and the Messenger and what was sent down to him, they would not have taken unbelievers (instead of believers) for their allies. But many of them have rebelled against Allah altogether.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dccli{%
Of all men you will find the Jews and those who associate others with Allah in His divinity to be the most hostile to those who believe; and you will surely find that of ail people they who say: 'We are Christians', are closest to feeling affection for those who believe. This is because there are worshipful priests and monks among them, and because they are not arrogant.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dcclii{%
And when they hear what has been revealed to the Messenger you see that their eyes overflow with tears because of the Truth that they recognize and they say: 'Our Lord! We do believe; write us down, therefore, with those who bear witness (to the Truth).\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dccliii{%
And why should we not believe in Allah and the Truth which has come down to us when we do fervently desire that our Lord include us among the righteous?'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dccliv{%
So Allah rewarded them for these words with Gardens beneath which rivers flow so that they would abide there for ever. Such is the reward of the people who do good.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dcclv{%
Those who disbelieved and gave the lie to Our signs are rightfully the inmates of the Blazing Flame.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dcclvi{%
Believers! Do not hold as unlawful the good things which Allah has made lawful to you, and do not exceed the bounds of right. Allah does not love those who transgress the bounds of right.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dcclvii{%
And partake of the lawful, good things which Allah has provided you as sustenance, and refrain from disobeying Allah in Whom you believe.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah does not take you to task for the oaths you utter vainly, but He will certainly take you to task for the oaths you have sworn in earnest. The expiation (for breaking such oaths) is either to feed ten needy persons with more or less the same food as you are wont to give to your families, or to clothe them, or to set free from bondage the neck of one man; and he who does not find the means shall fast for three days. This shall be the expiation for your oaths whenever you have sworn (and broken them.) But do keep your oaths. Thus does Allah make clear to you His commandments; maybe you will be grateful.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dcclix{%
Believers! Intoxicants, games of chance, idolatrous sacrifices at altars, and divining arrows are all abominations, the handiwork of Satan. So turn wholly away from it that you may attain to true success.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dcclx{%
By intoxicants and games of chance Satan only desires to create enmity and hatred between you, and to turn you away from the remembrance of Allah and from Prayer. Will you, then, desist?\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dcclxi{%
Obey Allah and obey the Messenger, and beware. But if you turn away, then know well that Our Messenger had merely to deliver the message clearly.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dcclxii{%
There will be no blame on those who believe and do righteous deeds for whatever they might have partaken (in the past) as long as they refrain from things prohibited, and persist in their belief and do righteous deeds, and continue to refrain from whatever is forbidden and submit to divine commandments, and persevere in doing good, fearing Allah. Allah loves those who do good.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
Believers! Allah will surely try you with a game which will be within the range of your hands and lances so that He might mark out those who fear Him, even though He is beyond the reach of human perception. A painful chastisement awaits whosoever transgresses after that the bounds set by Allah.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
Believers! Do not kill game while you are in the state of pilgrim sanctity. Whoever of you kills it wilfully there shall be a recompense, the like of what he has killed in cattle - as shall be judged by two men of equity among you - to be brought to the Ka'bah as an offering, or as an expiation the feeding of the needy, or its equivalent in fasting in order that he may taste the grievousness of his deed. Allah has pardoned whatever has passed; but Allah will exact a penalty from him who repeats it. Allah is All-Mighty. He is fully capable of exacting penalties.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dcclxv{%
The game of the water and eating thereof are permitted to you as a provision for you (who are settled) and for those on a journey; but to hunt on land while you are in the state of Pilgrim sanctity is forbidden for you. Beware, then, of disobeying Allah to Whom you shall all be mustered.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah has appointed the Ka'bah, the Sacred House, as a means of support for (the collective life of) men, and has caused the holy month (of Pilgrimage), and the animals of sacrificial of-fering and their distinguishing collars to assist therein. This is so that you may know that Allah is aware of all that is in the heavens and all that is in the earth; and that Allah has knowledge of everything.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know well that Allah is severe in retribution, and that Allah is also All-Forgiving, All-Compassionate.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
The Messenger is bound only to deliver the message, whereafter Allah knows well all that you disclose and all that you conceal.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dcclxix{%
(O Messenger!) Say to them: ``The bad things and the good things are not equal, even though the abundance of the bad things might make you pleased with them. Men of understanding, beware of disobeying Allah; then maybe you will attain true success.'\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dcclxx{%
Believers! Do not ask of the things which, if made manifest to you, would vex you; for, if you should ask about them while the Qur'an is being revealed, they will be made manifest to you. Allah has pardoned whatever happened in the past. He is All-Forgiving, All-Forbearing.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
Indeed some people before you had asked such questions and in consequence fell into unbelief.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
Allah has neither appointed (cattle devoted to idols such as) Bahirah, Sa'ibah, Wasilah nor Ham; but those who disbelieve forge lies against Allah and of them most have no understanding (and therefore succumb to such superstitions).\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
When they are asked: 'Come to what Allah has revealed, and come to the Messenger', they reply: 'The way of our refathers suffices us.' (Will they continue to follow their forefathers) even though their forefathers might have known nothing, and might have been on the wrong way?\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
Believers! Take heed of your own selves. If you are rightly guided, the error of he who strays will not harm you. To Allah will all of you return; then He will let all of you know what you did.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
Believers! When death approaches you, let two men of equity among you act as witnesses when you make your bequest; or let two of those from others than yourselves act as witnesses if you are on a journey when the affliction of death befalls you. Then if any doubt occurs you shall detain both of them (in the mosque) after the Prayer, and they shall swear by Allah: 'We shall neither sell our testimony in return for any gain even though it concerns any near of kin nor shall we conceal our testimony which we owe to Allah, for then we should become among sinners.'.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
Then if it is discovered later that the two are guilty of such sin, then two others shall stand in their place from among those against whom the two had sinfully deposed, and swear by Allah: 'Our testimony is truer than the testimony of the other two, and we have not transgressed in our statement; for then indeed we would become wrong-doers.'\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
Thus it is more likely that they will either bear the right testimony or else they will at least fear that their oaths may be rebutted by other oaths. Have fear of Allah and pay heed. Allah does not direct the disobedient to the right way.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
The Day when Allah will gather together the Messengers and say: 'What answer were you given?' They will reply: 'We have no real knowledge of it. You alone fully know all that lies beyond the reach of human perception.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
Imagine, then, when Allah will say: 'Jesus, son of Mary, recall My favour upon you and your mother, and when I strengthened you with the spirit of holiness so that you talked to men in the cradle and also when you became of age; and when I taught you the Book and Wisdom, and the Torah and the Gospel; and when, by My leave, you fashioned from clay the likeness of a bird and you breathed into it, and by My leave it became a bird; you healed, by My leave, the blind from birth and the leprous; and when, by My leave, you caused the dead to come to life. And recall when I restrained the Israelites from you when you came to them with clear proofs whereupon those of them who disbelieved said: ``This is nothing but clear magic."\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
And recall when I revealed to the disciples to believe in Me and in My Mes-senger, they said: ``We do believe, and we bear witness that we indeed are the ones who submit to Allah"\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
Also recall when the disciples asked Jesus, son of Mary: 'Jesus, son of Mary, has your Lord the power to send down to us a repast from the heaven?' There- upon Jesus said: 'Fear Allah if you do indeed have faith.'\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said: 'We desire to partake of it that our hearts be satisfied and we know that you did speak the truth to us, and that we are its witnesses.'\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
Jesus, son of Mary, then prayed: 'O Allah, our Lord, send down to us a repast from the heavens that shall be a festival for the first of us and for the last of us, and a sign from You. And provide us with sustenance, for You are the best Provider of sustenance.'\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Allah said: 'I shall indeed send it down to you; then, I shall afflict whoever among you who disbelieves with a chastisement wherewith I will afflict none in the worlds.'\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And imagine when thereafter Allah will say: 'Jesus, son of Mary, did you say to people: ``Take me and my mother for gods beside Allah?" and he will answer: ``Glory to You! It was not for me to say what I had no right to. Had I said so, You would surely have known it. You know all what is within my mind whereas I do not know what is within Yours. You, indeed You, know fully all that is beyond the reach of human perception.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
I said to them nothing except what You commanded me, that is: 'Serve Allah, my Lord and your Lord.' I watched over them as long as I remained among them; and when You did recall me, then You Yourself became the Watcher over them. Indeed, You are Witness over everything.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
If You chastise them, they are Your servants; and if You forgive them, You are the All-Mighty, the All-Wise."'\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Thereupon Allah will say: 'This day truthfulness shall profit the truthful. For them are Gardens beneath which rivers flow. There they will abide for ever. Allah is well- pleased with them, and they well-pleased with Allah. That indeed is the mighty triumph.'\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To Allah belongs the dominion of the heavens and the earth and all that is in them and He has full power over everything.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen All praise is for Allah alone, Who created the heavens and the earth, and brought into being light and darkness, and yet those who have rejected the call of the Truth ascribe others to be equals to their Lord.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@dccxci{%
He it is Who has created you out of clay, and then decreed a term (of life), and has also appointed another term, a term determined with Him. Yet you are in doubt!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@dccxcii{%
And He it is Who is One True God in the heavens and in the earth. He knows your deeds - both secret and open - and knows fully whatever you earn.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@dccxciii{%
Yet every time a sign of their Lord comes to them, they turn away from it,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@dccxciv{%
and thus they gave the lie to the Truth that has now come to them. Soon they will come upon some news concerning what they had mocked at.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Have they not seen how many a people We have destroyed before them? People whom We had made more powerful in the earth than you are and upon them We showered from the heavens abundant rains, and at whose feet We caused the rivers to flow? And then (when they behaved ungratefully) We destroyed them for their sins, and raised other peoples in their place.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
(O Messenger!) Had We sent down to you a book incribed on parchment, and had they even touched it with their own hands, the unbelievers would still have said: 'This is nothing but plain magic.'\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
They also say: 'Why has no angel been sent down to this Prophet?' Had We sent down an angel, the matter would surely have long been decided and no respite would have been granted them.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
Had We appointed an angel, We would have sent him down in the form of a man - and thus We would have caused them the same doubt which they now entertain.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@dccxcix{%
And indeed before your time (O Muhammad!) many a Messenger has been scoffed at; but those who mocked at them were encompassed by the Truth they had scoffed at.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@dccc{%
Say: 'Go about journeying the earth, and behold the end of those who gave the lie (to the Truth).'\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@dccci{%
Ask thern: 'To whom belongs all that is in the heavens and on the earth?' Say: 'Everything belongs to Allah.' He has bound Himself to the exercise of mercy (and thus does not chastise you for your disobedience and excesses instantly). Surely He will gather you all together on the Day of Resurrection - the coming of which is beyond doubt; but those who have courted their own ruin are not going to believe.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@dcccii{%
And to Him belongs all that dwells in the night and the day. He is All-Hearing, All-Knowing.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say: 'Shall I take for my guardian anyone other than Allah - the Originator of the heavens and earth; He Who feeds and Himself is not fed?' Say: 'Surely I have been commanded to be the first among those who submit (to Allah) and not to be one of those who associate others with Allah in His divinity (even though others may do so).'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say: 'Surely do I fear, if I disobey my Lord, the chastisement of an awesome Day.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@dcccv{%
Whosoever has been spared chastisement on that Day, Allah has bestowed His mercy upon him. That is the manifest triumph.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@dcccvi{%
Should Allah touch you with affliction, there is none to remove it but He; and should He touch you with good, He has the power to do everything.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@dcccvii{%
He has the supreme hold over His servants. He is All-Wise, All-Aware.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Ask them: 'Whose testimony is the greatest?' Say: 'Allah is the witness between me and you; and this Qur'an was revealed to me that I should warn you thereby and also whomsoever it may reach.' Do you indeed testify that there are other gods with Allah? Say: 'I shall never testify such a thing.' Say: 'He is the One God and I am altogether averse to all that you associate with Him in His divinity.'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those whom We have given the Book will recognize this just as they recognize their own ofspring; but those who have courted their own ruin will not believe.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@dcccx{%
And who could be more wrong-doing than he who either foists a lie on Allah or gives the lie to His signs? Surely such wrong-doers shall not attain success.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@dcccxi{%
And on the Day when We shall gather them all together, We shall ask those who associated others with -Allah in His divinity: 'Where, now, are your partners whom you imagined (to have a share in the divinity of Allah)?'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@dcccxii{%
Then they will be able to play no mischief but will say (falsely): 'By Allah, our Lord, we associated none (with You in Your divinity).'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Behold, how they will lie against themselves and how their forged deities will forsake them!\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
And of them there are some who appear to pay heed to you, but upon their hearts We have laid coverings so they understand it not; and in their ears, heaviness (so they hear not). Even if they were to witness every sign, they would still not believe in it so much so that when they come to you, they dispute with you, those who disbelieve contend: 'This is nothing but fables of the ancient times.'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@dcccxv{%
As for others, they prevent them from embracing the Truth; and themselves, they flee from it (so as to harm you). But they court their own ruin, although they do not realize it.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If you could but see when they shall be made to stand by the Fire! They will plead: 'Would that we were brought back to life? Then we would not give the lie to the signs of our Lord and would be among the believers.'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
No! They will say this merely because the Truth which they had concealed will become obvious to them; or else if they were sent back, they would still revert to what was forbidden to them. (So this plea of theirs would be a lie too) for they are just liars.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
They say now: 'There is nothing but the life of this world, and we shall not be raised from the dead.'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If you could but see when they will be made to stand before their Lord. He will say: 'Is not this the truth?' They will say: 'Yes indeed, by our Lord.'Whereupon He will say: 'Taste the chastisement, then, for your denying the Truth.'\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@dcccxx{%
Those who consider it a lie that they will have to meet Allah are indeed the losers so much so that when that Hour comes to them suddenly they will say: 'Alas for us, how negligent we have been in this behalf.' They will carry their burden (of sins) on their backs. How evil is the burden they bear!\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
The life of this world is nothing but a sport and a pastime, and the life of the Hereafter is far better for those who seek to ward off their ruin. Will you not, then, understand?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
(O Muhammad!) We know indeed that the things they say grieve you, though in truth it is not you whom they give the lie to, but it is the signs of Allah that these wrong-doers reject.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
Messengers before you have been given the lie to, and they endured with patience their being given the lie to and being persecuted until the time when Our help reached them. None has the power to alter the words of Allah. Indeed some account of the Messengers has already reached you.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
Nevertheless, if their turning away grieves you, then seek - if you can - either a way down into the earth or a ladder to the heavens, and try to bring to them some sign. Had Allah so willed, He would have gathered them all to the true guidance. Do not, then, be among the ignorant.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
Only they who listen can respond to the call of the Truth; as for the dead, Allah will raise them and then to Him they will be returned.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
And they say: 'Why has no miraculous sign been sent down to him from his Lord?' Say: 'Surely Allah has the power to send down a sign, but most of them do not know.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
There is no animal that crawls on the earth, no bird that flies with its two wings, but are communities like you. We have neglected nothing in the Book (of decree). Then to their Lord will they all be mustered.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
Those who gave the lie to Our signs are deaf and dumb and blunder about in darkness. Allah causes whomsoever He wills to stray in error, and sets whomsoever He wills on the straight way.'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say: 'What do you think if some chastisement of Allah or the Hour suddenly overtakes you: do you cry to any other than Allah? Answer, if you speak the truth.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
Lo, it is to Him alone that you cry and then, if He so wills, He removes the distress for which you had cried to Him. Then you forget the partners you had set up with Allah.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
And We did indeed send Messengers to other nations before you and then We seized those nations with misfortune and hardship so that they might humble themselves (before Us).\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
But when misfortune befell them from Us why did they not humble themselves? Their hearts had hardened and Satan had made their deeds seem fair to them.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
So, when they forgot what they had been reminded of, We opened the gates of all things so that while they rejoiced in what they had been granted We seized them suddenly and they were plunged into utter despair.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
Thus the last remnant of those wrongdoing people was cut off. All praise is for Allah, the Lord of the entire universe, (for having punished them so).\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say (O Muhammad!): What do you think? If Allah should take away your hearing and your sight and seal your hearts - who is the god, other than Allah, who could restore them to you? Behold, how We put forth Our signs in diverse forms, and yet they turn away from them.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say: 'If the chastisement of Allah were to overtake you unawares or openly shall any except the wrong-doing people be destroyed?'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
We do not send Messengers except as bearers of glad tidings and warners. So, he who believes in their message and mends his conduct need have no fear and need not grieve;\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
whereas those who give the lie to Our signs, chastisement will visit them for their transgression.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
(O Muhammad!) Say: 'I do not say to you I have the treasures of Allah. Nor do I have knowledge of what is beyond the reach of human perception. Nor do I say to you: I am an angel. I only follow what is revealed to me.' Then ask them: 'Are the blind and the seeing alike?' Do you not then reflect?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And warn with this (revealed message) those who fear that they shall be mustered to their Lord, that there will be none apart from Allah to act as their protector and intercessor; then maybe they will become God-fearing.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@dcccxli{%
And do not drive away those who invoke their Lord in the morning and the evening, seeking His pleasure all the time. You are by no means accountable for them just as they are by no means accountable for you. If you still drive them away, you will become among the wrong-doers.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
Thus We have made some of them a means for testing others so that they should say: 'Are these theones among us upon whom Allah has bestowed His favour?' Yes, does Allah not know well who are the thankful?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
And when those who believe in Our signs come to you, say to them: 'Peace be upon you. Your Lord has made mercy incumbent upon Himself so that if anyone of you does a bad deed out of ignorance and thereafter repents and makes amends, surely you will find Him All-Forgiving, AllCompassionate.'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
Thus We clearly set forth Our signs so that the way of the wicked might become distinct.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say (O Muhanimad!): 'I have been forbidden to serve those to whom you call other than Allah.' Say: 'I do not follow your desires, for were I to do that, I would go astray and would not be of those who are rightly guided.'\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say: 'I take stand upon a clear evidence from my Lord and it is that which you have given the lie to. That which you desire to be hastened is not within my power. Judgement lies with Allah alone. He declares the Truth, and He is the best judge.'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say: 'If what you demand so hastily were in my power, the matter between me and you would have been long decided. But Allah knows best how to judge the wrong-doers.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
He has the keys to the realm that lies beyond the reach of human perception; none knows them but He. And He knows what is on the land and in the sea; there is not a leaf which falls that He does not know about and there is not a grain in the darkness of the earth or anything green or dry which has not been recorded in a Clear Book.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
He recalls your souls by night, and knows what you do by day; and then He raises you back each day in order that the term appointed by Him is fulfilled. Then to Him you will return whereupon He will let you know what you have been doing..\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@dcccl{%
And He alone holds sway over His servants and sets guardians over you till death approaches any of you and Our deputed angels take his soul, neglecting no part of their task.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then all are restored to Allah, their true protector. Behold, His is the judgement. He is the swiftest of those who take account.'\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@dccclii{%
Ask them (O Muhammad!): 'Who is it that delivers you from dangers in the deep darknesses of the land and the sea, and to whom do you call in humility and in the secrecy of your hearts? To whom do you pray: ``If He will but save us from this distress, we shall most certainly be among the thankful?"\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say: ``It is Allah alone Who delivers you from this and from every distress, and yet you associate others with Allah in His divinity."\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say: ``It is He Who has the power to send forth chastisement upon you from above you, or from beneath your feet, or split you into hostile groups and make some of you taste each others' violence. Behold, how We set forth Our signs in diverse forms, so that maybe they will understand the Truth".\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@dccclv{%
Your people have denied it even though it is the Truth. Say: ``I am not a guardian over You.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@dccclvi{%
Every tiding has its appointed time; you yourselves will soon know (the end)."\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@dccclvii{%
When you see those who are engaged in blasphemy against Our signs, turn away from them until they begin to talk of other things; and should Satan ever cause you to forget, then do not remain, after recollection, in the company of those wrong-doing people.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@dccclviii{%
For those who are God-fearing are by no means accountable for the others except that it is their duty to adinonish them; maybe then, they will shun evil.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@dccclix{%
Leave alone those who have made a sport and a pastime of their religion and whom the life of the world has beguiled. But continue to admonish them (with the Qur'an) lest a man should be caught for what he has himself earned for there shall neither be any protector nor intercessor apart from Allah; and though he may offer any conceivable ransom it shall not be accepted from him, for such people have been caught for the deeds that they have themselves earned. Boiling water to drink and a painful chastisement to suffer for their unbelief is what awaits them.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@dccclx{%
Ask them (O Muharnmad!): ``Shall we invoke, apart from Allah, something that can neither benefit nor harm us, and thus be turned back on our heels after Allah has guided us? Like the one whom the evil ones have lured into bewilderment in the earth, even though he has friends who call him to true guidance saying: ``Come to us." Say: ``Surely Allah's guidance is the only true guidance, and we have been commanded to submit ourselves to the Lord of the entire universe,\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@dccclxi{%
and to establish Prayer, and to have fear of Him. It is to Him that all of you shall be gathered.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@dccclxii{%
And He it is Who has created the heavens and the earth in truth; and the very day He will say: ``Be!" (resurrection) there will be. His word is the Truth and His will be the dominion on the day when the-Trumpet is blown. He knows all that lies beyond the reach of human perception as well as all that is visible to man; He is the All-Wise, the All-Aware.'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
And recall when Abraham said to his father, Azar: 'Do you take idols for gods? I see you and your people in obvious error.'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
And thus We showed Abraham the kingdom of the heavens and the earth, so that he might become one of those who have sure faith.. The adversaries are told that they can observe God's signs in the phenomena of the universe, just as Abraham could. The difference is that they see nothing, as if they were blind, whereas Abraham saw with open eyes. The sun, moon and stars which rise and set before their eyes day after day and night after night witness them as misguided at their setting as at their rising. Yet the same signs were observed by the perceptive Abraham, and the physical phenomena helped him arrive at the Truth.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@dccclxv{%
Then, when the night outspread over him, he beheld a star, and said: 'This is my Lord.' But when it went down, he said: 'I do not love the things that go down.'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
Then, when he beheld the moon rising, he said: 'This is my Lord!' But when it went down, he said: 'Were that my Lord did not guide me, I surely would have become among the people who have gone astray.'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
Then when he beheld the sun rising, he said: 'This is my Lord. This is the greatest of all.' Then, when it went down, he said: 'O my people! Most certainly I am quit of those whom you associate with Allah in His divinity.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
Behold, I have turned my face in exclusive devotion to the One Who originated the heavens and the earth, and I am certainly not one of those who associate others with Allah in His divinity.'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@dccclxix{%
His. people remonstrated with him whereupon Abraharn said: 'Do you remonstrate with me concerning Allah Who has guided me to the right way? I do not fear those whom you associate with Allah in His divinity. Only that which my Lord wills, indeed that alone will come by. My Lord embraces all things within His knowledge. Will you not take heed?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@dccclxx{%
Why should I fear those whom you have associated (with Allah in His divinity) when you do not fear associating others with Allah in His divinity - something for which He has sent down to you no authority. Then, which of the two parties has better title to security? Tell us, if you have any knowledge!\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
Those who believe and did not tarnish their faith with wrong-doing for them there is security, and it is they who have been guided to the right way.'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
That was Our argument which We gave to Abraham against his people. We raise in ranks whom We will. Truly your lord is All-Wise, All-Knowing.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We bestowed upon Abraham (offspring) Ishaq (Isaac) and Ya'qub (Jacob) and each of them did We guide to the right way as We had earlier guided Noah to the right way; and (of his descendants We guided) Da'ud (David) and Sulayman (Solomon), Ayyub (Job), Yusuf (Joseph), Musa (Moses) and Harun (Aaron). Thus do We reward those who do good.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
(And of his descendants We guided) Zakariya (Zachariah), Yahya (John), Isa (Jesus) and Ilyas (Elias): each one of them was of the righteous.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
(And of his descendants We guided) Isma'il (Ishmael), al-Yasa' (Elisha), Yunus (Jonah), and Lut (Lot). And each one of them We favoured over all mankind.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
And likewise We elected for Our cause and guided on to a straight way some of their forefathers and their offspring and their brethren.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
That is Allah's guidance wherewith He guides those of His servants whom He wills. But if they ever associated others with Allah in His divinity, then all that they had done would have gone to waste.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
Those are the ones to whom We gave the Book, and judgement and prophethood. And if they refuse to believe in it now, We will bestow this favour on a people who do believe in it.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
(O Muhammad!) Those are the ones Allah guided to the right way. Follow, then, their way, and say: 'I ask of you no reward (for carrying on this mission); it is merely an admonition to all mankind.'\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
They did not form any proper estimate of Allah when they said: 'Allah has not revealed anything to any man.' Ask them: 'The Book which Moses brought as a light and guidance for men and which you keep in bits and scraps, some of which you disclose while the rest you conceal, even though through it you were taught that which neither you nor your forefathers knew -who was it who revealed it?' Say: 'Allah!'- and then leave them to sport with their argumentation.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
(Like that Book) this too is a Book which We have revealed; full of blessing, confirming what was revealed before it so that you might warn the people of the Mother of Cities (Makka) and those around it. Those who believe in the Hereafter believe in it, and are evermindful of their Prayers.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
Who can be more unjust than he who places a lie on Allah and who says: 'Revelation has come to me' when in fact nothing was revealed to him, and who says: 'I will produce the like of what Allah has revealed?' If you could but see the wrongdoers in the agonies of death, and the angels stretching out their hands (saying): 'Yield up your souls! Today you will be recompensed with the chastisement of humiliation for the lie you spoke concerning Allah, and for you waxing proud against His signs.'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
(And Allah will say): 'Now you have come to Us all alone even as We had created you in the first instance, and you have left behind all that We had bestowed upon you in the world. We do not see with you your intercessors whom you imagined to have a share with Allah in your affairs. You have now been cut off from one another and all those whom you imagined (to be Allah's associates in your affairs) have failed you.'\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
Truly it is Allah Who causes the grain and the fruit-kernel to sprout. He brings forth the living from the dead and brings forth the dead from the living. Such is Allah. So whither are you tending in error?\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
It is He Who causes the dawn to split forth, and has ordained the night for repose, and the sun and the moon for reckoning time. All this is determined by Allah the Almighty, the All-Knowing.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
It is He Who has made for you the stars that you may follow the right direction in the darkness of the land and the sea. We have indeed spelled out signs for the people who have knowledge.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
It is He Who created you out of a single being, and appointed for each of you a time-limit and a resting place. We have indeed spelled out Our signs for those who can understand.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
And it is He Who has sent down water from the heavens, and thereby We have brought vegetation of every kind, and out of this We have brought forth green foliage and then from it close-packed ears of corn, and out of the palm-tree from the sheath of it - thick clustered dates, hanging down with heaviness, and gardens of vines, and the olive tree, and the pomegranate - all resembling one another and yet so different. Behold their fruit when they bear fruit and ripen! Surely, in all this there are signs for those who believe.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
And yet, some people have come to associate the jinn with Allah in His divinity, even though it is He Who created them; and in ignorance they impute to Him sons and daughters. He is Holy and Exalted far above that which they attribute to Him.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@dcccxc{%
He is the Originator of the heavens and the earth. How can He have a son when He has had no mate? And He has created everything and He has full knowledge of all things.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@dcccxci{%
Such is Allah, your Lord. There is no god but He - the Creator of all things. Serve Him alone - for it is He Who is the guardian of everything.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
No visual perception can encompass Him, even though He encompasses all visual perception. He is the All-Subtle, the All-Aware.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
The lights of clear perception have now come to you from your Lord. Then, he who chooses to see clearly, does so for his own good; and he who chooses to remain blind, does so to his own harm. I am not your keeper.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
Thus do We make Our signs clear in diverse ways that they might say: 'You have learned this (from somebody)'; and 'We do this in order that We make the Truth clear to the people of knowledge.'\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
(O Muhammad!) Follow the revelation which has come to you from your Lord, other than Whom there is no god, and turn away from those who associate others with Allah in His divinity.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
Had Allah so willed they would not have associated others with Him in His divinity; and We have not appointed you a watcher over them, and you are not their guardian.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
Do not revile those whom they invoke other than Allah, because they will revile Allah in ignorance out of spite. For We have indeed made the deeds of every people seem fair to them. Tlen, their return is to their Lord and He will inform them of what they have done.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
They swear by Allah with their most solemn oaths that if a sign comes to them, they will certainly believe in it. Say: 'Signs are in Allah's power alone. What will make you realize that even if those signs were to come, they would still not believe?\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
We are turning their hearts and eyes away from the Truth even as they did not believe in the first instance - and We leave them in their insurgence to stumble blindly.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@cm{%
Even if We had sent angels down to them and the dead had spoken to them, and even if We had assembled before them all the things, face to face, they would still not believe unless it be Allah's will that they believe. Most of them behave in utter ignorance.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@cmi{%
And so it is that against every Prophet We have set up the evil ones from among men and jinn, some of them inspire others with specious speech only by way of. delusion. Had it been your Lord's will, they would not have done it. Leave them alone to fabricate what they will.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@cmii{%
So that the hearts of those who do not believe in the Life to Come might incline towards this attractive delusion, and that they may be well pleased with it and might acquire the evils that they are bent on acquiring.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@cmiii{%
Shall I look upon anyone apart from Allah for judgement when it is He Who has revealed to you the Book in detail? And those whom We gave the Book (before you) know that this (Book) has been revealed in truth by your Lord. Do not, then, be among the doubters.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@cmiv{%
The Word of your Lord is perfect in truthfulness and justice; no one can change His words. He is the All-Hearing, the All-Knowing.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@cmv{%
(O Muhammad!) If you obey the majority of those who live on earth, they will lead you away from Allah's path. They only follow idle fancies, indulging in conjecture.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@cmvi{%
And your - Lord knows well who stray from His path, and also those who are rightly-guided.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@cmvii{%
If you believe in the signs of Allah, eat (the flesh) of that over which Allah's name has been pronounced.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@cmviii{%
And how is it that you do not eat of that over which Allah's name has been pronounced even though He has clearly spelled out to you what He has forbidden you unless you are constrained to it? Many indeed say misleading things without knowledge, driven merely by their lowly desires. But your Lord knows well the transgressors.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@cmix{%
Abstain from sin, be it either open or secret. Indeed those who commit sins shall surely be requited for all they have done.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@cmx{%
Do not eat of (the animal) over which the name of Allah has not been pronounced (at the time of its slaughtering), for that is a transgression. And behold, the evil ones do inspire doubts and objections into the hearts of their friends so that they dispute with you; but if you obey them, you will surely yourselves turn into those who associate others with Allah in His divinity.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@cmxi{%
He who was dead and whom We raised to life, and We set a light for him to walk among men - is he like the one steeped in darkness out of which he does not come out?. Thus have their own doings been made to seem fair to the unbelievers.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@cmxii{%
Thus We have appointed the leaders of the wicked ones in every land to weave their plots; but in truth they plot only to their own harm, without even realizing it.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@cmxiii{%
Whenever there comes to them a sign from Allah, they say: 'We will not believe until we are given what was given to the Messengers of Allah.' Allah knows best where to place His message. Soon shall these wicked ones meet with humiliation and severe chastigement from Allah for all their evil plotting.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@cmxiv{%
Thus, (it is a fact that) whomsoever Allah wills to guide, He opens his breast for Islam; and whomsoever He wills to let go astray, He causes his breast to become strait and constricted, as if he were climbing towards the heaven. Thus Allah lays the abomination (of flight from and hatred of Islam) on those who do not believe\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@cmxv{%
even though this way is the straight way of your Lord, and We have distinguished its signs to those who heed to admonition.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@cmxvi{%
Theirs shall be an abode of peace with their Lord - their Protector - in recompense for all they have done.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@cmxvii{%
And on the Day when He shall muster them all together, He will say (to the jinn): 'O assembly of the jinn, you have seduced a good many of mankind.' And their companions from among the humans will say: 'Our Lord! We did indeed benefit from one another and now have reached the term which You had set for us.' Thereupon Allah will say: 'The Fire is now your abode, and therein you shall abide.' Only those whom Allah wills shall escape the Fire. Surely your Lord is All-Wise, All-Knowing.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@cmxviii{%
In this manner We shall make the wrong-doers friends of each other (in the Hereafter) because they earned (evil together in the world).\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@cmxix{%
(Then Allah will also ask them): 'O assembly of jinn and men! Did there not come to y ou Messengers from among yourselves, relating to you My signs, and warning you of the encounter of this your Day (of Judgement)?' They will say: 'Yes, we bear witness against ourselves.' They have been deluded by the life of this world, and they will bear witness against themselves that they had disbelieved.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@cmxx{%
(They will be made to bear this witness to show that) it is not the way of your Lord to destroy cities unjustly while their people were unaware of the Truth.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@cmxxi{%
Everyone is assigned a degree according to his deed. Your Lord is not heedless of what they do.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@cmxxii{%
Your Lord is Self-Sufficient, full of compassion. If He wills, He can put you away and cause whomever He wills to succeed you just as He has produced you from the seed of another people.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
Surely what you have been promised shall come to pass; and you do not have the power to frustrate (Allah).\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say (O Muhammad!): 'O people! Work in your place; and I too am at work. Soon you will know in whose favour the ultimate decision will be. Surely the wrong-doers will not prosper.'\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@cmxxv{%
They assign to Allah a portion out of the produce and cattle that He has created, saying out of their fancy: 'This is for Allah' - so they deem -'and this is for the associates (of Allah) whom we have contrived.' Then, the portion assigned to the beings whom they have set up as associates (of Allah) does not reach Allah, but the portion assigned to Allah reaches the beings they set up as associates (of Allah)! Indeed evil is what they decide!\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
And, likewise, the beings supposed to have a share in Allah's divinity have made the slaying of their offspring seem lawful to many of those who associate others with Allah in His divinity so that they may ruin them and confound them regarding their faith. If Allah had so willed, they would not have done that. Leave them alone to persist in their fabrication.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
They say: 'These animals and these crops are sacrosanct: none may eat of them save those whom we will' - imposing interdictions of their own contriving. And they declare that it is forbidden to burden the backs of certain cattle, and these are the cattle over which they do not pronounce the name of Allah. All these are false fabrications against Allah, and He will soon requite them for all that they fabricate.\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they say: 'What is within the bellies of such-and-such cattle is exclusively for our males and is forbidden to our females; but if it be born dead, they all may share in it.' He will soon requite them for all that they (falsely) attribute to Allah. He is All-Wise, All-Knowing.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Those who slayed their children in folly, without knowledge,. and forbade the sustenance that Allah has provided them, falsely ascribing that to Allah, are utter losers; they have gone astray, and are certainly not among those guided to the right way.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@cmxxx{%
It is He Who has brought into being gardens - the trellised and untrellised - and the palm trees, and crops, all varying in taste, and. the olive and pomegranates, all resembling one another and yet so different. Eat of their fruits when they come to fruition and pay His due on the day of harvesting. And do not exceed the proper limits, for He does not love those who exceed the proper limits.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And of the cattle (He has reared) some for burden, and some whose flesh you eat and whose skins and hair you use to spread the ground. Eat of the sustenance Allah has provided you and do not follow in the footsteps of Satan, for surely he is your open enemy.\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
These are eight couples, two of sheep, two of goats. Now ask them: 'Is it either the two males that Allah has forbidden or the two females, or what the wombs of the two females may contain? Tell me about this on the basis of sure knowledge, if you speak the truth.'\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
And likewise, of camels there are two, and of oxen there are two. Ask them: 'Is it either the two males that He has forbidden or the two females, or that which the wombs of the two females may contain? Or were you present when Allah enjoined this commandment upon you?' Who, then, would be more unjust than he who fabricates a lie against Allah that he might lead people astray without knowledge. Surely Allah never guides such a wrong-doing folk.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Tell them (O Muhammad!): 'I do not find in what has been revealed to me anything forbidden for anyone who wants to eat unless it is carrion, outpoured blood and the flesh of swine, all of which is unclean; or that which is profane having been slaughtered in a name other than that of Allah. But whosoever is constrained to it by necessity - neither desiring to disobey nor exceeding the limit of necessity - your Lord is surely AllForgiving, All-Compassionate.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
And to those who had Judaized We have forbidden all beasts with claws, and the fat of oxen and sheep except the fat which is either on their backs or their entrails, or that which sticks to the bones. Thus did We requite them for their rebellion. Surely We state the Truth.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
'Then if they give you the lie, say: 'Your Lord is of unbounded mercy; but His punishment shall not be averted from the guilty folk.'\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
Those who associate others with Allah in His divinity will now surely say: 'Had Allah willed, neither we nor our forefathers would have associated others with Allah in His divinity, nor would we have declared anything (which Allah did not forbid) as forbidden.' Even so those who had lived before them gave the lie (to the Truth) until they tasted Our chastisement. Tell them: 'Have you any sure knowledge that you can produce before us? In fact you are only following idle fancies, merely conjecturing.'\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
'Then say to them: '(As against your argument) Allah's is the conclusive argument. Surely, had He willed, He would have guided you all to the Truth.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say to them: 'Call your witnesses to testify that Allah forbade such-and-such.' Then if they do testify, neither testify with them nor follow the desires of those who have given the lie to Our signs and who do not believe in the Hereafter and set up equals with their Lord.\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say to them (O Muhammad!): 'Come, let me recite what your Lord has laid down to you: (i) that you associate nothing with Him; (ii) and do good to your parents; (iii) and do not slay your children out of fear of poverty. We provide you and will likewise provide them with sustenance; (iv) and do not even draw to things shameful - be they open or secret; (v) and do not slay the soul santified by Allah except in just cause; this He has enjoined upon you so that you may understand;\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@cmxli{%
(vi) and do not even draw near to the property of the orphan in his minority except in the best manner; (vii) and give full measures and weight with justice; We do not burden anyone beyond his capacity; (viii) When you speak, be just, even though it concern a near of kin; (ix) and fulfil the covenant of Allah. That is what He has enjoined upon you so that you may take heed.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@cmxlii{%
(x) This is My way -that which is straight: follow it, then, and do not follow other paths lest they scatter you from His path. This is what He has enjoined upon you, so that you may beware.'\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then We gave to Moses the Book, completing the benediction of Allah upon the one who acts righteously, spelling out everything clearly, a guidance and a mercy; so that they may believe in their meeting with their Lord.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And likewise We revealed this (Book) - a blessed one. Follow it, then, and become God-fearing; you may be shown mercy.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@cmxlv{%
(You may no longer) say now that the Book was revealed only to two groups of people before Us and that we had indeed been unaware of what they read.\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Nor may you claim that: 'Had the Book been revealed to us, we would have been better guided than they.' Surely clear evidence has come to you from your Lord, which is both a guidance and a mercy. Who, then, is more unjust than he who gave the lie to the signs of Allah and turned away from them? And We shall soon requite those who turn away from Our signs with a severe chastisement for having turned away.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
What! Do they wait either for the angels to appear before them or for your Lord to come unto them or for some clear signs of your Lord to appear before them? When some clear signs of your Lord will appear, believing will be of no avail to anyone who did not believe before, or who earned no good deeds through his faith. Say: 'Wait on; we too are waiting.'\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
Surely you have nothing to do with those who have made divisions in their religion and become factions. Their matter is with Allah and He will indeed tell them (in time) what they have been doing.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@cmxlix{%
Whoever will come to Allah with a good deed shall have ten times as much, and whoever will come to Allah with an evil deed, shall be requited with no more than the like of it. They shall not be wronged.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@cml{%
Say: 'As for me, my Lord has guided me on to a straight way, a right religion, the way of Abraham who adopted it in exclusive devotion to Allah, and he was not of those who associated others with Allah in His divinity.'\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@cmli{%
Say: 'Surely my Prayer, all my acts of worship, and my living and my dying are for Allah alone, the Lord of the whole universe.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@cmlii{%
He has no associate. Thus have I been bidden, and I am the foremost of those who submit themselves (to Allah).`\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say: 'Shall I seek someone other than Allah as Lord when He is the Lord of everything?' Everyone will bear the consequence of what he does, and no one shall bear the burden of another. Thereafter, your return will be to your Lord, whereupon He will let you know what you disagreed about.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@cmliv{%
For He it is Who has appointed you vicegerent over the earth, and has exalted some of you over others in rank that He may try you in what He has bestowed is upon you. Indeed your Lord is swift in retribution, and He is certainly AllForgiving, All-Compassionate.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif-Lam-Mim-Sad.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@cmlvi{%
This is a Book revealed to you. Let there be no impediment in your heart about it. (It has been revealed to you) that you may thereby warn [the unbelievers], that it may be a reminder to the believers.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@cmlvii{%
[O men!] Follow what has been revealed to you from your Lord and follow no masters other than Him. Little are you admonished.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@cmlviii{%
How many a township We have destroyed! Our scourge fell upon them at night, or when they were taking midday rest.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@cmlix{%
And when Our scourge fell upon them their only cry was: 'We are indeed transgressors.'\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@cmlx{%
So We shall call to account those to whom Messengers were sent, and We shall call to account the Messengers (to see how dutifully they conveyed the Message, and how people responded to it).\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@cmlxi{%
Then We shall narrate to them with knowledge the whole account. For surely, We were not away from them.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@cmlxii{%
The weighing on that Day will be the true weighing: those whose scales are heavy will prosper.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
and those whose scales are light will be the losers, for they, are the ones who have been unjust to Our signs.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
We assuredly established you in the earth and arranged for your livelihood in it. Little do you give thanks.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@cmlxv{%
We initiated your creation, then We gave you each a shape, and then We said to the angels: 'Prostrate before Adam.') They all prostrated except Iblis: he was not one of those who fell Prostrate.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
Allah said: 'What prevented you from prostrating, when I commanded you to do so?' He said: 'I am better than he. You created me from fire, and him You created from clay.'\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
Allah said: 'Then get you down from here. It does not behove you to be arrogant here. So be gone. You will be among the humiliated.'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
Satan replied: 'Give me respite till the Day they shall be raised.'\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@cmlxix{%
Allah said: 'You are granted respite.'\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@cmlxx{%
Satan said: 'Since You have led me astray, I shall surely sit in ambush for them on Your Straight Path.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
Then I will come upon them from the front and from the rear, and from their right and from their left. And You will not find most of them thankful.'\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
Allah said: 'Go away from here - disgraced and expelled. I shall fill the Hell with all those that follow you.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
O Adam! Live you and your spouse in the Garden and both of you eat from it wherever you will, but never approach the tree or you shall become wrongdoers.'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
But Satan made an evil suggestion to both of them that he might reveal to them their shame that had remained hidden from them. He said: 'Your Lord has forbidden you to approach this tree only to prevent you from becoming angels or immortals.'\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he swore to them both: 'Surely I am your sincere adviser.'\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
Thus Satan brought about their fall by deceit. And when they tasted of the tree, their shame became vislible to them, and both began to cover themselves with leaves from the Garden. Then their Lord called out to them: 'Did I not forbid you from that tree, and did I not warn you that Satan 'is your declared enemy?'\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
Both cried out: 'Our Lord! We have wronged ourselves. If You do not forgive us and do not have mercy on us, we shall surely be among the losers.'\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
Allah said: 'Go down; you are enemies one of the other. For you there is dwelling and provision on the earth for a while.'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He continued: 'You shall live there, and there shall you die, and from it you shall be raised to life.'\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O Children of Adam! Indeed We have sent down to you a garment which covers your shame and provides protection and adornment. But the finest of all is the garment of piety. That is one of the signs of Allah so that they may take heed.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
Children of Adam! Let not Satan deceive you in the manner he deceived your parents out of Paradise, pulling off from them their clothing to reveal to them their shame. He and his host surely see you from whence you do not see them. We have made satans the guardians of those who do not believe.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And when such people commit an indecent act they say: 'We found our fathers doing that, and Allah has enjoined it on us. Say: 'Surely Allah never enjoins any indecency. Do you say things regarding Allah that you do not know?'\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say to them (O Muhammad): 'My Lord enjoins justice; and that you set your faces aright at the time of every Prayer; and that you call upon Him, exclusively dedicating your faith to Him. You shall return to Him as you were created.'\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
A party He has guided to the Right Way, and for another party straying is justly its due for they have taken satans, rather than Allah, as their guardians, even though they think that they are rightly-guided.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
Children of Adam! Take your adornment at every time of Prayer; and eat and drink without going to excesses. For Allah does not like those who go to excess.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say (O Muhammad): 'Who has forbidden the adornment which Allah has brought forth for His creatures or the good things from among the means of sustenance?' Say: 'These are for the enjoyment of the believers in this world, and shall be exclusively theirs on the Day of Resurrection.' Thus do We clearly expound Our revelations for those who have knowledge.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Tell them (O Muhammad): 'My Lord has only forbidden indecent acts, whether overt or hidden; all manner of sin; wrongful transgression; and [He has forbidden] that you associate with Allah in His divinity that for which He has sent down no sanction; and that you ascribe to Allah things of which you have no sure knowledge that they are from Him.'\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
For every community there is an appointed term; and when its term arrives, they cannot tarry behind a moment, nor can they get ahead.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
Children of Adam! If Messengers come to you from amongst yourselves who rehearse to you My signs, then those who shun disobedience and mend their ways shall have nothing to fear, nor shall they grieve.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@cmxc{%
And those who reject Our revelations as false and turn away from them in arrogance, they shall be the inmates of Hell; and there shall they abide.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@cmxci{%
Who is more unjust then he who invents a falsehood, ascribing it to Allah, or who rejects His revelation as false? Their full portion of God's Decree shall reach them, until Our deputed angels come to them to take charge of their souls, and say: 'Where are the deities now, those whom you invoked besides Allah?' They will say: 'They are all gone away from us.' And they shall bear witness against themselves that they were unbelievers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@cmxcii{%
Allah ivill say: 'Enter the fire of Hell and join the nations of jinn and men that have gone before You.' As a nation enters Hill, it will curse the one that went before it, and when all are gathered there, the last of them shall say of the first: 'Our Lord! These are the ones who led us astray. Let their torment be doubled in Hell-Fire.' He will answer: 'Each will have a doubled torment; although you do not know.'\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@cmxciii{%
Then the preceding ones will say to the succeeding ones: 'You were in no way superior to us; taste, then, this torment for your deeds.'\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Surely the gates of Heaven shall not be opened for those who reject Our signs as false and turn away ' from them in arrogance; nor shall they enter Paradise until a camel passes through the eye of a needle. Thus do We reward the guilty ones.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@cmxcv{%
Hell shall be their bed, and also above them their covering. Thus do We reward the wrong-doers.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
And those who believe and do good - We do not impose upon any of them a burden beyond his capacity. They are the people of Paradise. And there they shall abide.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
We shall strip away all rancour from their hearts, and rivers shall flow beneath them, and they shall say: 'All praise be to Allah Who has guided us on to this. Had it not been for Allah Who granted us guidance, we would not be on the Right Path. Surely the Messengers of our Lord did indeed come down with truth.' Then a voice will cry out to them: 'This is the Paradise which you are made to inherit as a reward for your deeds.'\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
And the people of Paradise shall cry to the people of Hell: 'Surely we have found our Lord's promise to us to be true. have you also found true what your Lord has promised you?' 'Yes', they shall answer; and a herald shall cry out among them: 'Allah's curse be upon the wrong-doers';\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@cmxcix{%
upon those who hinder men from the path of Allah and seek to make it crooked; and disbelieve in the Hereafter.'\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@m{%
And between the two there will be a barrier, and on the Heights will be men who will recognize each person by his mark and will cry, out to the people of Paradise: 'Peace be to you.'These will be the ones who had not yet joined them in Paradise, though they long to do so.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mi{%
And when the eyes of the people of the Heights will be turned towards the people of Hell they will say: 'Our Lord! Do not cast us among the wrongdoing people.'\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mii{%
And the people of the Heights will cry out to the men whom they would recognize by their marks. saving: 'Neither your numbers nor the riches of which you were proud availed you.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@miii{%
Are these not the ones of whom you swore that Allah shall grant them nothing of His mercy?' To such it will be said: 'Enter Paradise. You have no cause to fear, nor shall you grieve.'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@miv{%
And the people of the Fire will cry out to the people of Paradise: 'Pour out some water on us or throw at us something of what Allah has bestowed upon you.' They will reply: 'Allah has forbidden them to the deniers of the truth,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mv{%
who have made their religion a sport and play. and whom the life of the world has beguiled. So on that Day We shall forget them in the manner they forget their meeting of this Day with Us and persist in denying Our revelations.'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mvi{%
Surely We have brought them a Book which We expounded with knowledge; a guidance and a mercy to those who believe '\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mvii{%
Are they waiting for the fulfilment of its warning? On the Day that warning is fulfilled, those that have neglected it before will say: 'The Messengers of Our Lord did indeed bring forth the truth. Are there any intercessors who will now plead on our behalf? Or, can we be restored to life that we might perform differently from that which we did? ' They surely ended in utter loss, and the lies they had fabricated failed them.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mviii{%
Surely your Lord is none other than Allah, Who created the heavens and the earth in six days, and then ascended His Throne; Who causes the night to cover the day and then the day swiftly pursues the night; Who created the sun and the moon and the stars making them all subservient to His command. Lo! His is the creation and His is the command. Blessed is Allah, the Lord of the universe.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mix{%
Call upon your Lord with humility and in secret. Surely He does not love transgressors.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mx{%
Anddo not make mischief in the earth after it has been set in order, and call upon Him with fear and longing. Surely Allah's mercy is close to those who do good.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mxi{%
And it is He Who sends forth winds as glad tidings in advance of His Mercy, and when they have carried a heavy-laden cloud We drive it to a dead land, then We send down rain from it and bring forth therwith fruits of every kind. In this manner do We raise the dead that you may take heed.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mxii{%
As for the good land, vegetation comes forth in abundance by the command of its Lord, whereas from the bad land, only poor vegetation comes forth. Thus do We expound Our signs in diverse ways for a people who are grateful.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mxiii{%
Indeed We sent forth Noah to his people and he said: 'O my people! Serve Allah, you have no other god than Him Indeed I fear for you the chastisement of an awesome Day.'\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mxiv{%
The leading men of his people replied: 'We see that you are in palpable error.'\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mxv{%
He said: 'O my people! There is no error in me, but I am a Messenger from the Lord of the universe.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mxvi{%
I convey to you the messages of my Lord, give you sincere advice, and I know from Allah that which you do not know.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mxvii{%
Do you wonder that admonition should come to you from your Lord through a man from amongst yourselves that he may warn you, that you may avoid evil and that mercy may be shown to you?'\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mxviii{%
But they charged him with falsehood. Thereupon We delivered Noah and those who were with him in the Ark, and caused those who rejected Our signs as false to be drowned. Surely they were a blind folk.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mxix{%
And to 'Ad We sent forth their brother Hud. He said: 'O my people! Serve Allah; you have no other god than Him. Will you, then, not avoid evil?'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mxx{%
The unbelievers among the leading men of his people said: 'Indeed we see you in folly, and consider you to be liars.'\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mxxi{%
He said: 'O my people! There is no folly in me; rather I am a Messenger from the Lord of the universe.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mxxii{%
I convey to you the messages of my Lord, and I give you sincere advice.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mxxiii{%
Do you wonder that an exhortation should come to you from your Lord through a man from amongst yourselves that he may warn you? And do call to mind when He made you successors after the people of Noah and amply increased you in stature. Remember then the wondrous bounties of Allah, that you may prosper.'\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said: 'Have you come to us that we should worship none other than Allah and forsake all whom our forefathers were wont to worship? Then bring upon us the scourge with which you have threatened us if you are truthful?'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mxxv{%
Hud warned them: 'Surely punishment and wrath from your Lord have befallen upon you. Do you dispute with me about mere names that you and your forefathers have concocted and for which Allah has sent down no sanction? Wait, then, and I too am with you among those who wait.'\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mxxvi{%
Then We delivered Hud and his companions by Our mercy, and We utterly cut off the last remnant of those who called the lie to Our signs and would not believe.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And to Thamud We sent forth their brother. Salih. He said to them: 'O my people! Serve Allah, you have no other god than Him. Truly there has come to you a clear proof from your Lord. This she-camel from Allah is a Divine portent for you. So leave her alone to pasture on Allah's earth, and touch her with no evil lest a painful chastisement should seize you.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mxxviii{%
And call to mind when He made you successors after 'Ad and gave you power in the earth so that you took for yourselves palaces in its plains and hewed out dwellings in the mountains. Remember, then, the wondrous bounties of Allah and do not go about creating mischief in the land.'\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mxxix{%
The haughty elders of his people said to those believers who had been oppressed: 'Do you know that Salih is one sent forth with a message from his Lord?' They, replied: 'Surely we believe in the message with which he has been sent.'\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mxxx{%
The haughty ones remarked. 'Most certainly we disbelieve in that which you believe.'\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mxxxi{%
Then they hamstrung the she-camel, disdainfuliy disobeyed the commandment of their Lord, and said: 'O Salih! Bring upon us the scourge with which you threatened us if you are truly a Messenger [of Allah].'\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mxxxii{%
Thereupon a shocking catastrophe seized them, so that they lay prostrate in their dwellings.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
And Salih left them, saying: 'O my people! I conveyed to you the message of my Lord and gave you good advice; but you have no liking for your well-wishers.'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And remember when We sent Lot [as a Messeng to his people and he said to them: 'Do you realize you practise an indecency of which no other people in the world were guilty of before you?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mxxxv{%
You approach men lustfully in place of women. You are a people who exceed all bounds.'\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
Their only answer was: 'Banish them from your town. They are a people who pretend to be pure.'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
Then We delivered Lot and his household save his wife who stayed behind,\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
and We let loose a shower [of stones] upon them, Observe, then, the end of the evil-doers.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And to Midian We sent forth their brother Shu'ayb He exhorted them: O my people! Serve Allah, you have no god but Him. Indeed a clear proof has come to you from your Lord. So give just weight and measure and diminish not to men their things ' and make no mischief on the earth after it has been set in good order. That is to your own good, if you truly believe.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mxl{%
And do not lie in ambush by every path [of life] seeking to overawe or to hinder from the path of Allah those who believe, nor seek to make the path crooked. Remember, how you were once few, and then He multiplied you, and keep in mind what was the end of mischiefmakers.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mxli{%
And if there are some among you who believe in the message that I bear while some do not believe, have patience till Allah shall judge between us. He is the best of those who judge.'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mxlii{%
The haughty elders of his people said: 'O Shu'ayb! We shall certainly banish you and your companions-in-faith from our town, or else you shall return to our faith.' Shu'ayb said: 'What! Even though we abhor [your faith]?\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mxliii{%
If we return to your faith after Allah has delivered us from it we would be fabricating a lie against Allah. nor can we return to it again unless it be by, the will of Allah, our Lord. Our Lord has knowledge of all things, and in Allah we put our trust. Our Lord! Judge rightly between us and our people, for You are the best of those who judge.'\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mxliv{%
The elders of his people who disbelieved said: 'Should you follow Shu'ayb, you will be utter losers.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mxlv{%
Thereupon a shocking catastrophe seized them, and they remained prostrate in their dwellings.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mxlvi{%
Those who had charged Shu'ayb with lying became as though-they had never lived there; it is they who became utter losers.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mxlvii{%
Shu'ayb then departed from his people, and said: 'O my people! Surely I conveyed to you the message of my Lord, and gave you sincere advice. How, then, can I mourn for a people who refuse to accept the truth?'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mxlviii{%
Never have We sent a Prophet to a place without trying its people with adversity and hardship that they may humble themselves.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then We changed adversity into ease until they throve and said: 'Our forefathers had also seen both adversity and prosperity.' So We suddenly seized them without their even perceiving it.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@ml{%
Had the people of those towns believed and been God-fearing, We would certainly have opened up to them blessings from the heavens and the earth; but they gave the lie [to their Prophets] and so We seized them for their deeds. so.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mli{%
Do the people of those towns feel secure that Our punishment will not come to them at night while they are asleep?\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mlii{%
Or, do the people of those towns feel secure that Our punishment will not come to them by daylight while they are at play?\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mliii{%
Do they feel secure against the design of Allah None can feel secure against the design of Allah except the utter losers.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mliv{%
Has it not, then, become plain to those who have inherited the earth in the wake of the former generations that, had We so willed, We could have afflicted them for their sins, (they, however, are heedless to basic facts and so) We seal their hearts so that they hear nothing.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mlv{%
To those [earlier] communities - some of whose stories We relate to you - there had indeed come Messengers with clear proofs, but they would not believe what they had once rejected as false. Thus it is that Allah seals the hearts of those who deny the truth.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mlvi{%
We did not find most of them true to their covenants; indeed We found most of them to he transgressors.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mlvii{%
After those We sent forth Moses with Our signs to Pharaoh and his nobles, but they dealt with Our signs unjustly. Observe, then, what happened to the mischief-makers.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mlviii{%
And Moses said: 'O Pharaoh! I am a Messenger from the Lord of the universe.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mlix{%
And it behoves me to say nothing about Allah except what is true. I have come to you with a clear sign of having been sent from your Lord. So let the Children of Israel go with me.'\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mlx{%
Pharaoh said: if you have brought a sign, then bring it forth if you are truthful.'\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mlxi{%
Thereupon Moses threw his rod, and suddenly it was a veritable serpent.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mlxii{%
Then he drew out his hand, and it appeared luminous to all beholders.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mlxiii{%
The elders of Pharaoh's people said: 'Surely this man is a skilful magician\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mlxiv{%
who seeks to drive you out from your land. What would you have us do?'\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mlxv{%
Then they advised Pharaoh: 'Put off Moses and his brother for a while, and send forth heralds to your cities\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mlxvi{%
to summon every skilful magician to your presence.'\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mlxvii{%
And the magicians came to Pharaoh and said: 'Shall we have a reward if we win?'\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mlxviii{%
Pharaoh replied: 'Certainly, and you shall be among those who are near to me.'\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mlxix{%
Then they said: 'O Moses, will you [first] throw your rod, or shall we throw?'\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mlxx{%
Moses said: 'You throw.' So when they threw [their rods], they enchanted the eyes of the people, and struck them with awe, and produced a mighty sorcery.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mlxxi{%
Then We directed Moses: 'Now you throw your rod.' And lo! it swallowed up all their false devices.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mlxxii{%
Thus was the truth established, and their doings proved in vain.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
Pharaoh and his men were defeated and put to shame,\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
and the magicians flung themselves prostrate,\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mlxxv{%
saying: 'We believe in the Lord of the universe,\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
the Lord of Moses and Aaron.'\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Pharaoh said: 'What! Do you believe before you have my permission? Surely this is a plot you have contrived to drive out the rulers from the capital. So you shall see,\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
I shall cut off your hands and feet on the opposite sides, and then crucify you all.'\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They replied: 'We shall surely return to our Lord.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mlxxx{%
Will you punish us just because we believed in the signs of our Lord when they came to us? Our Lord! Shower us with perseverance and cause us to die as those who have submitted [to You].'\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
The elders of Pharaoh's people said: 'Will you leave alone Moses and his people to spread mischief in the land, and forsake you and your gods?' Pharaoh replied: 'We will kill their male children and spare their female ones. For indeed we hold irresistible sway over them.'\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Moses said to his people: 'Seek help from Allah and be steadfast. The earth is Allah's, He bestows it on those of His servants He chooses. The end of things belongs to the God-fearing.'\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
The people of Moses replied: 'We were oppressed before your coming to us and after it.' Moses said: 'Your Lord will soon destroy your enemy and make you rulers in the land. Then He will see how you act.'\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
We afflicted the people of Pharaoh with hard times and with poor harvest that they may heed.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
But whenever prosperity came their way, they said: 'This is our due.' And whatever hardship befell them, they attributed it to the misfortune of Moses and those who followed him. Surely, their misfortune had been decreed by Allah - but most of them do not know that.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
And they said to Moses: 'Whatever sign you might produce before us in order to enchant us, we are not going to believe you.'\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
Then We afflicted them with a great flood and locusts, and the lice, and the frogs, and the blood. All these were distinct signs and yet they remained haughty. They were a wicked people.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
Each time a scourge struck them they, said: 'O Moses! Pray for us to your Lord on the strength of the prophethood He has bestowed upon you. Surely, if you remove this scourge from us, we will truly believe in you, and will let the Children of Israel go with you.'\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But when We removed the scourge from them until a term - a term which they were bound to reach - they at once broke their promise.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mxc{%
So We inflicted Our retribution on them, and caused them to drown in the sea because they gave the lie to Our signs and were heedless of them.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mxci{%
And We made those who had been persecuted inherit the eastern and western lands which We had blessed. Thus your Lord's gracious promise was fulfilled to the Children of Israel, for they had endured with patience; and We destroyed all that Pharaoh and his people had wrought, and all that they had built.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We led the Children of Israel across the sea; and then they came upon a people who were devoted to the worship of their idols. They said: 'O Moses, make for us a god even as they have gods.' Moses said: 'You are indeed an ignorant people.'\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mxciii{%
The way these people follow is bound to lead to destruction; and all their works are vain.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mxciv{%
Moses said: 'Should I seek any god for you other than Allah although it is He who has exalted you above all?'\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mxcv{%
And call to mind when We delivered you from Pharaoh's people who perpetrated on you a terrible torment, putting your males to death and sparing your females. Surely in it there was an awesome trial for you from your Lord.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And We appointed for Moses thirty nights, to which We added ten, whereby the term of forty nights set by his Lord was fulfilled. And Moses said to Aaron, his brother: 'Take my place among my people, act righteously, and do not follow the path of those who create mischief.'\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Moses came at Our appointment, and his Lord spoke to him, he said: 'O my Lord! Reveal Yourself to me, that I may look upon You!' He replied: 'Never can you see Me. However, behold this mount; if it remains firm in its place, only then you will be able to see Me.' And as soon as his Lord unveiled His glory to the mount, He crushed it into fine dust, and Moses fell down in a swoon. And when he recovered, he said: 'Glory be to You! To You I turn in repentance, and I am the foremost among those who believe.'\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mxcviii{%
He said: 'O Moses! I have indeed preferred you to all others by virtue of the Message I have entrusted to you and by virtue of My speaking to you. Hold fast therefore, to whatever I have granted you, and give thanks.'\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We ordained for Moses in the Tablets all manner of admonition, and instruction concerning all things, and said to him: Hold to these, with all your strength. and bid your people to follow them in accord with their best understanding. I shall soon show you the habitation of the wicked.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mc{%
I shall turn away from My signs those who, without any right, behaved haughtily in the earth, even if they may, witness each and every, sign, they shall not believe therein. And even if they see the right path, they shall still not follow it; but if they see the path of error. they shall choose it for their path. This is because they rejected Our signs as false and were heedless to them.\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mci{%
Vain are the deeds of those who reject Our signs as false and to the meeting of the Hereafter. Shall they be recompensed, except according to their deeds?'\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mcii{%
And in the absence of Moses his people made the image of a calf from their ornaments, which lowed. Did they not observe that it could neither speak nor give them any guidance? And still they made it an object of worship. They were indeed wrong-doing.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mciii{%
And when they were afflicted with remorse and realized that they had fallen into error, they said: 'If our Lord does not have mercy on us and does not pardon us, we shall be among the losers.'\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Moses returned to his people, full of wrath and sorrow, he said: 'Vile is the course you have followed in my absence. Could you not patiently wait for the decree of your Lord?' And he threw down the Tablets [of the Law] and took hold of his brother's head, dragging him to himself. Aaron said: 'My mother's son, the people overpowered me and almost killed me. So let not my enemies gloat over me, and do not number me among the wrong-doing folk.'\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mcv{%
Thereupon Moses said: 'O Lord! Grant forgiveness upon me and my brother and admit us to Your Mercy, for You are most merciful of the merciful.'\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mcvi{%
In reply they were told: 'Verily those who worshipped the calf will certainly incur indignation from their Lord, and will be abased in the life of this world. Thus do We reward those who fabricate lies.\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mcvii{%
As for those who do evil, and later repent and have faith, such shall find their Lord All-Forgiving, All-Compassionate after (they repent and believe)\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mcviii{%
And when the anger of Moses was stilled, he took up the Tablets again, the text of which comprised guidance and mercy to those who fear their Lord.\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mcix{%
And out of his people Moses singled out seventy men for Our appointment. Then, when violent shaking seized them, he addressed his Lord: 'Had You willed, O my Lord, You could have destroyed them and me long ago. Will You destroy us for what the fools amongst us did? That was nothing but a trial from You whereby You mislead whom You will and guide whom You will. You alone are our guardian. Forgive us, then, and have mercy upon us. You are the best of those who forgive.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mcx{%
And ordain for us what is good in this world and in the World to Come for to You have we turned.'He replied: 'I afflict whomsoever I wish with My chastisement. As for My mercy, it encompasses everything. will show mercy to those who abstain from evil, pay Zakat and have faith in Our signs.'\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mcxi{%
[To-day this mercy is for] those who follow the ummi Prophet, whom they find mentioned in the Torah and the Gospel with them. He enjoins upon them what is good and forbids them what is evil. He makes the clean things lawful to them and prohibits all corrupt things, and removes from them their burdens and the shackles that were upon them. So those who believe in him and assist him, and succour him and follow the Light which has been sent down with him, it is they who shall prosper.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mcxii{%
[Say, O Muhammad]: 'O men! I am Allah's Messenger to you all - of Him to Whom belongs the dominion of the heavens and the earth. There is no god but He. He grants life and deals death. Have faith then, in Allah and in His Messenger, the ummi Prophet who believes in Allah and His words; and follow him so that you may be guided aright.'\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mcxiii{%
Among the people of Moses' there was a party who guided others in the way of the truth and established justice in its light.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mcxiv{%
And We divided them into twelve tribes, forming them into communities. When his people asked Moses for water We directed him: 'Smite the rock with your rod.' Then twelve springs gushed forth from the rock and every people knew their drinking-places. And We caused thick clouds to provide them shade, and We sent down upon them manna and quails, saying: 'Eat of the clean things that We have provided you.' They wronged not Us, but it was themselves that they wronged.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mcxv{%
And recall when it was said to them: 'Dwell in this town and eat plentifully of whatever you please, and say: ``Repentance", and enter the gate prostrate. We shall forgive you your sins and shall bestow further favours on those who do good.'\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mcxvi{%
Then the wrong-doers among them substituted another word in place of the one told them. So We sent upon them a scourge from the heaven as a punishment for their Wrong-doing.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mcxvii{%
And ask the people of Moses concerning the town situated along the sea how its people profaned the Sabbath when fish came to them breaking the water's surface on Sabbath days, and would not come to them on other than Sabbath-days. Thus did We try them because of their disobedience.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And recall when a party of them said: 'Why do you admonish a people whom Allah is about to destroy or punish severely?' They said: 'We admonish them in order to be able to offer an excuse before Your Lord, and in the hope that they will guard against disobedience.'\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mcxix{%
Then, when they forgot what they had been exhorted, We delivered those who forbade evil and afflicted the wrong-doers with a grievous chastisement because of their evildoing.\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mcxx{%
And when they persisted in pursuing that which had been forbidden We said: 'Become despised apes.'\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mcxxi{%
And recall when Your Lord proclaimed that 'He would continually set in authority over them, till the Day of Judgement, those who would ruthless oppress thern.' Surely, your Lord is swift in chastising; and yet He is All-Forgiving, All-Merciful.\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We dispersed them through the earth in communities - some were righteous, others were not -and We tested them with prosperity and adversity that they may turn back (to righteousness).\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
Then others succeeded them who inherited the scriptures, and yet kept themselves occupied in acquiring the goods of this world and kept saying: 'We shall be forgiven.' And when there comes to them an opportunity for acquiring more of those goods, they seize it. Was not the covenant of the Book taken from them that they would not ascribe to Allah anything but the truth? And they have read what is in the Book and know that the abode of the Hereafter is better for the God-fearing. Do you not understand?\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
Those who hold fast to the Book and establish Prayer - We shall not allow the reward of such righteous men to go to waste.\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And recall when We shook the mountain over them as though it were a canopy, and they thought that it was going to fall over them; and We said: 'Hold firmly to that which We have given you, and remember what is in it, that you may guard against evil.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And recall (O Prophet) when your Lord brought forth descendants from the loins of the sons of Adam, and made them witnesses against their ownselves. asking them: 'Am I not your Lord?' They said: 'Yes, we do testify.' We did so lest you claim on the Day of Resurrection: 'We were unaware of this.'\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Or say: 'Our forefathers before us who associated others with Allah in His divinity; we were merely their offspring who followed them. And would You destroy us for that which the unrighteous did?'\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
And thus do We expound the signs that they may turn back (to the right path).\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mcxxix{%
And recite to them [O Muhammad] the story of the man to whom We gave Our signs and who turned away from them; then ultimately Satan caught up with him and he was led astray.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mcxxx{%
Now had We so willed We could indeed have exalted him through those signs, but he clung to earthly life and followed his carnal desires. Thus his parable is that of the dog who lolls out his tongue whether you attack him or leave him alone. Such is the parable of those who reject Our signs as false. Narrate to them these parables that they may reflect.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
Evil is the example of the people who reject Our signs as false and perpetrate wrong against their own selves.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
He whom Allah guides, he alone is rightly guided; and he whom Allah lets go astray - it is they who are the loser.'\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
And certainly We have created for Hell many of the jinn and mankind; they have hearts with which they fail to understand; and they have eyes with which they fail to see; and they have ears with which they fail to hear. They are like cattle - indeed, even more astray. Such are utterly heedless.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
Allah has the most excellent names. So call on Him by His names and shun those who distort them. They shall soon be requited for their deeds.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
And of those whom We have created there is a party who guide men through the truth and act justly according to it.\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
As for those who reject Our signs as false, We shall lead them, step by step, to their ruin without their even perceiving it.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
And (for this purpose) I will grant them respite. My design is incontrovertible.\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Have they not pondered that their companion [i.e. the Prophet Muhammad] is not afflicted with insanity? He is only a plain warner.\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Have they not observed the kingdom of the heavens and the earth, and all that Allah has created and that their term of life might have drawn near After this warning from the Prophet, what will it be that will make them believe?\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@mcxl{%
For those whom Allah lets go astray, there is no guide; and He will leave them in their transgression to stumble blindly.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask you concerning the Hour, when will its coming be? Say: 'The knowledge of it is with my Lord alone: none but He will disclose it at its time. That will weigh heavily on the heavens and the earth; and it shall not come to you other than all of a sudden.' They ask you - as if you are eagerly inquisitive about it - concerning it. Say to them: 'The knowledge of it is with none except Allah. But most people are unaware of this reality.'\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Tell them [O Muhammad]: 'I have no power to benefit or harm myself except as Allah may please. And had I knowledge of the unseen, I should have amassed all kinds of good, and no evil would have ever touched me. I am merely a warner and the herald of glad tidings to those who have faith.'\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He - Allah -Who created you from a single being, and out of it He made its mate, that he may find comfort in her. And when he covers her, she bears a light burden and goes about with it. Then, when she grows heavy, they pray to their Lord: 'If You bestow upon us a healthy child, we will surely give thanks.'\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@mcxliv{%
But when He vouchsafes them a healthy child, they attribute to Him partners regarding what Allah had bestowed upon them. Subliminally exalted is Allah above that which they associate with Him.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Do they associate (with Allah in His divinity) those who can create nothing; rather, they are themselves created?\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
They have no power to help others. nor can they help themselves.\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
And if you call them to true guidance, they will not follow you. It is all the same for you whether you call them to true guidance or keep silent.\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Those whom you invoke other than Allah are creatures like you. So invoke them. and see if they answer your call, if what you claim is true.\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Have they feet on which they can walk? Have they hands with which they can grasp? Have they eyes with which they can see? Have they ears with which they can hear? Say [O Muhammad]: 'Invoke all those to whom you ascribe a share in Allah's divinity, then scheme against me and grant me no respite.\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@mcl{%
My guardian is Allah Who has revealed the Book, and it is He Who protects the righteous.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@mcli{%
And those whom you invoke other than Allah, they can neither help themselves nor you.\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@mclii{%
And if you were to call them to true guidance, they will not hear; and you observe them looking at you whereas they have no power to see.'\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@mcliii{%
[O Prophet!] Show forgiveness, enjoin equity, and avoid the ignorant.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@mcliv{%
And if it happens that a prompting from Satan should stir you up, seek refuge with Allah. He is All-Hearing, All-Knowing.\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@mclv{%
If the God-fearing are instigated by any suggestion of Satan, they instantly become alert, whereafter they clearly perceive the right way.\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@mclvi{%
As for their brethren [the Satans], they draw them deeper into error and do not relax in their efforts.\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@mclvii{%
[O Prophet!] When you do not produce before them any miracle, they say: 'Why do you not choose for yourself a miracle?' Say to them: 'I follow only what is revealed to me by my Lord. This is nothing but a means of insight into the truth, and guidance and mercy from your Lord to the people who believe.\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@mclviii{%
So when the Qur'an is recited, listen carefully to it, and keep silent so that you may, be shown mercy.'\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@mclix{%
And remember [O Prophet] your Lord in your mind, with humility and fear, and without raising your voice; remember Him in the morning and evening, and do not become of those who are negligent.\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@mclx{%
[The angels] who are near to Your Lord, never turn away from His service out of arrogance; they rather glorify Him and prostrate themselves before Him.\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask you concerning the spoils of war? Tell them: 'The spoils of war belong to Allah and the Messenger. So fear Allah, and set things right between you, and obey Allah and His Messenger if you are true believers.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mclxii{%
The true believers are those who, when Allah's name is mentioned, their hearts quake, and when His verses are recited to them their faith grows, and who put their trust in their Lord;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mclxiii{%
who establish Prayer and spend out of what We have provided them.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mclxiv{%
Such people are indeed true believers. They have high ranks with their Lord, and forgiveness for their sins and an honourable sustenance.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mclxv{%
(Now with regard to the spoils the same situation exists as when) your Lord brought you forth from your home in a righteous cause while a party among the believers were much averse to it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mclxvi{%
They disputed with you about the truth after that had become evident, as if they were being driven to death with their eyes wide open.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mclxvii{%
And recall when Allah promised you that one of the two hosts would fall to you, and you wished that the one without arms should fall into your hands. But Allah sought to prove by His words the truth to be true and to annihilate the unbelievers to the last remnant\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mclxviii{%
that He might prove the truth to be true and the false to be false, however averse the evil-doers might be to it.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mclxix{%
And recall when you implored your Lord for help and He responded to you: 'I will indeed reinforce you with a thousand angels, coming host after host.'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mclxx{%
Allah meant this as glad tidings and that your hearts may be set at rest. For every help comes from Allah alone. Surely Allah is All-Mighty, All-Wise.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mclxxi{%
And recall when Allah brought on you drowsiness, giving you a feeling of peace and security from Him, and He sent down rain upon you from the sky that He might cleanse you through it and take away from you the pollution of Satan and strengthen your hearts, and steady your feet through it.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mclxxii{%
And recall when your Lord inspired the angels: 'I am certainly with you. So make firm the feet of those who believe. I will cast terror into the hearts of those who disbelieve. So strike at their necks and strike at every pore and tip.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
This is because they defied Allah and His Messenger. Whoever defies Allah and His Messenger must know that Allah is severe in punishment.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
That is your punishment (from Allah). So taste this punishment, and know that for the unbelievers is the punishment of the Fire.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mclxxv{%
Believers, whenever you encounter a hostile force of unbelievers, do not turn your backs to them in flight.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
For he who turns his back on them on such ar occasion - except that it be for tactical reasons, or turning to join another company - he shall incur the wrath of Allah and Hell shall be his abode. It is an evil destination.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
So the fact is that it was not you, but it was Allah Who killed them; and it was not you when you threw [sand at them], but it was Allah Who threw it, (and the believers were employed for the task) that He might cause the believers to successfully pass through this test. Allah is All-Hearing, All-Knowing.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
This is His manner of dealing with you. As for the unbelievers, Allah will surely undermine their designs.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mclxxix{%
(Tell the unbelievers:) 'If you have sought a judgement, then surely a judgement has come to you. And if you desist from disobedience, it is all the better for you. But if you revert to your mischief, We will again chastise you; and your host, howsoever numerous, will never be of any avail to you. Know well, Allah is with the believers.'\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mclxxx{%
Believers! Obey Allah and His Messenger and do not turn away from him after you hear his command.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
And do not be like those who say: 'We hear', though they do not hearken.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
Indeed the worst kind of all beasts in the sight of Allah are the people that are deaf and dumb, and do not understand.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
And had Allah known in them any good He would surely, have made them hear; but (being as they, are) even if He made them hear, they would have surely turned away in aversion.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
Believers! Respond to Allah, and respond to the Messenger when he calls you to that which gives you life. Know well that Allah stands between a man and his heart, and it is to Him that all of you shall be mustered.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And guard against the mischief that will not only bring punishment to the wrong-doers among you. Know well that Allah is severe in punishment.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And recall when you were few in numbers and deemed weak in the land, fearful lest people do away with you. Then He provided you refuge, strengthened you with His help, and provided you sustenance with good things that you may be grateful.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
Believers! Do not be unfaithful to Allah and the Messenger, nor be knowingly unfaithful to your trusts.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
Know well that your belongings and your children are but a trial, and that with Allah there is a mighty reward.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
Believers! If you fear Allah He will grant you a criterion and will cleanse you of your sins and forgive you. Allah is Lord of abounding bounty.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcxc{%
And recall how those who disbelieved schemed against you to take you captive, or kill you, or drive you away. They schemed and Allah did also scheme. Allah is the best of those who scheme.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcxci{%
And when Our verses are recited to them, they say: 'We have heard. We could, if we willed, compose the like of it. They, are nothing but fables of the ancient times.'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And also recall when they said: 'O Allah! If this indeed be the truth from You, then rain down stones upon us from heaven, or bring upon us a painful chastisement.'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcxciii{%
But Allah was not to chastise them while you are in their midst; nor was Allah going to chastise them while they sought His forgiveness.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcxciv{%
But what prevents Allah from chastising them now when they are hindering people from the Holy Mosque, even though they are not even its true guardians. For its true guardians are none but the God-fearing, though most of them do not know that.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcxcv{%
Their Prayer at the House is nothing but whistling and handclapping. Taste, then, this chastisement for your denying the truth.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Surely those who deny the truth spend their wealth to hinder people from the way of Allah, and will continue to so spend until their efforts become a source of intense regret for them, and then they will be vanquished, and then these deniers of the truth will be driven to Hell,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
so that Allah may separate the bad from the good, and join together all those who are bad into a pile one upon another, and cast them into Hell. They, it is they who are the losers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
[O Prophet!] Tell the unbelievers that if they desist from evil, their past shall be forgiven and if they revert to their past ways, then it is well known what happened with the people of the past.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcxcix{%
And fight against them until the mischief ends and the way prescribed by Allah - the whole of it -prevail Then, if they give up mischief, surely Allah sees what they do.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcc{%
But if they turn away, then know well that Allah is your Protector - an excellent Protector and an excellent Helper.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcci{%
Know that one fifth of the spoils that you obtain belongs to Allah, to the Messenger, to the near of kin, to the orphans, and the needy, and the wayfarer. This you must observe if you truly believe In Allah and in what We sent down on Our servant on the day when the true was distinguished from the false, the day on which the two armies met in battle. Allah has power over all things.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mccii{%
And recall when you were encamped at the nearer end of the valley (of Badr) and they were at the farther end and the caravan below you (along the seaside). Had you made a mutual appointment to meet in encounter, you would have declined. But encounter was brought about so that Allah might accomplish what He had decreed, and that he who was to perish should perish through a clear proof, and who was to survive might survive through a clear proof. Surely Allah is All-Hearing, All-Knowing.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcciii{%
And recall when Allah showed them to you in your dream to be few in number. And had He showed them to you to be numerous, you would have flagged and disagreed with one another about fighting them. But Allah saved you. Surely Allah knows what is hidden in the breasts.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcciv{%
And recall when He made them appear as few in your eyes when you met them in the battle just as He lessened you in their eyes so that Allah might accomplish what had been decreed. To Allah are all matters referred for decision.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mccv{%
Believers! When you encounter a host in battle, stand firm and remember Allah much that you may triumph.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey Allah and His Messenger, and do not quarrel with one another lest you should lose courage and your power depart. Be steadfast, surely Allah is with those who remain steadfast.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mccvii{%
And be not like those who came forth from their homes exulting, with a desire to be seen of men, and hindering others from the way of Allah. Allah encompasses all that they do.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mccviii{%
And recall when Satan made their works seem fair to them and said: 'None shall overcome you today. and I am your supporter.' But when the two armies faced each other, he turned on his heels, and said: 'Surely I am quit of you for I behold that which you do not. Indeed I fear Allah, and Allah is stern in punishment.'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mccix{%
And recall when the hypocrites and those whose hearts were diseased said: 'Their faith has deluded these (believers). But he who puts his trust in Allah shall find Allah All-Mighty. All-Wise.'\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mccx{%
And if you could only see when the angels took away the souls of the unbelievers, striking them on their faces and backs, saying: 'Taste the torment of burning.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mccxi{%
This is your punishment for what your hands wrought. Allah is not unjust in the least to His creatures.'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mccxii{%
Their case is like that of the people of Pharaoh and those before them. They denied the signs of Allah and so Allah seized them for their sins. Surely Allah is All-Powerful, Stern in retribution.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mccxiii{%
This happened because Allah is not one to change the favour which He has bestowed upon a people until they have changed their attitude., Surely Allah is All-Hearing, All-Knowing.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mccxiv{%
Their case is like that of the people of Pharaoh and those before them: they rejected the signs of their Lord as false and so We destroyed them for their sins, and caused the people of Pharaoh to drown. For they were wrong-doers all.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mccxv{%
Surely the worst moving creatures in the sight of Allah are those who definitively denied the truth and are therefore in no way prepared to accept it;\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mccxvi{%
(especially) those with whom you entered into a covenant and then they broke their covenant time after time, and who do not fear Allah.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mccxvii{%
So if you meet them in war, make of them a fearsome example for those who follow them that they may he admonished.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mccxviii{%
And if you fear treachery from any people (with whom you have a covenant) then publicly throw their covenant at them. Allah does not love the treacherous.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mccxix{%
Let not the deniers of the truth be deluded that they will gain any advantage. Surely, they, can never overcome Us!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mccxx{%
Make ready for an encounter against them all the forces and well-readied horses you can muster that you may overawe the enemies of Allah and your own enemies and others besides them of whom you are unaware but of whom Allah is aware. Whatever you may spend in the cause of Allah shall be fully repaid to you, and you shall not be wronged.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mccxxi{%
If they incline to peace, incline you as well to it, and trust in Allah. Surely He is All-Hearing. All-Knowing.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mccxxii{%
And should they seek to deceive you, Allah is sufficient for you. He it is Who strengthened you with His succour and the believers\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
and joined their hearts. Had you given away all the riches of the earth you could not have joined their hearts, but it is Allah Who joined their hearts. Indeed He is All-Mighty. All-Wise.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Prophet! Allah is sufficient for you and the believers who follow you.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Prophet! Rouse the believers to fighting. If they be twenty of you who persevere they shall vanquish two hundred; and if there be of you a hundred, they shall vanquish a thousand of those who disbelieve, for they are a people who lack understanding.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
Allah has now lightened your burden for He found weakness in you. So if there be hundred of you who persevere, they shall vanquish two hundred; and if there be a thousand of you they shall, by the leave of Allah, vanquish two thousand. Allah is with those who persevere.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It behoves not a Prophet to take captives until he has sufficiently suppressed the enemies in the land. You merely seek the gains of the world whereas Allah desires (for you the good) of the Hereafter. Allah is All-Mighty, All-Wise.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Had there not been a previous decree from Allah, a stern punishment would have afflicted you for what you have taken.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mccxxix{%
So eat that which you have obtained - for it is lawful and clean--and fear Allah. Surely Allah is Ever-Forgiving, Most Merciful.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet! Say to the captives in your hands: 'If Allah finds any goodness in your hearts He will give you that which is better than what has been taken away from you, and He will forgive you. Allah is Ever-Forgiving, Most Merciful.'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
But if they seek to betray you, know that they had already betrayed Allah. Therefore He made you prevail over them. Allah is All-Knowing, All-Wise.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Surely those who believed and migrated and strove hard in the way of Allah with their possessions and their lives, and those that sheltered and helped them - they alone are the true allies of one another. And those who believed but did not migrate (to Dar-al-Islam), you are under no obligation of alliance unless they migrate. And should they seek help from you in the matter of religion, it is incumbent on you to provide help unless it be against a people with whom you have a pact. Allah is cognizant of all that you do.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
And those who disbelieve. they are allies of one another; and unless you act likewise. there will be oppression in the world and great corruption.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
Those who believe and have migrated and strove in the way of Allah, and those who gave them refuge and help - it is they who are the true believers. Theirs shall be forgiveness and honourable sustenance.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who believed afterwards and migrated and strove along with you: they belong to you. But those related by blood are nearer to one another according to the Book of Allah. Allah has knowledge of everything.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen This is a declaration of disavowal by Allah and His Messenger to those who associate others with Allah in His Divinity and with whom you have made treaties:\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
``You may go about freely in the land, for four months, but know well that you will not be able to frustrate Allah, and that Allah will bring disgrace upon those who deny the Truth."\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
This is a public proclamation by Allah and His Messenger to all people on the day of the Great Pilgrimage: ``Allah is free from all obligation to those who associate others with Allah in His Divinity; and so is His Messenger. If you repent, it shall be for your own good; but if you turn away, then know well that you will not be able to frustrate Allah. So give glad tidings of a painful chastisement to those who disbelieve.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
In exception to those who associate others with Allah in His Divinity are those with whom you have made treaties and who have not violated their treaties nor have backed up anyone against you. Fulfil your treaties with them till the end of their term. Surely Allah loves the pious."\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mccxl{%
But when the sacred months expire slay those who associate others with Allah in His Divinity wherever you find them; seize them, and besiege them, and lie in wait for them. But if they repent and establish the Prayer and pay Zakah, leave them alone. Surely Allah is All-Forgiving, Ever-Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mccxli{%
And if any of those who associate others with Allah in His Divinity seeks asylum, grant him asylum that he may hear the Word of Allah, and then escort him to safety for they are a people who do not know.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be a covenant with those who associate others with Allah in His Divinity be binding upon Allah and His Messenger, excepting those with whom you made a covenant near the Sacred Mosque? Behave in a straight manner with them so long as they behave with you in a straight manner for Allah loves the Godfearing.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How can there be any covenant with the other polytheists for were they to prevail against you, they will respect neither kinship nor agreement. They seek to please you with their tongues while their hearts are averse to you, and most of them are wicked.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They have sold the revelations of Allah for a paltry price and have firmly hindered people from His Path. Evil indeed is what they have done.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mccxlv{%
They neither have any respect for kinship nor for agreement in respect of the believers. Such are indeed transgressors.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
But if they repent and establish Prayer and give Zakah they are your brothers in faith. Thus do We expound Our revelations to those who know.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
But if they break their pledges after making them and attack your faith, make war on the leaders of unbelief that they may desist, for they have no regard for their pledged words.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will you not fight against those who broke their pledges and did all they could to drive the Messenger away and initiated hostilities against you? Do you fear them? Surely Allah has greater right that you should fear Him, if you are true believers.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Make war on them. Allah will chastise them through you and will humiliate them. He will grant you victory over them, and will soothe the bosoms of those who believe,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mccl{%
and will remove rage from their hearts, and will enable whomsoever He wills to repent. Allah is All-Knowing, All-Wise.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mccli{%
Do you imagine that you will be spared without being subjected to any test? Know well that Allah has not yet determined who strove hard (in His cause), and has not taken any others instead of His Messenger and the believers as his trusted allies? Allah is well aware of all that you do.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcclii{%
It does not become those who associate others with Allah in His Divinity to visit and tend Allah's mosques while they bear witness of unbelief against themselves. All their works have gone to waste. They shall abide in the Fire.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mccliii{%
It only becomes those who believe in Allah and the Last Day and establish Prayer and pay Zakah and fear none but Allah to visit and tend the mosques of Allah. These are likely to be guided aright.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mccliv{%
Do you consider providing water to the Pilgrims and tending the Sacred Mosque equal in worth to believing in Allah and the Last Day and striving in the cause of Allah? The two are not equal with Allah. Allah does not direct the wrong-doing folk to the Right Way.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcclv{%
The higher rank with Allah is for those who believed and migrated and strove in His cause with their belongings and their persons. It is they who are triumphant.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord gives them glad tidings of mercy from Him and of His good pleasure. For them await Gardens of eternal bliss.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcclvii{%
Therein they shall abide forever. Surely with Allah a mighty reward awaits them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcclviii{%
Believers, do not take your fathers and your brothers for your allies if they choose unbelief in preference to belief. Whosoever of you takes them as allies those are wrong-doers.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcclix{%
Tell them, (O Prophet): ``If your fathers and your sons and your brothers and your wives and your tribe and the riches you have acquired and the commerce of which you fear a slackening, and the dwellings that you love, if they are dearer to you than Allah and His Messenger and striving in His cause, then wait until Allah brings about His decree. Allah does not guide the evil-doing folk."\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcclx{%
Surely Allah has succoured you before on many a battlefield, and (you have yourselves witnessed His succour to you) on the day of Hunayn when your numbers made you proud, but they did you no good, and the earth, for all its vastness, constrained you, and you turned your backs in retreat.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then Allah caused His tranquillity to descend upon His Messenger and upon the believers, and He sent down hosts whom you did not see, and chastised those who disbelieved. Such is the recompense of those who deny the Truth.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Then (after so chastising the unbelievers), Allah enables, whomsoever He wills, to repent. Allah is All-Forgiving, All-Merciful.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
Believers, those who associate others with Allah in His Divinity are unclean. So, after the expiry of this year, let them not even go near the Sacred Mosque. And should you fear poverty, Allah will enrich you out of His bounty, if He wills. Surely Allah is All-Knowing, All-Wise.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Those who do not believe in Allah and the Last Day - even though they were given the scriptures, and who do not hold as unlawful that which Allah and His Messenger have declared to be unlawful, and who do not follow the true religion - fight against them until they pay tribute out of their hand and are utterly subdued.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcclxv{%
The Jews say: ``Ezra ('Uzayr) is Allah's son," and the Christians say: ``The Messiah is the son of Allah." These are merely verbal assertions in imitation of the sayings of those unbelievers who preceded them. May Allah ruin them. How do they turn away from the Truth?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They take their rabbis and their monks for their lords apart from Allah, and also the Messiah, son of Mary, whereas they were commanded to worship none but the One True God. There is no god but He. Exalted be He above those whom they associate with Him in His Divinity.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
They seek to extinguish the light of Allah by blowing through their mouths; but Allah refuses everything except that He will perfect His light howsoever the unbelievers might abhor it.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
He it is Who has sent His Messenger with the guidance and the True Religion that He may make it prevail over all religions, howsoever those who associate others with Allah in His Divinity might detest it.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcclxix{%
Believers! Many of the rabbis and monks wrongfully devour mankind's possessions and hinder people from the Way of Allah. And there are those who amass gold and silver and do not spend it in the Way of Allah. Announce to them the tidings of a painful chastisement\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcclxx{%
on a Day when they shall be heated up in the Fire of Hell, and their foreheads and their sides and their backs shall be branded with it, (and they shall be told): ``This is the treasure which you hoarded for yourselves. Taste, then, the punishment for what you have hoarded."\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
Surely the reckoning of months, in the sight of Allah, is twelve months, laid down in Allah's decree on the day when He created the heavens and the earth; and out of these months four are sacred. That is the true ordainment. Do not, therefore, wrong yourselves, with respect to these months. And fight all together against those who associate others with Allah in His Divinity in the manner that they fight against you all together, and know well that Allah is with the God-fearing.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
The intercalation (of sacred months) is an act of gross infidelity which causes the unbelievers to be led further astray. They declare a month to be lawful in one year and forbidden in another year in order that they may conform to the number of months that Allah has declared as sacred, and at the same time make lawful what Allah has forbidden. Their foul acts seem fair to them. Allah does not direct those who deny the Truth to the Right Way.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
Believers! What is amiss with you that when it is said to you: ``March forth in the cause of Allah," you cling heavily to the earth? Do you prefer the worldly life to the Hereafter? Know well that all the enjoyment of this world, in comparison with the Hereafter, is trivial.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If you do not march forth, Allah will chastise you grievously and will replace you by another people, while you will in no way be able to harm Him. Allah has power over everything.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
It will matter little if you do not help the Prophet, for Allah surely helped him when the unbelievers drove him out of his home and he was but one of the two when they were in the cave, and when he said to his companion: ``Do not grieve. Allah is with us." Then Allah caused His tranquillity to descend upon him, and supported him with hosts you did not see, He humbled the word of the unbelievers. As for Allah's Word, it is inherently uppermost. Allah is All-Powerful, All-Wise.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
March forth whether light or heavy, and strive in the way of Allah with your belongings and your lives. That is best for you if you only knew it.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Were it a gain at hand or a short journey, they would have surely followed you, but the distance seemed too far to them. Still they will swear by Allah: ``If only we could, we would surely have gone forth with you." They merely bring ruin upon themselves. Allah knows well that they are liars.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
(O Prophet), may Allah forgive you! Why did you give them leave to stay behind before it became clear to you as to who were truthful and who were liars?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in Allah and the Last Day will never ask your leave to be excused from striving (in the cause of Allah) with their belongings and their lives. Allah fully knows the God-fearing.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
It is only those who do not believe in Allah and the Last Day, and whose hearts are filled with doubt that seek exemption from striving (in the cause of Allah). They keep tossing to and fro in their doubt.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
Had they truly intended to march forth to fight, they would have certainly made some preparation for it. But Allah was averse to their going forth, so He made them lag behind, and they were told: ``Stay behind with those that are staying behind."\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they gone forth with you, they would have only added to your trouble, and would have run about in your midst seeking to stir up sedition among you, whereas there are among you some who are prone to lend ears to them. Allah knows well the wrong-doers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
Surely they sought even earlier to stir up sedition, and turned things upside down to frustrate you until the Truth came and the decree of Allah appeared, however hateful this may have been to them.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
And among them is he who says: ``Grant me leave to stay behind, and do not expose me to temptation." Lo! They have already fallen into temptation. Surely Hell encompasses the unbelievers.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good fortune befalls you, it vexes them; and if an affliction befalls you, they turn away in jubilation and say: ``We have taken due care of our affairs in good time."\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say: ``Nothing will befall us except what Allah has decreed for us; He is our Protector." Let the believers, then, put all their trust in Allah.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Tell them: ``What you await to befall upon us is nothing but one of the two good things! And what we await for you is that Allah visit you with chastisement from Him or chastise you at our hands. So continue waiting; we too shall wait with you."\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Tell them: ``Whether you spend your money willingly or unwillingly, it shall not find acceptance (with Allah) for you are an evil-doing folk."\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
Nothing prevents that their expendings be accepted except that they disbelieve in Allah and His Messenger, and whenever they come to the Prayer they do so lazily, and whenever they spend they do so grudgingly.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mccxc{%
Let neither their riches nor their children excite your admiration. Allah only wants to chastise them through these things in the present life, and to cause them to die while they are unbelievers.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mccxci{%
They swear by Allah that they are part of you whereas they are certainly not part of you. They are merely a people who dread you.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mccxcii{%
If they could find any shelter or any cavern, or any retreat, they would turn around and rush headlong into it.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mccxciii{%
(O Prophet), some of them find fault with you in the distribution of alms. If they are given something of it they are pleased, and if they are given nothing they are angry.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mccxciv{%
Would that they were content with what Allah and His Messenger gave them, and were to say: ``Allah suffices for us, and Allah will give us out of His bounty and so will His Messenger. It is to Allah alone that we turn with hope."\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mccxcv{%
The alms are meant only for the poor and the needy and those who are in charge thereof, those whose hearts are to be reconciled, and to free those in bondage, and to help those burdened with debt, and for expenditure in the Way of Allah and for the wayfarer. This is an obligation from Allah. Allah is All-Knowing, All-Wise.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And of them there are some who distress the Prophet, saying: ``He is all ears." Tell them: ``He listens for your good. He believes in Allah and trusts the believers, and is a mercy for those of you who believe. A painful punishment lies in store for those who cause distress to the Messenger of Allah."\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear by Allah to please you, while it is Allah and His Messenger whose pleasure they should seek if they truly believe.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Are they not aware that Hell Fire awaits whosoever opposes Allah and His Messenger, and in it he shall abide? That surely is the great humiliation.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites are afraid lest a surah should be revealed concerning them intimating to the believers what lay hidden in their hearts. Tell them (O Prophet): ``Continue your mockery if you will. Allah will surely bring to light all that whose disclosure you dread."\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mccc{%
Should you question them what they were talking about, they would certainly say: ``We were merely jesting and being playful." Tell them: ``Was it Allah and His revelation and His Messenger that you were mocking?"\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mccci{%
Now, make no excuses. The truth is, you have fallen into unbelief after having believed. Even if We were to forgive some of you, We will surely chastise others because they are guilty.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocrites, be they men or women, are all alike. They enjoin what is evil, and forbid what is good, and withhold their hands from doing good. They forgot Allah, so Allah also forgot them. Surely the hypocrites are wicked.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah has promised Hell-Fire to the hypocrites, both men and women, and to the unbelievers. They shall abide in it: a sufficient recompense for them. Allah has cursed them, and theirs is a lasting torment.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mccciv{%
Your ways are like the ways of those who have gone before you. They were mightier than you in power, and more abundant in riches and children. They enjoyed their lot for a while as you have enjoyed your lot, and you also engaged in idle talk as they did. Their works have come to naught in this world, and in the Hereafter they are surely the losers.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcccv{%
Have they not heard the accounts of those who came before them - of the people of Noah and 'Ad and Thamud, and the people of Abraham and the dwellers of Madyan (Midian), and the cities that were overturned? Their Messengers came to them with Clear Signs. Then, it was not Allah Who caused them any wrong; they rather wronged themselves.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcccvi{%
The believers, both men and women, are allies of one another. They enjoin good, forbid evil, establish Prayer, pay Zakah, and obey Allah and His Messenger. Surely Allah will show mercy to them. Allah is All-Mighty, All-Wise.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah has promised the believing men and believing women Gardens beneath which rivers flow. They shall abide in it. There are delightful dwelling places for them in the Gardens of Eternity. They shall, above all, enjoy the good pleasure of Allah. That is the great achievement.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet! Strive against the unbelievers and the hypocrites, and be severe to them. Hell shall be their abode; what an evil destination!\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by Allah that they said nothing blasphemous whereas they indeed blasphemed, and fell into unbelief after believing, and also had evil designs which they could not carry into effect. They are spiteful against Muslims for no other reason than that Allah and His Messenger have enriched them through His bounty! So, if they repent, it will be to their own good. But if they turn away, Allah will sternly punish them in this world and in the Hereafter. None in the world will be able to protect or help them.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcccx{%
Some of them made a covenant with Allah: ``If Allah gives us out of His bounty, we will give alms and act righteously."\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcccxi{%
Then, when He gave them out of His bounty, they grew niggardly and turned their backs (upon their covenant).\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So He caused hypocrisy to take root in their hearts and to remain therein until the Day they meet Him because they broke their promise with Allah and because they lied.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Are they not aware that Allah knows what they conceal and what they secretly discuss, and that Allah has full knowledge even of all that is beyond the reach of perception.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
He also knows (the rich that are niggardly) who taunt the believers that voluntarily give alms, they scoff at those who have nothing to give except what they earn through their hard toil. Allah scoffs at them in return. A grievous chastisement awaits them.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcccxv{%
(O Prophet), it is all the same whether or not you ask for their forgiveness. Even if you were to ask forgiveness for them seventy times, Allah shall not forgive them. That is because they disbelieved in Allah and His Messenger; and Allah does not bestow His Guidance on such evil-doing folk.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who were allowed to stay behind rejoiced at remaining behind and not accompanying the Messenger of Allah. They were averse to striving in the Way of Allah with their belongings and their lives and told others: ``Do not go forth in this fierce heat." Tell them: ``The Hell is far fiercer in heat." Would that they understand!\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
Let them, then, laugh little, and weep much at the contemplation of the punishment for the evil they have committed.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
Then if Allah brings you face to face with a party of them, and they ask your leave to go forth (to fight in the Way of Allah), tell them: ``You shall not go forth with me, and shall never fight against any enemy along with me. You were well-pleased to remain at home the first time, so now continue to remain with those who have stayed behind."\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcccxix{%
Do not ever pray over any of them who dies, nor stand over his grave. They disbelieved in Allah and His Messenger and died in iniquity.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcccxx{%
Let not their riches or their children excite your admiration. Through these Allah seeks to chastise them in this world, and that their lives will depart them while they are unbelievers.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
And whenever any surah is revealed enjoining: ``Believe in Allah and strive (in His Way) along with His Messenger," the affluent among them ask you to excuse them, saying: ``Leave us with those who will sit back at home."\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They were content to stay behind with the womenfolk. Their hearts were sealed, leaving them bereft of understanding.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the Messenger and those who shared his faith strove with their belongings and their lives. It is they who shall have all kinds of good. It is they who shall prosper.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
Allah has prepared for them Gardens beneath which rivers flow. There shall they abide. That is the supreme triumph.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
Many of the bedouin Arabs came with excuses, seeking leave to stay behind. Thus those who were false to Allah and His Messenger in their covenant remained behind. A painful chastisement shall befall those of them that disbelieved.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is no blame on the weak nor on the sick nor on those who have nothing to enable them to join (the struggle in the Way of Allah) if they stay behind provided that they are sincere to Allah and to His Messenger. There is no cause for reproach against those who do good. Allah is All-Forgiving, Ever Merciful.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor can there be any cause for reproach against those who, when they came to you asking for mounts to go to the battlefront, and when you said that you had no mounts for them, they went back, their eyes overflowing with tears, grieving that they had no resources to enable them to take part in fighting.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
But there are grounds for reproach against those who seek leave to stay behind even though they are affluent. They are the ones who were content to be with the womenfolk who stay behind. Allah has set a seal on their hearts, leaving them bereft of understanding.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They will put up excuses before you when you return to them. Tell them: ``Make no excuses. We will not believe you. Allah has already informed us of the truth about you. Allah will observe your conduct, and so will His Messenger; then you will be brought back to Him Who knows alike what lies beyond perception and what lies in the range of perception and will let you know what you have done."\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
When you return to them they will surely swear to you in the name of Allah that you may leave them alone. So do leave them alone; they are unclean. Hell shall be their home, a recompense for what they did.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They will swear to you in order to please you. But even if you become pleased with them, Allah will not be pleased with such an evil-doing folk.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The bedouin Arabs surpass all in unbelief and hypocrisy and are most likely to be unaware of the limits prescribed by Allah in what He has revealed to His Messenger. Allah is All-Knowing, All-Wise.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
And among the bedouin Arabs there are such as regard whatever they spend (in the Way of Allah) as a fine and wait for some misfortune to befall you. May ill fortune befall them! Allah is All-Hearing, All-Knowing.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
And among the bedouin Arabs are those who believe in Allah and the Last Day, and regard their spending (in the Way of Allah) as a means of drawing near to Allah and of deserving the prayers of the Messenger. Indeed, this shall be a means of drawing near to Allah. Allah will surely admit them to His mercy. Allah is All-Forgiving, Ever Merciful.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
And of those who led the way - the first of the Emigrants (Muhajirun) and the Helpers (Ansar), and those who followed them in the best possible manner - Allah is well-pleased with them and they are well-pleased with Allah. He has prepared for them Gardens beneath which rivers flow; therein they will abide forever. That is the supreme triumph.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
As for the bedouin Arabs around you, some are hypocrites; and so are some of the people of Madinah who have become inured to hypocrisy. You do not know them, but We know them. We will inflict double chastisement on them, and then they shall be returned to an awesome suffering.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
There are others who have confessed their faults. They intermixed their good deeds with evil. It is likely that Allah will turn to them in mercy, for Allah is All- Forgiving, Ever Merciful.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
(O Prophet)! ``Take alms out of their riches and thereby cleanse them and bring about their growth (in righteousness), and pray for them. Indeed your prayer is a source of tranquillity for them." Allah is All-Hearing, All-Knowing.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Are they not aware that it is Allah Who accepts the repentance of His servants and accepts their alms, and that it is Allah Who is Oft-Relenting, Ever Merciful?\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mcccxl{%
And tell them, (O Prophet): ``Keep working: Allah will behold your works and so will His Messenger and the believers; and you shall be brought back to Him Who knows that which is beyond the reach of perception and that which is within the reach of perception. He will then declare to you all that you have been doing."\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mcccxli{%
There are others in whose regard Allah's decree is awaited: whether He will chastise them or relent towards them. Allah is All-Knowing, All-Wise.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
Then there are others who have set up a mosque to hurt the True Faith, to promote unbelief, and cause division among believers, and as an ambush for one who had earlier made war on Allah and His Messenger. They will surely swear: ``We intended nothing but good," whereas Allah bears witness that they are liars.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Never stand therein. Surely a mosque founded from the first day on piety is more worthy that you should stand in it for Prayer. In it are people who love to purify themselves, and Allah loves those that purify themselves.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Is he, then, who has erected his structure on the fear of Allah and His good pleasure better, or he who erects his structure on the brink of a crumbling bank, so that it crumbles down with him into the Hell-Fire? Allah does not bestow His Guidance on the wrong-doing folk.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
And the structure which they have erected will ever inspire their hearts with doubts unless it be that their very hearts are cut into pieces. Allah is All-Knowing, All-Wise.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Surely Allah has purchased of the believers their lives and their belongings and in return has promised that they shall have Paradise. They fight in the Way of Allah, and slay and are slain. Such is the promise He has made incumbent upon Himself in the Torah, and the Gospel, and the Qur'an. Who is more faithful to his promise than Allah? Rejoice, then, in the bargain you have made with Him. That indeed is the mighty triumph.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
Those who constantly turn to Allah in repentance, who constantly worship Him, who celebrate His praise, who go about the world to serve His cause, who bow down to Him, who prostrate themselves before Him, who enjoin what is good and forbid what is evil, and who keep the limits set by Allah. Announce glad tidings to such believers.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
After it has become clear that they are condemned to the Flaming Fire, it is not for the Prophet and those who believe to ask for the forgiveness of those who associate others with Allah in His Divinity even if they be near of kin.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
And Abraham's prayer for the forgiveness of his father was only because of a promise which he had made to him. Then, when it became clear to him that he was an enemy of Allah, he dissociated himself from him. Surely Abraham was most tender-hearted, God-fearing, forbearing.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mcccl{%
It is not Allah's way to cause people to stray in error after He has guided them until He has made clear to them what they should guard against. Surely Allah knows everything.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mcccli{%
Indeed Allah's is the Kingdom of the heavens and the earth. He it is Who confers life and causes death. You have no protector or helper apart from Allah.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mccclii{%
Surely Allah has relented towards the Prophet, and towards the Muhajirun (Emigrants) and the Ansar (Helpers) who stood by him in the hour of hardship, although the hearts of a party of them had well-nigh swerved. (But when they gave up swerving from the Right Course and followed the Prophet), Allah relented towards them. Surely to them He is the Most Tender, the Most Merciful.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And He also relented towards the three whose cases had been deferred. When the earth, for all its spaciousness, became constrained to them, and their own beings became a burden to them, and they realized that there was no refuge for them from Allah except in Him; He relented towards them that they may turn back to Him. Surely, it is Allah Who is Much Forgiving, Ever Merciful.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mcccliv{%
Believers! Have fear of Allah and stand with those that are truthful.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mccclv{%
It did not behove the people of Madinah and the bedouin Arabs around them that they should refrain from accompanying the Messenger of Allah and stay behind and prefer their own security to his. For whenever they suffer from thirst or weariness or hunger in the Way of Allah, and whenever they tread a place which enrages the unbelievers (whenever anything of this comes to pass), a good deed is recorded in their favour. Allah does not cause the work of the doers of good to go to waste.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Likewise, each amount they spend, be it small or large, and each journey they undertake, shall be recorded in their favour so that Allah may bestow upon them reward for their good deeds.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mccclvii{%
It was not necessary for the believers to go forth all together (to receive religious instruction), but why did not a party of them go forth that they may grow in religious understanding, and that they may warn their people when they return to them, so that they may avoid (erroneous attitudes)?\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mccclviii{%
Believers! Fight against the unbelievers who live around you; and let them find in you sternness. Know that Allah is with the God-fearing.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mccclix{%
And whenever a new surah is revealed some of the hypocrites ask the believers (in jest): ``Whose faith has increased because of this?" As for those who believe, it will certainly increase their faith, and they are joyful over that.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mccclx{%
But those whose hearts are affected with the disease (of hypocrisy), every new surah added a fresh abomination to their abomination. They remained unbelievers till their death.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mccclxi{%
Do they not see that they are tried every year once or twice? Yet they neither repent nor take heed.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever a surah is revealed, they glance at each other as though saying: ``Is anyone watching?" Then they slip away. Allah has turned away their hearts for they are a people who are bereft of understanding.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
There has come to you a Messenger of Allah from among yourselves, who is distressed by the losses you sustain, who is ardently desirous of your welfare and is tender and merciful to those that believe.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
Yet, if they should turn away, then tell them: ``Allah is sufficient for me; there is no god but He. In Him I have put my trust. He is the Lord of the Mighty Throne."\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif. Lam. Ra. These are the verses of the Book overflowing with wisdom.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Does it seem strange to people that We should have revealed to a man from among themselves, directing him to warn the people (who lie engrossed in heedlessness); and to give good news to the believers that they shall enjoy true honour and an exalted status with their Lord? (Is this so strange that) the deniers of the truth should say: 'This man is indeed an evident sorcerer'?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Surely your Lord is Allah, Who created the heavens and the earth in six days, then established Himself on the Throne (of His Dominion), governing all affairs of the universe. None may intercede with Him except after obtaining His leave. Such is Allah, your Lord; do therefore serve Him. Will you not take heed?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
To Him is your return. This is Allah's promise that will certainly come true. Surely it is He Who brings about the creation of all and He will repeat it so that He may justly reward those who believe and do righteous deeds; and that those who disbelieve may have a draught of boiling water and suffer a painful chastisement for their denying the truth.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mccclxix{%
He it is Who gave the sun radiance and the moon light, and determined the stages (for the waxing and waning of the moon) that you may learn the calculation of years and the reckoning of time. Allah has created all this with a rightful purpose (rather than out of play). He expounds His signs for the people who know.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mccclxx{%
Surely in the alternation of the night and the day and in all that Allah has created in the heavens and the earth there are signs for the people who seek to avoid (error of outlook and conduct).\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Surely those who do not expect to meet Us, who are gratified with the life of the world and content with it, and are heedless of Our signs,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
their abode shall be the Fire in return for their misdeeds,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Surely those who believe (in the truths revealed in the Book) and do righteous deeds their Lord will guide them aright because of their faith. Rivers shall flow beneath them in the Gardens of Bliss.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
Their cry in it will be: 'Glory be to You, Our Lord!', and their greeting: 'Peace!'; and their cry will always end with: 'All praise be to Allah, the Lord of the universe.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
Were Allah to hasten to bring upon men (the consequence of) evil in the way men hasten in seeking the wealth of this world, their term would have long since expired. (But that is not Our way.) So We leave alone those who do not expect to meet Us that they may blindly stumble in their transgression.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
And (such is man that) when an affliction befalls him, he cries out to Us, reclining and sitting and standing. But no sooner than We have removed his affliction, he passes on as though he had never cried out to Us to remove his affliction. Thus it is that the misdeeds of the transgressors are made fair-seeming to them.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
Surely We destroyed the nations (which had risen to heights of glory in their times) before you when they indulged in wrong-doing and refused to believe even when their Messengers brought clear signs to them. Thus do We recompense the people who are guilty.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Now We have appointed you as their successors in the earth to see how you act.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And whenever Our clear revelations are recited to them, those who do not expect to meet Us say: 'Bring us a Qur'an other than this one, or at least make changes in it. Tell them (O Muhammad): 'It is not for me to change it of my accord. I only follow what is revealed to me. Were I to disobey my Lord, I fear the chastisement of an Awesome Day.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Tell them: 'Had Allah so willed, I would not have recited the Qur'an to you, nor would Allah have informed you of it. I have spent a lifetime among you before this. Do you, then, not use your reason?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
Who, then, is a greater wrong-doer than he who forges a lie against Allah or rejects His signs as false? Surely the guilty shall not prosper.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
They worship, beside Allah, those who can neither harm nor profit them, saying; 'These are our intercessors with Allah.' Tell them (O Muhammad): 'Do you inform Allah of something regarding whose existence in the heavens or on the earth He has no knowledge? Holy is He and He is exalted far above what they associate with Him in His divinity'.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
Once all men were but a single community; then they disagreed (and formulated different beliefs and rites). Had it not been that your Lord had already so ordained, a decisive judgement would have been made regarding their disagreements.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
They say: 'Why was a sign not sent down upon the prophet from His Lord? Tell (such people): 'The realm of the Unseen belongs to Allah. Wait, then; I shall wait along with you.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
No sooner than We bestow mercy on a people after hardship has hit them than they begin to scheme against Our signs. Tell them: 'Allah is swifter in scheming. Our angels are recording all your intriguing.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
He it is Who enables you to journey through the land and the sea. And so it happens that when you have boarded the ships and they set sail with a favourable wind, and the passengers rejoice at the pleasant voyage, then suddenly a fierce gale appears, and wave upon wave surges upon them from every side, and people believe that they are surrounded from all directions, and all of them cry out to Allah in full sincerity of faith: 'If You deliver us from this we shall surely be thankful.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
But no sooner than He delivers them than they go about committing excesses on the earth, acting unjustly. Men! The excesses you commit will be of harm only to yourselves, (Enjoy, if you will) the fleeting pleasure of this world; in me end you shall all return to Us, and then We shall tell you what you did.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
The example of the life of this world (which has enamoured you into becoming heedless to Our signs) is that of water that We sent down from the heaven which causes the vegetation of the earth, which sustains men and cattle, to grow luxuriantly. But when the earth took on its golden raiment and became well adorned and the owners believed that they had full control over their lands Our command came upon them by night or by day, and We convened it into a stubble, as though it had not blossomed yesterday. Thus do We expound the signs for a people who reflect.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
(You are being lured by this ephemeral world) although Allah calls you to the abode of peace and guides whomsoever He wills to a straightway.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcccxc{%
For those who do good there is good reward and more besides; neither gloom nor humiliation shall cover their faces. They are the people of the Garden and in it they shall abide.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcccxci{%
Those who do evil deeds, the recompense of an evil deed is its like, and humiliation shall spread over them and there will be none to protect them from Allah. Darkness will cover their faces as though they were veiled with the dark blackness of night. These are the people of the Fire and in it they shall abide.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
And the Day when We shall muster them all together, We shall say to those who associated others with Allah in His divinity: 'Keep to your places - you and those whom you associated with Allah.' Then We shall remove the veil of foreignness separating them. Those whom they had associated with Allah will say. 'It was not us that you worshipped.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
Allah's witness suffices between you and us that (even if you worshipped us) we were totally unaware of your worshipping us.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
Thereupon everyone shall taste the recompense of his past deeds. All shall be sent back to Allah, their true Lord, and then all the falsehoods they had fabricated will have forsaken them.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Ask them: 'Who provides you with sustenance out of the heavens and the earth? Who holds mastery over your hearing and sight? Who brings forth the living from the dead and the dead from the living? Who governs all affairs of the universe?' They will surely say: 'Allah.' Tell them: 'Will you, then, not shun (going against reality)?"\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
Such, then, is Allah, your true Lord. And what is there after truth but error? How, then, are you being turned away?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
Thus the word of your Lord is fulfilled concerning the transgressors that they shall not believe.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Ask them: 'Is there any among those whom you associate with Allah in His divinity who brings about the creation of all beings in the first instance and will then repeat it?' Tell them: 'It is Allah Who brings about the creation of all beings and will then repeat it. How are you, then, being misled?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Ask them: 'Are there among ones whom you associate with Allah in His divinity those who can guide to the truth? Say: 'It is Allah alone Who guides to the truth.' Then, who is more worthy to be followed - He Who guides to the truth, or he who cannot find the right way unless others guide him to it? What is wrong with you? How ill do you judge!\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcd{%
Most of them only follow conjectures; and surely conjecture can be no substitute for truth. Allah is well aware of whatever they do.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcdi{%
And this Qur'an is such that it could not be composed by any unless it be revealed from Allah. It is a confirmation of the revelation made before it and a detailed exposition of the Book. Beyond doubt it is from the Lord of the universe.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcdii{%
Do they say that the Messenger has himself composed the Qur'an? Say: 'In that case bring forth just one surah like it and call on all whom you can, except Allah, to help you if you are truthful.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcdiii{%
In fact they arbitrarily rejected as false whatever they failed to comprehend and whose final sequel was not apparent to them. Likewise had their predecessors rejected the truth, declaring it falsehood. Do observe, then, what was the end of the wrong-doers.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcdiv{%
Of those some will believe and others will not. Your Lord knows best the mischief-makers.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcdv{%
And if they reject you as false, tell them: 'My deeds are for myself and your deeds for yourselves. You will not be held responsible for my deeds, nor I for your deeds.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcdvi{%
Of them some seem to give heed to you; will you, then, make the deaf hear even though they understand nothing?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And of them some look towards you; will you, then, guide the blind, even though they can see nothing?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Surely Allah does not wrong men; they rather wrong themselves.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcdix{%
(But today they are oblivious of everything except enjoyment of worldly life.) And on the Day when He will muster all men together, they will feel as though they had been in the world no more than an hour of the day to get acquainted with one another. (It will then become evident that) those who called the lie to meeting with Allah were utter losers and were not rightly-directed. underlies this sharp remark is the faint hope that perhaps such people would be shaken out of their slumber.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcdx{%
Whether We let you see (during your lifetime) some of the chastisement with which We threaten them, or We call you unto Us (before the chastisement strikes them), in any case they are bound to return to Us. Allah is witness to all what they do.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcdxi{%
A Messenger is sent to every people; and when their Messenger comes, the fate of that people is decided with full justice; they are subjected to no wrong.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcdxii{%
They say:'If what you promise is true, when will this threat be fulfilled?'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Tell them: 'I have no power to harm or benefit even myself, except what Allah may will. There is an appointed term for every people; and when the end of their term comes, neither can they put it off for an hour, nor can they bring it an hour before.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Tell them: 'Did you consider (what you would do) were His chastisement to fall upon you suddenly by night or by day? So why are the culprits seeking to hasten its coming?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcdxv{%
Is it only when this chastisement has actually overtaken you that you will believe in it? (And when the chastisement will surprise you), you will try to get away from it, although it is you who had sought to hasten its coming.'\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
The wrong-doers will then be told: 'Suffer now the abiding chastisement. How else can you be rewarded except according to your deeds?'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
They ask you if what you say is true? Tell them: 'Yes, by my Lord, this is altogether true, and you have no power to prevent the chastisement from befalling.'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
If a wrong-doer had all that is in the earth he would surely offer it to ransom himself. When the wrong-doers perceive the chastisement, they will feel intense remorse in their hearts. But a judgement shall be made with full justice about them. They shall not be wronged.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Indeed all that is in the heavens and the earth belongs to Allah. And most certainly Allah's promise will be fulfilled, though most men are not aware.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mcdxx{%
He it is Who gives life and causes death, and to Him shall you all be returned.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
Men! Now there has come to you an exhortation from your Lord, a healing for the ailments of the hearts, and a guidance and mercy for those who believe.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Tell them (O Prophet!): 'Let them rejoice in Allah's grace and mercy through which this (Book) has come to you. It is better than all the riches that they accumulate.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Did you consider that the sustenance which Allah had sent down for you of your own accord you have declared some of it as unlawful and some as lawful? Ask them: 'Did Allah bestow upon you any authority for this or do you forge lies against Allah?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
Think how those who invent lies against Him will be treated on, the Day of Judgement? Allah is bountiful to men yet most of them do not give thanks.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
(O Prophet!) Whatever you may be engaged in, whether you recite any portion of the Qur'an, or whatever else all of you are doing, We are witnesses to whatever you may be occupied with. Not even an atom's weight escapes your Lord on the earth or in the heaven, nor is there anything smaller or bigger than that, except that it is on record in a Clear Book.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Oh, surely the friends of Allah have nothing to fear, nor shall they grieve -\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
the ones who believe and are God-fearing.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
For them are glad tidings in this world and in the Hereafter. The words of Allah shall not change. That is the supreme triumph.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
(O Prophet!) Let not the utterances of the opponents distress you. Indeed all honour is Allah's. He is All-Hearing, All-Knowing.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Verily whoever dwells in the heavens or the earth belongs to Allah. Those who invoke others beside Allah, associating them with Him in His divinity, only follow conjectures and are merely guessing.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
It is Allah alone Who has made the night that you may rest in it, and has made the day light-giving. Surely in that there are signs for those who give heed (to the call of the Messenger).\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They say: 'Allah has taken a son. Glory be to Him. He is self-sufficient! His is all that is in the heavens and all that is in the earth. Have you any authority to support (that Allah has taken a son)? Do you ascribe to Allah something of which you have no knowledge?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Tell them (O Muhammad!): 'Indeed those who invent lies against Allah will never prosper.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
They may enjoy the life of this world, but in the end they must return to Us, and then We shall cause them to taste severe chastisement for their disbelieving.'\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
And narrate to them the story of Noah when he said to his people: 'My people! If my living in your midst and my effort to shake you out of heedlessness by reciting to you the revelations of Allah offend you, then remember that I have put all my trust in Allah. So draw up your plan in concert with those whom you associate with Allah in His divinity, leaving no part of it obscure, and then put it into effect against me, and give me no respite.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
When you turned your back on my admonition (what harm did you cause me?) I had asked of you no reward, for my reward lies only with Allah, and I am commanded to be of those who totally submit (to Allah)\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
But they rejected Noah, calling him a liar. So We saved him and those who were with him in the Ark, and made them successors (to the authority in the land), and drowned all those who had rejected Our signs as false. Consider, then, the fate of those who had been warned (and still did not believe).\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then We sent forth after him other Messengers, each one to his people. They brought to them clear signs, but they were not such as to believe in what they had rejected earlier as false. Thus do We seal the hearts of those who transgress.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then, after them, We sent forth Moses and Aaron to Pharaoh and his chiefs with Our signs, but they waxed proud. They were a wickd people.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcdxl{%
And when truth came to them from Us, they said: 'Indeed this is plain sorcery.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Moses said: 'Do you say this about the truth after it has come to you? Is this sorcery? You call this sorcery although sorcerers never come to a happy end.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They replied: 'Have you come to turn us away from the way of our forefathers that the two of you might become supreme in the land? We shall never accept what the two of you say.'\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
And Pharaoh said (to his) men: 'Bring every skilled sorcerer to me.'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
And when the sorcerers came Moses said to them: 'Cast whatever you wish to cast.'\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
Then when they had cast (their staffs), Moses said: 'What you have produced is sheer sorcery. Allah will certainly reduce it to naught. Surely Allah does not set right the work of the mischief-makers.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
Allah vindicates the truth by His commands, howsoever much the guilty might detest that.'\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
None but a few youths of Moses' people accepted him, fearing that Pharaoh and their own chiefs would persecute them. Indeed Pharaoh was mighty in the land, he was among those who exceed all limits.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
Moses said: 'My people! If you believe in Allah and are truly Muslims then place your reliance on Him alone.'\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They replied: 'We place our reliance on Allah. Our Lord! Do not make us a trial for the oppressors,\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcdl{%
and deliver us, through Your mercy, from the unbelievers.'\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We directed Moses and his brother: 'Prepare a few houses for your people in Egypt, and make your houses a direction for men to pray, and establish Prayer, and give glad tidings to the men of faith.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcdlii{%
Moses prayed: 'Our Lord! You bestowed upon Pharaoh and his nobles splendour and riches in the world. Our Lord! Have You done this that they may lead people astray from Your path? Our Lord! Obliterate their riches and harden their hearts that they may not believe until they observe the painful chastisement.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcdliii{%
Allah responded: 'The prayer of the two of you is accepted. So keep steadfast, and do not follow the path of the ignorant.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We led the Children of Israel across the sea. Then Pharaoh and his hosts pursued them in iniquity and transgression until Pharaoh cried out while he was drowning: 'I believe that there is no god but Allah in Whom the Children of Israel believe, and I am also one of those who submit to Allah.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcdlv{%
(Thereupon came the response): 'Now you believe, although you disobeyed earlier and were one of the mischief-makers.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
We shall now save your corpse that you may serve as a sign of warning for all posterity, although many men are heedless of Our signs.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
We settled the Children of Israel in a blessed land, and provided them with all manner of good things. They only disagreed among themselves after knowledge (of the truth had) come to them. Surely your Lord will judge between them on the Day of Resurrection concerning their disagreements.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
Now, if you are in doubt concerning what We have revealed to you, then ask those who have been reading the Book before you. It is the truth that has come to you from your Lord, so do never become one of those who doubt,\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcdlix{%
or reject the signs of Allah as false, for then you shall be among those who will be in utter loss.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Surely those against whom the word of your Lord has been fulfilled will not believed\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
even if they witness every single sign that might come to them until they are face to face with the painful chastisement,\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
Did it ever happen that the people of a town believed on seeing God's chastisement and its believing profited them? (There is no such instance) except of the people of Yunus. When they believed We granted them reprieve from humiliating chastisement in this world, and We let them enjoy themselves for a while.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
Had your Lord so willed, all those who are on the earth would have believed. Will you, then, force people into believing?\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
No one can believe except by Allah's leave, and Allah lays abomination on those who do not use their understanding. and conduct.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Tell them: 'Observe carefully all that is in the heavens and the earth.' But no signs and warnings can avail those who are bent on not believing.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
What are they waiting for except to witness the repetition of the days of calamity that their predecessors witnessed? Tell them: 'Wait; I too am waiting with you.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then, (when Allah's wrath falls upon the wicked) We save our Messengers and also those who believe. It is incumbent on Us to deliver the believers.' set fire to the whole city and its environs. The Assyrian king set his own palace ablaze and was himself burnt to death.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
(O Prophet!) Tell them: 'Men! If you are still in doubt concerning my religion, know that I do not serve those whom you serve beside Allah. I only serve Allah Who will cause (all of) you to die. I have been commanded to be one of those who believe,\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
and to adhere exclusively and sincerely to the true faith, and not to be one of those who associate others with Allah in His divinity.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
Do not call upon any apart from Allah on those who have no power to benefit or hurt you. For if you call upon others than Allah you will be reckoned among the wrong-doers.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
If Allah afflicts you with any hardship, none other than He can remove it; and if He wills any good for you, none can avert His bounty. He bestows good upon whomsoever of His servants He wills. He is AllForgiving, All-Merciful.'\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Tell them (O Muhammad): 'Men! Truth has come to you from your Lord. Whosoever, then, follows the true guidance does so for his own good; and whosoever strays, his straying will be to his own hurt. I am no custodian over you.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And follow, (O Prophet!), whatever is revealed to you, and remain patient until Allah brings forth His judgement. He is the best of those who judge.'\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif. Lam. Ra. This is a Divine Command whose contents have been made firm and set forth in detail from One Who is All-Wise, All-Aware\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
that you may worship none but Allah. Verily, I have come to you as a warner and a bearer of good news from Him\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
that you may seek forgiveness of your Lord and turn to Him in repentance whereupon He will grant you a fair enjoyment of life until an appointed term, and will bestow favour on everyone who merits favour. But should you turn away (from the truth), I fear for you the chastisement of an Awesome Day.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
Unto Allah is your return, and He has power to do everything.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
Lo! They fold up their breasts that they may conceal themselves from Him. Surely when they cover themselves up with their garments Allah knows well what they cover and what they reveal. Indeed He even knows the secrets hidden in the breasts.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
There is not a single moving creature on the earth but Allah is responsible for providing its sustenance. He knows where it dwells and where it will permanently rest. All this is recorded in a clear Book.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
And He it is Who created the heavens and the earth in six days - and [before that] His Throne was upon the water that He may test you, who of you is better in conduct If you were to say (O Muhammad): 'All of you will surely be raised after death', then those who disbelieve will certainly say: 'This is nothing but plain sorcery.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And were We to put off the chastisement from them for a determined period, they will cry out: 'What withholds Him from chastising?' Surely when the day of the chastisement will come, nothing will avert it and the chastisement which they had ridiculed shall encompass them.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
If We ever favour man with Our Mercy, and then take it away from him, he becomes utterly desperate, totally ungrateful.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
And if We let him taste favour after harm has touched him, he says: 'All my ills are gone', and he suddenly becomes exultant and boastful,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
except those who are patient and act righteously. Such shall have Allah's forgiveness and a great reward.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
(O Messenger!) Let it not happen that you omit (to expound) a portion of what was revealed to you. And do not be distressed that they will say: 'Why was a treasure not bestowed upon him?' or 'Why did no angel accompany him?' For you are merely a warner, whereas Allah has control over everything.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Do they say: 'He has invented this Book himself?' Say: 'If that is so, bring ten surahs the like of it of your composition, and call upon all (the deities) you can other than Allah to your help. Do so if you are truthful.'\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
Then if (your deities) do not respond to your call for help then feel assured that this Book was revealed with the knowledge of Allah, and that there is no true god but Him. Will you, then, surrender (to this truth)?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Those who seek merely the present world and its adornment. We fully recompense them for their work in this world, and they are made to suffer no diminution in it concerning what is their due.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
They are the ones who shall have nothing in the Hereafter except Fire. (There they shall come to know) that their deeds in the world have come to naught; and that whatever they have done is absolutely useless.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcdxc{%
Can it happen that he who takes his stand on a clear evidence from his Lord, subsequently followed by a witness from Him (in his support), and prior to that the Book of Moses was revealed as a guide and a mercy, (would even he deny the truth in the manner of those who adore the life of this world)? Rather, such men are bound to believe in it. The Fire shall be the promised resort of the groups that disbelieve. So be in no doubt about it for this indeed is the truth from your Lord although most people do not believe.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mcdxci{%
And who is a greater wrong-doer than he who invents a lie against Allah? Such men will be set forth before their Lord and witnesses will say: 'These are the ones who lied against their Lord. Lo! Allah's curse be upon the wrong-doers;\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
upon those who bar people from the way of Allah, and seek in it crookedness, and disbelieve in the Hereafter.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
They had no power to frustrate Allah's design in the earth, nor did they have any protectors against Allah. Their chastisement will be doubled. They were unable to hear, nor could they see.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
They caused utter loss to themselves, and all that they had invented failed them.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
Doubtlessly, they shall be the greatest losers in the Hereafter.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
As for those who believed and acted righteously and dedicated themselves totally to their Lord -they are the people of Paradise, and there they shall abide forever.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The example of the two parties is that one is blind and deaf, and the other capable of seeing and hearing. Can the two be equals? Will you, then, not heed?'\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
(Such were the circumstances) when We sent forth Noah to his people. (He said): 'I have been sent to you to warn you plainly\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
that you may worship none but Allah or else I fear for you the chastisement of a Grievous Day.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@md{%
The notables among Noah's own people, who had refused to follow him, responded: 'We merely consider you a human being like ourselves. Nor do we find among those who follow you except the lowliest of our folk, the men who follow you without any proper reason. We see nothing in you to suggest that you are any better than us. Rather, we believe you to be liars.'\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdi{%
Noah said: 'My people! If I base myself on a clear evidence from my Lord, and I have also been blessed by His mercy to which you have been blind, how can we force it upon you despite your aversion to it?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdii{%
My people! I seek no recompense from you. My recompense is only with Allah. Nor will I drive away those who believe. They are destined to meet their Lord. But I find you to be an ignorant people.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdiii{%
My people! Were I to drive the men of faith away, who will protect me from (the chastisement of) Allah? Do you not understand even this much?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdiv{%
I do not say to you that I possess Allah's treasures, nor that I have access to the realm beyond the ken of sense-perception, nor do I claim to be an angel. Nor do I say regarding those whom you look upon with disdain that Allah will not bestow any good upon them. Allah knows best what is in their hearts. Were I to say so I would be one of the wrongdoers.'\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdv{%
They said: 'O Noah! Surely you have disputed with us and have prolonged your dispute. Now bring upon us the chastisement that you threaten us with; do so, if you are truthful.'\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdvi{%
Noah said: 'Only Allah will bring it upon you if He so wills, and you will be utterly unable to frustrate that.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdvii{%
If I want to give you good advice that will not profit you if Allah Himself has decided to let you go astray. He is your Lord, and to Him will you be returned.'\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdviii{%
(O Muhammad!) Do they say that he himself has forged this message? Tell them: 'If I have forged this, the guilt of it will fall upon me, but I am not responsible for the crimes you are committing.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdix{%
It was revealed to Noah that no more of your people, other than those who already believe, will ever come to believe. So do not grieve over their deeds,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdx{%
and build the Ark under Our eyes and Our direction. And do not supplicate Me concerning those who have engaged in wrong-doing. They are doomed to be drowned.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdxi{%
As Noah was building the Ark, whenever the leading men of his nation passed by him, they would scoff at him. He said: 'If you scoff at us, we too scoff at you in like manner.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdxii{%
You will come to know who will be struck by a humiliating chastisement, and who will be subjected to an unceasing torment.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdxiii{%
Thus it was until Our command came to pass and the oven boiled over. We said: 'Take into the Ark a pair of every species; and take your own family except those who have already been declared (as unworthy); and also take everyone who believes. But those who, along with him, had believed were indeed just a few.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdxiv{%
Noah said: ' Embark in it. In the name of Allah is its sailing and its anchorage. My Lord is Ever Forgiving, Most Merciful.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdxv{%
The Ark sailed along with them amid mountain-like waves. Noah, spotting his son at a distance, called out to him: 'My son. embark with us. and do not be with the unbelievers.'\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdxvi{%
The son replied: 'I will go to a mountain for refuge and it will save me from the water.' Noah said: 'None can save anyone today from the command of Allah except those on whom He may have mercy.' Thereupon a wave swept in between the two and he was drowned.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And the command was given: 'Earth! Swallow up your water'; and: 'Heaven! Abate!' So the water subsided, the command was fulfilled, and the Ark settled on Mount Judi, and it was said: 'Away with the wrong-doing folk!'\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Noah called out to his Lord, saying: 'My Lord! My son is of my family. Surely Your promise is true, and You are the greatest of those who judge.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdxix{%
In response Noah was told: 'Most certainly he is not of your family; verily he is of unrighteous conduct. So do not ask of Me for that concerning which you have no knowledge. I admonish you never to act like the ignorant ones.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdxx{%
Noah said: 'My Lord! I take refuge with You that I should ask you for that concerning which I have no knowledge. And if You do not forgive me and do not show mercy to me, I shall be among the losers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said: 'Noah! Disembark, with Our peace, and with blessings upon you and upon those who are with you. There are also people whom We shall allow to enjoy themselves for a while, and then a painful chastisement from Us shall afflict them.'\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdxxii{%
We reveal to you these accounts of matters that are beyond the reach of human perception. Neither you nor your people knew about them before this. Be, then, patient. Surely, the good end is for the God-fearing.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And to 'Ad We sent their brother Hud. He said: 'My people! Serve Allah: you have no god save Him. (In attributing partners to Allah) you have merely been fabricating lies.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
My people! I seek no reward from you for my work. My reward lies only with Him Who created me. Do you not understand anything?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdxxv{%
My people! Ask your Lord for forgiveness and turn to Him in repentance. He will shower abundant rains upon you from the heaven, and will add strength to your strength. Do not turn away as those given to guilt.'\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said: 'O Hud! You have not brought to us any clear evidence, and we are not going to forsake our gods merely because you say so. We are not going to believe you.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
All we can say is that some god of ours has afflicted you with evil.. Hud said: 'Indeed I take Allah as my witness, and you too to be my witnesses that I have nothing to do with your associating with Allah\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
others than Him in His divinity. So conspire against me, all of you, and give me no respite.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdxxix{%
I have put my trust in Allah, Who is my Lord and your Lord. There is no moving creature which He does not hold by its forelock. Surely, My Lord is on the straight path.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdxxx{%
If you, then, turn away (from the truth), know that I have delivered the message with which I was sent to you. Now my Lord will set up another people in place of you and you shall in no way be able to harm Him. Surely my Lord keeps a watch over everything.'\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our com-mand came to pass, We delivered Hud, together with those who shared his faith, out of special mercy from Us. We delivered them from a woeful chastisement.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
Such were 'Ad. They repudiated the signs of their Lord, disobeyed His Messengers, and followed the bidding of every tyrannical enemy of the truth.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
They were pursued by a curse in this world, and so will they be on the Day of Judgement. Lo! 'Ad disbelieved in the Lord. Lo! ruined are 'Ad, the people of Hud.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And to Thamud We sent their brother Sali'h. He said: 'My people! Serve Allah; you have no god other than Him. He brought you into being out of the earth, and has made you dwell in it. So ask Him to forgive you, and do turn towards Him in repentance. Indeed My Lord is near, responsive to prayers.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said: 'O Salih! Until now you were one of those among us on whom we placed great hopes. Now, would you forbid us to worship what our forefathers were wont to worship? Indeed we are in disquieting doubt about what you are calling us to.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
Salih said: 'My people! What do you think? If I had a clear evidence from my Lord, and then He also bestowed His mercy upon me, who will rescue me from the punishment of Allah if I still disobey Him? You can only make me lose even more.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
My people! This she-camel of Allah is a sign for you. So let her pasture on Allah's earth, and do not hurt her or else some chastisement - which is near at hand -should overtake you.'\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
But they slaughtered her. Thereupon Salih warned them: 'Enjoy yourselves in your homes for a maximum of three days. This is a promise which shall not be belied.'\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
Then, when Our command came to pass, We saved Salih and those who shared his faith through Our special mercy, from the disgrace of that day. Truly Your Lord is All-Strong, All-Mighty.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdxl{%
And the Blast overtook those who were wont to do wrong, and then they lay lifeless in their homes\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdxli{%
as though they had never lived there before. Oh, verily the Thamud denied their Lord! Oh, the Thamud were destroyed.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdxlii{%
Indeed Our messengers came to Abraham, bearing glad tidings. They greeted him with 'peace', and Abraham answered back to them 'peace', and hurriedly brought to them a roasted calf.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdxliii{%
When he perceived that their hands could not reach it, he mistrusted them, and felt afraid of them. They said: 'Do not be afraid. We have been sent to the people of Lot.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And Abraham's wife was standing by and on hearing this she laughed. And We gave her the good news of (the birth of) Isaac, and after Isaac, of Jacob.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said: 'Woe is me! Shall I bear a child now that I am an old woman and my husband is well advanced in years. This is indeed strange!'\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said: 'Do you wonder at Allah's decree? Allah's mercy and His blessings be upon you, O people of the house. Surely, He is Praiseworthy, Glorious.'\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
Thus when fear had left Abraham and the good news had been conveyed to him, he began to dispute with Us concerning the people of Lot.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Surely Abraham was forbearing, tenderhearted and oft-turning to Allah.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdxlix{%
Thereupon (Our angels) said to him: 'O Abraham! Desist from this, for indeed your Lord's command has come; and a chastisement which cannot be averted is about to befall them.' words literally suggest; the purpose is merely to express a sense of wonder.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our messengers came to Lot, he was perturbed by their coming and felt troubled on their account, and said: 'This is a distressing day.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came to him rushing. Before this they were wont to commit evil deeds. Lot said: 'My people! Here are my daughters; they are purer for you. Have fear of Allah and do not disgrace me concerning my guests. Is there not even one right-minded person in your midst?'\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said: 'Surely you already know that we have nothing to do with your daughters. You also know well what we want.'\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said: 'Would that I had the strength to set you straight, or could seek refuge in some powerful support.'\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdliv{%
Thereupon the angels said: 'O Lot! We indeed are messengers of your Lord. And your people will in no way be able to hurt you. So depart with your family in a part of the night and let no one of you turn around excepting your wife (who shall not go); for what will befall them shall also befall her. In the morning their promised hour will come. Is not the morning near?'\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdlv{%
And when Our command came to pass, We turned the town upside down, and rained on it stones of baked clay, one on another,\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdlvi{%
marked from your Lord. Nor is the punishment far off from the wrong-doers.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And to (the people of) Midian We sent their brother Shu'ayb. He said: 'My people! Serve Allah; you have no god other than Him. And do not diminish the measure and weight. Indeed I see that you are prospering now, but I fear for you the chastisement of an encompassing day in the future.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdlviii{%
My people! Give full measure and weight with justice, do not diminish the goods of others, and do not go about creating corruption in the land.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdlix{%
The gains that Allah lets you retain are better for you, if you indeed believe. In any case, I have not been appointed a keeper over you.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdlx{%
They replied: 'O Shu'ayb! Does your Prayer enjoin upon you that we should forsake the deities whom our forefathers worshipped, or that we should give up using our wealth as we please? Do you fancy that you, and only you, are forbearing and right-directed?'\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdlxi{%
Shu'ayb said: 'My people! What do you think? If I stand on clear evidence from my Lord, and He has also provided me a handsome provision from Himself -(should I be ungrateful to Him and share your error and iniquity?) Nor do I desire to act contrary to what I admonish you. I desire nothing but to set things right as far as I can. My succour is only with Allah. In Him have I put my trust, and to Him do I always turn.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdlxii{%
My people! Let not your opposition to me lead you to guilt that would bring upon you the chastisement that struck earlier the people of Noah, and the people of Hud, and the people of Salih. And the land of the people of Lot is not far from you!\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
Seek the forgiveness of your Lord and turn to Him in repentance. Surely my Lord is Ever Merciful, Most Loving.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said: 'O Shu'ayb! We do not understand much of what you say. Indeed we see you weak in our midst. Were it not for your kinsmen, we would surely have stoned you for you have no strength to overpower us.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdlxv{%
Shu'ayb said: 'My people! Are my kinsmen mightier with you than Allah that you (hold the kinsmen in awe while) you cast Allah behind your back? Surely my Lord encompasses all what you do.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
My people! Go on working according to your way and I will keep working (according to mine). Soon you will come to know who will be afflicted by a humiliating chastisement, and who is proved a liar. And watch, I shall also watch with you.'\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our command came to pass, We delivered Shu'ayb and those who shared his faith, through Our mercy, and the Blast seized those who were engaged in wrong-doing, so they lay lifeless in their homes\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
as though they had never dwelt in them before. Lo! Away with (the people of) Midian, even as the Thamud were done away with!\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And indeed We sent Moses with Our signs and with a clear authority\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdlxx{%
to Pharaoh and his nobles. But they obeyed the command of Pharaoh even though Pharaoh's command was not rightly-directed.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He shall stand at the head of his people on the Day of Resurrection, and will bring them down to the Fire. What a wretched destination to be led to!\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
They were pursued by a curse in this world and so will they be on the Day of Resurrection. What an evil reward will they receive!\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
That is an account of some towns which We recount to you. Of them some are still standing and some have been mown down.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
We did not wrong them; it is rather they who wronged themselves. And when the command of your Lord came to pass, the gods besides Allah whom they had called upon, did not avail them in the least. They added nothing to them except ruin.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
Such is the seizing of your Lord that when He does seize the towns immersed in wrong-doing, His seizing is painful, terrible.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Surely in that is a sign for him who fears the chastisement of the Hereafter. That will be a Day when all men shall be mustered together; that will be a Day when whatever happens shall be witnessed by all.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
Nor shall We withhold it except till an appointed term.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
And when the appointed Day comes, no one shall even dare to speak except by the leave of Allah. Then some will be declared wretched, others blessed.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
As for the wretched, they shall be in the Fire, and in it they shall sigh and groan.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
They shall abide in it as long as the heavens and the earth endure, unless your Lord may will otherwise. Surely your Lord does whatsoever He wills.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And as for those who are blessed, they shall abide in the Garden as long as the heavens and the earth endure, unless your Lord may will otherwise. They shall enjoy an unceasing gift.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
[O Prophet!] Have no doubt about what they worship. For they worship what their fathers worshipped before. And (yet) We shall grant them their due portion in full, diminishing of it nothing.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
And We certainly gave Moses the Book before, and there arose disagreements about it (even as there are disagreements now about the Book revealed to you). Had it not been for a decree that had already gone forth from your Lord, the matter would have long been decided between them. Indeed they are in a disquieting doubt about it.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
Surely your Lord will recompense all to the full for their deeds. For indeed He is well aware of all what they do.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So remain, (O Muhammad), you and those who have returned with you (to the fold of faith and obedience from unbelief and rebellion) steadfast (in adhering to the straight way) as you were commanded. And do not exceed the limits of (service to Allah). For certainly He is aware of all what you do.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And do not incline towards the wrong-doers lest the Fire might seize you and you will have none as your protector against Allah; and then you will not be helped from anywhere.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And establish the Prayer at the two ends of the day and in the first hours of the night. Indeed the good deeds drive away the evil deeds. This is a Reminder to those who are mindful of Allah.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And be patient; for indeed Allah never lets the reward of those who do good go to waste.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
Why were there not, out of the generations that passed away before you, righteous men who would forbid others from causing corruption on the earth? And if such were there, they were only a few whom We had saved from those generations, or else the wrong-doers kept pursuing the ease and comfort which had been conferred upon them, thus losing themselves in sinfulness.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mdxc{%
And your Lord is not such as would wrongfully destroy human habitations while their inhabitants are righteous.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mdxci{%
Had your Lord so willed, He would surely have made mankind one community. But as things stand, now they will not cease to differ among themselves and to follow erroneous ways\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mdxcii{%
except for those on whom your Lord has mercy. And it is for this (exercise of freedom of choice) that He has created them. And the word of your Lord was fulfilled: 'Indeed I will fill the Hell, with men and jinn, altogether.'\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mdxciii{%
(O Muhammad!) We narrate these anecdotes of Messengers to you that We may strengthen through them your heart. In these anecdotes come to you the truth, and an exhortation, and a reminder for the believers.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mdxciv{%
As for those who are bent on not believing, tell them: 'Work according to your way and we are working according to our way.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mdxcv{%
And do wait for the end of things; we too are waiting.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
All that is hidden in the heavens and the earth lies within the power of Allah. To Him are all matters referred for judgement. So do serve Him, and place in Him all your trust. Your Lord is not heedless of what you do.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif. Lam. Ra'. These are the verses of a Book that clearly expounds the truth.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
We have revealed it as a Recitation in Arabic that you may fully understand.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdxcix{%
(O Muhammad), by revealing the Qur'an to you We narrate to you in the best manner the stories of the past although before this narration you were utterly unaware of them.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdc{%
Call to mind when Joseph said to his father: ``My father! I saw (in a dream) eleven stars and the sun and the moon: I saw them prostrating themselves before me."\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdci{%
His father said: ``My son! Do not relate your dream to your brothers lest they hatch a plot to harm you. Indeed Satan is man's open enemy.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcii{%
(As you have seen in the dream), so will your Lord choose you (for His task) and will impart to you the comprehension of the deeper meaning of things and will bestow the full measure of His favour upon you and upon the house of Jacob even as He earlier bestowed it in full measure upon your forefathers, Abraham and Isaac. Surely your Lord is All- Knowing, All-Wise."\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdciii{%
Verily in the story of Joseph and his brothers there are many signs for those who inquire (about the truth).\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdciv{%
And call to mind when the brothers of Joseph conferred together and said: ``Surely Joseph and his brother are dearer to our father than we are, although we are a group of so many. Our father is clearly mistaken.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcv{%
So either kill Joseph or cast him into some distant land so that your father's attention may become exclusively yours. And after so doing become righteous."\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcvi{%
Thereupon one of them said: ``Do not kill Joseph, but if you are bent upon doing something, cast him down to the bottom of some dark pit, perhaps some caravan passing by will take him out of it."\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcvii{%
After so deciding they said to their father: ``Why is it that you do not trust us regarding Joseph although we are his true well-wishers?"\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcviii{%
Send him out with us tomorrow that he may enjoy himself and play while we will be there, standing guard over him."\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcix{%
Their father answered: ``It grieves me indeed that you should take him with you for I fear that some wolf might eat him up while you are negligent of him."\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said: ``Should a wolf eat him, despite the presence of our strong group, we would indeed be a worthless lot!"\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So when they went away with Joseph and decided to cast him in the bottom of the dark pit, We revealed to Joseph: ``Surely a time will come when you will remind them of their deed. They know nothing about the consequence of what they are doing."\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcxii{%
At nightfall they came to their father weeping\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
and said: ``Father! We went racing with one another and left Joseph behind with our things, and then a wolf came and ate him up. We know that you will not believe us howsoever truthful we might be."\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought Joseph's shirt, stained with false blood. Seeing this their father exclaimed: ``Nay (this is not true); rather your evil souls have made it easy for you to commit a heinous act. So I will bear this patiently, and in good grace. It is Allah's help alone that I seek against your fabrication."\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcxv{%
And a caravan came, and they sent their water drawer to draw water. As he let down his bucket in the well he (observed Joseph) and cried out: ``This is good news. There is a boy." They concealed him, considering him as part of their merchandise, while Allah was well aware of what they did.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
Later they sold him for a paltry sum - just a few dirhams; they did not care to obtain a higher price.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
The man from Egypt who bought him said to his wife: ``Take good care of him, possibly he might be of benefit to us or we might adopt him as a son." Thus We found a way for Joseph to become established in that land and in order that We might teach him to comprehend the deeper meaning of things. Allah has full power to implement His design although most people do not know that.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And when Joseph reached the age of maturity, We granted him judgement and knowledge. Thus do We reward those who do good.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcxix{%
And it so happened that the lady in whose house Joseph was living, sought to tempt him to herself, and one day bolting the doors she said: ``Come on now!" Joseph answered: ``May Allah grant me refuge! My Lord has provided an honourable abode for me (so how can I do something so evil)? Such wrong-doers never prosper."\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcxx{%
And she advanced towards him, and had Joseph not perceived a sign from his Lord he too would have advanced towards her. Thus was Joseph shown a sign from his Lord that We might avert from him all evil and indecency, for indeed he was one of Our chosen servants.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
Then both of them rushed to the door, each seeking to get ahead of the other, and she tore Joseph's shirt from behind. Then both of them found the husband of the lady at the door. Seeing him she said: ``What should be the punishment of him who has foul designs on your wife except that he should be imprisoned or subjected to painful chastisement?"\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
Joseph said: ``It is she who was trying to tempt me to herself." And a witness belonging to her own household testified (on grounds of circumstantial evidence): ``If his shirt is torn from the front, then she is telling the truth and he is a liar.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
But if his shirt is torn from behind, then she has lied, and he is truthful."\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
So when the husband saw Joseph's shirt torn from behind he exclaimed: ``Surely, this is one of the tricks of you women; your tricks are indeed great.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
Joseph, disregard this. And you - woman - ask forgiveness for your sin, for indeed it is you who has been at fault."\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
And some ladies in the city began to say: ``The chief's wife, violently in love with her houseboy, is out to tempt him. We think she is clearly mistaken."\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
Hearing of their sly talk the chief's wife sent for those ladies, and arranged for them a banquet, and got ready couches, and gave each guest a knife. Then, while they were cutting and eating the fruit, she signalled Joseph: ``Come out to them." When the ladies saw him they were so struck with admiration that they cut their hands, exclaiming: ``Allah preserve us. This is no mortal human. This is nothing but a noble angel!"\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said: ``So now you see! This is the one regarding whom you reproached me. Indeed I tried to tempt him to myself but he held back, although if he were not to follow my order, he would certainly be imprisoned and humiliated."\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
Joseph said: ``My Lord! I prefer imprisonment to what they ask me to do. And if You do not avert from me the guile of these women, I will succumb to their attraction and lapse into ignorance."\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
Thereupon his Lord granted his prayer, and averted their guile from him. Surely He alone is All-Hearing, All-Knowing.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then it occurred to them to cast Joseph into prison for a while even though they had seen clear signs (of Joseph's innocence and of the evil ways of their ladies).\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
And with Joseph two other slaves entered the prison. One of them said: ``I saw myself pressing wine in a dream"; and the other said: ``I saw myself carrying bread on my head of which the birds were eating." Both said: ``Tell us what is its interpretation; for we consider you to be one of those who do good."\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
Joseph said: ``I will inform you about the interpretation of the dreams before the arrival of the food that is sent to you. This knowledge is part of what I have been taught by my Lord. I have renounced the way of those who do not believe in Allah, and who deny the Hereafter,\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
and I have adopted the way of my forefathers - Abraham and Isaac and Jacob. It is not for us to associate any with Allah in His Divinity. It is out of Allah's grace upon us and upon mankind (that He did not require of us to serve any other than Allah), and yet most people do not give thanks.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
Fellow-prisoners! Is it better that there be diverse lords, or just Allah, the One, the Irresistible?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
Those whom you serve beside Him are merely idle names that you and your fathers have fabricated, without Allah sending down any sanction for them. All authority to govern rests only with Allah. He has commanded that you serve none but Him. This is the Right Way of life, though most people are altogether unaware.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
Fellow-prisoners! (This is the interpretation of your dreams): one of you will serve wine to his lord (the king of Egypt). As for the other, he will be crucified and birds will eat of his head. The question concerning what you asked has thus been decided."\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And Joseph said to the one of the two prisoners who he knew would be set free: ``Mention me in your lord's presence." But Satan caused him to forget mentioning this to his lord (the ruler of Egypt) and so Joseph languished in prison for several years.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
And once the king said: ``I have dreamt that there are seven fat cows and seven lean cows are devouring them, and there are seven fresh green ears of corn and seven others dry and withered. My nobles! Tell me what is the interpretation of this dream, if you are well-versed in interpretation of dreams."\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They said: ``These are confused dreams, and we do not know the interpretation of such dreams."\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdcxli{%
Then of the two prisoners, the one who had been set free, now remembered, after the lapse of a long period, what Joseph had said. He said: ``I will tell you the interpretation of this dream; just send me (to Joseph in prison)."\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
Then he went to Joseph and said to him: ``Joseph, O truthfulness incarnate, tell the true meaning of the dream in which seven fat cows are devoured by seven lean ones; and there are seven green ears of corn and seven others dry and withered so that I may return to the people and they may learn."\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
Joseph said: ``You will cultivate consecutively for seven years. Leave in the ears all that you have harvested except the little out of which you may eat.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
Then there will follow seven years of great hardship in which you will eat up all you have stored earlier, except the little that you may set aside.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
Then there will come a year when people will be helped by plenty of rain and they will press (grapes)."\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
The king said: ``Bring this man to me." But when the royal messenger came to Joseph he said: ``Go back to your master and ask him about the case of the women who had cut their hands. Surely my Lord has full knowledge of their guile."\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
Thereupon the king asked the women: ``What happened when you sought to tempt Joseph?" They said: ``Allah forbid! We found no evil in him." The chief's wife said: ``Now the truth has come to light. It was I who sought to tempt him. He is indeed truthful."\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
Joseph said: ``I did this so that he [i.e. the chief) may know that I did not betray him in his absence, and that Allah does not allow the design of the treacherous to succeed.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
I do not seek to acquit myself; for surely one's self prompts one to evil except him to whom my Lord may show mercy. Verily my Lord is Ever Forgiving, Most Merciful."\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdcl{%
The king said: ``Bring him to me. I will select him exclusively for my own service." So when Joseph spoke to him the king said: ``You are now one of established position, fully-trusted by us."\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdcli{%
Joseph said: ``Place me in charge of the treasures of the land. I am a good keeper and know my task well."\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdclii{%
Thus did We establish Joseph in the land so that he could settle wherever he pleased. We bestow favour, out of Our Mercy, on whomsoever We please, and We do not cause the reward of those who do good to go to waste.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdcliii{%
Surely the reward of the Hereafter is better for those who believe and act in a God-fearing way.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And Joseph's brothers came to Egypt and presented themselves before him. He recognized them, but they did not know him.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he had prepared for them their provisions, Joseph said: ``Bring to me your other brother from your father. Do you not see that I give full measure and am most hospitable?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdclvi{%
If you do not bring him to me, you shall have no corn from me; and do not even attempt to come close to me."\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said: ``We will surely try to prevail over our father to send him. Be sure we shall do so."\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdclviii{%
And Joseph said to his servants: ``Put surreptitiously in their packs the goods they had given in exchange for corn." Joseph did so expecting that they would find it when they returned home. Feeling grateful for this generosity, they might be inclined to return to him.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdclix{%
When they returned to their father they said: ``Father! We have been denied further supply of corn. So send with us our brother that we may bring the supplies. We shall be responsible for his protection."\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdclx{%
The father said: ``Shall I trust you with regard to him as I had trusted you earlier with regard to his brother? Allah is the Best Protector and is the Most Merciful."\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their things they found that their goods had been given back to them. Thereupon they cried: ``Father! What else would we desire? Look, even our goods have been given back to us, so we shall go now and bring supplies for our family, we shall protect our brother, and bring another camel-load of corn. That additional supply will be easily secured."\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdclxii{%
Their father said: ``I shall never send him with you until you give me a solemn promise in the name of Allah that you will bring him back to me, unless you yourselves are surrounded." Then after they had given him their solemn promise, he said. ``Allah watches over what we have said."\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
And he enjoined them: ``My sons! Do not enter the city by one gate; rather enter it by different gates. I can be of no help to you against Allah. Allah's command alone prevails. In Him have I put my trust and in Him should all those who have faith put their trust."\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And it so happened that when they entered the city (by many gates) as their father had directed them, this precautionary measure proved ineffective against Allah's will. There was an uneasiness in Jacob's soul which he so tried to remove. Surely he was possessed of knowledge owing to the knowledge that We bestowed upon him. But most people do not know the truth of the matter.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdclxv{%
When they presented themselves before Joseph, he took his brother aside to himself and said: ``Verily I am your own brother Joseph; so do not grieve over the manner they have treated you."\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
Then, while Joseph was having their provisions loaded, he put his drinking-cup in his brother's saddlebag. And then a herald cried: ``Travellers, you are thieves."\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
Turning back they asked: ``What have you lost?"\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
The officials said: ``We have lost the king's cup." (And their chief added): ``He who brings it shall have a camel-load of provisions, I guarantee that."\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdclxix{%
They said: ``By Allah, you certainly know that we did not come to act corruptly in this land, nor are we those who steal."\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdclxx{%
The officials said: ``If you are lying, what will be the penalty for him who has stolen?"\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They replied: ``He in whose saddlebag the cup is found, he himself shall be its recompense." Thus do we punish the wrong-doers.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
Then Joseph began searching their bags before searching his own brother's bag. Then he brought forth the drinking-cup from his brother's bag. Thus did We contrive to support Joseph. He had no right, according to the religion of the king (i.e. the law of Egypt), to take his brother, unless Allah so willed. We exalt whomsoever We will over others by several degrees. And above all those who know is the One Who truly knows.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said: ``No wonder that he steals for a brother of his stole before." But Joseph kept his reaction to himself without disclosing the truth to them. He merely said to himself: ``You are an evil lot. Allah knows well the truth of the accusation that you are making against me (to my face)."\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said: ``O powerful chief (al-aziz)! His father is an age-stricken man, (and in order that he may not suffer) seize one of us in his stead. We indeed consider you an excellent person."\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
Joseph said: ``Allah forbid that we should seize any except him with whom we found our good. Were we to do so, we would surely be one of the wrong-doers."\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
Then, when they had despaired of Joseph they went to a corner and counselled together. The eldest of them said: ``Do you not know that your father has taken a solemn promise from you in the name of Allah, and you failed in your duty towards Joseph? So I will not depart from this land until my father permits me, or Allah pronounces His judgement in my favour. He is the best of those who judge."\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
So go back to your father and tell him: ``Father! Your son has certainly been guilty of stealing. We did not see him stealing but testify according to what we know, and obviously we had no power to keep watch over that what is altogether hidden from us.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
You may inquire of the dwellers of the city where we were, and of the people of the caravan with whom we travelled. We are altogether truthful in what we say."\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
The father heard the narration and said: ``(All that is untrue). But your souls have made it easy for you to engage in a heinous act. So, I will be graciously patient even at this. Allah may well bring them all back to me. He is All-Knowing, All-Wise."\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
Then he turned his back to them, and said: ``O my grief for Joseph!" His eyes whitened with grief and he was choked up with sorrow trying to suppress his grief.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
The sons said: ``By Allah! You will continue to remember Joseph until you will either consume yourself with grief, or will die."\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said: ``I will address my sorrow and grief only to Allah, and I know from Allah what you do not know.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
My sons! Go and try to find out about Joseph and his brother and do not despair of Allah's mercy. Verily only the unbelievers despair of Allah's mercy."\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
On going to Egypt they presented themselves to Joseph and said to him: ``O chief! We and our family are struck with distress and have brought only a paltry sum. So give us corn in full measure, and give it to us in charity. Allah rewards those who are charitable."\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
When Joseph heard this (he could not hold himself and said): ``Do you remember what you did to Joseph and his brother when you were ignorant?"\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They exclaimed: ``Are you indeed Joseph?" He said: ``Yes, I am Joseph and this is my brother. Allah has surely been gracious to us. Indeed whoever fears Allah and remains patient, Allah does not allow the reward of such people to go to waste."\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said: ``We swear by Allah! Indeed Allah has chosen you in preference to us and we were truly guilty."\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He replied: ``No blame lies with you today. May Allah forgive you. He is the Most Merciful of all those that are merciful.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
Take this shirt of mine and throw it over my father's face. He will regain his sight. And bring to me all your family."\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdcxc{%
And as the caravan set out (from Egypt), their father said (in Canaan): ``Indeed I smell the fragrance of Joseph. I say so although you may think that I am doting."\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said: ``Surely you are still in your same old craze."\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
And when the bearer of good news came he threw Joseph's shirt over Jacob's face, whereupon he regained his sight, and said: ``Did I not tell you that I know from Allah what you do not know?"\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said: ``Father! Pray for the forgiveness of our sins; we were truly guilty."\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said: ``I shall pray to my Lord for your forgiveness, for He, and indeed He alone, is Ever Forgiving, Most Merciful."\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
And when they went to Joseph, he took his parents aside and said (to the members of his family): ``Enter the city now, and if Allah wills, you shall be secure."\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And after they had entered the city, Joseph raised his parents to the throne beside himself, and they (involuntarily) bowed in prostration before him. Joseph said: ``Father! This is the fulfilment of the vision I had before - one that My Lord has caused to come true. He was kind to me when He rescued me from the prison, and brought you from the desert after Satan had stirred discord between me and my brothers. Certainly my Lord is Subtle in the fulfilment of His will; He is All-Knowing, All-Wise.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
My Lord! You have bestowed dominion upon me and have taught me to comprehend the depths of things. O Creator of heavens and earth! You are my Guardian in this world and in the Hereafter. Cause me to die in submission to You, and join me, in the end, with the righteous."\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
(O Muhammad), this is part of news from the Unseen that We reveal to you for you were not present with them when Joseph's brothers jointly resolved on a plot.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
And most of the people, howsoever you might so desire, are not going to believe.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mdcc{%
You do not seek from them any recompense for your service. This is merely an admonition to all mankind.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mdcci{%
How many are the signs in the heavens and the earth which people pass by without giving any heed!\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them believe in Allah only when they associate others with Him in His Divinity.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Do they, then, feel secure that an overwhelming chastisement shall not visit them, and the Hour shall not suddenly come upon them without their even perceiving it?\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Tell them plainly: ``This is my way: I call you to Allah, on the basis of clear perception - both I and those who follow me. Allah - Glory be to Him - is free of every imperfection. I have nothing to do with those who associate others with Allah in His Divinity."\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mdccv{%
The Messengers whom We raised before you, (O Muhammad), and to whom We sent down revelations, were only human beings, and were from among those living in earthly habitations. Have these people not travelled in the earth that they may observe the end of their predecessors? Certainly the abode of the Hereafter is much better for those (who accepted the call of the Messengers and) acted in a God-fearing manner. Will you still not act with good sense?\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mdccvi{%
(It also happened with the earlier Messengers that for long they preached and people paid no heed) until the Messengers despaired of their people, and the people also fancied that they had been told lies (by the Messengers), then suddenly Our help came to the Messengers. And when such an occasion comes We rescue whom We will; as for the guilty, Our chastisement cannot be averted from them.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mdccvii{%
Certainly in the stories of the bygone people there is a lesson for people of understanding. What is being narrated in the Qur'an is no fabrication; it is rather confirmation of the Books that preceded it, and a detailed exposition of everything, and a guidance and mercy for people of faith.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif. Lam. Mim. Ra'. These are the verses of the Divine Book. Whatever has been revealed to you from your Lord is the truth, and yet most (of your) people do not believe.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdccix{%
It is Allah Who has raised the heavens without any supports that you could see, and then He established Himself on the Throne (of Dominion). And He it is Who has made the sun and the moon subservient (to a law), each running its course till an appointed term. He governs the entire order of the universe and clearly explains the signs that you may be firmly convinced about meeting your Lord.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdccx{%
He it is Who has stretched out the earth and has placed in it firm mountains and has caused the rivers to flow. He has made every fruit in pairs, two and two, and He it is Who causes the night to cover the day. Surely there are signs in these for those who reflect.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And on the earth there are many tracts of land neighbouring each other. There are on it vineyards, and sown fields, and date palms: some growing in clusters from one root, some standing alone. They are irrigated by the same water, and yet We make some excel others in taste. Surely there are signs in these for a people who use their reason.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdccxii{%
And were you to wonder, then wondrous indeed is the saying of those who say: ``What! After we have been reduced to dust, shall we be created afresh?" They are the ones who disbelieved in their Lord; they are the ones who shall have shackles around their necks. They shall be the inmates of the Fire, wherein they will abide for ever.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
They challenge you to hasten the coming of evil upon them before the coming of any good, although people who followed a like course before had met with exemplary punishment (from Allah). Verily your Lord is forgiving to mankind despite all their wrong-doing. Verily your Lord is also severe in retribution.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
Those who refused to believe in you say: ``Why has no (miraculous) sign been sent down upon him from his Lord?" You are only a warner, and every people has its guide.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah knows what every female bears; and what the wombs fall short of (in gestation), and what they may add. With Him everything is in a fixed measure.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
He knows both what is hidden and what is manifest. He is the Supreme One, the Most High.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
It is all the same for Him whether any of you says a thing secretly, or says it loudly, and whether one hides oneself in the darkness of night, or struts about in broad daylight.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
There are guardians over everyone, both before him and behind him, who guard him by Allah's command. Verily Allah does not change a people's condition unless they change their inner selves. And when Allah decides to make a people suffer punishment, no one can avert it. Nor can any be of help to such a people against Allah.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdccxix{%
He it is Who causes you to see lightning that inspires you with both fear and hope, and He it is Who whips up heavy clouds.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdccxx{%
The thunder celebrates His praise and holiness, and the angels, too, celebrate His praise for awe of Him. He hurls thunderbolts, striking with them whom He wills while they are engaged in disputation concerning Allah. He is Mighty in His contriving.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
To Him alone should all prayer be addressed, for those to whom they do address their prayers beside Him are altogether powerless to respond to them. The example of praying to any other than Allah is that of a man who stretches out his hands to water, asking it to reach his mouth, although water has no power to reach his mouth. The prayers of the unbelievers are a sheer waste.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
All that is in the heavens and the earth prostrates itself, whether willingly or by force, before Allah; and so do their shadows in the morning and in the evening.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Ask them: ``Who is the Lord of the heavens and the earth?" Say: ``Allah." Tell them: ``Have you taken beside Him as your patrons those who do not have the power to benefit or to hurt even themselves?" Say: ``Can the blind and the seeing be deemed equals? Or can light and darkness be deemed equals?" If that is not so, then have those whom they associate with Allah in His Divinity ever created anything like what Allah did so that the question of creation has become dubious to them? Say: ``Allah is the creator of everything. He is the One, the Irresistible."\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
Allah sends down water from the heavens and the river-beds flow, each according to its measure, and the torrent carries along a swelling scum. In like manner, from that metal which they smelt in the fire to make ornaments and utensils, there arises scum like it. Thus does Allah depict truth and falsehood. As for the scum, it passes away as dross; but that which benefits mankind abides on the earth. Thus does Allah explain (the truth) through examples.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
There is good reward for those who respond to the call of their Lord. And those who do not respond to their Lord, (a time will come when) they shall offer all they have - even if they have all the riches of the world and the like of it besides to redeem themselves (from the chastisement of Allah). They will be subjected to a severe reckoning and Hell shall be their refuge. What a wretched resting place it is!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
He who knows that the Book which has been sent to you from your Lord is the Truth, is he like him who is blind to that truth? It is only people of understanding who take heed:\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
those who fulfil their covenant with Allah and do not break their compact after firmly confirming it;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
who join together the ties which Allah has bidden to be joined; who fear their Lord and dread lest they are subjected to severe reckoning;\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
who are steadfast in seeking the good pleasure of their Lord; who establish Prayer and spend both secretly and openly out of the wealth We have provided them, and who ward off evil with good. Theirs shall be the ultimate abode\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
- the Ever-lasting Gardens which they shall enter and so shall the righteous from among their fathers, and their spouses, and their offspring. And angels shall enter unto them from every gate, and say:\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
``Peace be upon you. You merit this reward for your steadfastness." How excellent is the ultimate abode!\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
As for those who break the covenant of Allah after firmly confirming it, who cut asunder the ties that Allah has commanded to be joined, and who create corruption in the land: Allah's curse shall be upon them and theirs shall be a wretched abode (in the Hereafter).\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah grants the provision to whomsoever He wills abundantly and grants others in strict measure. They exult in the life of the world, although compared with the Hereafter, the life of the world is no more than temporary enjoyment.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
Those who have rejected (the message of Muhammad) say: ``Why has no sign been sent down upon him from his Lord?" Tell them: ``Allah lets go astray those whom He wills, and guides to Himself those who turn to Him."\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
Such are the ones who believe (in the message of the Prophet) and whose hearts find rest in the remembrance of Allah. Surely in Allah's remembrance do hearts find rest.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
So those who believe (in the message of the Truth) and do good are destined for happiness and a blissful end.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus have We sent you as a Messenger to a community before which many other communities have passed away that you may recite to them whatever We have revealed to you. And yet they deny the Lord of Mercy. Say to them: ``He is my Lord, there is no god but Him. In Him I have placed all my trust and to Him I shall return."\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
And what would have happened were a Qur'an to be revealed wherewith mountains could be set in motion, or the earth cleft, or the dead made to speak? (To show such signs is not at all difficult for) everything rests entirely with Allah. So, do not the people of faith (still look forward to such a sign in response to the demand of the unbelievers and) despair as a result of knowing that had Allah so willed, He could have guided all to the Truth. Misfortune continues to afflict the unbelievers on account of their misdeeds, or to befall on locations close to their habitation. This will continue until Allah's promise (of chastisement) is fulfilled. Indeed Allah does not go back upon His promise.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
Surely the Messengers before you were ridiculed, but I always initially granted respite to those who disbelieved, and then I seized them (with chastisement). Then, how awesome was My chastisement!\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdccxl{%
Is it, then, in regard to Him Who watches over the deeds of every person that they are acting blasphemously by setting up His associates? Tell them: ``Name those associates (if Allah Himself has made them His associates)! Or are you informing Allah of something the existence of which He does not even know?" Or do people arbitrarily utter empty words? Indeed, their foul contriving has been made to seem fair to the unbelievers and they have been barred from finding the Right Way. Whomsoever Allah lets go astray will have none to guide him.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdccxli{%
They shall suffer chastisement in the life of the world, and surely the chastisement of the Hereafter is even more grievous. None has the power to shield them from (the chastisement of) Allah.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
And such will be the Paradise promised to the God-fearing: rivers will flow beneath it, its fruits will be eternal, and so will be its blissful shade. That is the ultimate destiny of the God-fearing while Fire is the destiny of the unbelievers.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
Those upon whom We bestowed the Scriptures earlier rejoice at the Book revealed to you, while there are also some among different groups that reject part of it. Tell them: ``I have only been commanded to serve Allah and not to associate anyone with Him. To Him do I call, and to Him is my return."\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
And it is with the same directive that We revealed to you this Arabic Writ. Were you indeed to follow the vain desires of people after the true knowledge has come to you, none will be your supporter against Allah, and none will have the power to shield you from His punishment.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
We indeed sent many Messengers before you and We gave them wives and children; and no Messenger had the power to produce a miraculous sign except by the command of Allah. Every age has its own (revealed) Book.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah effaces whatever He wills and retains whatever He wills. With Him is the Mother of the Book.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
(O Prophet), whether We make you see a part of the punishment that We have threatened them with come to pass during your life-time, or We take you away before that happens, your duty is no more than to convey the Message, and it is for Us to make a reckoning.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
Do they not see that We are advancing in the land, diminishing it by its borders on all sides? Allah judges, and no one has the power to reverse His judgement. He is swift in reckoning.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
Those who lived before them also devised many a plot, but the master plot rests with Allah. He knows what everyone does. The deniers of the truth will soon come to know whose end is good.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdccl{%
The unbelievers claim that you have not been sent by Allah. Tell them: ``Allah is sufficient as a witness between me and you; and so also do those who know the Scriptures."\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif. Lam. Ra'. This is a Book which We have revealed to you that you may bring forth mankind from every kind of darkness into light, and direct them, with the leave of their Lord, to the Way of the Mighty, the Innately Praiseworthy,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdcclii{%
(to the Way of) Allah to Whom belongs all that is in the heavens and all that is in the earth. Woe be to those who reject the Truth for a severe chastisement,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdccliii{%
to those who have chosen the life of the world in preference to the Hereafter, who hinder people from the Way of Allah, and seek to make it crooked. They have gone far astray.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdccliv{%
Never have We sent a Messenger but he has addressed his people in their language that he may fully expound his Message to them. (And after the Message is expounded), Allah lets go astray whomsoever He wills, and guides to the Right Way whomsoever He wills. He is the All-Mighty, the All-Wise.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdcclv{%
We indeed sent Moses with Our Signs, saying: ``Lead your people out of all kinds of darkness into light, and admonish them by narrating to them anecdotes from the Days of Allah." Verily in it there are great Signs for everyone who is patient and gives thanks (to Allah).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
And call to mind when Moses said to his people: ``Remember Allah's favour upon you when He delivered you from Pharaoh's people who afflicted you with a grievous chastisement, slaughtering your sons, while letting your women live. In it there was a terrible trial from your Lord."\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
Also call to mind when your Lord proclaimed: ``If you give thanks, I will certainly grant you more; but if you are ungrateful for My favours, My chastisement is terrible.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
Moses said: ``Were you to disbelieve - you and all those who live on earth - Allah is still Self-Sufficient, Innately Praiseworthy."\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Have the accounts of your predecessors not reached you: the people of Noah, the Ad, the Thamud, and those who came after them - they whose number is not known to any except Allah? Their Messengers came to them with Clear Signs, but they thrust their hands in their mouths, and said: ``We do surely reject the Message you have brought, and we are in disquieting doubt about what you are summoning us to."\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their Messengers said: ``Can there be any doubt about Allah, the Creator of the heavens and the earth? He invites you that He may forgive you your sins and grant you respite till an appointed term." They replied: ``You are only a human being like ourselves. You seek to prevent us from serving those whom our forefathers have been serving all along. If that is so, produce a clear authority for it."\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their Messengers told them: ``Indeed we are only human beings like yourselves, but Allah bestows His favour on those of His servants whom He wills. It does not lie in our power to produce any authority except by the leave of Allah. It is in Allah that the believers should put their trust.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
And why should we not put our trust in Allah when it is indeed He Who has guided us to the ways of our life? We shall surely continue to remain steadfast in face of your persecution. All those who have to put trust, should put their trust only in Allah."\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
Then the unbelievers told their Messengers: ``You will have to return to the fold of our faith or else we shall banish you from our land." Thereupon their Lord revealed to them: ``We will most certainly destroy these wrong-doers,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
and will then cause you to settle in the land as their successors. That is the reward for him who fears to stand for reckoning and holds My threat in awe."\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
They sought Our judgement. And (thanks to that judgement) every obstinate tyrant opposed to the Truth was brought to naught.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
Hell is before him and he shall be made to drink of the oozing pus,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
which he will gulp but will scarcely swallow, and death will come upon him from every quarter, and yet he will not be able to die. A terrible chastisement lies ahead in pursuit of him.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
This is the example of those who disbelieve in their Lord: their works are like ashes upon which the wind blows fiercely on a tempestuous day. They shall find no reward for their deeds. That indeed is the farthest point in straying.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Do you not see that Allah created the heavens and the earth in Truth? Were He to will, He could take you away and bring a new creation.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
That is not at all difficult for Allah.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
Then all of them will appear exposed before Allah, and the weak ones will say to the haughty ones: ``We merely followed you. Will you, then, protect us from Allah's chastisement?" They will say: ``Had Allah shown us the Way to our salvation, we would surely have also guided you. Now it is all the same whether we cry or suffer patiently, we have no escape."\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
After the matter has been finally decided Satan will say: ``Surely whatever Allah promised you was true; as for me, I went back on the promise I made to you. I had no power over you except that I called you to my way and you responded to me. So, do not blame me but blame yourselves. Here, neither I can come to your rescue, nor can you come to mine. I disavow your former act of associating me in the past with Allah. A grievous chastisement inevitably lies ahead for such wrong-doers."\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
As for those who had believed and did good in the world, they shall be admitted to the Gardens beneath which rivers flow. There, with the leave of Allah, they shall abide forever, and will be greeted with: ``Peace".\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Do you not see how Allah has given the example of a good word? It is like a good tree, whose root is firmly fixed, and whose branches reach the sky,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
ever yielding its fruit in every season with the leave of its Lord. Allah gives examples for mankind that they may take heed.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the example of an evil word is that of an evil tree, uprooted from the surface of the earth, wholly unable to endure.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Thus, through a firm word, Allah grants firmness to the believers both in this world and in the Hereafter. As for the wrong-doers, Allah lets them go astray. Allah does whatever He wills.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Did you not see those who have exchanged Allah's favour with ingratitude to Him, causing their people to be cast in the abode of utter perdition\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
Hell, wherein they shall roast? How wretched a place to settle in!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
They have set up rivals to Allah that they may lead people astray from His way. Tell them: ``Enjoy for a while. You are doomed to end up in the Fire!"\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
(O Prophet), tell those of My servants who believe that they should establish Prayer and spend out of what We have provided them with, both secretly and openly, before there arrives the Day when there will be no bargaining, nor any mutual befriending.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
It is Allah Who created the heavens and the earth, Who sent down water from the heaven and thereby brought forth a variety of fruits as your sustenance, Who subjected for you the ships that they may sail in the sea by His command, Who subjected for you the rivers,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
Who subjected for you the sun and the moon and both of them are constant on their courses, Who subjected for you the night and the day,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
and Who gave you all that you asked Him for. Were you to count the favours of Allah you shall never be able to encompass them. Verily man is highly unjust, exceedingly ungrateful.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And call to mind when Abraham prayed: ``My Lord! Make this city secure, and keep me and my sons away from worshipping the idols.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
My Lord! They have caused many people to go astray. Now, if anyone follows my way, he is from me; and if anyone follows a way opposed to mine, then surely You are Ever-Forgiving, Most Merciful."\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
``Our Lord! I have made some of my offspring settle in a barren valley near Your Sacred House! Our Lord! I did so that they may establish Prayer. So make the hearts of people affectionately inclined to them, and provide them with fruits for their sustenance that they may give thanks.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
Our Lord! Surely You know all that we conceal and all that we reveal, and nothing in the earth or in the heaven is hidden from Allah.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
All praise be to Allah Who, despite my old age, has given me Ishmael and Isaac. Surely my Lord hears all prayers.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdccxc{%
My Lord! Enable me and my offspring to establish Prayer, and do accept, our Lord, this prayer of mine.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdccxci{%
Our Lord! Forgive me and my parents and the believers on the Day when the reckoning will take place."\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
Do not think Allah is heedless of the evil deeds in which the evil-doers are engaged. He is merely granting them respite until a Day when their eyes shall continue to stare in horror,\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
when they shall keep pressing ahead in haste, their heads lifted up, their gaze directed forward, unable to look away from what they behold, their hearts utterly void.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
(O Muhammad), warn mankind of the Day when a severe chastisement shall overtake them, and the wrong-doers will say: ``Our Lord, grant us respite for a short while; we shall respond to Your call and will follow Your Messengers." (But they will be clearly told): ``Are you not the same who swore earlier that they shall never suffer decline?"\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
You said so even though you had lived in the dwellings of those who had wronged themselves (by sinning), and you were aware how We dealt with them, and We had even explained to you all this by giving examples.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
Indeed the unbelievers contrived their plan, but it is in Allah's power to nullify their plan, even though their plans were such that would move even mountains.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
So, do not think, (O Prophet), that Allah will go back upon His promise to His Messengers. Surely Allah is Mighty, Lord of retribution.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
(Do warn them of the) Day when the heavens and the earth shall be altogether changed; when all will appear fully exposed before Allah, the One, the Irresistible!\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
On that Day you shall see the guilty ones secured in chains;\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdccc{%
their garments shall be black as if made out of pitch, and flames of the Fire shall cover their faces\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdccci{%
so that Allah may requite each person for his deeds. Allah is swift in reckoning.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This is a proclamation for all mankind that they may be warned by it, and that they may know that their God is none but the One True God, and that men of understanding may take heed.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif. Lam. Ra'. These are the verses of the Book, and a Clear Qur'an.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mdccciv{%
Soon will the time come when the unbelievers will wish they were Muslims.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Leave them to eat and enjoy life and let false hopes amuse them. They will soon come to know.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
Whenever We destroyed a town, a definite term had previously been decreed for it.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No people can outstrip the term for its destruction nor can it delay it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
They say: ``O you to whom the Admonition has been revealed, you are surely crazed.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mdcccix{%
Why do you not bring down angels upon us if you are indeed truthful?"\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We do not send down the angels (in frivolity); and when We do send them down, We do so with Truth; then people are granted no respite.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
As for the Admonition, indeed it is We Who have revealed it and it is indeed We Who are its guardians.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
(O Muhammad), certainly We did send Messengers before you among the nations which have gone by.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
And whenever a Messenger came to them, they never failed to mock him.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
Even so We make a way for it (that is, the Admonition) in the hearts of the culprits (like a hot rod);\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
they do not believe in it. This has been the wont of people of this kind from ancient times.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
If We were even to open for them a way to the heavens, and they could continually climb up to it in broad daylight,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
they would still have said: ``Surely our eyes have been dazzled; rather, we have been enchanted."\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
We have indeed set constellations in the heavens and have beautified them for the beholders,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
and have protected them against every accursed satan\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
save him who may eavesdrop, and then a bright flame pursues him.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
As for the earth, We have stretched it out and have cast on it firm mountains, and have caused to grow in it everything well-measured.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And We have provided sustenance for you on it and also for those of whom you are not the providers.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
There is nothing except that its treasuries are with Us and We do not send it down except in a known measure.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
We send fertilizing winds, and then cause rain to descend from the sky, providing you abundant water to drink even though you could not have stored it up for yourselves.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
It is indeed We Who grant life and cause death and it is We who shall be the sole Inheritors of all.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
Surely We know those of you who have passed before and those who will come later.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
Indeed your Lord will gather them all together. Surely He is All-Wise, All-Knowing.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
Surely We brought man into being out of dry ringing clay which was wrought from black mud,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
while We had brought the jinn into being before out of blazing fire.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
Recall when your Lord said to the angels: ``I will indeed bring into being a human being out of dry ringing clay wrought from black mud.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
When I have completed shaping him and have breathed into him of My Spirit, then fall you down before him in prostration."\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
So, the angels - all of them - fell down in prostration,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
except Iblis; he refused to join those who prostrated.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
The Lord inquired: ``Iblis! What is the matter with you that you did not join those who prostrated?"\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
He said: ``It does not behove of me to prostrate myself before a human being whom You have created out of dry ringing clay wrought from black mud."\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
The Lord said: ``Then get out of here; you are rejected,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
and there shall be a curse upon you till the Day of Recompense."\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
Iblis said: ``My Lord! Grant me respite till the Day when they will be resurrected."\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
Allah said: ``For sure you are granted respite\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
until the day of a known time."\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
Iblis said: ``My Lord! In the manner You led me to error, I will make things on earth seem attractive to them and lead all of them to error,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
except those of Your servants whom You have singled out for Yourself."\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
Allah said: ``Here is the path that leads straight to Me.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
Over My true servants you will be able to exercise no power, your power will be confined to the erring ones, those who choose to follow you.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
Surely Hell is the promised place for all of them."\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
There are seven gates in it, and to each gate a portion of them has been allotted.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
As for the God-fearing, they shall be amid gardens and springs.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
They will be told: ``Enter it in peace and security."\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
And We shall purge their breasts of all traces of rancour; and they shall be seated on couches facing one another as brothers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mdcccl{%
They shall face no fatigue in it, nor shall they ever be driven out of it.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mdcccli{%
(O Prophet), declare to My servants that I am indeed Ever Forgiving, Most Merciful.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mdccclii{%
At the same time, My chastisement is highly painful.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And tell them about Abraham's guests.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
When they came to Abraham they said: ``Peace be upon you!" He replied: ``Indeed we feel afraid of you."\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They said: ``Do not feel afraid, for we give you the good news of a wise boy."\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
Abraham said: ``What, do you give me this tiding though old age has smitten me? Just consider what tiding do you give me!"\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They said: ``The good tiding we give you is of truth. Do not, therefore, be of those who despair."\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
Abraham said: ``Who despairs of the Mercy of his Lord except the misguided?"\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mdccclix{%
He added: ``What is your errand O sent ones?"\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said: ``Verily we have been sent to a guilty people\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
excepting the household of Lot. We shall deliver all of them,\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
except his wife (about whom Allah says that) We have decreed that she shall be among those who stay behind."\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
So when the envoys came to the household of Lot,\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
he said: ``Surely you are an unknown folk."\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said: ``Nay, we have brought to you that concerning which they have been in doubt.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
We truly tell you that we have brought to you the Truth.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
So set out with your family in a watch of the night, and keep yourself behind them, and no one of you may turn around, and keep going ahead as you have been commanded."\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We communicated to him the decree that by the morning those people will be totally destroyed.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
In the meantime the people of the city came to Lot rejoicing.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
He said: ``These are my guests, so do not disgrace me.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
Have fear of Allah, and do not humiliate me."\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They replied: ``Did we not forbid you again and again to extend hospitality to all and sundry?"\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
Lot exclaimed in exasperation: ``If you are bent on doing something, then here are my daughters."\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
By your life, (O Prophet), they went about blindly stumbling in their intoxication.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
Then the mighty Blast caught them at sunrise,\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
and turned the land upside down, and rained down stones of baked clay.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
There are great Signs in this for those endowed with intelligence.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
The place (where this occurred) lies along a known route.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Verily there is a Sign in this for the believers.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
And the people of Aykah were also wrong-doers.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
So We chastised them. The desolate locations of both communities lie on a well-known highway.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
Surely the people of al-Hijr also rejected the Messengers, calling them liars.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
We also gave them Our Signs, yet they turned away from them.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
They used to hew out houses from the mountains and lived in security.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
Then the Blast caught them in the morning\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
and whatever they had been earning proved of no avail.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
We have not created the heavens and the earth and all that is in between them except with Truth. Surely the Hour will come. So, (O Muhammad), do graciously overlook them (despite their misdeeds).\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Your Lord is indeed the Creator of all, the All-Knowing.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
We have indeed bestowed on you the seven oft-repeated verses and the Great Qur'an.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Do not even cast your eyes towards the worldly goods We have granted to different kinds of people, nor grieve over the state they are in, but turn your loving attention to the believers instead,\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
and clearly tell the unbelievers: ``I am most certainly a plain warner,"\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
even as We had sent warning to those who had divided their religion into fragments;\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
those who had split up their Qur'an into pieces.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
By your Lord, We will question them all\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
concerning what they have been doing.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
(O Prophet), proclaim what you are commanded, and pay no heed to those who associate others with Allah in His Divinity.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
Surely We suffice to deal with those who scoff at you,\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
those who set up another deity alongside Allah. They shall soon come to know.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
We certainly know that their statements sorely grieve you.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcm{%
When (you feel so) glorify your Lord with His praise and prostrate yourself before Him,\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mcmi{%
and worship your Lord until the last moment (of your life) that will most certainly come.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen Allah's judgement has (all but) come; do not, then, call for its speedy advent. Holy is He, and far above their associating others with Him in His Divinity.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sends down this spirit (of prophecy) by His command through His angels on any of His servants whom He wills, (directing them): ``Warn people that there is no deity but Me; so hold Me alone in fear."\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He created the heavens and the earth with Truth. Exalted is He above whatever they associate with Allah in His Divinity.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mcmv{%
He created man out of a mere drop of fluid, and lo! he turned into an open wrangler.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mcmvi{%
He created the cattle. They are a source of clothing and food and also a variety of other benefits for you.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And you find beauty in them as you drive them to pasture in the morning and as you drive them back home in the evening;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mcmviii{%
and they carry your loads to many a place which you would be unable to reach without much hardship. Surely your Lord is Intensely Loving, Most Merciful.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mcmix{%
And He created horses and mules and asses for you to ride, and also for your adornment. And He creates many things (for you) that you do not even know about.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mcmx{%
It rests with Allah alone to show you the Right Way, even when there are many crooked ways. Had He so willed, He would have (perforce) guided you all aright.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mcmxi{%
He it is Who sends down water for you from the sky out of which you drink and out of which grow the plants on which you pasture your cattle,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mcmxii{%
and by virtue of which He causes crops and olives and date-palms and grapes and all kinds of fruit to grow for you. Surely in this there is a great Sign for those who reflect.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
He has subjected for you the night and the day and the sun and the moon and the stars have also been made subservient by His command. Surely there are Signs in this for those who use their reason.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And there are also Signs for those who take heed in the numerous things of various colours that He has created for you on earth.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mcmxv{%
And He it is Who has subjected the sea that you may eat fresh fish from it and bring forth ornaments from it that you can wear. And you see ships ploughing their course through it so that you may go forth seeking His Bounty and be grateful to Him.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He has placed firm mountains on the earth lest it should move away from you, and has made rivers and tracks that you may find your way,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
and He has set other landmarks in the earth. And by the stars too do people find their way.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is then the One Who creates like the one who does not create? Will you not, then, take heed?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mcmxix{%
For, were you to count the favours of Allah, you will not be able to count them. Surely Allah is Ever Forgiving, Most Merciful.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mcmxx{%
Allah knows all that you conceal and all that you disclose.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
Those whom they call upon beside Allah have created nothing; rather, they themselves were created;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
they are dead, not living. They do not even know when they will be resurrected.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your God is the One God. But the hearts of those who do not believe in the Hereafter are steeped in rejection of the Truth, and they are given to arrogance.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Surely Allah knows all that they conceal and all that they disclose. He certainly does not love those who are steeped in arrogance.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
When they are asked: ``What is it that your Lord has revealed?" They answer: ``They are merely tales of olden times!"\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
(They say so) that they may bear the full weight of their burdens on the Day of Resurrection and also of the burdens of those whom they misled on account of their ignorance. What a heavy burden are they undertaking to bear!\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Surely many people before them had plotted in a similar manner to (vanquish the Truth), but Allah uprooted the whole structure of their plot from its foundations so that the roof fell in upon them, and the chastisement (of Allah) visited them from unknown directions.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
And again, on the Day of Resurrection, He will bring them to disgrace, and say: ``Tell Me, now, where are those to whom you ascribed a share in My Divinity, and for whose sake you disputed (with the upholders of the Truth)?" Those who were endowed with knowledge (in the world) will say: ``Surely today humiliation and misery shall be the lot of the unbelievers";\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
the same unbelievers who, when the angels seize them and cause them to die while they are engaged in wrong-doing, they will proffer their submission saying: ``We were engaged in no evil." (The angels will answer them): ``Surely Allah knows well all that you did.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
Go now, and enter the gate of Hell, and abide in it for ever. `` Evil indeed is the abode of the arrogant.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And when the God-fearing are asked: ``What has your Lord revealed?" they answer: ``Something excellent!" Good fortune in this world awaits those who do good; and certainly the abode of the Hereafter is even better for them. How excellent is the abode of the God-fearing:\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
everlasting gardens that they shall enter; the gardens beneath which rivers shall flow, and where they shall have whatever they desire! Thus does Allah reward the God-fearing,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
those whose souls the angels seize while they are in a state of purity, saying: ``Peace be upon you. Enter Paradise as a reward for your deeds."\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
(O Muhammad), are they waiting for anything else than that the angels should appear before them, or that your Lord's judgement should come? Many before them acted with similar temerity. And then what happened with them was not Allah's wrong-doing; they rather wronged themselves.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
The evil consequences of their misdeeds overtook them and what they mocked at overwhelmed them.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
Those who associate others with Allah in His Divinity say: ``Were Allah to will so, neither we nor our forefathers would have worshipped any other than Him, nor would we have prohibited anything without His command." Their predecessors proffered similar excuses. Do the Messengers have any other duty but to plainly convey the Message?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
We raised a Messenger in every community (to tell them): ``Serve Allah and shun the Evil One." Thereafter Allah guided some of them while others were overtaken by error. Go about the earth, then, and observe what was the end of those who rejected the Messengers, calling them liars.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
(O Muhammad), howsoever eager you may be to show them the Right Way, Allah does not bestow His guidance on those whom He lets go astray; and in fact none will be able to help them.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
They swear most solemnly in the name of Allah and say: ``Allah shall not raise to life any who dies." (Yes, He will do so); that is a promise by which He is bound, even though most people do not know that.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mcmxl{%
(That is bound to happen in order that) He may make clear to them the reality regarding the matters on which they differ and that the unbelievers may realize that they were liars.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mcmxli{%
(As for the possibility of resurrection, bear in mind that) whenever We do will something, We have to do no more than say: ``Be", and it is.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
As for those who have forsaken their homes for the sake of Allah after enduring persecution, We shall certainly grant them a good abode in this world; and surely the reward of the Hereafter is much greater. If they could but know (what an excellent end awaits)\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
those who remain steadfast and put their trust in their Lord.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
(O Muhammad), whenever We raised any Messengers before you, they were no other than human beings; (except that) to them We sent revelation. So ask those who possess knowledge if you do not know.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
We raised the Messengers earlier with Clear Signs and Divine Books, and We have now sent down this Reminder upon you that you may elucidate to people the teaching that has been sent down for them, and that the people may themselves reflect.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Do those who have been devising evil plans (against the mission of the Messenger) feel secure that Allah will not cause the earth to swallow them up or that chastisement will not come upon them from a direction that they will not even be able to imagine;\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
or that He will not suddenly seize them while they are going about to and fro and they will be unable to frustrate His design,\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
or that He will not seize them when they are apprehensive of the impending calamity? Surely your Lord is Most Compassionate, Most Merciful.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Do the people not see how the objects Allah has created cast their shadows right and left, prostrating themselves in utter submission to Allah?\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mcml{%
All living creatures and all angels in the heavens and on the earth are in prostration before Allah; and never do they behave in arrogant defiance.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mcmli{%
They hold their Lord, Who is above them, in fear, and do as they are bidden.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mcmlii{%
Allah has commanded: ``Do not take two gods; for He is but One God. So fear Me alone."\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mcmliii{%
His is whatever is in the heavens and the earth, and obedience to Him inevitably pervades the whole universe. Will you, then, hold in awe any other than Allah?\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mcmliv{%
Every bounty that you enjoy is from Allah; and whenever any misfortune strikes you, it is to Him that you cry for the removal of your distress.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mcmlv{%
But as soon as He removes the distress from you, some of you associate others with their Lord in giving thanks,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
that they may show ingratitude for the bounties We bestowed upon them. So enjoy yourselves for a while, soon you will come to know (the truth).\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
They set apart for those, whose reality they do not even know, a portion of the sustenance We have provided them. By Allah, you will surely be called to account for the lies that you have invented!\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
They assign daughters to Allah - glory be to Him - whereas they assign to themselves what they truly desire!\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mcmlix{%
When any of them is told about the birth of a female his face turns dark, and he is filled with suppressed anger,\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mcmlx{%
and he hides himself from people because of the bad news, thinking: should he keep the child despite disgrace, or should he bury it in dust? How evil is their estimate of Allah!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
Those who do not believe in the Hereafter deserve to be characterized with evil attributes whereas Allah's are the most excellent attributes. He is the Most Mighty, the Most Wise.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
Were Allah to take people to task for their wrong-doing, He would not have spared even a single living creature on the face of the earth. But He grants them respite until an appointed term. And when that term arrives, they have no power to delay it by a single moment, nor to hasten it.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
They assign to Allah what they dislike for themselves and their tongues utter a sheer lie in stating that a happy state awaits them. Without doubt the Fire awaits them and it is to it that they shall be hastened.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By Allah, (O Muhammad), We sent Messengers to other communities before you but Satan made their evil deeds attractive to them (so they paid no heed to the call of the Messengers). The same Satan is their patron today and they are heading towards a painful chastisement.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
We have sent down the Book that you may explain to them the truth concerning what they are disputing and that the Book may serve as a guidance and mercy for those who believe in it.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
Allah sends down water from the heaven, and thereby He instantly revives the earth after it lay dead. Verily there is a sign in it for those who have ears.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
Surely there is a lesson for you in the cattle: We provide you to drink out of that which is in their bellies between the faeces and the blood - pure milk - which is a palatable drink for those who take it.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And out of the fruits of date-palms and grapes you derive intoxicants as well as wholesome sustenance. Surely there is a sign for those who use reason.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
Your Lord inspired the bee, saying: ``Set up hives in the mountains and in the trees and in the trellises that people put up,\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
then suck the juice of every kind of fruit and keep treading the ways of your Lord which have been made easy." There comes forth from their bellies a drink varied in colours, wherein there is healing for men. Verily there is a sign in this for those who reflect.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
Allah has created you, and then He causes you to die. Some of you have your lives prolonged to an abject old age, when one loses all knowledge after having acquired it. Allah is All-Knowing, All-Powerful.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
Allah has favoured some of you with more worldly provisions than others. Then those who are more favoured do not give away their provisions to their slaves lest they become equal sharers in it. Do they, then, deny the favour of Allah?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
And Allah has given you spouses from your kind, and has granted you through your spouses, sons and grandsons, and has provided you wholesome things as sustenance. (After knowing all this), do they still believe in falsehood and deny Allah's bounty,\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
and worship instead of Allah, those helpless beings who have no control over providing them any sustenance from the heavens and the earth; do you worship those who have no power to do anything of this sort?\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
So do not strike any similitudes to Allah. Allah knows whereas you do not know.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah sets forth a parable: There is one who is a slave and is owned by another and has no power over anything; and there is one whom We have granted good provision Ourselves, of which he spends both secretly and openly. Can they be equal? All praise be to Allah. But most of them do not even know (this simple fact).\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
Allah sets forth another parable: There are two men, one of whom is dumb and has no power over anything; he is a burden to his master, and wheresoever his master directs him, he fails to bring forth any good. Can such a person be the equal of one who enjoins justice and himself follows the Right Way?\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
Allah has full knowledge of the truths beyond the reach of perception both in the heavens and the earth; and the coming of the Hour will take no more than the twinkling of an eye; it may take even less. Indeed Allah has power over everything.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
Allah has brought you forth from your mothers' wombs when you knew nothing, and then gave you hearing, and sight and thinking hearts so that you may give thanks.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Have they never noticed the birds how they are held under control in the middle of the sky, where none holds them (from falling) except Allah? Surely there are signs in this for those who believe.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
Allah has made your houses a repose, and has provided you with the skins of the cattle for your habitation which are light to handle both when you travel and when you camp; and out of their wool and their fur and their hair He has given you furnishings and goods for use over a period of time.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And Allah has provided shade for you out of some of the things He has created; and He has provided you with shelters in the mountains, and has given you coats that protect you from heat as well as coats that protect you in battle. Thus does He complete His favour upon you that you may submit to Him.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
But if they turn away, your only duty is to clearly deliver the message of the truth.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They are aware of the favours of Allah, and yet refuse to acknowledge them. Most of them are determined not to accept the Truth.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
(They are heedless of) the Day when We shall raise a witness from each community and then the unbelievers will neither be allowed to plead nor will they be asked to repent and seek pardon.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
Once the wrong-doers have beheld the chastisement, neither will it be lightened for them nor will they be granted any respite.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when those who associated others with Allah in His Divinity will see those to whom they ascribed this share, they will say: ``Our Lord! These are the beings to whom we ascribed a share in Your Divinity and whom we called upon instead of You," whereupon those beings will fling at them the words: ``You are liars."\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
On that Day they will offer their submission and all that they had fabricated will have vanished.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
As for those who disbelieved and barred others from the way of Allah, We shall add further chastisement to their chastisement for all the mischief they did.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mcmxc{%
(O Muhammad), warn them of the coming of a Day when We shall bring forth a witness against them from each community and We shall bring you forth as a witness against them all; (and it is for that purpose that) We sent down the Book to you which makes everything clear, and serves as a guidance and mercy and glad tidings to those who have submitted to Allah.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Surely Allah enjoins justice, kindness and the doing of good to kith and kin, and forbids all that is shameful, evil and oppressive. He exhorts you so that you may be mindful.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
And fulfil the covenant which you have made with Allah and do not break your oaths after having firmly made them, and after having made Allah your witness. Surely Allah knows all that you do.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And do not become like the woman who, after having painstakingly spun her yarn, caused it to disintegrate into pieces. You resort to oaths as instruments of mutual deceit so that one people might take greater advantage than another although Allah puts you to the test through this. Surely on the Day of Resurrection He will make clear the Truth concerning the matters over which you differed.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
Had Allah so willed, He would have made you all one single community. However, He lets go astray whomsoever He wills and shows the Right Way to whomsoever He wills. Surely you shall be called to account regarding what you did.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
Do not make your oaths a means of deceiving one another or else your foot may slip after having been firm, and you may suffer evil consequences because of hindering people from the way of Allah. A mighty chastisement awaits you.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
Do not barter away the covenant of Allah for a paltry gain. Verily that which is with Allah is far better for you, if you only knew.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
Whatever you have is bound to pass away and whatever is with Allah will last. And We shall surely grant those who have been patient their reward according to the best of what they did.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whosoever acts righteously - whether a man or a woman - and embraces belief, We will surely grant him a good life; and will surely grant such persons their reward according to the best of their deeds.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
Whenever you read the Qur'an seek refuge with Allah from Satan, the accursed.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mm{%
Surely he has no power over those who have faith and who place their trust in their Lord.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmi{%
He has power only over those who take him as their patron and who, under his influence, associate others with Allah in His Divinity.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmii{%
Whenever We replace one verse by another verse - and Allah knows what He should reveal - they are wont to say: ``You are nothing but a fabricator (who has invented the Qur'an)." The fact is that most of them are ignorant of the Truth.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmiii{%
Tell them: ``It is the spirit of holiness that has brought it down, by stages, from your Lord so that it might bring firmness to those who believe, and guidance to the Right Way, and give glad tidings of felicity and success to those who submit to Allah."\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmiv{%
Surely We know well that they say about you: ``It is only a human being who teaches him," (notwithstanding) that he whom they maliciously hint at is of foreign tongue, while this (Qur'an) is plain Arabic speech.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmv{%
Surely Allah will not enable those who do not believe in the signs of Allah to be directed to the Right Way, and a painful chastisement awaits them.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmvi{%
(It is not the Prophet who invents lies), it is rather those who do not believe in the signs of Allah who invent lies. They are liars.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmvii{%
Except for those who were forced to engage in infidelity to Allah after believing the while their hearts remained firmly convinced of their belief, the ones whose hearts willingly embraced disbelief shall incur Allah's wrath and a mighty chastisement lies in store for them.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmviii{%
That is because they love the life of this world more than the Hereafter; and Allah does not guide those who are ungrateful to Allah for His favours.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmix{%
They are the ones upon whose hearts and hearing and eyes Allah has set a seal. They are utterly steeped in heedlessness.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmx{%
No doubt they shall be losers in the Hereafter.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmxi{%
And surely your Lord will be Most Forgiving and Most Merciful towards those who left their homes after they were persecuted, and who thereafter struggled hard and remained constant.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmxii{%
Allah's judgement will come about them all on the Day when everyone shall come pleading in his defence, and everyone shall be fully requited for his deeds and none shall be wronged in the least.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmxiii{%
Allah sets forth the parable of (the people of) a town who were secure and content and whose sustenance came in abundance from every quarter. But then the people of the town showed ingratitude towards Allah for His bounties, so Allah afflicted them with hunger and fear in punishment for their evil deeds.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmxiv{%
Most certainly a Messenger came to them from among them; but they rejected him, calling him a liar. Therefore chastisement seized them while they engaged in wrong-doing.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmxv{%
So eat out of the lawful and good sustenance that Allah has bestowed upon you, and thank Allah for His bounty, if it is Him that you serve.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmxvi{%
Allah has forbidden you only carrion, and blood, and the flesh of swine; also any animal over which the name of any other than Allah has been pronounced. But whoever eats of them under compelling necessity - neither desiring it nor exceeding the limit of absolute necessity - surely for such action Allah is Much Forgiving, Most Merciful.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And do not utter falsehoods by letting your tongues declare: ``This is lawful" and ``That is unlawful," thus fabricating lies against Allah. Surely those who fabricate lies against Allah will never prosper.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmxviii{%
Brief is their enjoyment of the world, and thereafter they shall suffer a painful chastisement.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmxix{%
We have already recounted to you what We prohibited to the Jews. In so doing We did not wrong them; it is they who wronged themselves.\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmxx{%
But to those who commit evil out of ignorance and then repent and amend their ways, thereafter your Lord will be Much Forgiving, Most Merciful.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Indeed Abraham was a whole community by himself, obedient to Allah, exclusively devoted to Him. And he was never one of those who associated others with Allah in His Divinity.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmxxii{%
He rendered thanks to Allah for His bounties so that Allah chose him (for His favours) and directed him to the Right Way.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
We bestowed good upon him in this world, and in the Hereafter he shall certainly be among the righteous.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
Then We revealed to you: ``Follow the way of Abraham with exclusive devotion to Allah. He was not one of those who associated others with Allah in His Divinity."\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmxxv{%
As for the Sabbath, it was made incumbent only on those who differed about its laws. Certainly your Lord will judge on the Day of Resurrection between them regarding the matters they disputed.\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
(O Prophet), call to the way of your Lord with wisdom and goodly exhortation, and reason with them in the best manner possible. Surely your Lord knows best who has strayed away from His path, and He also knows well those who are guided to the Right Way.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
If you take retribution, then do so in proportion to the wrong done to you. But if you can bear such conduct with patience, indeed that is best for the steadfast.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
And bear with patience, (O Muhammad) - and your patience is only because of the help of Allah - and do not grieve over them, nor feel distressed by their evil plans.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmxxix{%
For surely Allah is with those who hold Him in fear and do good.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Holy is He Who carried His servant by night from the Holy Mosque (in Makkah) to the farther Mosque (in Jerusalem) whose surroundings We have blessed that We might show him some of Our Signs. Indeed He alone is All-Hearing, All-Seeing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
We gave Moses the Book, and made it a source of guidance for the Children of Israel, commanding: ``Take no other Guardian beside Me."\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
You are the descendants of those whom We carried (in the Ark) with Noah. He was truly a thankful servant.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
Then We clearly declared to the Children of Israel in the Book: ``Twice you will make mischief in the land and will commit transgression."\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
So, when the occasion for the first of the transgressions arrived, We raised against you some of Our creatures who were full of might, and they ran over the whole of your land. This was a promise that was bound to be fulfilled.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then We granted you an upper hand against them, and strengthened you with wealth and children, and multiplied your numbers.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
Whenever you did good, it was to your own advantage; and whenever you committed evil, it was to your own disadvantage. So, when the time of the fulfilment of the second promise arrived, (We raised other enemies that would) disfigure your faces and enter the Temple (of Jerusalem) as they had entered the first time, and destroy whatever they could lay their hands on.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
Your Lord may well show Mercy to you, but if you revert to your evil behaviour, We shall revert to chastising you. We have made Hell a prison for those who are thankless of Allah's bounties.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Verily this Qur'an guides to the Way that is the Straight most. To those who believe in it, and do righteous works, it gives the good news that a great reward awaits them,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
and warns those who do not believe in the Hereafter that We have prepared for them a grievous chastisement.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmxl{%
Man prays for evil in the manner he ought to pray for good. Man is ever hasty.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmxli{%
We have made night and day as two signs. We made the sign of the night devoid of light, and made the sign of the day radiant that you may seek the bounty of your Lord and know the computation of years and numbers. Thus We have expounded everything in detail to keep everything distinct from the other.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmxlii{%
We have fastened every man's omen to his neck. On the Day of Resurrection We shall produce for him his scroll in the shape of a wide open book, (saying):\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmxliii{%
``Read your scroll; this Day you suffice to take account of yourself."\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmxliv{%
He who follows the Right Way shall do so to his own advantage; and he who strays shall incur his own loss. No one shall bear another's burden. And never do We punish any people until We send a Messenger (to make the Truth distinct from falsehood).\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmxlv{%
When We decide to destroy a town We command the affluent among them, whereupon they commit sins in it, then the decree (of chastisement) becomes due against them and thereafter We destroy that town utterly.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
Many a generation has been destroyed by Our command since Noah's time. Your Lord is well aware and fully observant of the sins of His servants.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
If anyone desires immediate benefits, We hasten to grant whatever benefits We will in the present life to whomsoever We please, but thereafter We decree for him Hell wherein he shall burn, condemned and rejected.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
But he who desires the Hereafter and strives for it in the manner he should, and is a true believer, his striving will come to fruition.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmxlix{%
To all of these as well as those We shall provide the wherewithal of this life in the present world by dint of your Lord's Bounty; and from none shall the Bounty of your Lord be withheld.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mml{%
See, how We have exalted some above others in this world, and in the Life to Come they will have higher ranks and greater degrees of excellence over others.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmli{%
Do not set up any other god with Allah lest you are rendered humiliated and helpless.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmlii{%
Your Lord has decreed: (i) Do not worship any but Him; (ii) Be good to your parents; and should both or any one of them attain old age with you, do not say to them even ``fie" neither chide them, but speak to them with respect,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmliii{%
and be humble and tender to them and say: ``Lord, show mercy to them as they nurtured me when I was small."\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord is best aware of what is in your hearts. If you are righteous, He will indeed forgive those who relent and revert (to serving Allah).\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmlv{%
(iii) Give to the near of kin his due, and also to the needy and the wayfarer. (iv) Do not squander your wealth wastefully,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmlvi{%
for those who squander wastefully are Satan's brothers, and Satan is ever ungrateful to his Lord.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmlvii{%
(v) And when you must turn away from them - (that is, from the destitute, the near of kin, the needy, and the wayfarer) - in pursuit of God's Mercy which you expect to receive, then speak to them kindly.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmlviii{%
(vi) Do not keep your hand fastened to your neck nor outspread it, altogether outspread, for you will be left sitting rebuked, destitute.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmlix{%
Certainly Your Lord makes plentiful the provision of whomsoever He wills and straitens it for whomsoever He wills. He is well-aware and is fully observant of all that relates to His servants.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmlx{%
(vii) Do not kill your children for fear of want. We will provide for them and for you. Surely killing them is a great sin.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmlxi{%
(viii) Do not even approach fornication for it is an outrageous act, and an evil way.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmlxii{%
(ix) Do not kill any person whom Allah has forbidden to kill, except with right. We have granted the heir of him who has been wrongfully killed the authority to (claim retribution); so let him not exceed in slaying. He shall be helped.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
(x) And do not even go near the property of the orphan - except that it be in the best manner - till he attains his maturity. (xi) And fulfil the covenant, for you will be called to account regarding the covenant.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
(xii) Give full measure when you measure, and weigh with even scales. That is fair and better in consequence.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmlxv{%
(xiii) Do not follow that of which you have no knowledge. Surely the hearing, the sight, the heart - each of these shall be called to account.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
(xiv) Do not strut about in the land arrogantly. Surely you cannot cleave the earth, nor reach the heights of the mountains in stature.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
The wickedness of each of that is hateful to your Lord.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
That is part of the wisdom your Lord has revealed to you. So do not set up any deity beside Allah lest you are cast into Hell, rebuked and deprived of every good.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmlxix{%
What, has your Lord favoured you with sons and has taken for Himself daughters from among the angels? You are indeed uttering a monstrous lie.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmlxx{%
We have expounded (the Truth) in diverse ways in this Qur'an that they might take it to heart but all this only aggravates their aversion.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say, (O Muhammad): ``Had there been other gods with Him, as they claim, they would surely have attempted to find a way to the Lord of the Throne.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Holy is He and far above all that they say.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens, the earth, and all that is within them give glory to Him. There is nothing but gives glory to Him with His praise, though you do not understand their hymns of praise. He is Most Forbearing, Exceedingly Forgiving."\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
When you recite the Qur'an, We place a hidden barrier between you and those who do not believe in the Hereafter;\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
and We place a covering on their hearts so that they do not comprehend it, and We cause a heaviness in their ears; and when you mention your Lord, the Only True Lord, in the Qur'an, they turn their backs in aversion.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We are well aware of what they wish to hear when they listen to you and what they say when they confer in whispers, when the wrong-doers say: ``You are only following one who is bewitched."\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
Just see how strange are the things they invent about you. They have altogether strayed, and are unable to find the right way.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
They say: ``When we are turned to bones and particles (of dust), shall we truly be raised up as a new creation?"\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Tell them: ``(You will be raised afresh even if) you turn to stone or iron,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
or any other form of creation you deem hardest of all (to recreate from)." They will certainly ask: ``Who will bring us back (to life)?" Say: ``He Who created you in the first instance." They will shake their heads at you and inquire: ``When will that be?" Say: ``Perhaps that time might have drawn near;\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
on the Day when He will call you and you will rise praising Him in response to His call, and you will believe that you had lain in this state only for a while."\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
Tell My servants, (O Muhammad), to say always that which is best. Verily it is Satan who sows discord among people. Satan indeed is an open enemy to mankind.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord knows you best. He will have mercy on you if He wills and chastise you if He wills. We have not sent you, (O Muhammad), as an overseer over them.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
Your Lord knows all who dwell in the heavens and the earth. We have exalted some Prophets over others, and We gave the Psalms to David.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Tell them: ``Call upon those whom you fancy to be (your helpers) instead of Him! They have no power to remove any affliction from you, nor can they shift it (to any other)."\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those whom they call upon are themselves seeking the means of access to their Lord, each trying to be nearer to Him. They crave for His Mercy and dread His chastisement. Surely your Lord's punishment is to be feared.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
There is not a town but We shall destroy it or upon which We shall inflict severe chastisement before the Day of Resurrection. This is written down in the Eternal Book (of Allah).\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
Nothing hindered Us from sending Our Signs except that the people of olden times rejected them as lies. We publicly sent the she-camel to the Thamud to open their eyes but they wronged her. We never send Our Signs except to cause people to fear.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
And recall when We said to you, (O Muhammad), that your Lord encompasses these people; and that We have made that vision that We have shown you, and the tree accursed in the Qur'an, but as a trial for people. We go about warning them, but each warning leads them to greater transgression.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmxc{%
And recall when We asked the angels to prostrate themselves before Adam; all prostrated themselves except Iblis, who said: ``Shall I prostrate myself before him whom You created of clay?"\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmxci{%
He then continued: ``Look! This is he whom You have exalted above me! If you will grant me respite till the Day of Resurrection I shall uproot the whole of his progeny except only a few."\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmxcii{%
Thereupon He retorted: ``Be gone! Hell shall be the recompense - and a most ample one - of whosoever of them who follows you.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmxciii{%
Tempt with your call all whom you wish. Muster against them all your forces - your cavalry and your foot soldiers; share with them riches and offspring, and seduce them with rosy promises - and Satan's promise is nothing but a deception -\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmxciv{%
but know well that you will have no power against My servants. Your Lord suffices for them to place their trust in."\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmxcv{%
Your Lord is He Who steers your vessels across the seas that you may seek of His Bounty. He is ever Merciful towards you.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
When a calamity befalls you on the sea, all those whom you invoke forsake you except Him. But when He delivers you safely to the shore you turn away from Him, for man is indeed most thankless.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Do you, then, feel secure against His causing you to be swallowed up by a tract of the earth, or letting loose a deadly whirlwind charged with stones towards you, and there you will find none to protect you?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or do you feel secure that He will not cause you to revert to the sea, and let a tempest loose upon you and then drown you for your ingratitude whereupon you will find none even to inquire of Us what happened to you?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmxcix{%
Indeed, We honoured the progeny of Adam, and bore them across land and sea and provided them with good things for their sustenance, and exalted them above many of Our creatures.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmc{%
Then think of the Day We shall summon every community with its leader. Those who are given their Record in their right hand shall read the Record of their deeds and shall not be wronged a whit.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmci{%
Whoever lived in this world as blind shall live as blind in the Life to Come; rather, he will be even farther astray than if he were (just) blind.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcii{%
(O Muhammad), they had all but tempted you away from what We have revealed to you that you may invent something else in Our Name. Had you done so, they would have taken you as their trusted friend.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmciii{%
Indeed, had We not strengthened you, you might have inclined to them a little,\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmciv{%
whereupon We would have made you taste double (the chastisement) in the world and double (the chastisement) after death, and then you would have found none to help you against Us.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcv{%
They were bent upon uprooting you from this land and driving you away from it. But were they to succeed, they would not be able to remain after you more than a little while.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcvi{%
This has been Our Way with the Messengers whom We sent before you. You will find no change in Our Way.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Establish Prayer from the declining of the sun to the darkness of the night; and hold fast to the recitation of the Qur'an at dawn, for the recitation of the Qur'an at dawn is witnessed.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And rise from sleep during the night as well- this is an additional Prayer for you. Possibly your Lord will raise you to an honoured position.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcix{%
And pray: ``My Lord! Cause me to enter wherever it be, with Truth, and cause me to exit, wherever it be, with Truth, and support me with authority from Yourself."\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcx{%
And proclaim: ``The Truth has come, and falsehood has vanished. Surely falsehood is ever bound to vanish."\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcxi{%
What We are sending down in the course of revealing the Qur'an is a healing and a grace for those who have faith; but it adds only to the ruin of the wrong-doers.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcxii{%
Whenever We bestow favours upon man, he arrogantly turns away and draws aside; and whenever evil visits him, he is in utter despair.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say, (O Prophet): ``Each one acts according to his own manner. Your Lord knows well who is best-guided to the Right Path."\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
They ask you about ``the spirit". Say: ``The spirit descends by the command of my Lord, but you have been given only a little knowledge."\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcxv{%
Had We willed, We could take away what We have revealed to you, then you would find none to help you in recovering it from Us.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
(Whatever you have received) is nothing but grace from your Lord. Indeed His favour to you is great.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say: ``Surely, if mankind and jinn were to get together to produce the like of this Qur'an, they will never be able to produce the like of it, howsoever they might help one another."\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
We have explained things for people in this Qur'an in diverse ways to make them understand the Message, yet most people obstinately persist in unbelief.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcxix{%
They said: ``We shall not accept your Message until you cause a spring to gush forth for us from the earth;\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcxx{%
or that there be a garden of palms and vines for you and then you cause rivers to abundantly flow forth through them;\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
or cause the sky to fall on us in pieces as you claimed, or bring Allah and the angels before us, face to face;\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
or that there come to be for you a house of gold, or that you ascend to the sky - though we shall not believe in your ascension (to the sky) - until you bring down a book for us that we can read." Say to them, (O Muhammad): ``Holy is my Lord! Am I anything else than a human being, who bears a Message (from Allah)?"\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
Whenever Guidance came to people, nothing prevented them from believing except that they said: ``Has Allah sent a human being as a Messenger?"\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say: ``Had angels been walking about in peace on the earth, We would surely have sent to them an angel from the heavens as Messenger."\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Tell them, (O Prophet): ``Allah suffices as a witness between me and you. Allah is well aware and fully observes everything pertaining to His servants."\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
Whomsoever Allah guides is rightly guided; and whomsoever Allah lets go astray, you shall find none - apart from Him - who could protect him. We shall muster them all on the Day of Resurrection, on their faces - blind and dumb and deaf. Hell shall be their refuge. Every time its Fire subsides, We will intensify for them its flame.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
That will be their recompense because they disbelieved in Our Signs and said: ``What, when we shall be reduced to bones and particles (of dust), shall we be raised again as a new creation?"\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
Have they not perceived that Allah, Who has created the heavens and the earth, has the power to create the like of them? He has fixed a term for them about which there is no doubt. And yet the wrong-doers obstinately persist in unbelief.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Tell them, (O Prophet): ``Even if you owned the treasures of my Lord's Mercy you would have held them back for fear of spending them." Man is indeed ever niggardly.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
We granted Moses nine clear signs. Ask the Children of Israel about that: when these signs came forth, Pharaoh said to him: ``Moses, I think that you are bewitched."\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
Moses replied: ``You know well that no one but the Lord of the heavens and the earth has sent these as eye-opening proofs. I truly think, O Pharaoh, that you are indeed doomed."\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
At last Pharaoh decided to uproot Moses and the Children of Israel from the land, but We drowned him together with all who were with him;\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
and thereafter We said to the Children of Israel: ``Now dwell in the land, but when the promised time of the Hereafter comes, We shall bring you all together."\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
We have sent down the Qur'an with the Truth, and it is with the Truth that it has descended. And We have not sent you but to proclaim good news and to warn.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
We have revealed the Qur'an in parts that you may recite it to people slowly and with deliberation; and (for that reason) We have revealed it gradually (to suit particular occasions).\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Tell them, (O Prophet): ``Whether you believe in it, or do not believe," but when it is recited to those who were given the knowledge before its revelation, they fall down upon their faces in prostration\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
and say: ``Glory be to our Lord. Surely the promise of our Lord was bound to be fulfilled."\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
And they fall down upon their faces, weeping, and their humility increases when (the Qur'an) is recited to them.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say to them (O Prophet!): ``Call upon Him as Allah or call upon Him as al-Rahman; call Him by whichever name you will, all His names are beautiful. Neither offer your Prayer in too loud a voice, nor in a voice too low; but follow a middle course."\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say: ``All praise be to Allah Who has neither taken to Himself a son, nor has He any partner in His kingdom, nor does He need anyone, out of weakness, to protect Him." So glorify Him in a manner worthy of His glory.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen Praise be to Allah Who has revealed to His servant the Book devoid of all crookedness;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
an unerringly Straight Book, meant to warn of a stern punishment from Allah, and to proclaim, to those who believe and work righteous deeds, the tiding that theirs shall be a good reward\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
wherein they shall abide for ever;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
and also to warn those who say: ``Allah has taken to Himself a son,"\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
a thing about which they have no knowledge, neither they nor their ancestors. Dreadful is the word that comes out of their mouths. What they utter is merely a lie.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
(O Muhammad), if they do not believe in this Message, you will perhaps torment yourself to death with grief, sorrowing over them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
Surely We have made all that is on the earth an embellishment for it in order to test people as to who of them is better in conduct.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
In the ultimate, We shall reduce all that is on the earth to a barren plain.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Do you think that the people of the Cave and the Inscription were one of Our wondrous signs?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcl{%
When those youths sought refuge in the Cave and said: ``Our Lord! Grant us mercy from Yourself and provide for us rectitude in our affairs."\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcli{%
We lulled them to sleep in that cave for a number of years\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmclii{%
and then roused them so that We might see which of the two parties could best tell the length of their stay.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We narrate to you their true story. They were a party of young men who had faith in their Lord, and We increased them in guidance\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcliv{%
and strengthened their hearts when they stood up and proclaimed: ``Our Lord is the Lord of the heavens and the earth. We shall call upon no other god beside Him; (for if we did so), we shall be uttering a blasphemy."\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmclv{%
(Then they conferred among themselves and said): ``These men, our own people, have taken others as gods beside Him: why do they not bring any clear evidence that they indeed are gods? Who can be more unjust than he who foists a lie on Allah?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmclvi{%
And now that you have dissociated yourselves from them and from whatever they worship beside Allah, go and seek refuge in the Cave. Your Lord will extend His mercy to you and will provide for you the means for the disposal of your affairs."\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmclvii{%
Had you seen them in the Cave it would have appeared to you that when the sun rose, it moved away from their Cave to the right; and when it set, it turned away from them to the left, while they remained in a spacious hollow in the Cave. This is one of the Signs of Allah. Whomsoever Allah guides, he alone is led aright; and whomsoever Allah lets go astray, you will find for him no guardian to direct him.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmclviii{%
On seeing them you would fancy them to be awake though they were asleep; and We caused them to turn their sides to their right and to their left, and their dog sat stretching out its forelegs on the threshold of the Cave. Had you looked upon them you would have certainly fled away from them, their sight filling you with terror.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmclix{%
Likewise, We roused them in a miraculous way that they might question one another. One of them asked: ``How long did you remain (in this state)?" The others said: ``We remained so for a day or part of a day." Then they said: ``Your Lord knows better how long we remained in this state. Now send one of you to the city with this coin of yours and let him see who has the best food, and let him buy some provisions from there. Let him be cautious and not inform anyone of our whereabouts.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmclx{%
For if they should come upon us, they will stone us to death or force us to revert to their faith whereafter we shall never prosper."\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmclxi{%
Thus did We make their case known to the people of the city so that they might know that Allah's promise is true, and that there is absolutely no doubt that the Hour will come to pass. But instead of giving thought to this, they disputed with one another concerning the People of the Cave, some saying: ``Build a wall over them. Their Lord alone knows best about them." But those who prevailed over their affairs said: ``We shall build a place of worship over them."\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmclxii{%
Some will say concerning them: ``They were three and their dog, the fourth"; and some will say: ``They were five, and their dog, the sixth" -- all this being merely guesswork; and still others will say: ``They were seven, and their dog, the eighth." Say: ``My Lord knows their number best. Only a few know their correct number. So do not dispute concerning their number, but stick to what is evident, and do not question anyone about them."\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And never say about anything: ``I shall certainly do this tomorrow"\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
unless Allah should will it. And should you forget (and make such a statement), remember your Lord and say: ``I expect my Lord to guide me to what is nearer to rectitude than this."\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmclxv{%
They remained in the Cave for three hundred years; and others added nine more years.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say: ``Allah knows best how long they remained in it, for only He knows all that is hidden in the heavens and the earth. How well He sees; how well He hears! The creatures have no other guardian than Him; He allows none to share His authority."\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
(O Prophet), recite to them from the Book of your Lord what has been revealed to you for none may change His words; (and were you to make any change in His words) you will find no refuge from Him.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
Keep yourself content with those who call upon their Lord, morning and evening, seeking His pleasure, and do not let your eyes pass beyond them. Do you seek the pomp and glitter of the world? Do not follow him whose heart We have caused to be heedless of Our remembrance, and who follows his desires, and whose attitude is of excess.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmclxix{%
And proclaim: ``This is the Truth from your Lord. Now let him who will, believe; and let him who will, disbelieve. We have prepared a Fire for the wrong-doers whose billowing folds encompass them. If they ask for water, they will be served with a drink like dregs of oil that will scald their faces. How dreadful a drink, and how evil an abode!\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmclxx{%
As for those who believe and do good We shall not cause their reward to be lost.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
They shall dwell in the Gardens of Eternity, beneath which streams flow. There they will be adorned with bracelets of gold, will be arrayed in green garments of silk and rich brocade, and will recline on raised couches. How excellent is their reward, and how nice their resting-place!"\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
(O Muhammad), propound a parable to them. There were two men of whom We bestowed upon one of the two vineyards, surrounding both of them with date-palms and putting a tillage in between.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Both the vineyards yielded abundant produce without failure and We caused a stream to flow in their midst\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
so the owner had fruit in abundance and he said to his neighbour, while conversing with him: ``I have greater wealth than you and I am stronger than you in numbers."\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
Then he entered his vine-yard and said, wronging himself: ``Surely, I do not believe that all this will ever perish.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
Nor do I believe that the Hour of Resurrection will ever come to pass. And even if I am returned to my Lord, I shall find a better place than this."\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
While conversing with him his neighbour exclaimed: ``Do you deny Him Who created you out of dust, then out of a drop of sperm, and then fashioned you into a complete man?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
As for myself, Allah alone is my Lord, and I associate none with my Lord in His Divinity.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
When you entered your vineyard, why did you not say: 'Whatever Allah wills shall come to pass, for there is no power save with Allah!' If you find me less than yourself in wealth and children\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
it may well be that my Lord will give me something better than your vineyard, and send a calamity upon your vineyard from the heavens and it will be reduced to a barren waste,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
or the water of your vineyard will be drained deep into the ground so that you will not be able to seek it out."\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
Eventually all his produce was destroyed and he began to wring his hands in sorrow at the loss of what he had spent on it, and on seeing it fallen down upon its trellises, saying: ``Would I had not associated anyone with my Lord in His Divinity."\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
And there was no host, beside Allah, to help him, nor could he be of any help to himself.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
(Then he knew) that all power of protection rests with Allah, the True One. He is the best to reward, the best to determine the end of things.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
(O Prophet), propound to them the parable of the present life: it is like the vegetation of the earth which flourished luxuriantly when it mingled with the water that We sent down from the sky, but after that the same vegetation turned into stubble which the winds blew about. Allah alone has the power over all things.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and children are an adornment of the life of the world. But the deeds of lasting righteousness are the best in the sight of your Lord in reward, and far better a source of hope.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
Bear in mind the Day when We shall set the mountains in motion and you will find the earth void and bare. On that Day We shall muster all men together, leaving none of them behind.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
They shall be brought before your Lord, all lined up, and shall be told: ``Now, indeed, you have come before Us in the manner We created you in the first instance, although you thought that We shall not appoint a tryst (with Us)."\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And then the Record of their deeds shall be placed before them and you will see the guilty full of fear for what it contains, and will say: ``Woe to us! What a Record this is! It leaves nothing, big or small, but encompasses it." They will find their deeds confronting them. Your Lord wrongs no one.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcxc{%
And recall when We said to the angels: ``Prostrate yourselves before Adam"; all of them fell prostrate, except Iblis. He was of the jinn and so disobeyed the command of his Lord. Will you, then, take him and his progeny as your guardians rather than Me although they are your open enemies? What an evil substitute are these wrong-doers taking!\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcxci{%
I did not call them to witness the creation of the heavens and the earth, nor in their own creation. I do not seek the aid of those who lead people astray.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
What will such people do on the Day when the Lord will say: ``Now call upon all those whom you believed to be My partners?" Thereupon they will call upon them, but they will not respond to their call; and We shall make them a common pit of doom,\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
and the guilty shall behold the Fire and know that they are bound to fall into it, and will find no escape from it.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
And surely We have explained matters to people in the Qur'an in diverse ways, using all manner of parables. But man is exceedingly contentious.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
What is it that prevented mankind from believing when the guidance came to them, and from asking forgiveness of their Lord, except that they would like to be treated as the nations of yore, or that they would like to see the scourge come upon them face to face?\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
We raise Messengers only to give good news and to warn. But the unbelievers resort to falsehood in order to rebut the truth with it, and scoff at My revelations and My warnings.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
Who is more wicked than the man who, when he is reminded by the revelations of his Lord, turns away from them and forgets (the consequence of) the deeds wrought by his own hands? We have laid veils over their hearts lest they understand the message of the Qur'an, and We have caused heaviness in their ears. Call them as you may to the Right Path, they will not be ever guided aright.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
Your Lord is All-Forgiving, full of mercy. Had He wished to take them to task for their doings, He would have hastened in sending His scourge upon them. But He has set for them a time-limit which they cannot evade.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
All the townships afflicted with scourge are before your eyes. When they committed wrong, We destroyed them. For the destruction of each We had set a definite term.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcc{%
(And recount to them the story of Moses) when Moses said to his servant: ``I will journey on until I reach the point where the two rivers meet, though I may march on for ages."\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcci{%
But when they reached the point where the two rivers meet, they forgot their fish, and it took its way into the sea, as if through a tunnel.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmccii{%
When they had journeyed further on, Moses said to his servant: ``Bring us our repast. We are surely fatigued by today's journey."\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcciii{%
The servant said: ``Did you see what happened? When we betook ourselves to the rock to take rest, I forgot the fish - and it is only Satan who caused me to forget to mention it to you - so that it made its way into the sea in a strange manner."\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcciv{%
Moses said: ``That is what we were looking for." So the two turned back, retracing their footsteps,\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmccv{%
and there they found one of Our servants upon whom We had bestowed Our mercy, and to whom We had imparted a special knowledge from Ourselves.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Moses said to him: ``May l follow you that you may teach me something of the wisdom which you have been taught?"\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmccvii{%
He answered: ``You will surely not be able to bear with me.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmccviii{%
For how can you patiently bear with something you cannot encompass in your knowledge?"\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmccix{%
Moses replied: ``You shall find me, if Allah wills, patient; and I shall not disobey you in anything."\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmccx{%
He said: ``Well, if you follow me, do not ask me concerning anything until I myself mention it to you."\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmccxi{%
Then the two went forth until, when they embarked on the boat, he made a hole in it, whereupon Moses exclaimed: ``Have you made a hole in it so as to drown the people in the boat? You have certainly done an awful thing."\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmccxii{%
He replied: ``Did I not tell you that you will not be able to patiently bear with me?"\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
Moses said: ``Do not take me to task at my forgetfulness, and do not be hard on me."\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
Then the two went forth until they met a lad whom he slew, whereupon Moses exclaimed: ``What! Have you slain an innocent person without his having slain anyone? Surely you have done a horrible thing."\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmccxv{%
He said: ``Did I not tell you that you will not be able to patiently bear with me?"\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
Moses said: ``Keep me no more in your company if I question you concerning anything after this. You will then be fully justified."\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
Then the two went forth until when they came to a town, they asked its people for food, but they refused to play host to them. They found in that town a wall that was on the verge of tumbling down, and he buttressed it, whereupon Moses said: ``If you had wished, you could have received payment for it."\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
He said: ``This brings me and you to a parting of ways. Now I shall explain to you the true meaning of things about which you could not remain patient.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmccxix{%
As for the boat it belonged to some poor people who worked on the river, and I desired to damage it for beyond them lay the dominion of a king who was wont to seize every boat by force.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmccxx{%
As for the lad, his parents were people of faith, and we feared lest he should plague them with transgression and disbelief,\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
and we desired that their Lord should grant them another in his place, a son more upright and more tender hearted.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
As for the wall, it belonged to two orphan boys in the city, and under it there was a treasure that belonged to them. Their father was a righteous man and your Lord intended that they should come of age and then bring forth their treasure as a mercy from your Lord; I did not do this of my own bidding. This is the true meaning of things with which you could not keep your patience."\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
(O Muhammad), they ask you about Dhu al-Qarnayn. Say: ``I will give you an account of him."\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
We granted him power in the land and endowed him with all kinds of resources.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
He set out (westwards) on an expedition,\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
until when he reached the very limits where the sun sets, he saw it setting in dark turbid waters; and nearby he met a people. We said: ``O Dhu al-Qarnayn, you have the power to punish or to treat them with kindness."\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said: ``We will chastise him who does wrong, whereafter he will be returned to his Lord and He will chastise him grievously.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
But as for him who believes and acts righteously, his will be a goodly reward and we shall enjoin upon him only mild commands."\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then he set out on another expedition\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
until he reached the limit where the sun rises and he found it rising on a people whom We had provided no shelter from it.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
Thus was the state of those people, and We encompassed in knowledge all concerning Dhu al- Qarnayn.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then he set out on another expedition\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
until when he reached a place between the two mountains, he found beside the mountains a people who scarcely understood anything.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said: ``O Dhu al-Qarnayn, Gog and Magog are spreading corruption in this land. So shall we pay you taxes on the understanding that you will set up a barrier between us and them?"\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He answered: ``Whatever my Lord has granted me is good enough. But help me with your labour and I will erect a rampart between you and them.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
Bring me ingots of iron." Then after he had filled up the space between the two mountain-sides, he said: ``(Light a fire) and ply bellows." When he had made it (red like) fire, he said: ``Bring me molten copper which I may pour on it."\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
Such was the rampart that Gog and Magog could not scale, nor could they pierce it.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
Dhu al-Qarnayn said: ``This is a mercy from my Lord: but when the time of my Lord's promise shall come, He will level the rampart with the ground. My Lord's promise always comes true."\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
And on that Day We shall let some of them surge like waves against others, and the Trumpet shall be blown. Then We shall gather them all together.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmccxl{%
That will be the Day We shall place Hell before the unbelievers\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmccxli{%
whose eyes had become blind against My admonition and who were utterly disinclined to hear it.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Do the unbelievers, then, believe that they can take any of My creatures as their guardians beside Me? Verily We have prepared Hell to welcome the unbelievers.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say, (O Muhammad): ``Shall We tell you who will be the greatest losers in respect of their works?\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
It will be those whose effort went astray in the life of the world and who believe nevertheless that they are doing good.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
Those are the ones who refused to believe in the revelations of their Lord and that they are bound to meet Him. Hence, all their deeds have come to naught, and We shall assign no weight to them on the Day of Resurrection.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
Hell is their recompense for disbelieving and their taking My revelations and My Messengers as objects of jest.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
As for those who believe and do good works, the Gardens of Paradise shall be there to welcome them;\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
there they will abide for ever, with no desire to be removed from there."\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say: ``If the sea were to become ink to record the Words of my Lord, indeed the sea would be all used up before the Words of my Lord are exhausted, and it would be the same even if We were to bring an equal amount of ink."\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say (O Muhammad): ``I am no more than a human being like you; one to whom revelation is made: 'Your Lord is the One and Only God.' Hence, whoever looks forward to meet his Lord, let him do righteous works, and let him associate none with the worship of his Lord."\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf. Ha'. Ya'. Ayn. Sad.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcclii{%
This is an account of the mercy of your Lord to His servant Zechariah\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmccliii{%
when he cried to his Lord in secret.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmccliv{%
He said: ``Lord! My bones have grown feeble and my head is glistening with age; yet, never have my prayers to You, my Lord, been unfruitful.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcclv{%
I fear evil from my kinsmen after I am gone; and my wife is barren, so grant me an heir out of Your special grace,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
one that might be my heir and the heir of the house of Jacob; and make him, Lord, one that will be pleasing to You.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
(He was told): ``Zechariah, We bring you the good news of the birth of a son whose name shall be Yahya (John), one whose namesake We never created before."\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said: ``My Lord! How can I have a boy when my wife is barren and I have reached an extremely old age?"\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcclix{%
He answered: ``So shall it be." Your Lord says: ``It is easy for Me," and then added: ``For beyond doubt, I created you earlier when you were nothing."\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcclx{%
Zechariah said: ``Lord, grant me a Sign." Said He: ``Your Sign is that you shall not be able to speak to people for three nights, though you will be otherwise sound."\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
Thereupon Zechariah came out from the sanctuary and directed his people by gestures to extol His glory by day and by night.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
``O John! Hold the Book with all your strength." We had bestowed wisdom upon him while he was still a child;\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
and We also endowed him with tenderness and purity, and he was exceedingly pious\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
and cherishing to his parents. Never was he insolent or rebellious.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
Peace be upon him the day he was born, and the day he will die, and the day he will be raised up alive.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
(O Muhammad), recite in the Book the account of Mary, when she withdrew from her people to a place towards the east;\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
and drew a curtain, screening herself from people whereupon We sent to her Our spirit and he appeared to her as a well-shaped man.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
Mary exclaimed: ``I surely take refuge from you with the Most Compassionate Lord, if you are at all God-fearing."\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
He said: ``I am just a message-bearer of your Lord, I have come to grant you a most pure boy."\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
Mary said: ``How can a boy be born to me when no man has even touched me, nor have I ever been unchaste?"\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
The angel said: ``Thus shall it be. Your Lord says: 'It is easy for Me; and We shall do so in order to make him a Sign for mankind and a mercy from Us. This has been decreed.' ``\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
Then she conceived him and withdrew with him to a far-off place.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
Then the birth pangs drove her to the trunk of a palm-tree and she said: ``Oh, would that I had died before this and had been all forgotten."\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
Thereupon the angel below her cried out: ``Grieve not, for your Lord has caused a stream of water to flow beneath you.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
Shake the trunk of the palm-tree towards yourself and fresh and ripe dates shall fall upon you.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
So eat and drink and cool your eyes; and if you see any person say to him: 'Verily I have vowed a fast to the Most Compassionate Lord, and so I shall not speak to anyone today.' ``\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
Then she came to her people, carrying her baby. They said: ``O Mary! You have committed a monstrous thing.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
O sister of Aaron! Your father was not an evil man, nor was your mother an unchaste woman."\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
Thereupon Mary pointed to the child. They exclaimed: ``How can we speak to one who is in the cradle, a mere child?"\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
The child cried out: ``Verily I am Allah's servant. He has granted me the Book and has made me a Prophet\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
and has blessed me wherever I might be and has enjoined upon me Prayer and Zakah (purifying alms) as long as I live;\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
and has made me dutiful to my mother. He has not made me oppressive, nor bereft of God's blessings.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
Peace be upon me the day I was born and the day I will die, and the day I will be raised up alive."\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
This is Jesus, the son of Mary; and this is the truth about him concerning which they are in doubt.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It does not befit Allah to take for Himself a son. Glory be to Him! When He decrees a thing He only says: ``Be" and it is.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
(Jesus had said): ``Indeed Allah is my Lord and your Lord, so serve Him alone. This is the Straight Way."\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
But different parties began to dispute with one another. A dreadful woe awaits on that great Day for those that reject the Truth.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
How well shall they hear and how well shall they see on the Day they come to Us! But today the evil-doers are in manifest error.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
(O Muhammad), warn those who are steeped in heedlessness and are obstinately rejecting the truth that the Day shall come when things will be finally decided and they shall be left with utter remorse.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmccxc{%
Ultimately, We shall inherit the earth and whatever is on it; to Us shall they be returned.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmccxci{%
(O Muhammad), recite in the Book the account of Abraham. Most surely he was a man of truth, a Prophet.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
(And remind people) when he said to his father: ``Father! Why do you worship that which neither sees nor hears, and which can be of no avail to you?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
Father, a knowledge that has not reached you has come to me. So follow me that I may guide you to a Straight Way.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
Father, do not serve Satan, for Satan has indeed been a persistent rebel against the Most Compassionate Lord.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
Father, I fear that a punishment from the Most Compassionate Lord might strike you and you may end up as one of Satan's companions?"\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
The father said: ``Abraham, have you turned away from my gods? If you do not give this up, I shall stone you to death. Now begone from me forever."\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
Abraham answered: ``Peace be upon you. I shall seek pardon for you from my Lord. My Lord has always been kind to Me.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
I shall withdraw from you and all that you call upon beside Allah. I shall only call upon my Lord. I trust the prayer to my Lord will not go unanswered."\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
Thereupon Abraham dissociated himself from his people and the deities they worshipped instead of Allah, and We bestowed upon him Isaac and Jacob and made each of them a Prophet;\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmccc{%
and We bestowed on them Our mercy, and granted them a truly lofty renown.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmccci{%
And recite in the Book the account of Moses. He was a chosen one, a Messenger, a Prophet.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcccii{%
We called out to him from the right side of the Mount, and We drew him near to Us by communing to him in secret,\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmccciii{%
and out of Our mercy We appointed his brother Aaron, a Prophet (that he may assist him).\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And recite in the Book the account of Ishmael. He was ever true to his promise, and was a Messenger, a Prophet.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcccv{%
He enjoined his household to observe Prayer and to give Zakah (purifying alms); and his Lord was well pleased with him.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And recite in the Book the account of Idris. He was a man of truth, a Prophet;\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
and We exalted him to a lofty position.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
These are the Prophets upon whom Allah bestowed His favour from the seed of Adam, and from the seed of those whom We carried (in the Ark) with Noah, and from the seed of Abraham and Israel. They were those whom We guided and chose (for an exalted position). They were such that when the words of the Most Compassionate Lord were recited to them, they fell down in prostration, weeping.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcccix{%
They were succeeded by a people who neglected the Prayers and pursued their lusts. They shall presently meet with their doom,\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcccx{%
except those who repent and believe and act righteously. Such shall enter Paradise and shall not be wronged at all.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
Theirs shall be everlasting Gardens which the Most Compassionate Lord has promised His servants in a realm which is beyond the ken of perception. Surely His promise shall he fulfilled.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They shall not hear in it anything vain; they shall hear only what is good; and they shall have their provision in it, morning and evening.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
Such is the Paradise which We shall cause those of Our servants who have been God-fearing to inherit.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
(The angels will say): ``(O Muhammad!) We descend not except by the command of your Lord. To Him belongs all that is before us and all that is behind us, and all that is in between. Your Lord is not forgetful in the least.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
He is the Lord of the heavens and the earth and all that is in between. Serve Him, then, and be constant in serving Him. Do you know anyone that might be His compeer?"\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
Man is prone to say: ``Shall I be raised to life after I die?"\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Does man not remember that We created him before when he was nothing?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
By your Lord, We will surely muster them and the devils together. Then We will surely bring them all, on their knees, around Hell,\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
and then We will draw aside from each party those who were most rebellious against the Most Compassionate Lord,\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
and then We shall know well all those most worthy to be cast in Hell.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
There is not one of you but shall pass by Hell. This is a decree which your Lord will fulfil.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then We shall deliver those that feared Allah and leave the wrong-doers there on their knees.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
When Our clear revelations are recited to those who deny the Truth they are wont to say to those who have faith: ``Which of the two groups has a better status and whose assemblies are grander?"\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
How numerous are the peoples We destroyed before them - those that were more resourceful and grander in outward appearance!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say: ``The Most Compassionate Lord grants respite to those who stray into error, until they behold what they had been threatened with, either God's chastisement (in the world) or the Hour (of Resurrection)" - then they fully know whose station is worse, and who is weaker in hosts!\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
(On the contrary), Allah increases in guidance those who follow the Right Way. Lasting acts of righteousness are better in the sight of your Lord as reward and conducive to a better end.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Have you seen him who rejected Our signs and said: ``Surely I shall continue to be favoured with riches and children."\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Has he obtained knowledge of the Unseen, or has he taken a covenant with the Most Compassionate Lord?\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
By no means! We shall write down all what he says; and We shall greatly prolong his chastisement,\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
and We shall inherit all the resources and hosts of which he boasts, and he will come to Us all alone.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
They have taken other gods instead of Allah that they may be a source of strength for them.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
By no means! They shall soon deny their worship and shall become their adversaries instead.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Do you not see that We have sent devils upon the unbelievers who greatly incite them (to oppose the Truth)?\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
Therefore, do not hasten (in seeking a scourge against them). We are counting their days.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
The Day shall soon come when We shall bring together the God-fearing to the Most Compassionate Lord, as honoured guests;\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
and We shall drive the guilty ones to Hell as a thirsty herd.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
On that Day none will have the power to intercede for them except those who received a sanction from the Most Compassionate Lord.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
They claim: ``The Most Compassionate Lord has taken a son to Himself."\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
Surely you have made a monstrous statement.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
It is such a monstrosity that heavens might well-nigh burst forth at it, the earth might be cleaved, and the mountains fall\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
at their ascribing a son to the Most Compassionate Lord.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
It does not befit the Most Compassionate Lord that He should take a son.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
There is no one in the heavens and the earth but he shall come to the Most Compassionate Lord as His servant.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
Verily He encompasses them and has counted them all.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
On the Day of Resurrection each one of these will come to Him singly.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Indeed, the Most Compassionate Lord will soon create enduring love for those who believe and do righteous works.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
Therefore, We have revealed the Qur'an in your tongue and made it easy to understand that you may give glad tidings to the God-fearing and warn a contentious people.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
How numerous are the peoples that We destroyed before them! Do you now perceive any one of them, or hear even their whisper?\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta' Ha'\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We did not reveal the Qur'an to you to cause you distress;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcccli{%
it is only a reminder for him who fears Allah;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmccclii{%
a revelation from Him Who created the earth and the high heavens.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
The Most Compassionate Lord is settled on the Throne (of the Universe).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
To Him belongs all that is in the heavens and all that is in the earth, and all that is in between, and all that is beneath the soil.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmccclv{%
Whether you speak out aloud (or in a low voice), He knows what is said secretly, and even that which is most hidden.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah - there is no god but He. His are the most excellent names.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
Has the story of Moses reached you?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire and said to his family: ``Hold on! I have just perceived a fire; perhaps I will bring a brand from it for you, or I will find some guidance at the fire about the way to follow."\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmccclix{%
When he came to it, a voice called out: ``Moses!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmccclx{%
Verily I am your Lord! Take off your shoes. You are in the sacred valley, Tuwa!\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
I Myself have chosen you; therefore, give ear to what is revealed.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
Verily I am Allah. There is no god beside Me. So serve Me and establish Prayers to remember Me.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
The Hour of Resurrection is coming. I have willed to keep the time of its coming hidden so that everyone may be recompensed in accordance with his effort.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
Let him who does not believe in it and follows his lust not turn your thought away from it, lest you are ruined.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
And what is in your right hand, O Moses?"\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
Moses answered: ``This is my staff. I lean on it (when I walk), and with it I beat down leaves for my flock, and I have many other uses for it."\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
He said: ``Moses, throw it down."\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
So he threw it down, and lo! it was a rapidly moving snake.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
Then He said: ``Seize it and have no fear. We shall restore it to its former state.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
And place your hand in your armpit, it will come forth shining white, without blemish. This is another Sign of Allah,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
for We shall show you some of Our greatest Signs.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
And go to Pharaoh now for he has transgressed all bounds."\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
Moses said: ``Lord! Open my breast for me;\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
and ease my task for me,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
and loosen the knot from my tongue\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
so that they may understand my speech;\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
and appoint for me, from my household, someone who will help me bear my burden -\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
Aaron, my brother.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
Strengthen me through him\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
and let him share my task\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
that we may abundantly extol Your glory;\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
and may remember You much.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
Verily, You have always watched over us."\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
He said: ``Moses, your petition is granted.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
We have again bestowed Our favour upon you.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
Recall, when We indicated to your mother through inspiration:\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
'Put the baby into a chest and then throw him in the river. The river will throw him up on the shore, and then an enemy of Mine and an enemy of his will take him.' And I spread My love over you in order that you might be reared in My sight.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
Recall, when your sister went along, saying: 'Shall I direct you to one who will take charge of him?' Thus We brought you back to your mother so that her heart might be gladdened and she might not grieve. Moses, recall when you slew a person. We delivered you from distress and made you go through several trials. Then you stayed for several years among the people of Midian, and now you have come at the right moment as ordained.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
I have chosen you for My service.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
So go forth, both you and your brother, with My Signs, and do not slacken in remembering Me.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
Go both of you to Pharaoh, for he has transgressed all bounds,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
and speak to him gently, perhaps he may take heed or fear (Allah)."\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
The two said:" Lord! We fear he may commit excesses against us, or transgress all bounds."\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He said: ``Have no fear. I am with you, hearing and seeing all.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
So, go to him, and say: 'Behold, both of us are the Messengers of your Lord. Let the Children of Israel go with us, and do not chastise them. We have come to you with a sign from your Lord; and peace shall be for him who follows the true guidance.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
It has been revealed to us that chastisement awaits those who called the lie to the truth and turned away from it.' ``\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
Pharaoh said:" Moses! Who is the Lord of the two of you?"\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
He said: ``Our Lord is He Who gave everything its form and then guided it."\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
Pharaoh asked: ``Then, what is the state of the former generations?"\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcd{%
Moses said: ``Its knowledge is with my Lord, recorded in the Book. My Lord does not err, nor does He forget."\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcdi{%
He it is Who spread the earth for you; and made in it paths for you, and sent down water from the sky, and then through it We brought forth many species of diverse plants.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcdii{%
So eat yourself and pasture your cattle. Surely there are many Signs in this for people of understanding.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
From this very earth We created you and to the same earth We shall cause you to return, and from it We shall bring you forth to life again.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
Indeed We showed Pharaoh Our Signs, all of them, but he declared them to be false and rejected them.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He said: ``Have you come to us to drive us out of our land by your sorcery?\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
We shall confront you with a sorcery like your own. So appoint a day when both of us might meet face to face in an open space; an appointment which neither we nor you shall fail to keep."\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
Moses said: ``The appointment to meet you is on the Day of the Feast and let all people come together before noon."\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
Pharaoh went back and concerted all his stratagem and returned for the encounter.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcdix{%
(At the time of the encounter) Moses said to them: ``Woe to you! Do not invent falsehoods against Allah lest He destroy you with a scourge. Surely those who invent lies shall come to grief."\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcdx{%
Thereupon they wrangled among themselves about the matter and conferred in secret.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
Some of them said: ``These two are magicians, who want to drive you out of your land with their magic and to destroy your excellent way of life.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
So muster all your stratagem and come forth in a row. Whoever prevails today shall triumph."\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
The magicians said: ``Moses, will you throw down or shall we be the first to throw?"\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
Moses replied: ``No, let it be you to throw first." Then suddenly it appeared to Moses, owing to their magic, as if their ropes and staffs were running.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
So Moses' heart was filled with fear.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We said to him: ``Have no fear; for it is you who will prevail.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
And throw down what is in your right hand; it will swallow up all that they have wrought. They have wrought only a magician's stratagem. A magician cannot come to any good, come whence he may."\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
Eventually the magicians were impelled to fall down prostrate and said: ``We believe in the Lord of Moses and Aaron."\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
Pharaoh said: ``What! Did you believe in Him even before I permitted you to do so? Surely, he must be your chief who taught you magic. Now I will certainly cut off your hands and your feet on opposite sides, and will crucify you on the trunks of palm-trees, and then you will come to know which of us can inflict sterner and more lasting torment."\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
The magicians answered: ``By Him Who has created us, we shall never prefer you to the Truth after manifest Signs have come to us. So decree whatever you will. Your decree will pertain, at the most, to the present life of the world.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
We believe in our Lord that He may forgive us our sins and also forgive us the practice of magic to which you had compelled us. Allah is the Best and He alone will abide."\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
The truth is that Hell awaits him who comes to his Lord laden with sin; he shall neither die in it nor live.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
But he who comes to Him with faith and righteous works shall be exalted to high ranks,\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
and shall live for ever in everlasting Gardens beneath which rivers flow. Such will be the reward of those who purify themselves.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
Most certainly We revealed to Moses: ``Proceed with My servants in the night and strike for them a dry path in the sea. Have no fear of being overtaken, nor be afraid of treading through the sea."\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Pharaoh pursued them with his hosts, but they were fully overwhelmed by the sea.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
Pharaoh led his people astray; he did not guide them aright.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
Children of Israel! We saved you from your enemy and made a covenant with you on the right side of the Mount and sent down on you manna and quails,\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
saying: ``Partake of the good things that We have provided for you, but do not transgress lest My wrath fall upon you; for he upon whom My wrath falls is ruined.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
But I am indeed Most Forgiving to him who repents and believes and does righteous works and keeps to the Right Way."\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
``But, O Moses, what has made you come in haste from your people?"\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He said: ``They are close behind me, and I hastened to You, Lord, that You may be pleased with me."\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
Said He: ``Verily We tested your people in your absence and the Samiri led them astray."\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
Moses returned to his people full of wrath and grief, and said: ``My people! Has your Lord not made good an excellent promise He made to you? And has a long time passed since those promises were fulfilled? Or was it to incur the wrath of your Lord that you broke your promise with me?"\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They answered: ``We did not break our promise with you out of our own volition; but we were laden with the load of people's ornaments, and we simply threw them down(into the fire), and the Samiri also threw down something,\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
and brought out of there (from the molten gold) the effigy of a calf that lowed." The people cried out: ``This is your deity and the deity of Moses, whom Moses has forgotten."\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
Did they not see that it did not return a word to them, and had no power either to hurt them or to cause them any benefit?\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
Certainly Aaron had said to them even before (the return of Moses): ``My people, you were fallen into error because of the calf. Surely your Lord is Most Compassionate; so follow me and obey my command."\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
But they answered: ``By no means shall we cease to worship it until Moses returns to us."\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
(After rebuking his people) Moses turned to Aaron and said: ``Aaron! What prevented you, when you saw them going astray,\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
from following my way? Have you disobeyed my command?"\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
Aaron answered: ``Son of my mother! Do not seize me with my beard, nor by (the hair of) my head. I feared that on returning you might say: 'You sowed discord among the Children of Israel, and did not pay heed to my words.'"\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
Moses said: ``What, then, is your case, O Samiri?"\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
He answered: ``I saw what the people did not see. So I took a handful of dust from the trail of the Messenger, and I flung it (into the fire). Thus did my mind prompt me."\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
Moses said: ``Be gone, then. All your life you shall cry: 'Untouchable.' There awaits a term for your reckoning that you cannot fail to keep. Now look at your god that you devotedly adored: We shall burn it and scatter its remains in the sea.\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Your God is none else than Allah, beside Whom there is no god. His knowledge embraces everything."\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
(O Muhammad), thus do We recount to you the events of the past, and We have bestowed upon you from Ourself an admonition.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
He who turns away from it will surely bear a heavy burden on the Day of Resurrection,\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
and will abide under this burden for ever. Grievous shall be the burden on the Day of Resurrection,\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmcdl{%
the Day when the Trumpet shall be sounded and We shall muster the sinners, their eyes turned blue with terror.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmcdli{%
They shall whisper among themselves: ``You stayed on the earth barely ten days."\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We know well what they will say to one another: We also know that even the most cautious in his estimate will say: ``You lived in the world no more than a day."\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
They ask you concerning the mountains: ``Where will they go?" Say: ``My Lord will scatter them like dust,\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
and leave the earth a levelled plain\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
in which you shall find no crookedness or curvature.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that Day people shall follow straight on to the call of the summoner, no one daring to show any haughtiness. Their voices shall be hushed before the Most Compassionate Lord, so that you will hear nothing but a whispering murmur.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
On that Day intercession shall not avail save of him whom the Most Compassionate Lord permits, and whose word of intercession is pleasing to Him.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knows all that is ahead of them and all that is behind them, while the others do not know.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
All faces shall be humbled before the Ever-Living, the Self-Subsisting Lord, and he who bears the burden of iniquity will have failed;\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
but whosoever does righteous works, being a believer, shall have no fear of suffering wrong or loss."\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
(O Muhammad), thus have We revealed this as an Arabic Qur'an and have expounded in it warning in diverse ways so that they may avoid evil or become heedful.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
Exalted is Allah, the True King! Hasten not with reciting the Qur'an before its revelation to you is finished, and pray: ``Lord! Increase me in knowledge."\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
Most certainly We had given Adam a command before, but he forgot. We found him lacking in firmness of resolution.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
Recall when We said to the angels: ``Prostrate yourselves before Adam"; all prostrated themselves save Iblis. He refused.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
Then We said: ``Adam! He is an enemy to you and to your wife. So let him not drive both of you out of Paradise and plunge you into affliction,\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
(for in Paradise) neither are you hungry nor naked,\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
nor face thirst or scorching heat."\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
But Satan seduced him, saying: ``Adam! Shall I direct you to a tree of eternal life and an abiding kingdom?"\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
Then the two of them ate the fruit of that tree and their shameful parts became revealed to each other, and they began to cover themselves with the leaves from the Garden. Thus Adam disobeyed his Lord and strayed into error.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
Thereafter his Lord exalted him, accepted his repentance, and bestowed guidance upon him,\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
and said: ``Get down, both of you, (that is, man and Satan), and be out of it; each of you shall be an enemy to the other. Henceforth if there comes to you a guidance from Me, then whosoever follows My guidance shall neither go astray nor suffer misery.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
But whosoever turns away from this Admonition from Me shall have a straitened life; We shall raise him blind on the Day of Resurrection,"\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
where-upon he will say: ``Lord! Why have You raised me blind when I had sight in the world?"\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
He will say: ``Even so it is. Our Signs came to you and you ignored them. So shall you be ignored this Day."\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
Thus do We requite him who transgresses and does not believe in the signs of your Lord (during the life of the world); and surely the punishment of the Hereafter is even more terrible and more enduring.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Did they not find any guidance in the fact that We destroyed many nations in whose ruined dwelling-places they now walk about? Surely there are many Signs in them for people endowed with wisdom.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
Were it not for a word already gone from your Lord, the decree (of their destruction) would have come to pass.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
So bear patiently with what they say. Glorify your Lord, praising Him before sunrise and before sunset, and in the watches of the night, and glorify Him and at the ends of the day that you may attain to happiness.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
Do not turn your eyes covetously towards the embellishments of worldly life that We have bestowed upon various kinds of people to test them. But the clean provision bestowed upon you by your Lord is better and more enduring.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
Enjoin Prayer on your household, and do keep observing it. We do not ask you for any worldly provision; rather, it is We Who provide you, and ultimately the pious will end up the best.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
They ask: ``Why does he not bring us a (miraculous) sign from his Lord?" Has there not come to them a Book containing the teachings of the previous scriptures?\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
Had We destroyed them through some calamity before his coming, they would have said: ``Our Lord! Why did You not send any Messenger to us that we might have followed Your signs before being humbled and disgraced?"\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Tell them, (O Muhammad): ``Everyone is waiting for his end. Wait, then, and you will soon know who are the people of the Right Way, and are rightly-guided."\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen The time of people's reckoning has drawn near, and yet they turn aside in heedlessness.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
Whenever any fresh admonition comes to them from their Lord they barely heed it and remain immersed in play,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
their hearts being set on other concerns. The wrong-doers whisper to one another: ``This person is no more than a mortal like yourselves. Will you, then, be enchanted by sorcery while you see?"\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
He said: ``My Lord knows well all that is spoken in the heavens and the earth. He is All-Hearing, All- Knowing."\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
They say: ``Nay, these are confused dreams; nay, he has forged it; nay, he is a poet. So let him bring us a sign, even as the Messengers of the past were sent with signs."\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
Not one township that We destroyed before them believed. Would they, then, believe?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
(O Muhammad), even before you We never sent any other than human beings as Messengers, and to them We sent revelation. Ask the People of the Book if you do not know.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
We did not endow the Messengers with bodies that would need no food; nor were they immortals.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
Then We fulfilled the promise We had made to them: We rescued them and those whom We wished, and We destroyed those who exceeded all bounds.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
We have bestowed upon you a Book that mentions you. Do you not understand?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
How many a wrong-doing town did We shatter and then raise up another people.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
Then, when they perceived Our chastisement they took to their heels and fled.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
(They were told): ``Flee not, but return to your comforts and to your dwellings. You are likely to be questioned."\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They said: ``Woe to us; surely we were wrong-doers."\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
They did not cease to cry this until We reduced them to stubble, still and silent.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
We did not create in sport the heavens and the earth and all that lies between the two.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmd{%
Had it been Our will to find a pastime, We would have found one near at hand; if at all We were inclined to do so.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdi{%
Nay, We hurl the Truth at falsehood so that the Truth crushes falsehood, and lo! it vanishes. Woe to you for what you utter!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdii{%
To Him belongs whosoever dwells in the heavens and on earth. Those (angels) that are with Him neither disdain to serve Him out of pride, nor do they weary of it.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They glorify Him night and day, without flagging.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Have they taken earthly gods who are such that they raise up the dead to life?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdv{%
Had there been any gods in the heavens and the earth apart from Allah, the order of both the heavens and the earth would have gone to ruins. Glory be to Allah, the Lord of the Throne, Who is far above their false descriptions of Him.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdvi{%
None shall question Him about what He does, but they shall be questioned.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Have they taken gods other than Him? Say, (O Muhammad): ``Bring forth your proof! Here is the Book with admonition for those of my time and there are also scriptures with admonition for people before me." But most people do not know the Truth, and have, therefore, turned away from it.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdviii{%
Never did We send any Messenger before you to whom We did not reveal: ``There is no god but Me. So serve Me alone."\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdix{%
They say: ``The Most Compassionate Lord has taken to Himself a son." Glory be to Him! Those whom they so designate are only His honoured servants.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdx{%
They do not outstrip Him in speech and only act as He commands.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows whatever is before them and whatsoever is remote from them and they do not intercede except for him, intercession on whose behalf pleases Him, and they stand constantly in awe of Him.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdxii{%
And if anyone of them were to claim: ``Indeed I am a god apart from Him," We shall recompense both with Hell. Thus do We recompense the wrong-doers.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Did the unbelievers (who do not accept the teaching of the Prophet) not realize that the heavens and the earth were one solid mass, then We tore them apart, and We made every living being out of water? Will they, then, not believe (that We created all this)?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We placed firm mountains on earth lest it should sway with them, and We made wide paths in them that they may find their way;\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdxv{%
and We made the sky a secure canopy; and yet they turn away from these Signs.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
It is He Who created the night and the day, and the sun and the moon. Each of them is floating in its orbit.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
(O Muhammad), We did not grant everlasting life to any human being even before you. If you were to die, will they live for ever?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every living being shall taste death and We shall subject you to ill and good by way of trial, and to Us shall all of you be eventually sent back.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdxix{%
When the unbelievers see you they make you an object of fun, saying: ``Is he the one who mentions your gods?" They say so, and yet they reject with disdain the very mention of the Most Compassionate Lord.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man is hasty by nature. I shall certainly show you My Signs. Do not ask Me to be hasty.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
They say: ``(Tell us) when will the threat of punishment come to pass if you are truthful?"\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If only the unbelievers knew of the Hour when they shall not be able to keep off the Fire from their faces, nor from their backs; nor shall they be helped.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
That will suddenly come upon them and stupefy them. They shall not be able to ward it off, nor shall they be granted any respite.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
Other Messengers before you were also mocked, but those who scoffed at the Messengers were overtaken by the same scourge that they had scoffed at.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Tell them, (O Muhammad): ``Who protects you, during the night or the day from the Most Compassionate Lord?" And yet they turn away from the Admonition of their Lord.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Do they have any gods who would protect them against Us? They have no power even to help themselves; nor do they enjoy Our support.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
Nay, We generously provided them and their fathers, and they enjoyed Our provision for long. Do they not see that We are now advancing into their territory, diminishing it from different sides? Is it they, then, who will triumph?"\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Tell them: ``I only warn you by the Revelation." But the deaf do not hear the cry when they are warned.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
Were only the slightest whiff from your Lord's punishment to touch them, they would cry out: ``Woe to us; we were indeed wrong-doers."\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
We shall set up just scales on the Day of Resurrection so that none will be wronged in the least. (We shall bring forth the acts of everyone), even if it be the weight of a grain of mustard seed. We shall suffice as Reckoners.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
Surely We had granted to Moses and Aaron the Criterion (between right and wrong), and Light and Admonition for the good of the God-fearing,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
for those who fear their Lord without seeing Him and dread the Hour (of Reckoning).\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
This is a Blessed Admonition that We have revealed. Are you, then, going to reject it?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
Surely We had bestowed wisdom upon Abraham even earlier, and We knew him well.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
Recall, when he said to his father and his people: ``What are these images to which you are devoutly clinging?"\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They answered: ``We found our fathers worshipping them."\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said: ``Certainly you and your fathers have all been in manifest error."\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said: ``Are you expressing your true ideas before us or are you jesting?"\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said: ``Nay, but your Lord is the Lord of the heavens and the earth which He created and to that I bear witness before you.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdxl{%
By Allah, I shall certainly carry out my plan against your gods after you are gone."\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdxli{%
Then he broke them all into pieces, sparing only the supreme one among them that they may possibly return to him.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
(When they saw the idols in this state) they said: ``Who has done this to our gods? Surely he is one of the wrong-doers."\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
Some of them said: ``We heard a youth called Abraham speak (ill) of them."\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
The others said: ``Bring him, then, before the eyes of the people that they may see (what will be done to him)."\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
(On Abraham's arrival) they said: ``Abraham, are you he who has done this to our gods?"\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
He answered: ``Rather it was this supreme one who has done it. So ask them, if they can speak."\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
Thereupon they turned to their (inner) selves and said (to themselves): ``Surely it is you who are the wrong-doers."\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
Then their minds were turned upside down, and they said: ``You know well that they do not speak."\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
Abraham said: ``Do you, then, worship beside Allah a thing that can neither benefit you nor hurt you?\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdl{%
Fie upon you and upon all that you worship beside Allah. Do you have no sense?"\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said: ``Burn him, and come to the support of your gods, if you are going to do anything."\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We said: ``O fire, become coolness and safety for Abraham."\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdliii{%
They had sought to do evil to him, but We caused them to be the worst losers,\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdliv{%
and We saved him and Lot and brought him to the land upon which We had bestowed Our blessings for all the people of the world.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We bestowed upon him Isaac and Jacob as an additional gift, making each of them righteous.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them into leaders to guide people in accordance with Our command, and We inspired them to good works, and to establish Prayers and to give Zakah. They worshipped Us alone.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
We bestowed upon Lot sound judgement and knowledge, and We delivered him from the city that was immersed in foul deeds. They were indeed a wicked people, exceedingly disobedient.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We admitted him into Our mercy. Verily he was of the righteous.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdlix{%
We bestowed the same favour upon Noah. Recall, when he cried to Us before; We accepted his prayer and delivered him and his household from the great distress\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdlx{%
and We helped him against a people who rejected Our signs as false. They were indeed an evil people and so We drowned them all.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
We bestowed the same favour upon David and Solomon. Recall, when they gave judgement regarding a tillage into which the sheep of some people had strayed at night, and We were witnesses to their judgement.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
We guided Solomon to the right verdict, and We had granted each of them judgement and knowledge. We made the mountains and the birds celebrate the praise of Allah with David. It was We Who did all this.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
It was We Who taught him the art of making coats of mail for your benefit so that it may protect you from each other's violence. Do you, then, give thanks?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And We subdued the strongly raging wind to Solomon which blew at his bidding towards the land We blessed. We know everything.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And We subdued many devils who dived (into the sea) for him and carried out other jobs besides that. We kept watch over all of them.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
We bestowed (the same wisdom, judgement and knowledge) upon Job. Recall, when he cried to his Lord: ``Behold, disease has struck me and You are the Most Merciful of those that are merciful."\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
We accepted his prayer and removed the affliction from him, and We not only restored to him his family but as many more with them as a mercy from Us and as a lesson to the worshippers.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And (We bestowed the same favour) upon Ishmael, Idris and Dhu al-Kifl, for they were all steadfast.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
And We admitted them into Our mercy, for they were of the righteous.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And We bestowed Our favour upon Dhu al-Nun. Recall, when he went forth enraged, thinking We have no power to take him to task. Eventually he cried out in the darkness:" There is no god but You. Glory be to You! I have done wrong."\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
Thereupon We accepted his prayer, and rescued him from grief. Thus do We rescue the believers.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And We bestowed favour upon Zechariah, when he cried to his Lord: ``Lord! Leave me not solitary (without any issue). You are the Best Inheritor."\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We accepted his prayer and bestowed upon him John, and We made his wife fit (to bear a child). Verily they hastened in doing good works and called upon Us with longing and fear, and humbled themselves to Us.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And also recall the woman who guarded her chastity: We breathed into her of Our spirit, and made her and her son a Sign to the whole world.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Verily this community of yours is a single community, and I am your Lord; so worship Me.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
But they tore asunder their faith into many parts. But to Us they are bound to return.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
Then whosoever does righteous works, while believing, his striving will not go unappreciated. We record them all for him.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
It has been ordained against every town that We ever destroyed that they shall not return (to enjoy a new lease of life)\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
until Gog and Magog are let loose, and begin swooping from every mound,\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
and the time for the fulfilment of the true promise of Allah draws near, whereupon the eyes of those who disbelieved will stare in fear, and they will say: ``Woe to us, we were indeed heedless of this; nay, we were wrongdoers."\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
(They will be told): ``Verily you and the gods you worshipped beside Allah are the fuel of Hell. All of you are bound to arrive there.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
Had these indeed been gods they would not have gone there. But (as it is), all of you shall ever abide in it."\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
There they shall groan with anguish and the din and noise in Hell will not let them hear anything.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
But for those whom We had decided to favour with good reward, they shall be kept far removed from Hell.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
They shall not hear even a whisper of it, and they shall live for ever in the delights which they had desired.\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The Hour of the Great Terror shall not grieve them, and the angels shall receive them saying: ``This is your Day which you had been promised."\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
On that Day We shall roll up the heavens like a scroll for writing. Even as We originated the creation first so We shall repeat it. This is a promise binding on Us; and so We shall do.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
Surely We wrote in the Psalms, after the exhortation, that the earth shall be inherited by My righteous servants.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Herein, surely, is a message for those devoted to worship.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmdxc{%
We have sent you forth as nothing but mercy to people of the whole world.\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say: ``It is revealed to me that your God is only One God. Will you, then, submit to Him?"\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
If they turn away, say to them: ``I have warned you all alike; and I cannot say whether what you have been promised is near or distant.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
Indeed He knows what you say loudly and what you hide.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
I think that this [reprieve] is possibly a trial for you, an opportunity to enjoy yourselves until an appointed time."\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
The Messenger said: ``My Lord! Judge with truth. Our Compassionate Lord alone is our support against your (blasphemous) utterances."\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O mankind, fear the (wrath of) your Lord! Indeed, the earthquake of the Hour (of Judgement) will be an awesome thing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
On the Day when you witness it, the suckling woman shall utterly neglect the infant she suckles, and every pregnant woman shall cast her burden, and you will see people as though they are drunk, when they are not drunk; but dreadful shall be Allah's chastisement.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
Among people there are some who wrangle about Allah without knowledge and follow every rebellious devil,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
although it is decreed about him that he shall lead into error whosoever takes him for a friend, and will direct him to the torment of the Fire.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdc{%
O mankind! If you have any doubt concerning Resurrection, then know that it is surely We Who created you from dust, then from a drop of sperm, then from a clot of blood, then from a little lump of flesh, some of it shapely and other shapeless. (We are rehearsing this) that We may make the reality clear to you. We cause (the drop of sperm) that We please to remain in the wombs till an appointed time. We bring you forth as infants (and nurture you) that you may come of age. Among you is he that dies (at a young age) and he who is kept back to the most abject age so that after once having known, he reaches a stage when he knows nothing. You see the earth dry and barren and then no sooner than We send down water upon it, it begins to quiver and swell and brings forth every kind of beauteous vegetation.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdci{%
All this is because Allah, He is the Truth, and because He resurrects the dead, and because He has power over everything,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdcii{%
(all of which shows that) the Hour shall surely come to pass - in this there is no doubt - and Allah shall surely resurrect those that are in graves.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And among people are those that wrangle about Allah without knowledge, without any true guidance, and without any scripture to enlighten them.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdciv{%
They wrangle arrogantly, intent on leading people astray from the Way of Allah. Such shall suffer disgrace in this world and We shall cause them to taste the chastisement of burning (in the Next).\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdcv{%
That is the outcome of what your own hands have wrought, for Allah never wrongs His creatures.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And among people is he who worships Allah on the borderline; if any good befalls him, he is satisfied; but if a trial afflicts him, he utterly turns away. He will incur the loss of this world and the Hereafter. That indeed is a clear loss.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He invokes, instead of Allah, those who can neither harm nor benefit him. That indeed is straying far away.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He invokes those that are more likely to cause him harm than benefit. Such is surely an evil patron, and an evil associate.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdcix{%
(In contrast) Allah will assuredly cause those who believe and act righteously to enter Gardens beneath which rivers flow. For, most certainly, Allah does whatever He pleases.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Anyone who fancies that Allah will not support him in this world and in the Hereafter, let him reach out to heaven through a rope, and then make a hole in the sky and see whether his device can avert that which enrages him.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
Even so We have revealed the Qur'an with Clear Signs. Verily Allah guides whomsoever He wills.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
On the Day of Resurrection Allah will most certainly judge among those who believe, and those who became Jews, and Sabaeans, and Christians, and Magians, and those who associate others with Allah in His Divinity. Surely Allah watches over everything.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Have you not seen that all those who are in the heavens and all those who are in the earth prostrate themselves before Allah; and so do the sun and the moon, and the stars and the mountains, and the trees, and the beasts, and so do many human beings, and even many of those who are condemned to chastisement? And he whom Allah humiliates, none can give him honour. Allah does whatever He wills.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These two groups (the believers and unbelievers) are in dispute about their Lord. As for those that disbelieve, garments of fire have been cut out for them; boiling water shall be poured down over their heads,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
causing (not only) their skins but all that is in their bellies as well to melt away.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
There shall be maces of iron to lash them.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Whenever they try, in their anguish, to escape from Hell, they will be driven back into it, (and shall be told): ``Now taste the torment of burning."\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
(On the other hand), Allah will cause those who believed and acted righteously to enter the Gardens beneath which rivers flow. They shall be decked in them with bracelets of gold and pearls and their raiment shall be of silk.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
They were guided (to accept) the pure word; they were guided to the Way of the Praiseworthy (Lord).\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
Indeed those who disbelieve and who (now) hinder people from the Way of Allah and hinder them from the Holy Mosque which We have set up (as a place of worship) for all people, equally for those who dwell therein and for those who come from outside, (they surely deserve punishment). Whosoever deviates therein from the Right Way and acts with iniquity, We shall cause him to taste a painful chastisement.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
Call to mind when We assigned to Abraham the site of the House (Kabah), directing him: ``Do not associate aught with Me" and ``Keep My House pure for those who walk around it, and for those who stand and who bow down and who prostrate themselves (in worship),\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
and publicly proclaim Pilgrimage for all mankind so that they come to you on foot and mounted on lean camels from every distant point\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
to witness the benefits in store for them, and pronounce the name of Allah during the appointed days over the cattle that He has provided them. So eat of it and feed the distressed and the needy.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Thereafter, let them tidy up and fulfil their vows and circumambulate the Ancient House."\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
Such (was the purpose of building the Kabah). Whosoever, then, venerates Allah's sanctities will find it to be good for him in the sight of his Lord. Cattle have been made lawful for you except those mentioned to you (as unlawful). So shun the abomination of idols and shun all words of falsehood.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Become exclusively devoted to Allah, ascribing Divinity to none other than Him. Whoso ascribes Divinity to aught beside Allah, it is as though he fell down from the sky whereafter either the birds will snatch him away, or the wind will sweep him to a distant place (causing him to be shattered to pieces).\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
Such is the fact. And whoso venerates the sanctity of all that have been ordained as symbols of Allah surely does so because it is part of the true piety of the hearts.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
You may derive benefit (from sacrificial animals) until an appointed time. Thereafter their place (of sacrifice) is near the Ancient House.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
For every people We have laid down a ritual of sacrifice(- although the purpose of the ritual is the same -)that they pronounce the name of Allah over the cattle He has provided them. Your Lord is One God; so submit yourselves to Him alone. And give, (O Prophet), glad tidings to those that humble themselves (before Allah),\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
whose hearts shiver whenever Allah is mentioned, who patiently bear whatever affliction comes to them, who establish Prayer, and who spend (for good purposes) out of what We have provided them.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
We have appointed sacrificial camels among the symbols of (devotion to) Allah. There is much good in them for you. So make them stand (at the time of sacrifice) and pronounce the name of Allah over them, and when they fall down on their sides (after they are slaughtered), eat and also feed them who do not ask and those who ask. Thus have We subjected these animals that you may give thanks.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
Neither their flesh reaches Allah nor their blood; it is your piety that reaches Him. He has subjected these animals (to you) that you may magnify Allah for the guidance He has bestowed upon you. Give glad tidings, (O Prophet), to those who do good.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Surely Allah defends those who believe. Certainly Allah has no love for the perfidious, the thankless.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Permission (to fight) has been granted to those for they have been wronged. Verily Allah has the power to help them:\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
those who were unjustly expelled from their homes for no other reason than their saying: ``Allah is Our Lord." If Allah were not to repel some through others, monasteries and churches and synagogues and mosques wherein the name of Allah is much mentioned, would certainly have been pulled down. Allah will most certainly help those who will help Him. Verily Allah is Immensely Strong, Overwhelmingly Mighty.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
(Allah will certainly help) those who, were We to bestow authority on them in the land, will establish Prayers, render Zakah, enjoin good, and forbid evil. The end of all matters rests with Allah.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
(O Prophet), if they give the lie to you, then before them the people of 'Ad and Thamud, also gave the lie (to the Prophets),\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
and so too did the people of Abraham and the people of Lot;\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
and so did the dwellers of Midian, and Moses too was branded a liar. Initially I granted respite to the unbelievers for a while and then seized them. How dreadful was My punishment!\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
How many towns have We destroyed because their people were steeped in iniquity: so they lie fallen down upon their turrets! How many wells lie deserted; and how many towering palaces lie in ruins!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
Have they not journeyed in the land that their hearts might understand and their ears might listen? For indeed it is not the eyes that are blinded; it is rather the hearts in the breasts that are rendered blind.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
They ask you to hasten the punishment. Allah shall most certainly not fail His promise; but a Day with your Lord is as a thousand years of your reckoning.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
How many towns did I respite at first though they were steeped in iniquity, and then I seized them! To Me are all destined to return.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say (O Muhammad): ``O people! I have been sent to you only as a plain warner (before the Doom strikes you)."\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
So those who believe and act righteously shall be granted forgiveness and an honourable sustenance,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
whereas those who strive against Our Signs, seeking to profane them, they are the friends of the Fire!\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
Never did We send a Messenger or a Prophet before you (O Muhammad), but that whenever he had a desire, Satan interfered with that desire. Allah eradicates the interference of Satan and strengthens His Signs. Allah is All-Knowing, All-Wise.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
(He does this) in order that He may make the evil caused by Satan a trial for those in whose hearts there is sickness (of hypocrisy), whose hearts are hard (and vitiated). Surely these wrong-doers have gone too far in their dissension.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
(He also does this) in order that those endowed with knowledge may know that it is the Truth from your Lord and that they may have faith in it and their hearts may humble themselves before Him. Verily Allah always directs those that believe to the Right Way.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdcl{%
The unbelievers will not cease to be in doubt about it until the Hour suddenly comes upon them, or the chastisement of an ominous day overtakes them.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdcli{%
On that Day all sovereignty shall be Allah's and He will judge among them. Then those who believed and acted righteously shall be in Gardens of Bliss.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdclii{%
A humiliating chastisement awaits those who disbelieved and denied Our Signs.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
As for those who migrated in the way of Allah, whereafter they were slain, or died, Allah will certainly grant them a goodly provision. Indeed, Allah is the Best of all those who provide.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
He will surely admit them to a resort which will please them. Most certainly Allah is All-Knowing, Most Forbearing.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdclv{%
That indeed is so, as for him who retaliates in proportion to the excess committed against him, and is thereafter again subjected to transgression, Allah will surely aid him. Verily Allah is All-Pardoning, All-Forgiving.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
So shall it be because it is Allah Who causes the night to emerge out of the day and causes the day to emerge out of the night and Allah is All-Hearing, All-Seeing.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
So shall it be because Allah, He is the Truth, and all whom they invoke instead of Him are false. Allah is Most High, All-Great.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Do you not see that Allah sends down water from the sky whereby the earth turns green? Verily Allah is Subtle, All-Aware.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him belongs all that is in the heavens and all that is in the earth. Surely Allah - He alone is Self- Sufficient, Praiseworthy.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Have you not seen how Allah has subjected to you all that is in the earth, and the vessels that sail in the sea by His command, and it is He Who holds back the sky that it may not fall on earth except by His leave? Surely Allah is Most Gentle, Ever Compassionate to people.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
And it is He Who has endowed you with life and it is He who causes you to die, and it is He Who will then resurrect you. Man is indeed extremely prone to denying the Truth.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
For every people We have prescribed a way of worship which they follow. So, (O Muhammad), let them not dispute with you concerning this, and call them to Your Lord. You are certainly on the Straight Way.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
And if they dispute with you, say: ``Allah knows well what you do.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
Allah will judge among you on the Day of Resurrection concerning matters about which you disagreed."\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Are you not aware that Allah knows all that is in the heaven and the earth? Surely it is all preserved in a Book. Indeed that is easy with Allah.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
Instead of Allah they worship those concerning whom He has revealed no sanction and concerning whom they have no true knowledge. None shall be able to help such evil-doers.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
When Our Signs are plainly recited to them, you will perceive utter repugnance on their faces and it all but seems as if they will soon pounce upon those who recite Our Signs to them. Say: ``Shall I tell you what is worse than that? The Fire with which Allah has threatened those who disbelieve. That is truly an evil end."\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O people, a parable is set forth: pay heed to it. Those who call upon aught other than Allah shall never be able to create even a fly, even if all of them were to come together to do that. And if the fly were to snatch away anything from them, they would not be able to recover that from it. Powerless is the supplicant; and powerless is he to whom he supplicates.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They have not formed a true estimate of Allah. Indeed, Allah is All-Powerful, All-Mighty.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooses Messengers from among angels and from among human beings (to convey His command). Allah is All-Hearing, All-Seeing.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows all that is before them and that which is hidden from them. And it is to Allah that all affairs are returned.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
Believers, bow down and prostrate yourselves before Your Lord and serve Your Lord and do good that you may prosper.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
Strive in the cause of Allah in a manner worthy of that striving. He has chosen you (for His task), and He has not laid upon you any hardship in religion. Keep to the faith of your father Abraham. Allah named you Muslims earlier and even in this (Book), that the Messenger may be a witness over you, and that you may be witnesses over all mankind. So establish Prayer, and pay Zakah, and hold fast to Allah. He is your Protector. What an excellent Protector; what an excellent Helper!\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen The believers have indeed attained true success:\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
those who, in their Prayers, humble themselves;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
who avoid whatever is vain and frivolous;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
who observe Zakah;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
who strictly guard their private parts\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
save from their wives, or those whom their right hands possess; for with regard to them they are free from blame ``\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
As for those who seek beyond that, they are transgressors"\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
who are true to their trusts and their covenants,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
and who guard their Prayers.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
Such are the inheritors\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
that shall inherit Paradise; and in it they shall abide for ever.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
We created man out of the extract of clay,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
then We made him into a drop of life-germ, then We placed it in a safe depository,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
then We made this drop into a clot, then We made the clot into a lump, then We made the lump into bones, then We clothed the bones with flesh, and then We caused it to grow into another creation. Thus Most Blessed is Allah, the Best of all those that create.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
Thereafter you are destined to die,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
and then on the Day of Resurrection you shall certainly be raised up.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
We have indeed fashioned above you seven paths. Never were We unaware of the task of creation.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
We sent down water from the sky in right measure, and caused it to stay in the earth, and We have the power to cause it to vanish (in the manner We please).\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
Then through water We caused gardens of date-palms and vines to grow for you wherein you have an abundance of delicious fruits and from them you derive your livelihood.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
And We also produced the tree which springs forth from Mount Sinai, containing oil and sauce for those that eat.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And indeed there is also a lesson for you in cattle. We provide you with drink out of what they have in their bellies; and you have many other benefits in them: you eat of them,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
and are carried on them and also on ships.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
We sent Noah to his people, and he said: ``My people! Serve Allah; you have no deity other than He. Do you have no fear?"\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
But the notables among his people had refused to believe, and said: ``This is none other than a mortal like yourselves who desires to attain superiority over you. Had Allah wanted (to send any Messengers) He would have sent down angels. We have heard nothing like this in the time of our forebears of old (that humans were sent as Messengers).\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
He is a person who has been seized with a little madness; so wait for a while (perhaps he will improve)."\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
Noah said: ``My Lord! Come to my help at their accusation that I am lying."\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcc{%
Thereupon We revealed to him, saying: ``Build the Ark under Our eyes and according to Our revelation. And when Our command comes to pass and the oven boils over, take on board a pair each from every species, and also take your household except those of them against whom sentence has already been passed and do not plead to Me on behalf of the wrong-doers. They are doomed to be drowned.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcci{%
And then when you and those accompanying you are firmly seated in the Ark, say: ``Thanks be to Allah Who has delivered us from the wrong-doing people."\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say: ``My Lord! Make my landing a blessed landing, for You are the Best of those Who can cause people to land in safety."\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
There are great Signs in this story; and surely We do put people to test.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then, after them, We brought forth another generation;\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdccv{%
and We sent among them a Messenger from among themselves, saying: ``Serve Allah; you have no god other than He. Do you have no fear?"\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
The notables among his people who had refused to believe and who denied the meeting of the Hereafter, and those whom We had endowed with ease and comfort in this life, cried out: ``This is no other than a mortal like yourselves who eats what you eat and drinks what you drink.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
If you were to obey a human being like yourselves, you will certainly be losers.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
Does he promise you that when you are dead and are reduced to dust and bones, you will be brought forth to life?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdccix{%
Far-fetched, utterly far-fetched is what you are being promised.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdccx{%
There is no other life than the life of the world. We shall live here and here shall we die; and we are not going to be raised again.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
This man has forged a mere lie in the name of Allah and we shall never believe what he says."\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
The Messenger said: ``My Lord! Come to my help at their accusing me of lying."\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
He answered: ``A short while, and they shall be repenting."\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
Then a mighty blast quite justly overtook them, and We reduced them to a rubble. So away with the wrong-doing folk!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then, after them, We brought forth other generations.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No nation can outstrip its term, nor can it put it back.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then We sent Our Messengers in succession. Whenever a Messenger came to his people they rejected him, calling him a liar. Thereupon, We made each people to follow the other (to its doom), reducing them to mere tales (of the past). Scourged be the people who do not believe!\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Moses and his brother Aaron with Our Signs and a clear authority\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
to Pharaoh and to his chiefs, but they behaved superciliously and they were haughty.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
They said: ``Shall we put faith in two mortals like ourselves when their people are slaves to us?"\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they rejected them, calling them liars, and they too eventually became of those that were destroyed.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And We gave Moses the Book that people might be guided by it.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made Mary's son, and his mother, a Sign, and We gave them refuge on a lofty ground, a peaceful site with springs flowing in it.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
Messengers! Partake of the things that are clean, and act righteously. I know well all that you do.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
This community of yours is one community, and I am your Lord; so hold Me alone in fear.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But people later cut up their religion into bits, each group rejoicing in what they have.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
So leave them immersed in their heedlessness till an appointed time.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Do they fancy that Our continuing to give them wealth and children (means) that\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We are busy lavishing on them all kinds of good? Nay, they do not perceive the reality of the matter.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Surely those who stand in awe for fear of their Lord,\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
who have full faith in the Signs of their Lord;\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
who associate none with their Lord in His Divinity,\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
who give, whatever they give in charity, with their hearts trembling at the thought that they are destined to return to their Lord;\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
it is these who hasten to do good works and vie in so doing with one another.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
We do not lay a burden on anyone beyond his capacity. We have a Book with Us that speaks the truth (about everyone); and they shall in no wise be wronged.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
Nay, their hearts are lost in ignorance of all this; and their deeds too vary from the way (mentioned above). They will persist in these deeds\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
until We seize with Our chastisement those of them that are given to luxuriant ways. They will then begin to groan.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
``Put a stop to your groaning now! Surely no help shall be provided to you from Us.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
My Signs were rehearsed to you and you turned back on your heels and took to flight,\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
behaving arrogantly, and making fun, and talking nonsense (about the Book in your nightly chats)."\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Did they never ponder over this Word (of God)? Or has he (to wit, the Messenger) brought something the like of which did not come to their forefathers of yore?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or is it that they were unaware of their Messenger and were therefore repelled by him for he was a stranger to them?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or do they say that there is madness in him? Nay, he has brought them the Truth and it is the Truth that most of them disdain.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
Were the Truth to follow their desires, the order of the heavens and the earth and those who dwell in them would have been ruined. Nay, the fact is that We have brought to them their own remembrance; and yet it is from their own remembrance that they are turning away.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Are you asking them for something? What Allah has given you is the best. He is the Best of providers.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
You are calling them to a Straight Way,\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
but those who do not believe in the Hereafter are ever prone to deviate from the Right Way.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
Were We to be merciful to them and remove from them their present afflictions, they would persist in their transgression, blindly wandering on.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
(They are such) that We seized them with chastisement (and yet) they did not humble themselves before their Lord, nor do they entreat\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmdccl{%
until We opened upon them the door of a severe chastisement. Then lo, in this state they become utterly despaired of any good.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmdccli{%
It is He Who has endowed you with the faculties of hearing and sight and has given you hearts (to think). Scarcely do you give thanks.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
It is He Who has dispersed you all around the earth, and it is unto Him that you shall all be mustered.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
It is He Who gives life and causes death, and He holds mastery over the alternation of night and day. Do you not understand this?\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
Nay, but they say the like of what their predecessors of yore had said.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They say: ``Is it that when we are dead and have been reduced to dust and bones, shall we then be raised up again?\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
We were promised such things and so were our forefathers before us. All these are no more than tales of the past."\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Ask them: ``Whose is the earth and those who are in it? Tell us if you know"\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will surely say: ``Allah's." Say: ``Then why do you not take heed?"\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Ask them: ``Who is the Lord of the seven heavens, the Lord of the Great Throne?"\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will surely say: ``Allah." Say: ``Will you not, then, fear (Allah)?"\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Ask them: ``Say, if you indeed know, to whom belongs the dominion over all things; (Who is it) that grants asylum, but against Whom no asylum is available?"\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will surely say: ``(The dominion over all things) belongs to Allah." Say: ``Whence are you then deluded?"\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
We have brought before them the Truth, and there is no doubt that they are lying.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
Never did Allah take unto Himself any son, nor is there any god other than He. (Had there been any other gods) each god would have taken his creatures away with him, and each would have rushed to overpower the other. Glory be to Allah from all that they characterize Him with!\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
He knows both what is visible and what is not visible. Exalted is Allah above all that they associate with Him.\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Pray, (O Muhammad): ``My Lord, if You should bring the scourge of which they had been warned in my presence,\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
then do not include me, my Lord, among these wrong-doing people."\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
Surely We are able to show you what We warn them against.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
(O Muhammad)! Repel evil in the best manner. We are well aware of all that they say about you.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And pray: ``My Lord! I seek Your refuge from the suggestions of the evil ones;\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
I even seek Your refuge, my Lord, lest they should approach me."\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
(They shall persist in their deeds) until when death comes to anyone of them he will say: ``My Lord, send me back to the world\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
that I have left behind. I am likely to do good." Nay, it is merely a word that he is uttering. There is a barrier behind all of them (who are dead) until the Day when they will be raised up.\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
And then no sooner the Trumpet is blown than there will remain no kinship among them that Day, nor will they ask one another.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
It will be an Hour when those whose scales are heavy, they alone will attain success;\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
and those whose scales are light, those will be the ones who will have courted loss. They will abide in Hell.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The Fire shall scorch their faces, exposing their jaws.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
``Are you not those to whom My revelations were recited, and you dubbed them as lies?"\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say: ``Our Lord! Our misfortune prevailed over us. We were indeed an erring people.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
Our Lord! Take us out of this. Then if we revert (to evil-doing) we shall indeed be wrongdoers."\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
Allah will say: ``Away from Me; stay where you are and do not address Me.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
You are those that when a party of My servants said: 'Our Lord, we believe, so forgive us, and have mercy on us, for You are the Best of those that are merciful,'\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
you made a laughingstock of them and your hostility to them caused you to forget Me, and you simply kept laughing.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Lo! I have rewarded them this Day for their steadfastness, so that they, and they alone, are triumphant."\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
Then Allah will ask them: ``For how many years did you stay on earth?"\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will say: ``We stayed for a day or part of a day. Ask of those who keep count of this."\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say: ``You stayed only for a while, if you only knew that.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
Did you imagine that We created you without any purpose, and that you will not be brought back to Us?"\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
So, exalted be Allah, the True King! There is no god but He, the Lord of the Great Throne.\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
He who invokes any other god along with Allah `` one for whom he has no evidence" his reckoning is with his Lord alone. Indeed, these unbelievers shall not prosper.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And say, (O Muhammad): ``My Lord, forgive us and have mercy on us, for You are the Best of those that are merciful."\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen This is a Surah which We have sent down and We have made it mandatory, and We have sent down clear Commandments in it so that you may learn lessons.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The woman and the man guilty of fornication, flog each one of them with a hundred stripes - and let not any pity for them restrain you in regard to a matter prescribed by Allah, if you believe in Allah and the Last Day, and let, some of the believers witness the punishment inflicted on them.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
A man guilty of adultery (or fornication) shall not marry any but the woman guilty of the same or a mushrik woman, and none shall marry a woman guilty of adultery (or fornication) but the man guilty of the same or a mushrik man: such marriages are forbidden to true believers.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
As for those persons who charge chaste women with false accusations but do not produce four witnesses, flog them with eighty stripes and never accept their evidence afterwards, for they themselves are transgressors,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
except those who repent and reform themselves; Allah is Forgiving and Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
As for those who accuse their own wives but have no witness except themselves, the evidence of one of them is that he shall swear four times by Allah and declare that he is true (in his charge).\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
Then the fifth time he shall declare that Allah's curse be upon him if he be false (in his charge).\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
(As for the woman), it shall avert the punishment from her if she swears four times by Allah that the man is false (in his charge)\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdccc{%
and the fifth time she invokes Allah's wrath upon herself, if he be true (in his charge).\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdccci{%
If Allah had not shown you His grace and mercy and if Allah had not been most Forgiving and All-Wise, (you would have been in a great fix because of accusing your wives).\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Those who have invented the slander, are some of your own people. You should not, however, regard this matter as evil for it has good in it for you. Whoso took any part in this, he earned his share of the sin accordingly, and the one, who had the greatest share of responsibility in it, shall have a terrible punishment.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
When you heard of it, why didn't the Believing men and the Believing women have a good opinion of themselves, and why did they not say, ``This is a manifest slander?"\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did the slanderers not bring four witnesses (to prove their charge)? Now that they have not brought witnesses, they themselves are liars in the sight of Allah.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
Were it not for Allah's grace and mercy towards you in this world and in the Hereafter, a painful scourge would have visited you because of the things in which you were involved.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
(Just think how erroneous you were,) when you passed this lie on from one tongue to the other and uttered with your mouths that of which you had no knowledge. You took it as a trifling matter whereas it was a grave offence in the sight of Allah.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
Why did you not, as soon as you heard of it, say, ``It is not proper for us to utter such a thing? Glory be to Allah! This is a great slander."\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah admonishes you that in future you should never repeat a thing like this, if you are true Believers.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
Allah makes His Revelations clear to you, and He is All-Knowing, All-Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
As for those, who like that indecency should spread among the Believers, they deserve a painful punishment in this world and in the Hereafter, for Allah knows and you do not know (its consequences).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
If Allah had not shown His grace and mercy to you, (this scandal would have produced very evil results): Allah is indeed very Kind and Merciful.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O Believers, do not follow in Satan's footsteps, for he will incite to indecency and wickedness any who will follow him. If Allah had not shown His Brace and mercy to you, none of you would have been able to cleanse yourself, for it is Allah alone Who cleanses whom He wills, and Allah is All-Hearing, All-Knowing.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
Those among you, who are bountiful and persons of means, should not swear on oath that they would withhold their help from their relatives, the indigent and those who have left their homes for the cause of Allah: they should forgive and forbear. Do you not wish that Allah should forgive you? and Allah is Forgiving and Merciful.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Those who charge with slander those Believing women, who are chaste but simple souls, are accursed in this world and in the Hereafter: there is a great punishment for them.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
They should not forget the Day when their own tongues and their own hands and test will bear testimony in regard to their misdeeds.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
On that Day Allah will give them the full recompense they deserve, and they will realize that Allah is the very Truth, Who makes the Truth manifest.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Impure women are for impure men and impure men for impure women, and pure women are for pure men and pure men for pure women. They are free from those scandals which the slanderers utter. There is forgiveness for them and honourable provision.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O Believers, do not enter other houses than your own until you have the approval of the inmates and have wished them peace; this is the best way for you: it is expected that you will observe it.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
Then, if you do not find anyone therein, do not enter until you have been given permission, and if you are told to go back, you should go back. This is a purer way for you; and Allah has full knowledge of what you do.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
There is, however, no harm if you enter houses which are not dwelling places, but contain something useful for you; Allah knows what you disclose and what you conceal.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
And O Prophet, enjoin the Believing men to restrain their gaze and guard their private parts. This is a more righteous way for them: Allah has knowledge of what they do.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
O Prophet, enjoin the Believing women to restrain their gaze and guard their private parts. and not to display their adornment except that which is displayed of itself, and to draw their veils over their bosoms and not to display their adornment except before their husbands, their fathers, the fathers of their husbands, their sons and the sons of their husbands (from other wives), their brothers, their brothers' sons, their sisters' sons, their female associates and those in their possession and male attendants incapable of sex desire and those boys who have not yet attained knowledge of sex matters concerning women; also forbid them to stamp their feet on the ground lest their hidden ornaments should be displayed. O Believers, turn all together towards Allah: it is expected that you will attain true success.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
Arrange marriages between the single men and women among your and between your slave men and slave women, who are righteous,, if they be indigent, Allah will provide means for them out of His bounty: Allah has boundless resources and He is AllKnowing.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
And those, who cannot find a match, should observe continence till Allah provides them with means out of His bounty And if those who are in your possession, ask for a deed of emancipation, execute the deed of emancipation with them, provided that you find some good in them; and give them something out of the means Allah has given you. And do not force your slave-girls into prostitution for your own worldly gains when they themselves want to keep chaste; and if anyone forces them into it, after such a compulsion Allah will be forgiving and merciful for them.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
We have sent down to you Revelations giving clear guidance and cited examples of the peoples who went before you to serve as warning and We have imparted admonitions for the God-fearing.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the light of the heavens and the earth: His light (in the universe) may be likened (to the light of) a lamp in a niche: the lamp is in a glass shade: the glass shade is like a glittering star and lamp is lit with the olive oil of a blessed tree which is neither eastern nor western: its oil is (so fine) as if it were going to shine forth by itself though no fire touched it (as though all the means of increasing) light upon light (were provided); Allah guides to His light whomever He wills. He cites parables to make the Message clear to the people; He has perfect knowledge of everything.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
(Those who obtain guidance to His light are found) in the houses which He has enjoined to raise up and to mention His name therein. In them such people glorify Him morning and evening\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
as are not diverted by trade and merchandise from remembering Him and from establishing Salat and paying Zakat, for they fear the Day when the hearts will be overturned and the eyes will become petrified.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
(And they behave like this) so that Allah may reward them for their excellent deeds and, in addition to it, show His favour to them out of His bounty: Allah provides without stint for anyone He pleases.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
(On the other hand,) the deeds of those who disbelieved, maybe likened to a mirage in a waterless desert, which the thirsty one took for water; but when he reached there he found nothing to drink; nay, he found there Allah Who settled his full account, and Allah is very swift at reckoning.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or (their efforts may be likened to those of a man trying to swim in) a deep dark ocean, covered with billows, one over the other, and above it a cloud: darkness upon darkness: so much so that if he stretches out his hand, he cannot see it. There is no light for the one whom Allah does not give light.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Do you not observe that all those who are in the heavens and the earth, and the birds with outspread wings, glorify Allah? Each one knows the mode of its prayer and glorification, and Allah has full knowledge of all they do.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
The kingdom of the heavens and the earth belongs to Allah alone, and all shall have to return to Him.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
Do you not observe that Allah makes the cloud move gently then joins its pieces together: then gathers it into a mass of thick cloud: then you see that rain-drops fall down from its midst: and He sends down hail out of the high up mountains in the heaven: then He smites with it whom He wills and turns it away from whom He pleases: then a flash of lightning from it dazzles the eyes.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
He alternates the day and the night: there is indeed a lesson in it for those who have observing eyes.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
And Allah created every creature from a sort of water: of them some one crawls upon its belly: another walks on two legs and still another on four; Allah creates whatever He wills for He has power over everything\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
We have sent down Revelations that make the reality quite plain; however, Allah guides to the straight path whomsoever He pleases.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
These people say ``We have believed in Allah and the Messenger and we have submitted"; but soon after this, some of them turn away (from obedience): such people are not true Believers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
When they are called to Allah and His Messenger so that the Messenger may judge between them, a party of them turns away.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
However, if the truth be on their side, they come towards the Messenger in all obedience.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Are their hearts afflicted with the disease (of hypocrisy)? Or, are they in doubt? Or, do they fear that Allah and His Messenger will be unjust to them? In fact, they themselves are unjust.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
As regards the Believers, when they are called towards Allah and His Messenger so that the Messenger may judge between them, they say, ``We have heard and obeyed"; such are the people who attain true success,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
and only those attain true success who obey Allah and His Messenger and fear Allah and refrain from His disobedience.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
They (the hypocrites) solemnly swear by Allah and say, ``If you order us, we will leave our homes." Say to them, ``Do not swear oaths for your `obedience' is well known; Allah is fully aware of what you are doing. ``\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say, ``Obey Allah and obey the Messenger, but if you turn away, you should note it well that the Messenger is responsible for the duty entrusted to him and you are responsible for the duty entrusted to you. If you obey him, you will be rightly guided, for the responsibility of the Messenger is only to convey the Message clearly to you.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah has promised to those among you who believe and do righteous deeds, that He will make them successors in the land just as He made those who passed away before them, and that He will establish their religion, which He has approved for them, on strong foundations and will change their (present) state of fear into peace and security. Let them worship Me and associate none with Me; and the one who disbelieves after this," shall be of those who are perverse transgressors.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
Therefore, establish Salat, pay the Zakat dues and obey the Messenger; it is expected that you will be shown mercy.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Do not think about those who have disbelieved that they will be able to frustrate Allah in the land; their abode is Hell and it is a very evil abode.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O Believers, your slaves and those of your children, who have not yet become sex conscious, must ask your permission before coming in to see you on three occasions: before the Fajr Prayer and at noon when you put off your clothes and after the `Isha' Prayer. These are your three times of privacy. There is no sin for you or for them if they come without permission at other times than these, for you have to visit: ne another over and over again. In this way Allah makes His Comm andments clear to you for He is All-Knowing, All-Wise.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
And when your children have grown sex conscious, they should receive your permission for this just as their elders get permission. In this way Allah makes His Revelations plain to you for He is All-Knowing, AllWise.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
There is no sin for such elderly women as are past the age of marriage, if they lay aside their outer graments provided that they do not mean to display their adornment. Nevertheless, if they behave modestly, it would be better for them: for Allah hears everything and knows everything.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
There is no harm if a blind or a lame or a sick person (takes a meal at another's house): nor is there any harm for yourselves if you take meals at your own houses or at the houses of your fathers and grandfathers or at the houses of your mothers and grandmothers or at your brothers' houses or at your sisters' houses or at the houses of your paternal uncles or at the houses of your paternal aunts or at the houses of your maternal uncles or at the houses of your maternal aunts or from the houses whose keys are in your possession or at the houses of your friends. There is no harm if you take your meals together or separately; however, when you enter the houses, you should send greetings of peace on your people, for the prayer of greetings prescribed by Allah is blessed and pure. Thus Allah makes His Revelation's clear to you. It is expected that you will use your common sense to grasp these.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
True Believers are those who sincerely believe in Allah and His Messenger and who do not leave him without permission when they are with the Messenger for some common good; only those who ask your permission sincerely believe in Allah and His Messenger. Therefore, when they ask your permission for a private business, you may give permission to whomever you like, and ask Allah's forgiveness for such people: Allah is indeed Forgiving and Merciful.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
O Believers, do not consider the summoning by the Messenger like the summoning among you by one another. Allah knows well those of you who steal away, concealing themselves behind others. Let those who disobey the order of the Messenger beware lest they should be involved in some affliction, or are visited by a woeful scourge.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Beware! whatever is in the heavens and the earth belongs to Allah. He knows whatever you are doing. On the Day you shall return to Him, He will let you know what you have. done: He has full knowledge of everything.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Highly blessed is He, Who has sent down Al-Furqan, to His servant so that it may be a warner to all mankind:\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
He to Whom belongs the Sovereignty of the heavens and the earth: Who has begotten no son: Who has no partner in His Sovereignty: Who created each and every thing and then ordained its destiny.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
Yet the people have set up, besides Him, deities, who do not create anything but are themselves created: who can neither harm nor help even themselves: who have no power over life or death, nor can they raise up the dead.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
Those who have rejected the Message of the Prophet, say, ``This (Al-Furgan) is a forgery which this man himself has devised, and some others have helped him at it. `` What a cruel injustice and an impudent lie!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
They say, ``These things are the writings of the ancients which he has got copied down for himself, and then these are recited to him in the morning and evening.''\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
O Muhammad, say to them, ``This has been sent down by Him, Who knows the secret of the heavens and the earth." The fact is that He is very Forgiving and Merciful.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
They say, ``What sort of a Messenger is he that he eats food and moves about in the streets? Why has not an angel been sent down to accompany him and threaten (the disbelievers)?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
Or why has not at least a treasure been sent down for him or a garden given to him for (easy) sustenance?" And the wicked people say, ``You are following a man bewitched."\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
Just see what strange arguments they bring forward with regard to you! They have gone so far astray that they cannot charge any thing against you.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Highly blessed is He, Who, if He wills, could give you much more and better things than what they propose for you: (Not one but) many gardens, beneath which rivers flow; and big castles:\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
The fact of the matter is that these people have denied ``the Hour", --And for the one who denies the coming of the Hour, We have prepared a blazing Fire.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it will see them from afar, they will hear the sounds of its raging and roaring.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they are chained together and flung into a narrow space therein, they will begin to call for death.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
(Then it will be said to them:) ``Do not call for one death today, but call for many deaths."\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Ask them ``Is this (Fire) better or the everlasting Garden which has been promised to the God-fearing righteous people?" which will be the recompense of their good deeds and the final destination of their journey\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
wherein they will get everything they desire and wherein they will dwell for ever. This is a promise which your Lord has taken upon Himself to fulfil.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
And on that Day (your Lord will gather these people together as well as their deities, whom they worship besides AIlah. Then He will ask them, ``Did you mislead these servants of Mine, or did they themselves go astray?"\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will answer, ``Glory be to Thee! We dared not take anyguardian besides Thee: (they were misled because) Thou didst give them and their forefathers all the good things of life till they forgot the Admonition, and incurred the punishment. ``\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
Thus will your gods deny alI that you are professing today. Then you shall neither be able to repel your punishment nor shall get any help from anywhere; and whoso is guilty. of iniquity'' among you, We shall make him taste a severe torment.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
O Muhammad,, all the Messengers whom We sent before you also ate food and moved about in the streets. In fact, We have made you all a means of test for one another. Will you show patience? for your Lord sees everything.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
Those people, who have no fear of coming before Us, say, ``Why should not the angels be sent down to us? Or else we should see our Lord. `` Great arrogance have they assumed in regard to themselves, and have transgressed all limits in their rebellion.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
The Day, when they will see the angels, will not be a day of rejoicing for the criminals; they will cry out, ``May Allah save us!"\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
Then We shall turn to what they had done and render it vain like scattered dust.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
(On the contrary) only those who have deserved the Garden, will have a good abode on that Day and a cool place for midday rest.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
On that Day, a cloud will appear rending the sky and the angels will be senthi down rank after rank.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
The real Kingdom on that Day will belong only to the Merciful, and it will be a very hard Day for the disbelievers.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
The unjust man will bite at his hand and say, ``Would that I had stood by the Messenger!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
O, woe to me! Would that I had not chosen so and so for a friend!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
For it was he, who had deluded me to reject the Admonition which had come to me. Satan has proved very treacherous to man. ``\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
And the Messenger will say, ``O my Lord, my people had made this Qur'an the object of their ridicule."\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
O Muhammad, in this very way We have made the criminals the enemies of every Prophet, but your Lord suffices for you as your Guide and Helper.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
The disbelievers say, ``Why has not the entire Qur'an been sent down to this man all at nce?" -Well, this has been done to impress it deeply on your mind, and (for the same object) We have sent it down piecemeal by degrees.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
And (there is another wisdom in this: whenever they brought to you an odd thing (or a strange question), We sent its right answer to you in time and explained it all in the best manner,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
those who are going to be driven to Hell upon their faces, have taken an utterly wrong stand and their way is most erroneous!\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
We gave Moses the Book and appointed his brother Aaron as his counsellor:\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
then We said to them, ``Go to the people who have treated Our Revelations as false. `` So We annihilated those people utterly.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
The same was the case with the people of Noah when they charged the Messenger with imposture: We drowned them and made them a sign of warning for entire mankind, and We have prepared a painful chastisement for the unjust.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
Likewise were destroyed the `Ad and the Thamud and the people of the Rass, and many a generation in between.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
We admonished each one of them by citing the examples (of those who were destroyed before them) and ultimately annihilated all of them.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
Surely, these people have passed by that habitation on which was rained an evil rain: have they not seen its ruins? But they do not expect another life in the Hereafter.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
When these people see you, they scoff at you, (saying), ``Is this the man whom Allah has sent as His Messenger?\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
He had almost led us astray from our gods, had we not remained firm in our faith with regard to them. `` The time is not far when they will see the torment and realize who had strayed far from the truth.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Have you ever considered the case of the person who has made his lust his god? Can you take the responsibility of guiding such a one aright?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Do you think that most of them hear or understand? They are only like the cattle; nay, even worse than the cattle.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcm{%
Have you not seen how your Lord lengthens out the shadow? Had He willed, He would have made it constant, but We have made the sun its pilot;\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcmi{%
then (as the sun climbs up), We roll it up little by little towards Ourselves.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And it is Allah Who has ordained the night as a garment for you, and the sleep as a repose of death, and the day as the time of return to life.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And it is He, Who drives the winds to be the harbingers of His mercy: then He sends down pure water from the sky\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
so that He may revive the dead land, and quench the thirst of many of His creatures from among beasts and men.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcmv{%
We present the same phenomenon over and over again before them so that they may learn a lesson from it; but most people decline to adopt any other attitude than of disbelief and ingratitude.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
Had We willed, We would have raised up a separate Warner in each habitation.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So, O Prophet, do not yield to the disbelievers, but wage a Jihad against them with this Qur'an.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And it is He, Who has let loose the two seas, one palatable and sweet, the other bitter and saltish, and there is a partition between them, which is an insurmountable barrier.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He, Who created man from water: then from him He caused two kinds of kindred, by blood and by marriage: your Lord is AI I-Powerful.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcmx{%
Yet they worship, instead of Allah, those who can neither benefit them nor harm them: more than this, the disbeliever has become a helper of every rebel against his Lord.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
O Muhammad, We have sent you only to proclaim good tidings and to give warning.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Tell them, ``I do not ask of you any recompense for this work: I only ask of the one, who will, to adopt the way of his Lord.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
O Muhammad trust in that Allah Who is Ever-Living and will never die' Glorify Him with His praise, for He alone is sufficient to be aware of the sins of His servants.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
In six days He created the earth and the heavens and all that is between them; then He established Himself on the ``Throne" (of the Kingdom of the uriverse). (He is) the Merciful: as to His Glory, ask the one who knows.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
When it is said to them. ``Prostrate yourselves before the Merciful," they retort, ``What is the Merciful? Would you have us prostrate ourselves before whomsoever you will?" And this invitation only helps to increase their hatred all the more.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Highly blessed is He, Who has made fortified spheres in the heavens and has set in it a ``lamp" and a shining moon.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
He it is Who caused the night and the day to succeed each other so that everyone who desires may learn a lesson or become grateful.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
The (true) servants of the Merciful are those who walk humbly on the earth who, when the ignorant people behave insolently towards them, say, ``Peace to you"\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
who pass their nights in prostrating themselves and standing before their Lord:\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
who pray, ``Our Lord, save us from the torment of Hell, for its torment is killing:\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
it is an evil abode and an evil resting place":\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
who, when they spend, are neither extravagant nor miserly but keep the golden mean between the two (extremes):\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
who do not invoke any god but Allah nor kill a soul, which Allah has forbidden, unjustly, nor commit adultery. -He who does this shall be punished for his sin,\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
and his torment shall be doubled on the Day of Resurrection, and he shall abide in a state of ignominy,\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
except the one who may have repented (after those sins) and have believed and done righteous works, for then Allah will change his evil deeds into good deeds, and He is very Forgiving and Merciful.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
In fact, the one who repents and does righteous deeds, returns to Allah as one ightly should. -\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
(And the servants of the Merciful are those:) who do not bear witness to falsehood and who; if they have ever to pass by what is vain, pass by like dignified people:\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
who do not behave like the blind and the deaf, when the Revelations of their Lord are recited to them for admonition;\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
who pray, ``Our Lord, bless us with wives and children, who may be the comfort of our eyes, and make us leaders of the righteous. `` -\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Such are the people who will be rewarded with high palaces for their fortitude,, wherein they will be welcomed with due respect, honour and salutations\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
and wherein they will live for ever: what an excellent abode and what an excellent resting place!\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
O Muhammad, tell the people, ``MyLord does not care at all if you do not invoke Him. Now that you have denied (His Revelation), you will soon be awarded such a punishment which you will never be able to avoid."\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta'. Sin. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are the verses of the Clear Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
(O Muhammad), you will perhaps grieve yourself to death because these people do not believe.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We will, We can send down a Sign to them from heaven, so their necks will be humbled to it.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
Never does there come to them an admonition from the Merciful Lord but they turn away from it.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
They will soon come to know the truth of that which they have been scoffing at.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Do they not look at the earth, how We caused a variety of fine vegetation to grow from it (in abundance)?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Surely there is a Sign in this, but most of them would not believe.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
Verily Your Lord is Infinitely Mighty, Most Compassionate.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
(Recount to them about the time) when Your Lord called Moses: ``Go to the wrong-doing people,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
the people of Pharaoh: do they have no fear?"\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said: ``My Lord! I fear that they will brand me a liar.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
My breast is constricted and my tongue is not fluent, so endow Messengership on Aaron.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
As for me, they hold the charge of a crime against me. I fear they will put me to death."\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
He said: ``Certainly not! So go both of you with Our Signs. We shall be with you listening to everything.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
Go, then, to Pharaoh and say to him: 'The Lord of the Universe has sent us\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
that you let the Children of Israel go with us.'"\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmcml{%
Pharaoh said: ``Did we not bring you up among us when you were a child?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmcmli{%
You spent many years of your life among us and then you committed that deed of yours. You are very ungrateful indeed."\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
Moses replied: ``I committed that act erringly.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
Then I fled for fear of you. Then my Lord bestowed wisdom and authority on me and made me one of the Messengers.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
Now this is the favour that you tauntingly remind me of: that you enslaved the Children of Israel!"\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Pharaoh said: ``And who is this Lord of the Universe?"\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
Moses answered: ``The Lord of the heavens and the earth and of all that is between them, if you were only to believe."\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
Pharaoh said to those around him: ``Do you hear (what he says)?"\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
Moses said: ``(He is) Your Lord and the Lord of your forefathers of yore."\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
Pharaoh said to the audience: ``This Messenger of yours who has been sent to you is simply mad."\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
Moses continued: ``(He is) the Lord of the east and the west, and all between them. If you only had any understanding!"\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
Pharaoh said: ``If you take any god other than me, I will certainly make you one of those (who are rotting) in prison."\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
Moses said: ``Even if I were to bring a Clear Sign to you?"\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
Pharaoh said: ``Then bring it if you are truthful at all."\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
(No sooner had he said this than) Moses threw down his rod and behold, it was a veritable serpent,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
and he drew his hand (out of his armpit) and lo! it had become a shining object to the beholders.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
Pharaoh said to the nobles around him: ``Surely this man is a skilled magician\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
who wants to drive you out of your land by his magic. Tell us, what do you advise us?"\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said: ``Detain him and his brother for a while and send forth heralds to the cities\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
to mobilise all skilled magicians."\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the magicians were brought together on a particular day at a set time\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
and the people were told: ``Will you join the assembly?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
We may perhaps follow the religion of the magicians if they triumph."\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
When the magicians came forth (for the encounter) they said to Pharaoh: ``Is there a reward for us if we triumph?"\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said: ``Yes, you will then become those near-stationed to me."\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Moses said to them: ``Throw down whatever you wish to throw."\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
Thereupon they threw down their ropes and their rods, and said: ``By the glory of Pharaoh, we shall prevail."\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Thereafter, Moses threw down his rod and behold, it went about swallowing up all the false devices they had contrived.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
Thereupon the magicians fell down in prostration,\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
saying: ``We (now) believe in the Lord of the Universe,\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
the Lord of Moses and Aaron."\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
Pharaoh said: ``You accepted the word of Moses even before I granted you the leave to do so. Surely he is your chief who has taught you magic. Soon shall you come to know. I shall cut off your hands and feet on opposite sides and shall crucify all of you."\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said: ``We do not care, for we are bound to return to our Lord,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
and we surely expect that Our Lord will forgive us our sins for we are the first ones to believe."\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
We revealed to Moses: ``Set forth with My servants by night for you will be pursued."\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Pharaoh sent heralds to the cities (to mobilise troops)\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
saying: ``These (Israelites) are only a small band of people\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
who have certainly provoked our wrath.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
But we are a numerous host, ever on guard."\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
Thus did We drive them out of their gardens and springs\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
and their treasures and excellent dwellings.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
This happened with them; (but on the other hand), We enabled the Children of Israel to inherit those bounties.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
At sunrise they set off in pursuit of them\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
and when the groups came face to face, the companions of Moses cried out: ``We are overtaken!"\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
Moses said: ``Certainly not. My Lord is with me; He will direct me."\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We revealed to Moses, (commanding him): ``Strike the sea with your rod." Thereupon the sea split up, and then each became like the mass of a huge mount.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
We also brought the other party close to the same spot,\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
and We delivered Moses and his companions, all of them,\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
then We drowned the others.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Surely there is a Sign in this, but most of them would not believe.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmm{%
Verily your Lord is Immensely Mighty, Ever Compassionate.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmi{%
And recount to them the story of Abraham:\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmii{%
when he asked his father and his people: ``What do you worship?"\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They answered: ``There are some idols that we worship and are devoted to them with constancy."\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He asked: ``Do they hear you when you call them\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmv{%
or do they cause you any benefit or harm?"\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They answered: ``No; but we found our forefathers doing so."\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmvii{%
Thereupon, Abraham said: ``Have you seen (with your eyes) those whom you have been worshipping,\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmviii{%
you and your forefathers of yore?\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmix{%
They are all enemies to me; all, except the Lord of the Universe\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmx{%
Who created me and Who guides me;\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmxi{%
Who gives me food and drink,\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmxii{%
and Who, when I am ill, heals me;\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
Who will cause me to die and then will again restore me to life;\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
Who, I hope, will forgive me my sins on the Day of Judgement."\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmxv{%
(And then Abraham prayed): ``My Lord, endow me with knowledge and wisdom and join me with the righteous,\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
and grant me an honourable reputation among posterity,\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
and make me of those who will inherit the Garden of Bliss,\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
and forgive my father for he is among those who strayed,\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmxix{%
and disgrace me not on the Day when people will be raised to life,\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmxx{%
the Day when nothing will avail, neither wealth nor offspring,\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
but only he that brings to Allah a sound heart will (attain to success)."\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
(On that Day) the Garden will be brought near to the God-fearing,\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
and the Fire will be uncovered for those who strayed,\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
and they will be asked: ``Where are the gods that you worshipped\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
beside Allah? Can they be of any help to you, or even be of any help to themselves?"\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
Then the idols and those who strayed will be hurled into the Fire headlong, one upon another,\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
and so too the hosts of Iblis, all of them.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
There they will quarrel with one another and the erring ones will say (to their deities):\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
``By Allah, we were surely in clear error\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
when we assigned to you a position equal to that of the Lord of the Universe.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
It is none but those steeped in guilt who led us into this error,\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
and now we have none to intercede on our behalf,\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
nor do we have a truly sincere friend.\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
If only we could return we would be among the believers."\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Surely there is a Sign in this, but most of them would not believe.\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
Verily Your Lord is Immensely Mighty, Ever Compassionate.\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The people of Noah gave the lie to the Messengers.\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
Recall when their brother Noah said to them: ``Do you have no fear?\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
I am a trustworthy Messenger to you;\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmmxl{%
so fear Allah and obey me.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmmxli{%
I seek of you no reward for this: my reward is with none except the Lord of the Universe.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
So fear Allah and obey me."\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They answered: ``Shall we accept you even though it is the meanest of people who follow you?"\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
Noah said: ``What knowledge do I have about their deeds?\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
It is only for my Lord to take account of them. Would that you made use of your understanding!\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
It is not for me to repel those who choose to believe.\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
I am none but a plain warner."\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said: ``O Noah! If you do not desist, you will certainly become one of the accursed."\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said: ``My Lord! My people have branded me a liar.\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmml{%
So pass a clear judgement between me and them and rescue me and the believers with me."\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmmli{%
Thereafter We rescued him and those who were with him in the laden Ark\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmmlii{%
and drowned the rest.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Surely there is a Sign in this, but most of them would not believe.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmmliv{%
Verily Your Lord is Immensely Mighty, Ever Compassionate.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmmlv{%
The Ad gave the lie to the Messengers.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
Recall, when their brother Hud said to them: ``Have you no fear?\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
I am a trustworthy Messenger to you.\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
So fear Allah and obey me.\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmmlix{%
I seek of you no reward for this; my reward is with none but the Lord of the Universe.\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmmlx{%
What, you build a monument on every hill merely for fun\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
and erect huge palaces as though you will live for ever,\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
and when you strike you strike like tyrants?\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
So fear Allah and obey me.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
Have fear of Him Who has provided you with all the (good) things you know;\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
Who has provided you with flocks and children\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
and with gardens and springs.\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
I fear for you the chastisement of an Awesome Day."\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They replied: ``It is all the same for us whether you admonish us or not.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
This has been happening all along.\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
We will not be subjected to any chastisement."\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
Eventually they gave the lie to him and We destroyed them. Surely there is a Sign in this, but most of them would not believe.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
Verily your Lord is Immensely Mighty, Most Compassionate.\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
The Thamud gave the lie to the Messengers.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
Recall when their brother Salih said to them: ``Have you no fear?"\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
``I am a trustworthy Messenger to you.\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
So fear Allah and obey me.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
I ask of you no reward. My reward is with none but the Lord of the Universe.\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
Do you believe that you will be left here to live securely in the present state\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
amidst gardens and springs\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
and cornfields and date-palms laden with juicy fruits?\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
You hew dwellings in mountains and exult in that.\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
Fear Allah and obey me\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
and do not follow the biddings of those that go to excesses\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
and spread mischief in the land rather than set things right."\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They replied: ``You are nothing but one of those who are bewitched;\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
you are no different from a mortal like us. So produce a sign if you are truthful."\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
Salih said: ``This is a she-camel. There is a day set for her to drink and there is a day set for you to drink.\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
Do not molest her lest the chastisement of an Awesome Day should seize you."\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
But they hamstrung her and then regretted it.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mmmxc{%
So the chastisement seized them. Surely there is a Sign in this, but most of them would not believe.\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mmmxci{%
Verily Your Lord is Immensely Mighty, Most Compassionate.\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The people of Lot rejected the Messengers, branding them liars.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
Recall, when their brother Lot said to them: ``Have you no fear?\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
I am a trustworthy Messenger to you.\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
So fear Allah and obey me.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
I seek of you no reward. My reward is with none but the Lord of the Universe.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
What, of all creation will you go to (fornicate with) the males,\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
leaving aside those whom Allah has created for you as your mates. Nay, you are a people that has transgressed all limits."\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said: ``O Lot! If you do not desist, you will be one of those expelled (from our towns)."\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said: ``I am one of those who abhor your practice.\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mmmci{%
My Lord, deliver me and my family from their wicked deeds."\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mmmcii{%
Then We delivered him and all his family\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mmmciii{%
except an old woman who was among those that stayed behind.\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mmmciv{%
Thereafter, We utterly destroyed the rest,\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mmmcv{%
and We sent upon them a rain, an evil rain that fell on those who had been warned.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Surely there is a Sign in this, but most of them would not believe.\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
Verily Your Lord is Immensely Mighty, Most Compassionate.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The people of Aykah also gave the lie to the Messengers.\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mmmcix{%
Recall, when Shuayb said to them: ``Have you no fear?\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mmmcx{%
I am a trustworthy Messenger to you.\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
So fear Allah and obey me.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
I ask of you no reward for this. My reward is with none but the Lord of the Universe.\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
Fill up the measure and do not diminish the goods of people,\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
weigh with an even balance\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
and do not deliver short, and do not go about creating mischief in the land,\qt@no{(183)}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
and have fear of Him Who created you and the earlier generations."\qt@no{(184)}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said: ``You are no more than one of those who have been bewitched,\qt@no{(185)}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
you are only a mortal like us. Indeed we believe that you are an utter liar.\qt@no{(186)}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
So cause a piece of the sky to fall upon us if you are truthful."\qt@no{(187)}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
Shuayb said: ``My Lord knows well all what you do."\qt@no{(188)}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
Then they branded him a liar, whereupon the chastisement of the Day of Canopy overtook them. It was the chastisement of a very awesome day.\qt@no{(189)}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Surely there is a Sign in this, but most of them would not believe.\qt@no{(190)}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
Verily Your Lord is Immensely Mighty, Most Compassionate.\qt@no{(191)}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
Indeed this is a revelation from the Lord of the Universe;\qt@no{(192)}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
which the truthful spirit has carried down\qt@no{(193)}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
to your heart that you might become one of those who warn (others on behalf of Allah),\qt@no{(194)}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
(a revelation) in clear Arabic language,\qt@no{(195)}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
(a revelation embodied) in the scriptures of the ancients.\qt@no{(196)}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Is it not a Sign to them - (to wit, the Makkans) - that the learned men of the Children of Israel know that?\qt@no{(197)}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
(But such is their adamance) that had We revealed it to one of the non-Arabs and even if he had recited (this clear Arabic discourse) to them\qt@no{(198)}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
they would still not have believed in it.\qt@no{(199)}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Thus have We caused this (Admonition) to penetrate the hearts of the culprits (like a hot rod).\qt@no{(200)}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe in it until they clearly see the grievous chastisement.\qt@no{(201)}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
But when it comes upon them suddenly, taking them unawares,\qt@no{(202)}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
they say: ``Can we be granted some respite?"\qt@no{(203)}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
Do they really want Our chastisement to be expedited?\qt@no{(204)}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Did you consider that if We were to let them enjoy life for many years\qt@no{(205)}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
and then the chastisement of which they were being warned were to come upon them,\qt@no{(206)}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
of what avail will be the provisions of life which they have been granted to enjoy?\qt@no{(207)}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
We never destroyed any habitation but that it had warners\qt@no{(208)}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
to admonish them. We have never been unjust.\qt@no{(209)}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
The satans did not bring down this (Clear Book),\qt@no{(210)}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
nor does it behove them, nor does it lie in their power.\qt@no{(211)}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Indeed they are debarred from even hearing it.\qt@no{(212)}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So do not call any other god beside Allah lest you become of those who will be punished,\qt@no{(213)}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
and warn your nearest kinsmen;\qt@no{(214)}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
and be meek to the believers who follow you.\qt@no{(215)}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
Then if they disobey you say to them: ``I am quit of what you do."\qt@no{(216)}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And put your trust in Him Who is Immensely Mighty, Most Compassionate,\qt@no{(217)}}%
\qt@newcmd\qurantrans@en@mmmcl{%
Who observes you when you rise (to pray)\qt@no{(218)}}%
\qt@newcmd\qurantrans@en@mmmcli{%
and observes your movements among those who prostrate themselves.\qt@no{(219)}}%
\qt@newcmd\qurantrans@en@mmmclii{%
He is All-Hearing, All-Knowing.\qt@no{(220)}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
O people, shall I tell you on whom it is that satans descend?\qt@no{(221)}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend on every forgerer steeped in sin,\qt@no{(222)}}%
\qt@newcmd\qurantrans@en@mmmclv{%
on those who whisper hearsay in the ears of people; and most of them are liars.\qt@no{(223)}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
As for poets, only the wayward follow them.\qt@no{(224)}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
Do you not see that they wander about in every valley\qt@no{(225)}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
and say things which they do not act upon,\qt@no{(226)}}%
\qt@newcmd\qurantrans@en@mmmclix{%
except those who believed and acted righteously and remembered Allah much, and when they themselves were subjected to wrong, they exacted retribution no more than to the extent of the wrong? Soon will the wrong-doers know the end that they shall reach.\qt@no{(227)}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta'. Sin. These are the verses of the Qur'an and a Clear Book;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
a guidance and good tidings for the believers\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
who establish Prayer and give Zakah, and have firm faith in the Hereafter.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
As for those who do not believe in the Hereafter, We have made their deeds seem attractive to them so they stumble around in perplexity.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
It is they for whom a grievous chastisement lies in store; it is they who shall be the greatest losers in the Hereafter.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
As for you, (O Muhammad), you are receiving the Qur'an from the Most Wise, the All-Knowing.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
(Recount to them) when Moses said to his family: ``I perceive something like fire: soon will I bring to you some information from there, or I will bring you a burning brand that you may warm yourselves."\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
But when Moses came to the fire, a call was sounded: ``Blessed is He Who is in the fire and whatever is around it. Glory be to Allah, the Sustainer of all in the Universe.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
O Moses, verily this is Me, Allah, the All-Mighty, the All-Wise!\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
Now cast your rod!" But when he saw the rod writhing as though it were a serpent, he turned his back in retreat and did not even look behind. ``O Moses, have no fear. Messengers have no fear in My presence,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
except he who has committed some wrong. But if he substitutes good in place of evil, I am Most Forgiving, Most Compassionate.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
Now put your hand into your bosom, and it will come forth shining without any blemish. (These are two of the) nine Signs to be carried to Pharaoh and his people. They are surely a wicked people."\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
But when Our Clear Signs came to them, they said: ``This is plain magic."\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
They denied those Signs out of iniquity and arrogance although their hearts were convinced of their truth. So see how evil was the end of those mischief-makers!\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
(On the other hand), We granted knowledge to David and Solomon and they said: ``All praise be to Allah Who has exalted us above many of His believing servants!"\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Solomon succeeded David and said: ``O people, we have been taught the speech of birds and we have been endowed with all kinds of things. Surely this is a conspicuous favour (from Allah)."\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
Hosts of jinn and humans and birds were marshalled for Solomon and were kept under full control.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
(Solomon was once on the move with them) until when they reached a valley of ants one of the ants said: ``O ants, get into your holes, lest Solomon and his hosts crush you (under their feet) without even knowing."\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
Smiling at the ant's utterance, Solomon burst into laughter and said: ``My Lord! Hold me under (Your) control that I may render thanks for the favour which You have bestowed on me and on my parents, and that I may act righteously in a manner that would please You. Include me, out of Your Mercy, among Your righteous servants."\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
(On another occasion) Solomon inspected the birds and said: ``Why is it that I do not see the hoopoe? Is he among the absentees?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
I will inflict a severe punishment on him or maybe even slaughter him unless he comes forth with a convincing reason (for his absence)."\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
Not before long the hoopoe came up and said: ``I have obtained a knowledge which you could not. I have brought for you sure news about Sheba.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
I found there a woman ruling over them, one who has been endowed with all things and has a mighty throne.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
I found that she and her people prostrate themselves before the sun rather than Allah. `` Satan has made their deeds appear attractive to them and has, thus, debarred them from the Right Path so they do not find true guidance\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
that they would prostrate themselves before Allah Who brings to light all that is hidden in the heavens and the earth and knows all that you conceal and all that you reveal.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
Allah - none is worthy of worship save He; He is the Lord of the Mighty Throne.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
Solomon said: ``Soon shall we see whether you have spoken the truth or are one of those that lie.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
Take this letter of mine, deliver it to them, and then draw back from them, and observe what they do."\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
The Queen said:" Know my nobles that a gracious letter has been delivered to me.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
It is from Solomon, and it is: ``In the name of Allah, the Most Merciful, the Most Compassionate."\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
(It says): ``Do not act towards me with defiance, but come to me in submission."\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
(After reading the letter) the Queen said: ``Nobles, let me have your counsel in this matter for I make no firm decision without you."\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said: ``We are strong and are given to vehement fighting. But the decision is yours. Therefore, consider what you would like to command."\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
The Queen said: ``When the kings enter a country they cause corruption in it and abase those of its people who are held in honour. This is what they are wont to do.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
I will send them a gift and then see with what answer my envoys return."\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
Now, when (the envoy of the Queen) came to Solomon, he said: ``Do you want to aid me with wealth? Whatever Allah has granted me is much more than what He has given you. (Keep for yourselves) your gift in which you are exulting.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
Envoy, go back to those who sent you and we shall certainly come upon them with hosts whom they will be unable to resist. We shall drive them out from there, and they will suffer humiliation and disgrace."\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
Solomon said: ``My nobles, which of you can bring me her throne before they come to me in submission?"\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
A stalwart of the jinn said: ``I will bring it to you before you rise from your council. Surely I have the power to do so and I am trustworthy."\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
And he who had some knowledge of the Book said: ``I will bring it before the twinkling of your eye." When Solomon saw the throne placed firmly beside him, he cried out: ``This is by the grace of my Lord so that He may test me whether I give thanks for (His Bounty) or act with ingratitude. Whoever is grateful is so to his own good; and whoever is ungrateful, let him know that my Lord is Immensely Resourceful, Most Bountiful."\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmcc{%
Solomon said: `` Set the throne before her casually, and let us see whether she gets to the Truth or is one of those who are not guided to what is right."\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmcci{%
When the Queen arrived, she was asked: ``Is your throne like this one?" She said: ``It seems as if it is the same. We had already come to know this and we had submitted ourselves."\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccii{%
What prevented her (from accepting the True Faith) was her worshipping deities other than Allah, for she belonged to an unbelieving people.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
She was told: ``Enter the palace." But when she saw it, she thought it was a pool of water and she bared both her calves (to enter into it). Solomon said: ``This is a slippery floor of crystal." Thereupon she cried out: ``My Lord, I have been inflicting much wrong on myself. Now I submit myself with Solomon to Allah, the Lord of the whole Universe."\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And We sent to Thamud their brother Salih (with the Message): ``Serve Allah," but all of a sudden they became split into two quarrelling factions.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccv{%
Salih said: ``My people, why do you wish to hasten that evil rather than good should come upon you? Why should you not seek pardon from Allah so that mercy be shown to you?"\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said: ``We augur ill of you and those who are with you." Salih replied: ``Your augury is with Allah. The truth is that you are a people who are being tried."\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
Now there were nine ring-leaders in the city who created corruption in the land and never worked to set things right.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said: ``Swear to one another in the name of Allah that we shall make a sudden night swoop on Salih and his family and will then tell their heirs that we did not witness the destruction of his family. We are indeed truthful."\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmccix{%
Thus they planned and We too planned, the while they did not know.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmccx{%
So see what was the outcome of the plan they made: We utterly destroyed them and their people, all of them.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
Now behold their houses that lie in utter ruins because of their wrong-doing. Verily there is a Sign in this for the people who know.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We delivered those who believed and were wont to avoid disobeying (Allah).\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
We also sent Lot, and recall when he told his people: ``Do you commit shameless acts with your eyes open?\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
Do you lustfully approach men instead of women? Nay, you engage in acts of sheer ignorance."\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
But this had only one answer from his people. They said: ``Expel Lot's folk from your city. They pretend to be absolutely clean."\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
Eventually We saved (Lot) and his family, except his wife. We had decreed that she should be among those who would remain behind.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained down upon them a rain. It was an evil rain for those who had already been warned.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say, (O Muhammad): ``All praise be to Allah, and peace be on those of His servants whom He has chosen." (Ask them): ``Who is better: Allah or the false gods that they associate with Him as His partners?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Who is it that has created the heavens and the earth and sent down for you water from the sky and then We caused to grow therewith orchards full of beauty whose trees you could never grow. Is there any god associated with Allah (in these tasks)?" Nay, they are a people who are veering away from the Right Path.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Who is it Who has made the earth a place of resort, and has caused rivers to flow in its midst, and has placed upon it firm mountains, and has placed a barrier between two masses of water? Is there any god associated with Allah (in these tasks)? Nay; but most of them do not know.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Who is it Who heeds the prayers of the distressed when he calls out to Him and Who removes his affliction? And who is it Who makes you vicegerents of the earth? Is there any god associated with Allah (in this task)? How little do you reflect!\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Who is it Who guides you through the darkness on land and sea? And Who sends winds as heralds of good tidings ahead of His Mercy? Is there any god associated with Allah (in this task)? Exalted be Allah above whatever they associate with Him in His Divinity!\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Who is it Who creates in the first instance and then repeats it? Who is it Who provides you with sustenance from the heavens and the earth? Is there any god associated with Allah (in these tasks)? Say: ``Bring forth your evidence, if you are truthful."\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say: ``None in the heavens or on the earth has knowledge of the Unseen save Allah. They do not know when they will be raised to life."\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
Nay, but they have lost their knowledge of the Hereafter. They are steeped in doubt and uncertainty about it: rather they are blind to it.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
The unbelievers say: ``When we become dust, we and our forefathers, shall we really be brought out (from our graves)?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
We were told about this and so were our forefathers before us. But these are no more than fairy tales that have been recounted from ancient times."\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say: ``Go about through the earth and see what has been the end of the evil-doers."\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
(O Prophet), do not grieve over them, nor be distressed at their designs.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
They also say: ``Tell us when this threat will come to pass, if you are truthful."\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say: ``The chastisement whose hastening you have been asking for, maybe a part of it has drawn quite near to you."\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
Indeed Your Lord is exceedingly bountiful to mankind. Yet most of them do not give thanks.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
Verily your Lord knows all that their hearts conceal as well as all that they reveal.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
There is nothing that is hidden - be it in the heaven or the earth - but is recorded in a Clear Book.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Surely this Qur'an explains to the Children of Israel most of the matters concerning which they have disagreements\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
and it is a guidance and mercy for the believers.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Indeed your Lord will decide between them by His judgement. He is All-Mighty, All-Knowing.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
So put your trust in Allah for you are on the manifest truth.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Surely you cannot make the dead hear you, nor can you make the deaf hear your call if they turn back in flight,\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
nor can you direct the blind to the Right Way, preventing them from falling into error. You can make only those who believe in Our verses to hear the call and then submit.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the time for the fulfilment of Our Word against them will come, We shall bring forth for them a beast from the earth who will speak to them because people did not believe in Our Signs.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
Just imagine the Day when We shall muster from every nation a large group of those who gave the lie to Our Signs, and they shall be duly arranged in ranks\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
until, when all of them have arrived, Allah will say: ``Did you give the lie to My Signs even without encompassing them with your knowledge? If that is not so, what did you do?"\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word will come to pass against them because of their wrong-doing: they will then be able to utter nothing.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
Did they not perceive that We had made the night so that they may repose in it and made the day clear and shining. Surely there are Signs in this for those who believe.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
The Day when the Trumpet will be blown all those who are in the heavens and on the earth shall be terror stricken - all except those whom Allah wills - and everyone shall come to Him utterly abject.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
You now see the mountains and consider them firmly fixed, but then they shall pass away even as clouds pass away. That will be the handiwork of Allah Who has created everything with perfect wisdom. He is well aware of what you do.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whosoever comes with good will receive a reward better than his deed, and they will be made secure from the terror of that Day.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And whosoever comes with evil, they will be flung upon their faces into the Fire. Will you be recompensed for aught other than what you do?\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmccl{%
(Tell them, O Muhammad): ``I have been commanded only to serve the Lord of this city that He has made inviolable, to serve Him to Whom all things belong. I have been commanded to be of those that submit to Allah,\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmccli{%
and to recite the Qur'an." So, whosoever is guided, his guidance will be to his own good. As for those who stray, tell them: ``I am none but a warner."\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say: ``All praise be to Allah, Who will soon show you His Signs that you will recognize." Your Lord is not unaware of what you do.\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta'. Sin. Mim\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are the verses of the Clear Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We recount to you with truth some parts of the story of Moses and Pharaoh for the benefit of those who believe.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Indeed Pharaoh transgressed in the land and divided its people into sections. One group of them he humiliated, and slew their sons and spared their daughters. Truly he was among the mischief-makers.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
We wanted to bestow favour on those who were oppressed in the land. We wanted to make them leaders and heirs\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
and to grant them power in the land, and make Pharaoh and Haman and their hosts see what they had feared.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
We suggested to the mother of Moses: ``Suckle your child, but when you fear for his life cast him into the river and be not fearful nor grieve, for We shall restore him to you and make him one of the Messengers."\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
Then Pharaoh's household picked him up (from the river) that he may be their adversary and be a cause of sorrow to them. Surely Pharaoh and Haman and their hosts erred (in their scheming).\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
The wife of Pharaoh said: ``Here is a delight of the eye to me and to you. Do not kill him. Maybe he will prove useful for us, or we may adopt him as a son." They were unaware of the end of it all.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
On the other hand, the heart of Moses' mother was sorely distressed. Had We not strengthened her heart that she might have full faith (in Our promise), she would have disclosed the secret.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
She told the sister of Moses: ``Follow him." So she kept watch over him unperceived (by the enemies).\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
And We had already forbidden the breasts of the nurses for the child. (So seeing the girl) said: ``Shall I direct you to the people of a household that will rear him with utter sincerity?"\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
Thus did We restore Moses to his mother that her eyes might be comforted and she might not grieve, and realise that the promise of Allah was true. But most people are unaware of this.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
When Moses reached the age of full youth and grew to maturity, We bestowed upon him wisdom and knowledge. Thus do We reward those who do good.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
Once he entered the city at a time when its people were heedless, and he encountered two men fighting, one of whom belonged to his own people and the other to his foes. Now the man belonging to Moses' own people cried out to him for help against the man from the foes, and Moses struck him with his fist and finished him. Moses said: ``This is an act of Satan. Surely he is an enemy who openly misleads."\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
Then he prayed: ``My Lord! I have indeed inflicted wrong on myself, so do forgive me," wherefore Allah forgave him for He is Ever Forgiving, Most Merciful.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
Thereupon Moses vowed: ``My Lord, because of the favour that You have done me I shall never support the guilty."\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
The next morning he proceeded to the city in fear and looking around as one apprehensive of danger when all of a sudden, the man who had sought his help the day before again called out to him for his help. Moses said to him: ``Clearly, you are a very misguided fellow."\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
And when Moses decided to lay his violent hands on the man belonging to the enemy, he cried out: ``Moses, do you intend to kill me as you killed a person yesterday?" You simply want to live in the land as a tyrant, and do not wish to set things right."\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
Then a man came running from the farther end of the city and said: ``O Moses, the nobles are deliberating about you that they may put you to death. So do be gone. I am one of your well-wishers."\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
Soon after hearing this Moses departed in a state of fear, looking around as one in apprehension and prayed: ``My Lord, deliver me from these unjust people."\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
When (after his departure from Egypt) Moses headed towards Midian, he said: ``I hope my Lord will show me the right Path."\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
When he arrived at the spring of Midian, he found there a crowd of people watering their flocks, and he found apart from them two women holding their flocks back. He asked the women: ``What is it that troubles you?" They said: ``We cannot water our flocks until the shepherds take their flocks away, and our father is a very old man."\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
On hearing this Moses watered their flocks for them, and then returned in a shaded place and said: ``My Lord, I am truly in great need of any good that You might send down to me."\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Soon thereafter one of the two women came to him, walking bashfully, and said: ``My father invites you that he may reward you for your having watered our flocks for us. `` When Moses came to him and narrated to him the whole of his story, he said: ``Have no fear. You are now safe from the iniquitous people."\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
One of the two women said: ``Father, employ this man in your service. The best whom you might employ is he who is strong and trustworthy."\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
Her father said to Moses: ``I want to marry one of these two daughters of mine to you if you serve me for eight years. But if you complete ten years, that will be of your own accord (but not an obligation). I do not intend to treat you harshly. If Allah wills, you will find me an upright man."\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
Moses replied: ``So that is agreed between me and you. Whichever of the two terms I fulfil, I trust that I shall not be wronged. Allah is a witness over the covenant we are committing ourselves to."\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
When Moses had fulfilled the term and was journeying with his family, he perceived a fire in the direction of the Mount (Sinai). He said to his family: ``Wait here; I have observed a fire. Maybe I will bring to you some news or a brand of fire from there that you may warm yourselves."\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
But when he came to the fire, a cry was heard from the right bank of the valley, from a tree in the hallowed ground: ``O Moses, verily I am Allah, the Lord of all creatures of the Universe."\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
He received the command: ``Throw away your rod!" But when he saw the rod writhing as though it were a serpent, he turned back in retreat, and did not even look behind. (He was told): ``O Moses, go ahead and have no fear. You are perfectly secure.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
Put your hand into your bosom, and it will come out shining without any blemish; and draw your hand close to your body to still your fear. Those are the two clear Signs from your Lord for Pharaoh and his chiefs, for truly they are a disobedient people."\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
Moses said: ``My Lord, I have killed one person from among them, and I fear that they will kill me.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
My brother Aaron is more eloquent in speech than I: so send him with me as a helper to confirm my truthfulness for I fear that they will reject me as a liar."\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
He said: ``We will certainly strengthen you through your brother and will invest both of you with such power that they shall not be able to hurt you. With the help of Our Signs the two of you and your followers will prevail."\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
But when Moses came to them with Our Clear Signs, they said: ``This is nothing but a magic that has been contrived. We never heard anything like it from our ancestors of yore."\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
Moses replied: ``My Lord knows best who comes with guidance from Him, and also whose end will be the best in the Hereafter. As for the wrongdoers, they shall not prosper."\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
Pharaoh said: ``O nobles, I do not know that you have any god beside myself. Haman, bake bricks out of clay and build a lofty palace for me so that I may mount up and be able to observe the god of Moses, even though I believe that Moses is a liar."\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he and his hosts waxed arrogant in the land without any right, believing that they will never have to return to Us!\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
Eventually We seized him and his hosts and We flung them into the sea. So do see the end of the wrong-doers!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We made them leaders who invite people to the Fire. On the Day of Judgement they shall not find help from any quarter.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
We have made a curse to pursue them in this world, and on the Day of Judgement they shall be among the despised.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
After We had destroyed the earlier generations We bestowed the Book on Moses - a source of enlightenment for people and a guidance and mercy -- that they may take heed.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
(O Muhammad), you were then not on the western side when We bestowed this commandment (of Law), and you were not among its witnesses.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
Thereafter We raised up many a generation and a long time passed. You were then not even present among the people of Midian to rehearse Our verses to them. But it is We Who are sending news about that.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
Nor were you on the side of the Mount (Sinai) when We called out to Moses (in the first instance). But it is out of Mercy from your Lord (that you are being informed of all this) so that you may warn a people to whom no warner came before you. Maybe they will take heed.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
(We did so) lest a calamity might seize them because of the misdeeds they committed whereafter they would say: ``Our Lord, why did you not send a Messenger to us that we follow Your revelation and become among those who believe?"\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccc{%
But when the Truth reached them from Us, they said: ``Why was he not given that which was given to Moses?" But did they not reject before what had been given to Moses? They said: ``Both are magic, each supporting the other!" And they said: ``We deny each of these."\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Tell them, (O Prophet): ``Then do bring a Book from Allah which is a better guide than either of them, and I will follow it! Do so if you are truthful!"\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
But if they do not hearken to this, know well that they only follow their lusts and who is in greater error than he who follows his lusts without any guidance from Allah? Allah does not guide those given to wrong-doing.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
We have constantly conveyed them the word (of admonition) that they may take heed.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those on whom We bestowed the Book before do believe in this (to wit, the Qur'an).\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
When it is recited to them they say: ``We believe in it for it is the Truth from our Lord. Indeed we were already Muslims."\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
These will be granted their reward twice over because they remained steadfast; they repel evil with good, and spend (in alms) out of the sustenance We provided them,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
and when they hear any vain talk, they turn away from it, saying: ``We have our deeds and you have your deeds. Peace be to you. We do not desire to act like the ignorant."\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
(O Prophet), you cannot grant guidance to whom you please. It is Allah Who guides those whom He will. He knows best who are amenable to guidance.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
They say: ``If we were to follow this guidance with you, we should be snatched away from our land." Have We not established for them a secure sanctuary to which fruits of all kinds are brought as a provision from Us? But most of them do not know.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many a town did We destroy whose inhabitants exulted on account of their affluence. These are their dwellings in which very few dwelt after them. Eventually it is We Who inherited them.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
Your Lord would not destroy a town until He had sent to its centre a Messenger who would recite to them Our verses. Nor would We destroy any town unless its inhabitants were iniquitous.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
Whatever you have been given is a provision for the life of this world and its glitter. But that which is with Allah is better and more enduring. Do you not use your intellect?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Now, he to whom We have promised a good which he is going to obtain - can he be like him whom We have given the good things of this life, but who will be brought up for punishment on the Day of Judgement?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
(Let them not forget) that the Day when Allah will call unto them, and say: ``Where are those whom you imagined to be My associates?"\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those against whom the Word will be realised will say: ``Our Lord, these are the ones whom we led astray just as we ourselves strayed. We absolve ourselves before You of all blame. It was not us that they worshipped."\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
They will then be told: ``Call upon those for help whom you declared to be Our associates." They will then call upon them but they will not answer them. They will have observed the chastisement in front of them. Would that they were guided!\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
(Let them not disregard) that the Day when Allah will call out to them saying: ``What was the answer you gave to the Messengers?"\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
Then they will not be able to think of any reply, nor will they be able to ask one another.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But those who repented and believed and acted righteously, they will perhaps be among those who will prosper there.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
Your Lord creates what He will and chooses (for His tasks) whomsoever He will. It is not for them to make the choice. Glory be to Allah. He is exalted far above their associating others in His Divinity.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
Your Lord knows all that their hearts conceal and all that they reveal.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
He is Allah; there is no god but He. His is the praise in this world and in the Hereafter. His is the command and to Him will all of you be returned.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
(O Prophet), tell them: ``Did you consider: if Allah were to make the night perpetual over you till the Day of Judgement, is there a god other than Allah who can bring forth light for you? Do you not hear?"\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say: ``Did you consider: if Allah were to make the day become perpetual over you till the Day of Judgement, is there a god other than Allah who can bring in night for you that you may repose in it? Will you not see?"\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
It is out of His Mercy that He has made for you night and day that you may repose (during the night) and seek His Bounty (during the day) that you might be grateful.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
(Let them bear in mind) that on that Day when He will call out to them saying: ``Where are My associates, those whom you imagined to be so?"\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And from each people We shall draw a witness, and shall say to them: ``Do produce your evidence now." Then they shall know that the Truth is with Allah alone, and the lies which they had invented will forsake them.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
To be sure, Qarun (Korah) was one of Moses' people; then he transgressed against them. We had bestowed on him such treasure that their very keys would have been raised with difficulty by a whole group of strong people. Once when his people said to him: ``Do not exult, for Allah does not love those who exult (in their riches).\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
Seek by means of the wealth that Allah has granted you the Abode of the Hereafter, but forget not your share in this world and do good as Allah has been good to you and do not strive to create mischief in the land, for Allah loves not those who create mischief."\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He replied: ``All this has been given to me on account of a certain knowledge that I have." Did he not know that Allah had destroyed before him those who were stronger in might than he and were more numerous in multitude? The wicked are not asked about their acts of sin.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
Once Korah went forth among his people in full glitter. Those seeking the life of this world said: ``Would that we had the like of what Korah has! He truly has a great fortune."\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those endowed with true knowledge said: ``Woe to you. The reward of Allah is best for those who believe and act righteously. But none except those who are patient shall attain to this."\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
At last We caused the earth to swallow him and his house. Thereafter there was no group of people that could come to his aid against Allah; nor was he able to come to his own aid.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And those who had envied his position the day before began to say on the morrow: ``Alas, we had forgotten that it is Allah Who increases the provision of those of His servants whom He will and grants in sparing measure to those whom He will. But for Allah's favour upon us, He could have made us to be swallowed too. Alas, we had forgotten that the unbelievers do not prosper."\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
As for the Abode of the Hereafter, We shall assign it exclusively for those who do not seek glory on earth nor want to cause mischief. The God-fearing shall have the best end.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
He who shall bring a good deed shall be rewarded with what is better. But those who bring evil deeds shall not be requited more than their deeds.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
(O Prophet), surely He Who has ordained the Qur'an on you will bring you to the best end. Say to them: ``My Lord knows best who has brought true guidance and who is in clear error."\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
(O Prophet), you never looked forward for the Book to be revealed to you. It is out of sheer Mercy of your Lord that it was (revealed to you). So do not lend any support to the unbelievers.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And let it never happen that the unbelievers might turn you away from the revelations of Allah after they have been revealed to you. Call people to your Lord and never become one of the unbelievers,\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
and do not invoke any god beside Allah. There is no god but He. All will perish but He. To Him belongs the command. And to Him shall all of you return.\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif. Lam. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do people think that they will be let go merely by saying: “We believe,” and that they will not be tested,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
for We indeed tested those who went before them? Allah will most certainly ascertain those who spoke the truth and those who lied.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Do the evil-doers suppose that they will get the better of Us? How evil is their judgement!\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Let him who looks forward to meeting Allah know that Allah's appointed term will surely come to pass. He is All-Hearing, All-Knowing.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
Whosoever strives (in the cause of Allah) does so to his own good. Surely Allah stands in no need of anyone in the whole Universe.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
Those who believe and do good deeds, We shall cleanse them of their evil deeds and reward them according to the best of their deeds.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
We have enjoined upon man kindness to his parents, but if they exert pressure on you to associate with Me in My Divinity any that you do not know (to be My associate), do not obey them. To Me is your return, and I shall let you know all that you have done.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
As for those who believed and acted righteously, We shall certainly admit them among the righteous.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
Among people there are some who say: “We believe in Allah.” But when such a person is made to endure suffering in Allah's cause, he reckons the persecution he suffers at the hands of people as though it is a chastisement from Allah. But if victory comes from your Lord, the same person will say “We were with you.” Does Allah not know whatever is in the hearts of the people of the world?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
Allah will surely ascertain who are the believers and who are the hypocrites.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
The unbelievers say to the believers: “Follow our way and we will carry the burden of your sins.” (They say so even though) they are not going to carry any part of their sins. Surely they are lying.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
They will certainly carry their own burdens and other burdens besides their own. They will assuredly be called to account on the Day of Resurrection concerning the fabrications which they contrived.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
We did indeed send Noah to his people and he lived among them a thousand years save fifty. Eventually the Flood overtook them while they were engaged in wrongdoing.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
Then We rescued Noah together with the people in the Ark and made it (that is, the Ark) a lesson for all people.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
We sent Abraham and he said to his people: “Serve Allah and fear Him. This is better for you if you only knew.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
Those that you worship instead of Allah are merely idols, and you are simply inventing lies (about them). Indeed those whom you worship beside Allah have no power to provide you with any sustenance. So seek your sustenance from Allah and serve only Him and give thanks to Him alone. It is to Him that you will be sent back.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
And if you give the lie (to the Messenger), then many nations before you also gave the lie (to their Messengers). The Messenger is charged with no other duty than to deliver the Message in clear terms.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
Have they never observed how Allah creates for the first time and then repeats it? Indeed (to repeat the creation of a thing) is even easier for Allah (than creating it for the first time).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say: “Go about the earth and see how He created for the first time, and then Allah will recreate life.” Surely, Allah has power over everything.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He chastises whom He will and forgives whom He will. To Him all of you will be sent back.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
You cannot overpower Allah, neither on the earth nor in the heaven. None can protect you from Allah nor come to your aid against Him.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
Those who disbelieved in Allah's signs and in meeting Him, it is they who have despaired of My Mercy; it is they for whom a painful chastisement lies ahead.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
The people (of Abraham) had no other answer than to say: “Kill him or burn him.” But Allah delivered him from the fire. There are many Signs in this for those who believe.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
He said: “You have taken up idols instead of Allah as a bond of love among yourselves in the present life, but on the Day of Resurrection you will disown and curse one another. Your refuge shall be the Fire, and none will come to your aid.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
Then did Lot believe him, and Abraham said: “I am emigrating unto my Lord. He is All-Powerful, All-Wise,”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
and We bestowed upon him (offspring like) Isaac and Jacob, and bestowed prophethood and the Book on his descendants and granted him his reward in this world; he will certainly be among the righteous in the Hereafter.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
We sent Lot and he said to his people: “You commit the abomination that none in the world ever committed before you.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
What! Do you go to men (to satisfy your lust), engage in highway robbery, and commit evil deeds in your gatherings?” Then they had no answer to offer other than to say: “Bring Allah's chastisement upon us if you are truthful.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
Lot said: “My Lord, aid me against these mischievous people.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
When Our emissaries brought the good news to Abraham, and said (to him): “We are surely going to destroy the inhabitants of this city; its inhabitants are immersed in wrong-doing.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
Abraham said: “But Lot is there.” They replied: “We are well aware of those who are there. We shall save him and all his household except his wife.” His wife is among those who will stay behind.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
When Our emissaries came to Lot he was distressed and embarrassed on their account. They said: “Do not fear nor be distressed. We shall save you and all your household except your wife who is among those that will stay behind.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
We shall bring down upon the people of this city a scourge from the heaven because of their evildoing.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And We have left a vestige of it in that city as a Clear Sign for a people who use their reason.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And We sent to Midian their brother Shuayb. He said: “My people, serve Allah and look forward to the Last Day and do not go about the earth committing mischief.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
But they denounced him as a liar. So a mighty earthquake overtook them, and by the morning they lay overturned in their houses.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And We destroyed Ad and Thamud, whose dwellings you have observed. Satan had embellished their deeds for them and had turned them away from the Right Path although they were a people of clear perception.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And We destroyed Qarun (Korah) and Pharaoh and Haman. Moses came to them with Clear Signs but they waxed arrogant in the land although they could not have outstripped (Us).\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
So We seized each for their sin. We let loose upon some a violent tornado with showers of stones; some were overtaken by a mighty Cry; some were caused to be swallowed up by the earth, and some We drowned. Allah would not wrong them, but it is they who wronged themselves.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The case of those who took others than Allah as their protectors is that of a spider who builds a house; but the frailest of all houses is the spider's house; if they only knew.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Surely Allah knows fully what they call upon apart from Him. He is the Most Powerful, the Most Wise.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
These are the parables that We set forth to make people understand. But only those endowed with knowledge will comprehend them.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
Allah has created the heavens and the earth in Truth. Certainly there is a Sign in this for those who believe.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
(O Prophet), recite the Book that has been revealed to you and establish Prayer. Surely Prayer forbids indecency and evil. And Allah's remembrance is of even greater merit. Allah knows all that you do.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
Argue not with the People of the Book except in the fairest manner, unless it be those of them that are utterly unjust. Say to them: “We believe in what was revealed to us and what was revealed to you. One is our God and your God; and we are those who submit ourselves to Him.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
(O Prophet), thus have We bestowed the Book on you. So those on whom We had bestowed the Book before believe in it, and of these (Arabs) too a good many believe in it. It is none but the utter unbelievers who deny Our Signs.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
(O Prophet), you did not recite any Book before, nor did you write it down with your hand; for then the votaries of falsehood would have had a cause for doubt.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
But it is a set of Clear Signs in the hearts of those who have been endowed with knowledge. None except the utterly unjust will deny Our Signs.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
They say: “Why were Signs from his Lord not sent down upon him?” Say: “The Signs are only with Allah. As for me, I am no more than a plain warner.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
Does it not suffice for them (as a Sign) that We revealed to you the Book that is recited to them? Surely there is mercy and good counsel in it for those who believe.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say (O Prophet): “Allah suffices as a witness between me and you. He knows whatever is in the heavens and the earth. As for those who believe in falsehood and are engaged in infidelity with Allah, it is they who will be the losers.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
They ask you to hasten in bringing chastisement upon them. Had there not been an appointed term for it, the chastisement would have already visited them; in fact it will come down upon them all of a sudden (at its appointed time) while they will not be aware of it.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They ask you to hasten the chastisement upon them although Hell encompasses the unbelievers.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
(They will become aware of it) the Day when the chastisement will overwhelm them from above and from under their feet, and He will say to them: “Taste now the consequence of the deeds that you used to commit.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My servants who believe, verily My earth is vast; so serve Me alone.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every being shall taste death, then it is to Us that you shall be sent back.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
We shall house those who believed and acted righteously in the lofty mansions of Paradise beneath which rivers flow. There they shall remain for ever. How excellent a reward it is for those who acted (in obedience to Allah),\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
who remained steadfast and put their trust in their Lord!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcd{%
How many an animal there is that does not carry about its sustenance. Allah provides sustenance to them and to you. He is All-Hearing, All-Knowing.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
If you were to ask them: “Who created the heavens and the earth and Who has kept the sun and the moon in subjection?” they will certainly say: “Allah.” How come, then, they are being deluded from the Truth?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah enlarges the sustenance of any of His servants whom He will, and straitens the sustenance of whom He will. Surely Allah has knowledge of everything.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
If you were to ask them: “Who sent down water from the sky and therewith revived the earth after its death?” they will certainly say: “Allah.” Say: “To Allah alone be praise and thanks.” But most people do not understand.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
The present life is nothing but sport and amusement. The true life is in the Abode of the Hereafter; if only they knew.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
When they embark in the ships they call upon Allah, consecrating their faith to Him. But when He rescues them and brings them to land, they suddenly begin to associate others with Allah in His Divinity\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
that they may be ungrateful for the rescue that We granted them, and that they may revel in the pleasures (of the present life). Soon they shall come to know.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Do they not see that We have given them a sanctuary of safety whereas people around them are being snatched away? So, do they believe in falsehood and ungratefully deny Allah's bounties?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
Who can be more unjust than he who foists a lie on Allah or gives the lie to the Truth after it has come to him? Is Hell not the resort of the unbelievers?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
As for those who strive in Our cause, We shall surely guide them to Our Ways. Indeed Allah is with those who do good.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif. Lam. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Romans have been defeated\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
in the neighbouring land; but after their defeat they shall gain victory in a few years.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
All power belongs to Allah both before and after. On that day will the believers rejoice\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
at the victory granted by Allah. He grants victory to whomsoever He pleases. He is the Most Mighty, the Most Compassionate.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
This is Allah's promise and He does not go back on His promise. But most people do not know.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
People simply know the outward aspect of the worldly life but are utterly heedless of the Hereafter.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Do they not reflect on themselves? Allah created the heavens and the earth and whatever lies between them in Truth and for an appointed term. Yet many people deny that they will meet their Lord.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
Have they not travelled through the earth that they may observe what was the end of their predecessors who were far mightier and tilled the land and built upon it more than these have ever built? And Allah's Messengers came to them with Clear Signs. It was not Allah Who wronged them, but it is they who wronged themselves.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Evil was the end of those evil-doers, for they gave the lie to Allah's Signs and scoffed at them.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
Allah creates in the first instance and will later repeat it. Thereafter it is to Him that you shall be sent back.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
On that Day when the Hour will come to pass, the criminals shall be dumbfounded.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
None whom they had associated with Allah in His Divinity will intercede on their behalf; rather, they will disown those whom they had set up as Allah's associates in His Divinity.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
On that Day when the Hour will come to pass, people will be split into groups.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
Then those who believed and acted righteously will be placed in a Garden and will be happy and jubilant.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
As for those who disbelieved and gave the lie to Our Signs and to the encounter of the Hereafter, they will be arraigned for chastisement.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So glorify Allah in the evening and the morning.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
His is all praise in the heavens and in the earth; (and glorify Him) in the afternoon and when the sun begins to decline.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He brings forth the living from the dead and brings forth the dead from the living, and revives the earth after it is dead. Likewise will you be raised to life (after you die).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And of His Signs is that He created you from dust and behold, you became human beings, and are multiplying around (the earth).\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And of His Signs is that He has created mates for you from your own kind that you may find peace in them and He has set between you love and mercy. Surely there are Signs in this for those who reflect.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And of His Signs is the creation of the heavens and the earth and the diversity of your tongues and colours. Indeed there are Signs in this for the wise.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And of His Signs is your sleeping at night and your seeking His Bounty during the day. Indeed there are Signs in this for those who hearken.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And of His Signs is that He shows you lightning, arousing both fear and hope, and sends down water from the sky and revives the earth after it is dead. Indeed there are Signs in this for those who use their reason.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And of His Signs is that the sky and the earth stand firm by His command. Then no sooner than He summons you out of the earth you will come forth.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
To Him belong all who are in the heavens and all who are on the earth. All are in obedience to Him.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
It is He Who creates in the first instance and it is He Who will repeat the creation, and that is easier for Him. His is the loftiest attribute in the heavens and the earth. He is the Most Mighty, the Most Wise.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He sets forth for you a parable from your own lives. Do you have among your slaves some who share with you the sustenance that We have bestowed on you so that you become equals in it, all being alike, and then you would hold them in fear as you fear each other? Thus do We make plain the Signs for those who use reason.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
But the wrong-doers follow their desires without any knowledge. Who, then, can show the way to him whom Allah lets go astray? Such shall have no helpers.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
(O Prophet and his followers), turn your face singlemindedly to the true Faith and adhere to the true nature on which Allah has created human beings. The mould fashioned by Allah cannot be altered. That is the True, Straight Faith, although most people do not know.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
(Adhere to the True Faith and) turn to Him, and hold Him in awe, and establish Prayer, and do not be of those who associate others with Allah in His Divinity,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
those who have split up their religion and have become divided into sects, each party exulting in what they have.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
(Such are human beings) that when any misfortune befalls them, they cry to their Lord, penitently turning to Him. But no sooner that He lets them have a taste of His Mercy than some of them begin associating others with their Lord in His Divinity\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
so that they may show ingratitude to Us for the favours We had bestowed upon them. So, enjoy yourselves a while; but then you shall soon come to know.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Have We sent down any sanction which provides support to their associating others with Allah in His Divinity?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
When We make people have a taste of Our Mercy, they exult in it; and when any misfortune befalls them in consequence of their deeds, then lo and behold, they despair.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
Do they not see that Allah enlarges and straitens the sustenance of those whom He pleases? There are Signs in this for those who believe.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
So give his due to the near of kin, and to the needy, and to the wayfarer. That is better for those who desire to please Allah. It is they who will prosper.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
Whatever you pay as interest so that it may increase the wealth of people does not increase in the sight of Allah. As for the Zakah that you give, seeking with it Allah's good pleasure, that is multiplied manifold.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
It is Allah Who created you, then bestowed upon you your sustenance, and He will cause you to die and then will bring you back to life. Can any of those whom you associate with Allah in His Divinity! do any such thing? Glory be to Him and exalted be He above whatever they associate with Allah in His Divinity.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Evil has become rife on the land and at sea because of men's deeds; this in order that He may cause them to have a taste of some of their deeds; perhaps they will turn back (from evil).\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
(O Prophet), say: “Traverse in the earth and see what was the end of those who went before you: most of them associated others with Allah in His Divinity.”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
So turn your face exclusively towards the True Faith before there comes the Day whose coming from Allah cannot be averted, the Day when people will split into groups.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
He who disbelieves will suffer the consequence of it and he who acts righteously, they will pave the way for their own good\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
so that Allah may, out of His Bounty, reward those who believe and act righteously. Verily He does not love the unbelievers.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And of His Signs is that He sends winds to herald good tidings and that He may give you a taste of His Mercy, and that ships may sail at His bidding, and you may seek His Bounty and give thanks to Him.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
We sent Messengers before you to their respective nations, and they brought Clear Signs to them. Then We took vengeance upon those who acted wickedly. It was incumbent on Us to come to the aid of the believers.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
Allah sends the winds that stir up clouds and then He spreads them in the sky as He pleases and splits them into different fragments, whereafter you see drops of rain pouring down from them. He then causes the rain to fall on whomsoever of His servants He pleases, and lo, they rejoice at it,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
although before that they were given to despair.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
See, then, the tokens of Allah's Mercy: how He revives the earth after it is dead. Verily He is the One Who will revive the dead. He has power over everything.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
But if We were to send a wind and then their tilth has become yellow, they would never cease to disbelieve.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
(O Prophet), you cannot make the dead hear, nor can you make the deaf hear your call when they turn back in retreat,\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
nor can you guide the blind out of their error. You can make none hear (your call) except those who believe in Our Signs and have surrendered themselves (to Him).\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
It is Allah Who created you in a state of weakness; then after weakness He gave you strength, then after strength He made you weak and old. He creates what He pleases. He is All-Knowing, All-Powerful.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
On that Day when the Hour will come to pass the wicked shall swear that they had stayed (in the world) no more than an hour. Thus they used to be deceived in the life of the world.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
But those who had been endowed with knowledge and faith shall say: “According to Allah's Record you have stayed till the Day of Resurrection. Now, this is the Day of Resurrection. But you did not know.”\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
So that will be the Day when the excuses of the wrong-doers will not avail them, nor will they be asked to make amends.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
In the Qur'an We have explained things to people in myriad ways. But no matter what Sign you bring to them, those who are resolved upon denying the Truth will say: “You are given to falsehood.”\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
Thus does Allah seal the hearts of those who have no knowledge.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
Therefore, (O Prophet), have patience. Surely Allah's promise is true. Let those who lack certainty not cause you to be unsteady.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif. Lam. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are the verses of the Wise Book,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
a guidance and mercy for the doers of good,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
who establish Prayer and pay Zakah, and have firm faith in the Hereafter.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
It is they who are on true guidance from their Lord, and it is they who shall prosper.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
There are some human beings who purchase an enchanting diversion in order to lead people away from the way of Allah without having any knowledge, who hold the call to the Way of Allah to ridicule. A humiliating chastisement awaits them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
When Our verses are recited to such a person, he arrogantly turns away, as though he had not heard them, or as though there was a deafness in his ears. So announce to him the tidings of a grievous chastisement.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
Surely those who believe and do good deeds shall have Gardens of Bliss.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
They shall abide in them forever. This is Allah's promise that shall come true. He is the Most Powerful, the Most Wise.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He created the heavens without any pillars visible to you and He placed mountains in the earth as pegs lest it should turn topsy turvy with you, and He dispersed all kinds of animals over the earth, and sent down water from the sky causing all kinds of excellent plants to grow on it.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
Such is Allah's creation. Show me, then, what any others, apart from Allah, have created. Nay, the fact is that the wrong-doers are in manifest error.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
We bestowed wisdom upon Luqman, (enjoining): “Give thanks to Allah.” Whoso gives thanks to Allah, does so to his own good. And whoso disbelieves (let him know that) Allah is All-Sufficient, Immensely Praiseworthy.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And call to mind when Luqman said to his son while exhorting him: “My son, do not associate others with Allah in His Divinity. Surely, associating others with Allah in His Divinity is a mighty wrong.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
We enjoined upon man to be dutiful to his parents. His mother bore him in weakness upon weakness, and his weaning lasted two years. (We, therefore, enjoined upon him): “Give thanks to Me and to your parents. To Me is your ultimate return.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
But if they press you to associate others with Me in My Divinity, (to associate) those regarding whom you have no knowledge (that they are My associates), do not obey them. And yet treat them well in this world, and follow the way of him who turns to Me in devotion. Eventually it is to Me that all of you shall return, and I shall then tell you all that you did.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
(Luqman said): “Son, Allah will bring forth everything even if it be as small as the grain of a mustard seed even though it be hidden inside a rock or (anywhere) in the heavens or earth. Allah is Most Subtle, All-Aware.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
Son, establish Prayer, enjoin all that is good and forbid all that is evil, and endure with patience whatever affliction befalls you. Surely these have been emphatically enjoined.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
Do not (contemptuously) turn your face away from people, nor tread haughtily upon earth. Allah does not love the arrogant and the vainglorious.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
Be moderate in your stride and lower your voice. Verily the most disgusting of all voices is the braying of the donkey.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
Have you not seen that Allah has subjected to your service all that is in the heavens and on the earth and has abundantly bestowed upon you all His bounties, both visible and invisible? Yet some persons dispute regarding Allah without having any knowledge or guidance or any illuminating Book.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
When they are told: “Follow what Allah has revealed,” they say: “We will rather follow that which we have found our forefathers following.” (Will they follow that) even though Satan might invite them to the chastisement of the Blazing Fire?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
Whoever surrenders himself to Allah and lives righteously grasps the most firm handle. The ultimate decision of all matters rests with Allah.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
So let the unbelief of the unbeliever not grieve you. To Us is their return and then We shall inform them of all that they did. Surely Allah knows well even the secrets that are hidden in the breasts (of people).\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We allow them to enjoy themselves a while in the world and then We shall drive them in utter helplessness to a harsh chastisement.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
If you were to ask them: “Who created the heavens and the earth?” they will certainly reply: “Allah.” Say: “All praise and thanks be to Allah.” Yet most of them do not know.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
All that is in the heavens and the earth belongs to Allah. Verily He is All-Sufficient, Immensely Praiseworthy.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
If all the trees on earth become pens, and the sea replenished by seven more seas were to supply them with ink, the Words of Allah would not be exhausted. Verily Allah is Most Mighty, Most Wise.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
To create all of you or to resurrect all of you is to Him like (creating or resurrecting) a single person. Verily Allah is All-Hearing, All-Seeing.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
Do you not see that Allah makes the night phase into the day and makes the day phase into the night and has subjected the sun and the moon to His will so that each of them is pursuing its course till an appointed time? (Do you not know that) Allah is well aware of all that you do?\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
All this is because Allah, He alone, is the Truth and all that which they call upon beside Him is false. Surely Allah, He alone, is All-High, Incomparably Great.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmd{%
Do you not see that ships sail in the sea by Allah's Grace that He may show you some of His Signs? Surely there are Signs in this for everyone who is steadfast, thankful.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdi{%
When waves engulf them (in the sea) like canopies, they call upon Allah, consecrating their faith solely to Him. But when He delivers them safely to the land, some of them become lukewarm. None denies Our Signs except the perfidious, the ungrateful.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O people, fear (the wrath) of your Lord, and dread the Day when no father will stand for his child, nor any child stand for his father. Surely Allah's promise is true. So let the life of this world not beguile you, nor let the Deluder delude you about Allah.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Surely Allah alone has the knowledge of the Hour. It is He Who sends down the rain and knows what is in the wombs, although no person knows what he will earn tomorrow, nor does he know in which land he will die. Indeed, Allah is All-Knowing, All-Aware.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif. Lam. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdv{%
This Book, beyond all doubt, was revealed by the Lord of the Universe.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Or do they say: “He has fabricated it?” Nay, it is the Truth from your Lord so that you may warn a people to whom no warner came before you; perhaps they will be guided to the Right Way.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
It is Allah Who created the heavens and the earth and all that is between the two, in six days, and then He established Himself on the Throne. You have no guardian or intercessor other than He. Will you, then, not take heed?\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He governs from the heaven to the earth and then the record (of this governance) goes up to Him in a day whose measure is a thousand years in your reckoning.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdix{%
He knows all that is beyond as well as all that is within a creature's sense-perception. He is the Most Mighty, the Most Compassionate,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdx{%
He Who excelled in the creation of all that He created. He originated the creation of man from clay,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
then made his progeny from the extract of a mean fluid,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
then He duly proportioned him, and breathed into him of His spirit, and bestowed upon you ears and eyes and hearts. And yet, little thanks do you give.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
They say: “Shall we be created afresh after we have become lost in the earth?” Nay, the fact is that they deny that they will meet their Lord.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Tell them: “The angel of death who has been charged with your souls shall gather you, and then you shall be brought back to your Lord.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
Would that you could see the guilty standing before their Lord with their heads downcast, (saying to Him): “Our Lord, we have now seen and heard, so send us back (to the world) that we might act righteously. For now we have come to have firm faith.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
(They will be told): “If We had so willed, We could have bestowed guidance on every person. But the Word from Me that I will fill Hell with men and jinn, all together, has been fulfilled.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
So taste the chastisement on account of your forgetting the encounter of this Day. We, too, have forgotten you. Taste the eternal chastisement as a requital for your misdeeds.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
None believes in Our Signs except those who, when they are given good counsel through Our verses, fall down prostrate and celebrate the praise of their Lord and do not wax proud.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Their sides forsake their beds, and they call upon their Lord in fear and hope, and expend (in charity) out of the sustenance We have granted them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
No one knows what delights of the eyes are kept hidden for them as a reward for their deeds.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Would a true believer be like him who was an evil-doer? Surely they are not equal.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
As for those who believe and act righteously, theirs shall be Gardens to dwell in, a hospitality to reward them for their deeds.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
As for the evil-doers, their refuge shall be the Fire. Every time they want to escape from it they shall be driven back and shall be told: “Taste the chastisement of the Fire which you used to reject as a lie.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
We shall certainly have them taste some chastisement in this world in addition to the greater chastisement (of the Hereafter); perhaps they will retract (from their transgression).\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who is more unjust than he who is given good counsel through the Signs of his Lord and yet he turns away from them? Surely We will exact full retribution from such criminals.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
Verily We bestowed the Book upon Moses. So entertain no doubt if (the Prophet Muhammad) received the same. We had made that Book a guidance for the Children of Israel,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
and when they remained steadfast and firmly believed in Our Signs, We created among them leaders who guided people by Our command.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Surely your Lord will judge among them on the Day of Resurrection concerning the matters about which the Children of Israel used to differ.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Did (these historical events) not make them realise that We destroyed many nations before them amidst whose dwellings they now move about? Surely there are many Signs in this. Are they unable to hear?\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Have they not seen that We drive water to the parched land, thereby bringing forth crops which they and their cattle eat? Are they unable to see?\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
They say: “If you are truthful, (tell us) when will the Judgement come?”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Tell them: “If the unbelievers were to believe on the Day of Judgement that will not avail them. For then they will be granted no respite.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
So (leave them to themselves and) turn away from them and wait; they too are waiting.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet, fear Allah and do not obey the unbelievers and the hypocrites. Verily Allah is All-Knowing, Most Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
Follow that which is revealed to you from your Lord. Verily Allah is fully aware of all that you do.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
Put your trust in Allah: Allah is sufficient as Guardian.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah has never put two hearts within one person's body; nor has He made your wives, whom you compare to your mothers' backs (to divorce them), your true mothers; nor has He made those whom you adopt as sons your own sons. These are only words that you utter with your mouths. But Allah proclaims the Truth and directs you to the Right Path.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call your adopted sons after their true fathers; that is more equitable in the sight of Allah. But if you do not know their true fathers, then regard them as your brethren in faith and as allies. You will not be taken to task for your mistaken utterances, but you will be taken to task for what you say deliberately. Allah is Most Forgiving, Most Compassionate.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
Surely the Prophet has a greater claim over the believers than they have over each other, and his wives are their mothers. According to the Book of Allah, blood relatives have greater claim over each other than the rest of the believers and the Emigrants (in the cause of Allah), except that you may do some good to your allies (if you so wish). This is inscribed in the Book of Allah.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And call to mind, (O Prophet), when We took the covenant from all Prophets; and also from you and Noah and Abraham, Moses, and Jesus the son of Mary. We took from them a solemn covenant\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
so that (their Lord) may question the truthful about their truthfulness. As for the unbelievers, He has kept a painful chastisement in store for them.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
Believers, call to mind Allah's favour to you when enemy hosts invaded you. Then We sent against them a wind and hosts that you did not see although Allah was observing all that you were then doing.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
When they came upon you from above you and from below you, when your eyes were stupefied with horror and your hearts leapt to your throats, and you began to entertain diverse thoughts about Allah.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
The believers were then put to a severe test and were most violently convulsed.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And call to mind when the hypocrites and all those with diseased hearts said: “All that Allah and His Messenger had promised us was nothing but deceit.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a section of them said: “(O people of Yathrib), now there is no place for you to stay, so turn back.” (And call to mind) when a section of them was seeking permission from the Prophet to leave, saying: “Our houses are exposed (to attack),” although they were not exposed (to attack); they only wished to flee (from the battle-front).\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
If the enemy were to enter the town from various directions, and they were summoned to act treacherously, they would have succumbed to it and would have shown little reluctance in doing so.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
They had earlier covenanted with Allah that they would not turn their backs in flight. And a covenant made with Allah must needs be answered for.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
(O Prophet), tell them: “If you run away from death or slaying, this flight will not avail you. You will have little time after that to enjoy (the pleasures of life).”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say (to them): “Who can protect you from Allah if He desires an evil for you? And who can prevent Him if He desires to show mercy to you?” They shall find none other than Allah to be their protector or helper.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Allah knows well those of you who create obstructions (in war efforts) and say to their brethren: “Come and join us.” They hardly take any part in battle.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
They are utterly niggardly (in coming to your aid). Whenever there is danger, you will see them looking at you, their eyes rolling as though they were on the verge of fainting at the approach of death. But when the danger passes away, their greed for wealth prompts them to greet you with their sharp, scissor-like tongues. These are the ones who never truly believed, and so Allah has caused their deeds to be reduced to naught. That is easy enough for Allah.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They think that the invading confederates have not yet gone. But if the confederates were to mount another assault, they would wish to be in the desert among the bedouins and keep themselves informed about you from there. But even if they remained in your midst, hardly would they fight.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
Surely there was a good example for you in the Messenger of Allah, for all those who look forward to Allah and the Last Day and remember Allah much.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
As for the true believers, when they saw the invading confederates, they cried out: “This is what Allah and His Messenger had promised us, and what Allah and His Messenger said was absolutely true.” This only increased their faith and submission.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Among the believers there are those who have remained true to the covenant they made with Allah. Among those some of them have fulfilled their vow and others await the appointed time. They have not changed in the least.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
(All this is) in order that Allah may reward the truthful for their truthfulness, and either punish the hypocrites or, if He so wills, accept their repentance. Verily Allah is Most Pardoning, Most Compassionate.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
Allah sent back the unbelievers empty-handed, their hearts seething with rage. Allah sufficed the believers in their fight. Allah is Most Powerful, Most Mighty.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
Allah brought down from their fortresses those People of the Book who had supported the invading confederates and cast such terror into their hearts that some of them you kill and some of them you take captive.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
Allah made you inherit their land, their dwellings, and their goods, and a piece of land on which you had not yet trodden. Verily Allah has power over all things.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet, tell your wives: “If you seek the world and its embellishments, then come and I will make some provision for you and release you in an honourable way.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
But if you seek Allah and His Messenger and the Abode of the Hereafter, then surely Allah has prepared a great reward for those of you who do good.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
Wives of the Prophet, if any of you commit flagrant indecency, her chastisement shall be doubled. That is easy for Allah.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
But whoever of you is obedient to Allah and His Messenger and does good deeds, Allah will double her reward. We have prepared for her a generous provision.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
Wives of the Prophet, you are not like other women. If you fear Allah, do not be too complaisant in your speech lest those with diseased hearts should covet you; but speak in a straight forward manner.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And stay in your homes and do not go about displaying your allurements as in the former Time of Ignorance. Establish Prayer, give Zakah, and obey Allah and His Messenger. Allah only wishes to remove uncleanness from you, O members of the (Prophet's) household, and to purify you completely.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
Remember the Signs of Allah and the words of wisdom which are rehearsed in your homes. Verily Allah is All-Subtle, All-Aware.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Surely the men who submit (to Allah) and the women who submit (to Allah), the men who have faith and the women who have faith, the men who are obedient and the women who are obedient, the men who are truthful and the women who are truthful; the men who are steadfast and the women who are steadfast, the men who humble themselves (to Allah) and the women who humble themselves (to Allah), the men who give alms and the women who give alms, the men who fast and the women who fast, the men who guard their chastity and the women who guard their chastity, the men who remember Allah much and the women who remember Allah much: for them has Allah prepared forgiveness and a mighty reward.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
It does not behove a believer, male or female, that when Allah and His Messenger have decided an affair they should exercise their choice. And whoever disobeys Allah and His Messenger has strayed to manifest error.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
(O Prophet), call to mind when you said to him whom Allah had favoured and you had favoured: “Cleave to your wife and fear Allah,” and you concealed within yourself for fear of people what Allah was to reveal, although Allah has greater right that you fear Him. So when Zayd had accomplished what he would of her, We gave her in marriage to you so that there should not be any constraint for the believers regarding the wives of their adopted sons after they had accomplished whatever they would of them. And Allah's command was bound to be accomplished.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There could be no hindrance to the Prophet regarding what Allah ordained for him. Such has been Allah's Way (with the Prophets) who went before. Allah's command is a decree firmly determined.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
(This is Allah's Way) regarding those who deliver the Messages of Allah and who fear Him, and fear no one else than Allah. Allah is Sufficient as a Reckoner.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of any of your men, but he is the Messenger of Allah and the seal of the Prophets. Allah has full knowledge of everything.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
Believers, remember Allah much\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
and glorify Him morning and evening.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
It is He Who lavishes His blessings on you and His angels invoke blessings on you that He may lead you out of darkness into light. He is Most Compassionate to the believers.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
On the Day they meet Him they will be greeted with: “Peace.” He has prepared for them a generous reward.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Prophet, We have sent you forth as a witness, a bearer of good tidings, and a warner,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
as one who calls people to Allah by His leave, and as a bright, shining lamp.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
Announce to the believers the good tidings that Allah has kept bounteous blessings in store for them.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
Do not yield to the unbelievers and the hypocrites, and disregard the hurt that comes from them, and put your trust in Allah. Allah suffices as the Guardian to entrust one's affairs to.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
Believers, when you marry believing women and then divorce them before you have touched them, you may not require them to observe a waiting period that you might reckon against them. So make provision for them and release them in an honourable manner.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet, We have made lawful for you your wives whose bridal dues you have paid, and the slave-girls you possess from among the prisoners of war, and the daughters of your paternal uncles and paternal aunts, and the daughters of your maternal uncles and maternal aunts who have migrated with you, and a believing woman who gives herself to the Prophet and whom he wants to take in marriage. (O Prophet), this privilege is yours alone to the exclusion of other believers. We know well what restrictions We have imposed upon them as regards their wives and those whom their right hands possess, (and have exempted you from those restrictions) that there may be no constraint upon you. Allah is Most Forgiving, Most Merciful.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
Of them you may put off any of them you wish, and you may take any of them whom you wish, and you may call back any of those whom you had (temporarily) set aside: there will be no blame on you (on this account). It is likelier that they will thus be comforted, and will not grieve, and every one of them will be well-pleased with what you give them. Allah knows what is in your hearts. Allah is All-Knowing, All-Forbearing.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
Thereafter women will not be lawful for you, and it will not be lawful for you to take other wives in place of them, even though their beauty might please you, unless they be those whom your right hand owns. Allah is watchful over everything.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
Believers, enter not the houses of the Prophet without his permission, nor wait for a meal to be prepared; instead enter when you are invited to eat, and when you have had the meal, disperse. Do not linger in idle talk. That is hurtful to the Prophet but he does not express it out of shyness; but Allah is not ashamed of speaking out the Truth. And if you were to ask the wives of the Prophet for something, ask from behind a curtain. That is more apt for the cleanness of your hearts and theirs. It is not lawful for you to cause hurt to Allah's Messenger, nor to ever marry his wives after him. Surely that would be an enormous sin in Allah's sight.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
(It does not matter) whether you disclose something or conceal it, for Allah certainly knows everything.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
It will not be blameworthy for the wives of the Prophet if their fathers, their sons, their brothers, their brothers' sons, their sisters' sons, and the women with whom they have social relations, and the persons whom their right hands possess enter their houses. (O women), shun disobeying Allah. Allah is watchful over everything.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Allah and His angels bless the Prophet. Believers, invoke blessings and peace on him.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Verily those who cause annoyance to Allah and His Messenger - Allah has cursed them in this world and in the Hereafter and has prepared for them a humiliating chastisement.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
Those who cause hurt to believing men and to believing women have invited upon themselves a calumny and a manifest sin.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet, enjoin your wives and your daughters and the believing women, to draw a part of their outer coverings around them. It is likelier that they will be recognised and not molested. Allah is Most Forgiving, Most Merciful.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites and those in whose hearts there is a sickness, and the scandal mongers in Madinah do not desist from their vile acts, We shall urge you to take action against them, and then they will hardly be able to stay in the city with you.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
They shall be cursed from all around and they shall be ruthlessly killed wherever they are seized.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
This has been Allah's Way with those who have gone before, and you shall find no change in Allah's Way.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
People ask you concerning the Hour (of Resurrection). Say: “Allah alone has knowledge of it. What do you know? Perhaps the Hour is nigh.”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Allah has cursed the unbelievers and has prepared for them a Blazing Fire;\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
therein they shall abide for ever. They shall find none to protect or help them.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
On that Day when their faces shall be turned around in the Fire, they will say: “Would that we had obeyed Allah and obeyed the Messenger.”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdc{%
They will say: “Our Lord, we obeyed our chiefs and our great ones, and they turned us away from the Right Way.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdci{%
Our Lord, mete out to them a double chastisement and lay upon them a mighty curse.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
Believers, do not be like those who distressed Moses and then Allah declared him quit of the ill they spoke about him; and he had a high standing with Allah.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
Believers, fear Allah and speak the truth:\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
Allah will set your deeds right for you and will forgive you your sins. Whoever obeys Allah and His Messenger has achieved a great triumph.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
We offered the trust to the heavens and the earth and the mountains, but they refused to carry it and were afraid of doing so; but man carried it. Surely he is wrong-doing, ignorant.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
(The consequence of man's carrying the trust is) that Allah may chastise hypocritical men and hypocritical women and accept the repentance of believing men and believing women. He is Most Forgiving, Most Merciful.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen All praise be to Allah to Whom belongs all that is in the heavens and all that is in the earth, and all praise be to Him in the World to Come. He is Most Wise, All-Aware.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows what penetrates into the earth and what goes forth from it, what descends from the heaven and what ascends to it. He is the Most Merciful, the Most Forgiving.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
The unbelievers say: “How come the Hour is not coming upon us!” Say to them: “Yes indeed, by my Lord, by Him Who fully knows the realm beyond the ken of perception, that the Hour shall inevitably come upon you. Nothing escapes Him, not even the smallest particle in the heavens or the earth; nor is anything smaller or bigger than that but is in a Manifest Book.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
(The Hour shall come) that He may reward those who believe and do righteous deeds. Theirs shall be forgiveness and a generous provision.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
As for those who worked against Our Signs in order to frustrate them, they shall suffer a painful chastisement.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
(O Prophet), those who have knowledge see clearly that what has been revealed to you from your Lord is the Truth and directs to the Way of the Most Mighty, the Immensely Praiseworthy Lord.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
The unbelievers say: “Shall we direct you to the man who tells you that when you have been utterly broken to pieces, you will be raised to life again?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
Has he forged a lie against Allah, or is he afflicted with madness?” Nay, but those who do not believe in the Hereafter are doomed to be chastised and are far gone in error.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
Do they not see how the heavens and the earth encompass them from the front and the rear? We could, if We so wished, cause the earth to swallow them or let fragments of the sky fall upon them. Verily there is a Sign in this for every servant (of Allah) who penitently turns to Him.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
We bestowed Our favour upon David. (We commanded): “O mountains, sing Allah's praises with him”; (and so did We command) the birds. We softened the iron for him, (saying):\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
“Fashion coats of mail and measure their links with care and act righteously. I am watching over whatever you do.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And We subdued the wind to Solomon: its morning course was a month's journey and its evening course was a month's journey. We gave him a spring flowing with molten brass, and We subdued for him jinn who, by his Lord's permission, worked before him. Such of them as swerved from Our commandment, We let them taste the chastisement of the Blazing Fire.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They made for him whatever he would desire: stately buildings, images, basins like water-troughs and huge, built-in-cauldrons: “Work, O house of David, in thankfulness (to your Lord). Few of My servants are truly thankful.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
When We executed Our decree of death on Solomon, nothing indicated to the jinn that he was dead except a worm eating away his staff. So when Solomon fell down, the jinn realised that had they known what lies in the realm beyond perception, they would not have continued to be in this humiliating chastisement.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
For Sheba there was also a Sign in their dwelling place: the two gardens to the right and to the left. “Eat of your Lord's provision, and render thanks to Him. Most pleasant is your land and Most Forgiving is your Lord.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away and so We let loose upon them a devastating flood that swept away the dams and replaced their gardens by two others bearing bitter fruits, tamarisks, and a few lote trees.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
Thus did We retribute them for their ingratitude. And none do We retribute in this manner except the utterly ungrateful.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
We placed other prominent towns between them, the towns that We had blessed and had set well-measured stages between them. Move back and forth between them, night and day, in perfect security.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But they said: “Lord, make the stages of our journeys longer.” They wronged their own selves so We reduced them to bygone tales, and utterly tore them to pieces. Verily there are Signs in this for everyone who is steadfast and thankful.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
Iblis found his estimate of them to be true, and they followed him, except a party of the believers.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
Iblis had no authority over them and whatever happened was in order that We might know him who believes in the Hereafter as distinct from him who is in doubt about it. Your Lord is watchful over everything.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
(O Prophet), say to those who associate others with Allah in His Divinity: “Call upon those whom you fancied to be deities beside Allah. They own not even the smallest particle, neither in the heavens nor on the earth; nor do they have any share in the ownership of either of them. Nor is any of them even a helper of Allah.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
No intercession can avail with Allah except for him whom Allah permits (to intercede). When their hearts are relieved of fright they will ask the intercessors: “What did your Lord say?” They will reply: “(He said) what is right, and He is the High, the Great.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Ask them, (O Prophet): “Who provides you sustenance from the heavens and the earth?” Say: “Allah. Now, inevitably only one of us is rightly guided, either we or you; and the other is in manifest error.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Tell them: “You will not be called to account about the guilt we committed, nor will we be called to account for what you did.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say: “Our Lord will bring us together and then He will rightly judge between us. He is the Great Judge, the All-Knowing.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say: “Show me those whom you have attached to Him as His associates (in Divinity).” Nay, Allah alone is Most Mighty, Most Wise.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
(O Prophet), We have not sent you forth but as a herald of good news and a warner for all mankind. But most people do not know.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
They ask you: “When will this promise (of Resurrection) be fulfilled, if what you say is true?”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say: “Your day is appointed, you can neither hold back its coming by an hour, nor hasten it by an hour.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
The unbelievers say: “We shall never believe in this Qur'an, nor in any Scripture before it.” If you could only see the wrong-doers arrayed before their Lord, each bandying charges against the other. Those who were suppressed will say to those who waxed arrogant: “Had it not been for you, we would have been believers.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
The arrogant ones will retort to those who were suppressed: “What! Did we bar you from the guidance after it came to you? Not at all; rather you yourselves were evil-doers.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
Those who were suppressed will say to those who waxed arrogant: “By no means; it was your scheming, night and day, when you would enjoin us to disbelieve in Allah and set up others as equals to Him.” When they are confronted with the chastisement, they will be remorseful in their hearts. We shall put fetters around the necks of the unbelievers. Can people be requited except for their deeds?\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
We never sent a warner to any town but its wealthy ones said: “We disbelieve in the Message you have brought.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
They always said: “We have more wealth and children than you have, and we shall not be chastised.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
(O Prophet), say to them: “My Lord grants provision abundantly to whomsoever He pleases and straitens it for whomsoever He pleases. But most people do not know this.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
It is not your riches nor your children that make you near-stationed to Us, except for him who has faith and acts righteously; it is they who will receive double the recompense for their deeds. They shall live in lofty mansions in perfect peace.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
As for those who work against Our Signs so as to frustrate them, they shall be arraigned into the chastisement.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say, (O Prophet): “Verily, my Lord grants provision abundantly to whomsoever He pleases and straitens it for whomsoever He pleases. Whatever you spend, He will replace it. He is the Best of all Providers.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
And on the Day when He will muster them all and will ask the angels: “Are they the ones who worshipped you?”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They will reply: “Glory to You! You are our Protector, not they. Nay, they rather used to worship the jinn. Most of them believe in them.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
Today none of you has the power to benefit or harm another; and We shall say to the evil-doers: “Taste now the chastisement of the Fire which you used to deny, calling it a lie.”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
When Our Clear Signs are rehearsed to them they say: “This is a person who wants to turn you away from the deities whom your ancestors worshipped.” They say: “This is nothing but an invented falsehood.” And when the Truth came to the unbelievers they declared: “This is nothing but plain sorcery,”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
whereas We gave them no Books that they could study nor sent to them any warner before you.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
Those who went before them also denounced (Allah's Messengers) as liars. They have not attained even a tenth of what We had given them. But when they rejected My Messengers, calling them liars, how terrible was My chastisement!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say to them, (O Prophet): “I give you but one counsel: stand up (for heaven's sake), singly and in pairs, and then think: what is it in your companion (to wit, Muhammad) that could be deemed as madness?” He is nothing but a warner, warning you before the coming of a grevious chastisement.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say to them: “Whatever recompense I might ask of you, it shall be yours. My recompense is with Allah, and He is witness over everything.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say to them: “My Lord hurls down the Truth (upon me). He knows fully all that lies beyond the range of perception.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say: “The Truth has come and falsehood can neither originate nor recreate anything.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say: “If I go astray then the hurt of straying will come only upon me. But if I am rightly-guided, that is only because of the revelation that my Lord makes to me. He is All-Hearing, Ever Nigh.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
If you could only see when the unbelievers will go about in a state of terror. They will have no escape and will be seized from a place near at hand.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
They will then say: “We believe in it”; but whence can they attain it from so far-off a place?\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
They disbelieved in it before and indulged in conjectures from far away.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
A barrier will be placed between them and what they desire, as was done with the likes of them before. Surely they were in a disquieting doubt.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen All praise be to Allah, the Fashioner of the heavens and earth, Who appointed angels as His message bearers, having two, three, four wings. He adds to His creation whatever He pleases. Verily Allah has power over everything.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
Whatever Mercy Allah accords to people, none can withhold; and whatever He withholds, no other will be able to release after Him. He is Most Mighty, Most Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O people, remember Allah's favour upon you. Is there any creator, apart from Allah, who provides you your sustenance out of the heavens and earth? There is no god but He. Whither are you, then, being misdirected?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
(O Prophet), (there is nothing novel in it) if they cry lies to you; Messengers before you were also cried lies to. To Allah shall all matters be sent back.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O people, assuredly Allah's promise is true. So let the life of the world not delude you, and let not the Deluder delude you concerning Allah.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Surely Satan is an enemy to you. Therefore, do take him as an enemy. He calls his followers to his way so that they may be among the inmates of the Fire.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
A severe chastisement lies in store for those that disbelieve, but there is pardon and a great reward for those that believe and work righteous deeds.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
(How awful is the straying of the person) for whom his evil deed has been embellished so that it looks fair to him? The fact is that Allah causes whomsoever He will to fall into error and shows the Right Way to whomsoever He will. So, (O Prophet), let not your life go to waste sorrowing over them. Allah is well aware of all that they do.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
It is Allah Who sends forth winds which then set the clouds in motion, which We drive to some dead land giving a fresh life to earth after it had become dead. Such will be the resurrection of the dead.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
He who seeks glory, let him know that all glory belongs to Allah alone. To Him do good words go up, and righteous action uplifts them. But those who contrive evil deeds, a severe punishment lies in store for them, and their contriving will come to naught.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
Allah created you from dust, then from a drop of sperm, then He made you into pairs. No female conceives, nor delivers (a child) except with His knowledge. None is given a long life nor is any diminished in his life but it is written in a Book. Surely that is quite easy for Allah.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
The two masses of water are not alike. The one is sweet, sates thirst, and is pleasant to drink from, while the other is salt, bitter on the tongue. Yet from both you eat fresh meat, and extract from it ornaments that you wear; and you see ships cruising through it that you may seek of His Bounty and be thankful to Him.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He causes the night to phase into the day and the day into the night, and He has subjected the sun and the moon, each running its course to an appointed term. That is Allah, your Lord; to Him belongs the Kingdom; but those whom you call upon, apart from Allah, possess not so much as the skin of a date-stone.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If you call upon them, they cannot hear your prayer. And if they hear it, they cannot answer it. On the Day of Resurrection they will disown you for associating others with Allah in His Divinity. No one can inform you of the truth save the All-Aware.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O people, it is you who stand in need of Allah; as for Allah, He is Self-Sufficient, Immensely Praiseworthy.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He wishes, He can remove you and put in your place a new creation.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
That surely is not difficult for Allah.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
No one can bear another's burden. If a heavily laden one should call another to carry his load, none of it shall be carried by the other, even though he be a near of kin. (O Prophet), you can warn only those who fear their Lord without seeing Him and establish Prayer. Whoever purifies himself does so to his own good. To Allah is the final return.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
The blind and the seeing are not alike,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
nor darkness and light;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
nor cool shade and torrid heat;\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
nor are the living and the dead alike. Allah makes to hear whomsoever He wishes, but you, (O Prophet), cannot cause to hear those who are in their graves.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
You are no more than a warner.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
We have sent you with the Truth to proclaim good news and to warn. Never has there been a nation but a warner came to it.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
If they give the lie to you now, those that went before them also gave the lie to their Messengers when they came to them with Clear Proofs, with Scriptures, and with the Illuminating Book.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then I seized those who denied the Truth, and how terrible was My punishment!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Do you not see that Allah sent down water from the sky with which We brought forth fruits of diverse hues? In the mountains there are white and red, of diverse hues, and pitchy black;\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
and human beings too, and beasts, and cattle -- diverse are their hues. From among His servants, it is only those who know that fear Allah. Verily Allah is Most Mighty, Most Forgiving.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Surely those who recite the Book of Allah and establish Prayer and spend, privately and publicly, out of what We have provided them, look forward to a trade that shall suffer no loss;\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
(a trade in which they have invested their all) so that Allah may pay them their wages in full and may add to them out of His Bounty. He is Most Forgiving, Most Appreciative.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
(O Prophet), the Book We have revealed to you is the Truth, confirming the Books that came before it. Verily Allah is well aware of His servants and sees everything.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then We bequeathed the Book to those of Our servants that We chose. Now, some of them wrong themselves and some follow the medium course; and some, by Allah's leave, vie with each other in acts of goodness. That is the great bounty.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
They shall enter the everlasting Gardens, shall be adorned with bracelets of gold and with pearls, and their apparel therein shall be silk.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
They will say: “All praise be to Allah Who has taken away all sorrow from us. Surely our Lord is Most Forgiving, Most Appreciative;\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
(the Lord) Who, out of His Bounty, has made us dwell in an abode wherein no toil, nor fatigue affects us.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
As for those who disbelieved, the Fire of Hell awaits them. There they shall not be finished off and die; nor will the torment (of Hell) be lightened for them. Thus do We requite every thankless being.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
They will cry out in Hell and say: “Our Lord, let us out so that we may act righteously, different from what we did before.” (They will be told): “Did we not grant you an age long enough for anyone to take heed if he had wanted to take heed? Besides, there came a warner to you. So have a taste of the torment now. None may come to the help of the wrong-doers.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Surely Allah knows the Unseen in the heavens and the earth. He even knows the secrets hidden in people's breasts.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
It is He Who made you vicegerents in the earth. So whoever disbelieves will bear the burden of his unbelief. The unbelievers' unbelief adds nothing but Allah's wrath against them. The unbelievers' unbelief adds nothing but their own loss.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say to them (O Prophet): “Have you ever seen those of your associates upon whom you call apart from Allah? Show me what have they created in the earth? Or do they have any partnership (with Allah) in the heavens? Or have We given them a Book so that they have a clear proof (for associating others with Allah in His Divinity)?” Nay, what these wrong-doers promise each other is nothing but delusion.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
Surely Allah holds the heavens and the earth, lest they should be displaced there, for if they were displaced none would be able to hold them after Him. Surely He is Most Forbearing, Most Forgiving.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
Swearing by Allah their strongest oaths they claimed that if a warner came to them they would be better-guided than any other people. But when a warner did come to them, his coming only increased their aversion (to the Truth).\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
They began to wax even more proud on earth and contrived evil designs although the contriving of evil designs only overtakes their authors. Are they waiting, then, for anything except what happened to the nations before them? You shall not find any change in the Way of Allah; and you shall not find anything that can ever alter the Way of Allah.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
Have they not journeyed in the earth to behold the end of those who went before them though they were stronger than them in might? Nothing in the heavens nor on earth can frustrate Him in the least. He is All-Knowing, All-Powerful.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
If Allah were to take people to task for their deeds, He would not leave any living creature on earth, but He grants them respite to an appointed time. When their appointed time comes to an end, surely Allah fully observes His servants.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya'. Sin.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the Wise Qur'an,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
you are truly among the Messengers,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
on a Straight Way,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
(and this Qur'an) is a revelation from the Most Mighty, the Most Compassionate\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
so that you may warn a people whose ancestors were not warned before wherefore they are heedless.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
Surely most of them merit the decree of chastisement; so they do not believe.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
We have put fetters around their necks which reach up to their chins so that they are standing with their heads upright,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
and We have put a barrier before them and a barrier behind them, and have covered them up, so they are unable to see.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
It is all the same for them whether you warn them or do not warn them for they shall not believe.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
You can warn only him who follows the Admonition and fears the Merciful Lord without seeing Him. Give such a one good tidings of forgiveness and a generous reward.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
We shall surely raise the dead to life and We record what they did and the traces of their deeds that they have left behind. We have encompassed that in a Clear Book.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
Recite to them, as a case in point, the story of the people of the town when the Messengers came to them.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
We sent to them two Messengers and they rejected both of them as liars. Then We strengthened them with a third (Messenger).\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They said: “We have been sent to you as Messengers.” The people of the town said: “You are only human beings like ourselves, and the Merciful Lord has revealed nothing. You are simply lying.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
The Messengers said: “Our Lord knows that we have indeed been sent to you\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
and our duty is no more than to clearly convey the Message.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
The people of the town said: “We believe you are an evil omen for us. If you do not desist, we will stone you or you will receive a grievous chastisement from us.”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
The Messengers replied: “Your evil omen is with you. (Are you saying this) because you were asked to take heed? The truth is that you are a people who have exceeded all bounds.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
In the meantime a man came running from the far end of the town, saying: “My people, follow the Messengers;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
follow those who do not ask any recompense from you and are rightly-guided.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
Why should I not serve the One Who created me and to Whom all of you shall be sent back?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
What! Shall I take any deities apart from Him whose intercession will not avail me the least were the Merciful One to bring any adversity upon me, nor will they be able to rescue me?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
Surely in that case I should indeed be in evident error.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
I believe in your Lord; so listen to me.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
(Eventually they killed him and he was told): “Enter Paradise.” The man exclaimed: “Would that my people knew\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
for what reason Allah has forgiven me and placed me among the honoured ones.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
After him, We did not send down any hosts from the heaven; We stood in no need to send down any host.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
There was but a single Blast and suddenly they became silent and still.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Alas for My servants! Never does a Messenger come to them but they mock him.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Have they not seen how many nations before them did We destroy? Thereafter they never came back to them.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
All of them shall (one day) be gathered before Us.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
Let the dead earth be a Sign for them. We gave it life and produced from it grain whereof they eat.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
We made in it gardens of date-palms and vines, and We caused springs to gush forth\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
that they might eat of its fruits. It was not their hands that made them. Will they not, then, give thanks?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Holy is He Who created all things in pairs, whether it be of what the earth produces, and of themselves, and of what they do not know.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
And the night is another Sign for them. We strip the day from it and they become plunged in darkness.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
The sun is running its course to its appointed place. That is the ordaining of the All-Mighty, the All-Knowing.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
We have appointed stages for the moon till it returns in the shape of a dry old branch of palm-tree.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
Neither does it lie in the sun's power to overtake the moon nor can the night outstrip the day. All glide along, each in its own orbit.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
Another Sign for them is that We carried all their offspring in the laden vessel\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
and then created for them other vessels like those on which they ride.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
Should We so wish, We can drown them, and there will be none to heed their cries of distress, nor will they be rescued.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
It is only Our Mercy (that rescues them) and enables enjoyment of life for a while.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
When it is said to such people: “Guard yourselves against what is ahead of you and what has preceded you that mercy be shown to you” (they pay scant heed to it).\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
Never does any Sign of their Lord come to them, but they turn away from it.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said to them: “Spend (in the Way of Allah) out of the sustenance that Allah has provided you,” the unbelievers say to the believers: “Shall we feed him whom, Allah would have fed, had He so wished?” Say: “You are in evident error.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
They say: “When will this threat (of Resurrection) come to pass? Tell us if indeed you are truthful.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
The Truth is that they are waiting for nothing but a mighty Blast to seize them the while they are disputing (in their worldly affairs),\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
and they will not even be able to make a testament, nor to return to their households.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
Then the Trumpet shall be blown and lo! they will come out of their graves and be on the move towards their Lord,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
(nervously) exclaiming. “Alas for us! Who roused us out of our sleeping-place?” “This is what the Merciful One had promised, and what (His) Messengers had said was true.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
Then there will simply be one single Blast, and all will have gathered before Us.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
Today no one shall suffer the least injustice, and you shall not be recompensed except according to your deeds.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Indeed, the people of Paradise will be busy enjoying themselves:\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
they and their spouses shall be reclining on their couches in shady groves;\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
therein there will be all kinds of fruits to eat, and they shall have all that they desire.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
“Peace” shall be the word conveyed to them from their Merciful Lord.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
“Criminals, separate yourselves from others today!\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
Children of Adam, did I not command you not to serve Satan -- he is to you an open enemy\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
and serve Me alone: this is the Straight Way?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
Still, he misguided a whole throng of you. Did you have no sense?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
Now this is the Hell of which you were warned.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
Burn in it on account of your disbelieving.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
Today We shall put a seal on their mouths, and their hands will speak to Us and their feet shall bear witness to what they had been doing.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
If We so willed, We would have put out their eyes, then they would rush to see the Way, but how would they be able to see?\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
If We so willed, We would have transformed them where they were so that they would not go forward or backward.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
Whomsoever We grant a long life, We reverse him in his constitution. Do they still not understand?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
We did not teach him (to wit, the Messenger) poetry and it does not behove him. This is none but an Admonition, and a Clear Book\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
that he may warn him who is alive and establish an argument against those that deny the Truth.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Do they not see Our handiwork: We created for them cattle which they own?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
We have subjected the cattle to them so that some of them they ride and eat the flesh of others.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
They derive a variety of benefits and drinks from them. Will they, then, not give thanks?\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
They set up deities apart from Allah, hoping that they will receive help from them.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
Those deities can render them no help. Yet these devotees act as though they were an army in waiting for them.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
Let not their words grieve you. Surely We know all things about them, what they conceal and what they reveal.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Does man not see that We created him of a sperm drop, and lo! he is flagrantly contentious?\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
He strikes for Us a similitude and forgot his own creation. He says: “Who will quicken the bones when they have decayed?”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say: “He Who first brought them into being will quicken them; He knows well about every kind of creation;\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
He Who created from a green tree a fire for you, a fire to light your stoves with.”\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Has He Who created the heavens and the earth no power to create the likes of them? Yes, indeed, He is the Superb Creator.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
Whenever He wills a thing, He just commands it “Be” and it is.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
Holy is He Who has full control over everything, and to Him you shall all be recalled.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By those who range themselves in rows;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
by those who reprove severely,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
and those who recite the Exhortation;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
surely your God is One,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
the Lord of the heavens and the earth and of whatever lies between the two, the Lord of the Easts.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
We have adorned the lower heaven with the adornment of the stars\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
and have protected it from every rebellious satan.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
These satans cannot listen to what transpires in the High Council for they are pelted away from every side\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
and are repelled. Theirs is an unceasing chastisement.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
And if any is able to snatch a fragment, he is pursued by a piercing flame.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
So ask them (that is, human beings): “Were they harder to create than the objects We created?” We created them from sticky clay.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
You marvel (at the wondrous creations of Allah) and they scoff at it,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
and when they are admonished, they pay no heed;\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
and if they see any Sign, they laugh it away\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
and say: “This is nothing but plain sorcery.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
Is it ever possible that after we die and are reduced to dust and (a skeleton of) bones, we will be raised to life?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
And so also shall our forefathers of yore be raised to life?”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Tell them: “Yes; and you are utterly helpless (against Allah).”\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
There will be a single stern rebuff and lo, they will be observing with their own eyes (all that they had been warned against).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
They will then say: “Woe for us. This is the Day of Judgement.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
“Yes, this is the Day of Final Decision that you used to deny as a lie.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
(Then will the command be given): “Muster all the wrong-doers and their spouses and the deities whom they used to serve\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
apart from Allah, and direct them to the path of Hell,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
and detain them there; they will be called to account.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
How is it that you are not helping one another?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
Indeed, today they are surrendering themselves completely.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
They will then turn towards each other (and start wrangling).\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
(The followers will say to their leaders): “You used to come to us from the right hand.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
They will say: “Nay, you yourselves were not the ones who would believe.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
We had no power over you. You were a rebellious people,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
and so we became deserving of the Word of our Lord that we shall be made to suffer chastisement.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
So we led you astray; we ourselves were strayed.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
On that Day, they will all share the chastisement.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Thus do We treat the culprits.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
Whenever it was said to them: “There is no true deity apart from Allah,” they waxed proud\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
and said: “Shall we forsake our deities for the sake of a distracted poet?”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
(They say so although) he brought the Truth and confirmed the veracity of the Messengers.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
(They will be told): “You shall taste the grievous chastisement.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
You will only be recompensed according to your deeds.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
But Allah's chosen servants (shall be spared this woeful end).\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
For them awaits a known provision,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
a variety of delicious fruits; and they shall be honoured\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
in the Gardens of Bliss.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
They will be seated upon couches set face to face;\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
a cup filled with wine from its springs, will be passed around to them;\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
white, sparkling (wine), a delight to the drinkers.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
There will neither be any harm in it for their body nor will it intoxicate their mind.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
Theirs shall be wide-eyed maidens with bashful, restrained glances,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
so delicate as the hidden peel under an egg's shell.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
Then some of them will turn to others, and will ask each other.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
One of them will say: “I had a companion in the world\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
who used to say: -- Are you also one of those who confirm the Truth (of life after death)?\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
After we are dead and have become all dust and bones shall we still be requited?'\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
He will say: -- Do you wish to know where he is now?'\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
Then he will look downwards, and will see him in the depths of Hell.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He will say to him: -- By Allah, you almost ruined me.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
But for Allah's favour, I should be one of those who have been mustered here.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
So, are we not going to die,\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
except for our first death? And shall we suffer no chastisement?'”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
Surely this is the supreme triumph.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For the like of it should the workers work.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is this a better hospitality or the tree of al-Zaqqum?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
We have made this tree a trial for the wrong-doers.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
It is a tree that grows in the nethermost part of Hell.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
Its spathes are like the heads of satans.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
(The people of Hell) will surely eat of it, filling their bellies with it.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
Then on top of it they will have a brew of boiling water.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
Then their return will be to the same blazing Hell.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
These are the ones who found their fathers steeped in error,\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
and they are running in their footsteps.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
Before them a multitude of people of olden times had erred,\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
and We had sent among them Messengers to warn them.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
Observe, then, what was the end of those that had been warned,\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
except for the chosen servants of Allah?\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
Noah had called upon Us (earlier). See, how excellent We were in answering him!\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
We delivered him and his household from the great calamity;\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
and made his offspring the only ones to survive,\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
and We established for him a good name among posterity.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
Peace be upon Noah among all the nations.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
Thus do We reward all those who do good.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
Surely he was one of Our truly believing servants.\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Thereafter We caused the others to be drowned.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
Abraham was on the self-same way (as Noah).\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
When he came to his Lord with a pure heart,\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
and said to his father and his people: “Whom do you worship?\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
Is it false deities that you want to serve rather than Allah?\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
What do you think of the Lord of the whole Universe?”\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
Then he looked carefully at the stars\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
and said: “I am sick.”\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
So turning their backs, they went away from him.\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then he went quietly to the (temple of the deities) and said: “What is the matter with you, why do you not eat?\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
What is the matter with you, why do you not speak?”\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
Then he turned upon them, striking them with his right hand,\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
whereupon people came to him running.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
Abraham said to them: “Do you worship what you yourselves have carved with your own hands\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
while it is Allah Who has created you and all that you make?”\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They spoke among themselves: “Build him a pyre and then throw him into the furnace.”\qt@no{(97)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
They had contrived an evil plan against him, but We abased them all.\qt@no{(98)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
Abraham said: “I am going to my Lord; He will guide me.\qt@no{(99)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
Lord, grant me a righteous son.”\qt@no{(100)}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
(In response to this prayer) We gave him the good news of a prudent boy;\qt@no{(101)}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
and when he was old enough to go about and work with him, (one day) Abraham said to him: “My son, I see in my dream that I am slaughtering you. So consider (and tell me) what you think.” He said: “Do as you are bidden. You will find me, if Allah so wills, among the steadfast.”\qt@no{(102)}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
When both surrendered (to Allah's command) and Abraham flung the son down on his forehead,\qt@no{(103)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We cried out: “O Abraham,\qt@no{(104)}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
you have indeed fulfilled your dream. Thus do We reward the good-doers.”\qt@no{(105)}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
This was indeed a plain trial.\qt@no{(106)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We ransomed him with a mighty sacrifice,\qt@no{(107)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
and We preserved for him a good name among posterity.\qt@no{(108)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
Peace be upon Abraham.\qt@no{(109)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Thus do We reward the good-doers.\qt@no{(110)}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
Surely he was one of Our believing servants.\qt@no{(111)}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And We gave him the good news of Isaac, a Prophet and among the righteous ones.\qt@no{(112)}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
And We blessed him and Isaac. Among the offspring of the two some did good and some plainly wronged themselves.\qt@no{(113)}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
Verily We bestowed Our favours on Moses and Aaron\qt@no{(114)}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
and We delivered both of them and their people from the great calamity.\qt@no{(115)}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
We succoured them, and they gained the upper hand (against their enemies).\qt@no{(116)}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
We granted them a Clear Book,\qt@no{(117)}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
and showed them the Straight Way,\qt@no{(118)}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
and preserved for them a good name among posterity.\qt@no{(119)}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
Peace be upon Moses and Aaron.\qt@no{(120)}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Thus do We reward the good-doers.\qt@no{(121)}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
Surely both of them were among Our believing servants.\qt@no{(122)}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
Surely, Elias too was among the Messengers.\qt@no{(123)}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
(Call to mind) when he said to his people: “Will you not fear Allah?\qt@no{(124)}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
Do you call upon Baal and forsake the Best of the Creators?\qt@no{(125)}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
Allah is your Lord and the Lord of your ancestors of yore.”\qt@no{(126)}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
But they denounced him as a liar, so they will surely be arraigned (for punishment),\qt@no{(127)}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
except Allah's chosen servants.\qt@no{(128)}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
We preserved a good name for him among posterity.\qt@no{(129)}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
Peace be upon Elias.\qt@no{(130)}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Thus do We reward the good-doers.\qt@no{(131)}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
He was one of Our believing servants.\qt@no{(132)}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
And Lot too was one of the Messengers.\qt@no{(133)}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
(Call to mind) when We delivered him and all his kinsfolk,\qt@no{(134)}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
except for an old woman who was among those that stayed behind.\qt@no{(135)}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
Then We utterly destroyed the rest of them.\qt@no{(136)}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
You pass by their desolate habitations in the morning\qt@no{(137)}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
and at night. Do you still not understand?\qt@no{(138)}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
And Jonah too was one of the Messengers.\qt@no{(139)}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
Call to mind when he fled to the laden ship,\qt@no{(140)}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
cast lots, and was among the losers.\qt@no{(141)}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
Then a fish swallowed him, and he was blameworthy.\qt@no{(142)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
Had he not been one of those who glorify Allah,\qt@no{(143)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
he would certainly have remained in its belly till the Day of Resurrection.\qt@no{(144)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
But We threw him on a wide bare tract of land while he was ill;\qt@no{(145)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
and caused a gourd tree to grow over him,\qt@no{(146)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
and We sent him forth to a nation of a hundred thousand or more,\qt@no{(147)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
and they believed. So We let them enjoy life for a while.\qt@no{(148)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
So ask their opinion: “(Are you convinced) that your Lord should have daughters and you should have sons?\qt@no{(149)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Did We create the angels as females the while they witnessed?”\qt@no{(150)}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Behold, it is one of their fabrications that they say:\qt@no{(151)}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
“Allah has begotten.” They are liars!\qt@no{(152)}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
Did He choose daughters rather than sons?\qt@no{(153)}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What is the matter with you that you make such strange judgements?\qt@no{(154)}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
Will you then not take heed?\qt@no{(155)}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Do you have any clear authority for such claims?\qt@no{(156)}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Bring your Book, if you are truthful.\qt@no{(157)}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
They have established a kinship between Allah and the angels; and the angels know well that these people will be arraigned (as culprits).\qt@no{(158)}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
(They say): “Exalted be Allah above what they attribute to Him,\qt@no{(159)}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
all of them except the chosen servants of Allah.\qt@no{(160)}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
So you and your deities\qt@no{(161)}}%
\qt@newcmd\qurantrans@en@mmmcml{%
shall not be able to tempt anyone away from Allah\qt@no{(162)}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
except him who shall roast in the Blazing Fire.\qt@no{(163)}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
As for us, there is none but has an appointed station.\qt@no{(164)}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
Verily we range ourselves in rows (as humble servants)\qt@no{(165)}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
and we are of those who glorify Allah.”\qt@no{(166)}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
They used to say before:\qt@no{(167)}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
“If only we had the Reminder which had been granted to the people of yore\qt@no{(168)}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
we would surely have been Allah's chosen servants.”\qt@no{(169)}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
But when it came to them, they rejected it. They shall soon come to know (the end of such an attitude).\qt@no{(170)}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
We have already given Our promise to Our Messengers\qt@no{(171)}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
that they shall certainly be succoured,\qt@no{(172)}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
and that Our hosts shall triumph.\qt@no{(173)}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So, (O Prophet), leave them alone for a while,\qt@no{(174)}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
and see, and soon they too shall see.\qt@no{(175)}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
Do they seek to hasten Our chastisement?\qt@no{(176)}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
When that chastisement will descend upon their courtyard, evil shall that Day be for those who had been warned.\qt@no{(177)}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
Leave them alone for a while,\qt@no{(178)}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
and see; and they too shall soon see.\qt@no{(179)}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Exalted be your Lord, the Lord of Glory, above what they attribute to Him,\qt@no{(180)}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
and peace be upon the Messengers,\qt@no{(181)}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
and all praise be to Allah, the Lord of the Universe.\qt@no{(182)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Sad, and by the Qur'an full of exhortation!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
Nay, but the unbelievers are steeped in arrogance and stubborn defiance.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many a nation did We destroy before them! (When they approached their doom) they cried out (for deliverance), but the time for deliverance was already past.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
They wondered that a warner had come to them from among themselves, and the deniers of the Truth said: “This is a sorcerer, and a big liar.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
Has he made the gods one single God? This is truly astounding.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
And the elders among them went forth saying: “Go ahead and be steadfast in adhering to your deities. What is being said is with a design.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
We have not heard this in the religious community close to our time. This is nothing but a fabrication.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
Has this Exhortation been sent down among us only to him, to the exclusion of all others?” Nay, they are in doubt regarding My Exhortation, and are saying all this because they have not yet had any taste of My chastisement.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Do they possess the treasures of your Lord, the Most Mighty, the Great Bestower?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or do they possess the dominion of the heavens and the earth and of all that is in between them? If so, let them ascend the heights of the realm of causation and see!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
This is only a small army out of the several armies that will suffer defeat here.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Before them the people of Noah, Ad, and Pharaoh of the tent-pegs gave the lie (to the Messengers)\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
and so did Thamud and the people of Lot and the people of Aykah. These were all leagued together.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
Each of them gave the lie to Messengers and My decree of chastisement came upon them.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
They are waiting for nothing except a single Cry, after which there will be no second Cry.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
They say: “Our Lord, hasten to us our share (of chastisement) before the Day of Reckoning.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
(O Prophet), bear with patience what they say, and call to mind Our servant David, who was endowed with great strength and who constantly turned (to Allah).\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
With him We had subjected the mountains that they join him in celebrating Allah's glory, evening and morning,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
and the birds, too, in their flocks, and turn again and again to celebrating Allah's glory.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
And We strengthened his kingdom and endowed him with wisdom and decisive judgement.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
Has the story of the litigants reached you -- of those who entered his private chambers by climbing over the wall?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
As they came upon David -- and he was frightened of them -- they said: “Be not afraid. We are just two litigants: one of us has committed excess against the other. So judge rightly between us, and be not unjust; and guide us to the Right Way.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
Behold, this is my brother; he has ninety-nine ewes and I have only one ewe.” And yet he said: “Give her into my charge,” and he got the better of me in argument.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
David said: “He has certainly wronged you in seeking to add your ewe to his ewes; and indeed many who live together commit excesses, one to the other, except those that believe and act righteously; and they are but few.” (While so saying) David realized that it is We Who have put him to test; therefore, he sought the forgiveness of his Lord, and fell down, bowing and penitently turning (to Him).\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
Thereupon We forgave him his shortcoming and indeed (an exalted position of) nearness awaits him, and an excellent resort.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
(We said to him): “O David, We have appointed you vicegerent on earth. Therefore, rule among people with justice and do not follow (your) desire lest it should lead you astray from Allah's Path. Allah's severe chastisement awaits those who stray away from Allah's Path, for they had forgotten the Day of Reckoning.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
We did not create this heaven and earth and all that lies between them in vain. That is the fancy of those who denied the Truth. So woe from the Fire to all who deny the Truth.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Shall We then treat alike those that believe and act righteously and those that create mischief on earth? Or treat alike the God-fearing and the wicked?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
This is the Blessed Book that We have revealed to you, (O Muhammad), that people with understanding may reflect over its verses and those with understanding derive a lesson.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmm{%
We bestowed upon David (an illustrious son), Solomon. How excellent a servant (of Ours he was)! Indeed he constantly turned to Us in devotion.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmi{%
And when one evening well-trained and running horses of noble breed were brought to him\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmii{%
he said: “Lo! I have come to love this wealth on account of the remembrance of my Lord.” And when the horses disappeared,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
(he ordered): “Bring these horses back to me,” and then he began to gently stroke their shanks and necks.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
Surely We put Solomon to the test and cast upon his throne a mere body. Thereupon he penitently turned (to Us).\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said: “My Lord, forgive me and bestow upon me a kingdom such as none other after me will deserve. Surely You are the Bounteous Giver.”\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
We subjected the wind to him, so that it blew gently at his bidding, wherever he directed it,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
and We also subjected the devils to him -- all kinds of builders and divers;\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
and others that were bound with chains.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmix{%
“This is Our bestowal. So give or withhold as you wish without account.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmx{%
Indeed an exalted position of nearness awaits him and an excellent resort.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
And remember Our servant Job: when he cried to his Lord: “Behold, Satan has afflicted me with much hardship and suffering.”\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
(We commanded him): “Stamp your foot on earth, and here is cool water to wash with and to drink.”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We granted to him his family and also the like of them, as a mercy from Us, and as a reminder to people of understanding,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
(and We said to him): “Take in your hand a bundle of rushes and strike with it, and do not break your oath.” Indeed We found him steadfast. How excellent a servant (of Ours) he was. Indeed he constantly turned (to his Lord).\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And remember Our servants -- Abraham, Isaac and Jacob -- they were endowed with great strength and vision.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Verily We exalted them in consideration of a sterling quality: their remembrance of the Abode of the Hereafter.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
In Our sight they are among the chosen and excellent ones.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And remember Ishmael, Elisha, and Dhu al-Kifl. All were of the best.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This was a remembrance. An excellent retreat awaits the God-fearing\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
-- everlasting Gardens with gates wide open for them\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
wherein they shall recline, wherein they shall ask for abundant fruit and drinks,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
and wherein there shall be with them well-matched, bashful mates.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
All this is what you are promised for the Day of Judgement.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
This is Our provision for you, never to end.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
All this (is for the God-fearing). But for the transgressors, an evil resort awaits them --\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell, where they will be roasted. An evil place to dwell!\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
All this (is for them); so let them taste boiling water and pus,\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
and other sufferings of the kind.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
(Observing their followers advancing to Hell they will say, among themselves: “This is a troop rushing in to you. There is no welcome for them. They are destined to roast in the Fire.”\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
They will reply: “Rather, no welcome to you. (You will roast in Hell.) It is you who led us to this end. What an evil resort!”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They will say: “Our Lord, give twofold punishment in the Fire to him who has led us to this.”\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
They will say to one another: “But why do we not see those whom we considered him among the wicked?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
Is it that we mistakenly made fun of them; or have they disappeared from our sight?”\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Verily all this is true. This is how the inmates of the Fire will dispute among themselves.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Tell them, (O Prophet): “I am nothing but a warner. There is no deity but Allah, the One, the Supreme,\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
the Lord of the heavens and the earth and all that is in between them, the Most Mighty, the Most Forgiving.”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say: “This is a tiding of tremendous import\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
from which you are turning away.”\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
(Tell them): “I had no knowledge of the High Council when they were disputing.\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
I am told (about matters) by means of revelation only because I am a clear warner.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
When your Lord said to the angels: “Verily I am creating a human being from clay.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
After I have created him and breathed into him of My spirit, fall you down, prostrating yourselves to him.”\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
Then the angels, all of them, prostrated themselves before Adam\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
except Iblis. He waxed proud and became one of the unbelievers.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
The Lord said: “O Iblis, what prevented you from prostrating yourself before him whom I created of My Two Hands. Are you waxing proud, or fancy yourself to be too exalted?”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
He replied: “I am nobler than he. You created me from fire and created him from clay.”\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
He said: “Get out of here; surely you are accursed,\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
and My curse shall remain upon you till the Day of Resurrection.”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
Satan said: “My Lord, then grant me respite till the Day that they are raised up.”\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmml{%
He said: “You are of those who have been granted respite\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmli{%
till the Day whose Hour I know.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
(Iblis) said: “By Your glory, I shall mislead them all\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
except those of Your servants, the chosen ones from amongst them.”\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
He (i.e. Allah) said: “This is the Truth -- and I only speak the Truth --\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
I will certainly fill the Gehenna with you and with all those among them who follow you.”\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
(O Prophet), tell them: “I do not ask you for any recompense for the performance of this task; nor am I given to affectation.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
This is nothing but an Admonition for all people the world over.\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
You will know the truth of the matter after a while.”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of this Book is from Allah, the Most Mighty, the Most Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
(O Prophet), it is We Who have revealed this Book to you with Truth. So serve only Allah, consecrating your devotion to Him.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Lo, religion is exclusively devoted to Allah. Your religion is entirely consecrated to Him. As for those who have taken others than Allah for their guardians, (they say): “We worship them only that they may bring us nearer to Allah.” Allah will judge between them concerning what they differ about. Verily Allah does not guide anyone who is given to sheer lying, is an utter unbeliever.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
If Allah had wanted to take to Himself a son, He could have chosen anyone He wanted out of those whom He creates. Glory be to Him (that He should have a son). He is Allah: the One, the Overpowering.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He created the heavens and the earth with Truth, and He folds up the day over the night and folds up the night over the day. He has subjected the sun and the moon, each is running its course until an appointed time. Lo, He is the Most Mighty, the Most Forgiving.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He it is Who created you from a single being, and He it is Who made from it its mate. He it is Who created for you eight heads of cattle in pairs. He creates you in your mothers' wombs, giving you one form after another in threefold depths of darkness. That, then, is Allah, your Lord. His is the kingdom. There is no god but He. So, whence are you being turned astray?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If you disbelieve, know well that Allah has no need of you. Yet He does not like unbelief in His servants. But if you are thankful, your thankfulness will please Him. No one shall bear another's burden. You are destined to return to your Lord and He will tell you what you used to do. He is well aware even of what lies hidden in your breasts.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
When any affliction befalls man, he cries out to his Lord, penitently turning to Him. But when his Lord bestows His favour upon him, he forgets the affliction regarding which he had cried out and sets up compeers to Allah that they may lead others astray from His Path. Say, (O Prophet): “Enjoy your unbelief for a while. Surely you will be among the inmates of the Fire.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Is such a person (preferable or he) who is obedient, and prostrates himself in the watches of the night, stands (in Prayer), is fearful of the Hereafter, and looks forward to the mercy of His Lord? Ask them: “Are those who know equal to those who do not know?” Only those endowed with understanding take heed.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Tell them (O Prophet): “O you servants of Mine who believe, have fear of your Lord. A good end awaits those who did good in this world. Allah's earth is spacious. Verily those who persevere shall be granted their reward beyond all reckoning.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Tell them, (O Prophet): “I am bidden to serve Allah, consecrating my devotion to Him,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
and I am bidden to be the first of those who surrender to Him.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say: “If I disobey my Lord, I fear the chastisement of an Awesome Day.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say: “Allah alone shall I serve, consecrating my devotion to Him.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
So serve, apart from Him, whomsoever you please.” Say: “Behold, the real losers shall be those who will have lost their own selves and their kith and kin on the Day of Resurrection. Behold, that is the obvious loss.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
There shall be sheets of fire above them and beneath them. This is the end against which Allah warns His servants. So dread My wrath, O you servants of Mine!”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
(On the other hand), good tidings await those who eschew serving false gods and penitently return to Allah. (O Prophet), give good tidings to My servants,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
to those who pay heed to what is said and follow the best of it. They are the ones whom Allah has guided to the Right Way; they are the ones endowed with understanding.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
(O Prophet), can you save him (from chastisement) against whom the sentence of chastisement has become due; him who has, (as it were), already fallen into the Fire?”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But those who fear their Lord shall have lofty mansions built over one another beneath which rivers flow. This is Allah's promise and never does Allah fail to fulfil His promise.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Do you not see that Allah sent down water from the sky, then made it flow on earth as springs and streams and rivers and then with it He brings forth vegetation of various hues; then this vegetation ripens and dries up, turning yellow, whereafter He reduces it to broken straw? Surely there is a lesson in this for those endowed with understanding.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
Can he whose breast Allah has opened up for Islam and who is thus (moving along a Path) illumined by a light from Allah (be likened to him who derives no lesson from what he observes)? Woe, then, to those whose hearts were further hardened after Allah's admonition. Such are indeed in obvious error.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah has revealed the best teaching, a self-consistent Book which repeats its contents in manifold forms whereat shiver the skins of those that hold their Lord in awe, and then their skins and their hearts soften for Allah's remembrance. That is Allah's Guidance wherewith He guides whosoever He pleases. And he whom Allah does not guide to the Right Path has none to guide him.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
How woeful is the plight of him who has nothing except his face to shield him from severe chastisement on the Day of Resurrection? Such evil-doers shall be told: “Taste now the consequence of your deeds.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Their predecessors gave the lie to the Truth and then chastisement came upon them from whence they could not imagine.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
So Allah made them taste degradation in the life of this world, and certainly the chastisement of the Hereafter will be much more grievous. Would that they knew!\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
We have indeed propounded for mankind all kinds of parables in this Qur'an that they may take heed.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
It is an Arabic Qur'an free of all crookedness that they may guard against their evil end.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah propounds a parable: there is a man whose ownership is shared by several quarrelsome masters, each pulling him to himself; and there is another who is exclusively owned by one man. Can the two be alike? All praise and thanks be to Allah. But most of them are unaware.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
(O Prophet), you are destined to die and they too are destined to die.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
Then eventually all of you will contend before your Lord on the Day of Resurrection.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
Who, then, can be more unjust than he who lied against Allah and denied the Truth when it came to him, calling it a lie? Is there no room for such unbelievers in Hell?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
But he who brought the Truth, and those who confirmed it as true, such are the ones who shall be guarded against the chastisement.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They shall have from their Lord all that they wish for. That is the reward of those that do good,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
so that Allah may remit their worst deeds and reward them according to the best of their deeds.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
(O Prophet), does Allah not suffice for His servant? They frighten you with others apart from Him, although he whom Allah lets go astray, none can guide him to the Right Way.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And he whom Allah guides to the Right Way, none can lead him astray. Is not Allah the Most Mighty, the Lord of Retribution?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
If you ask them: “Who created the heavens and the earth?” they will surely answer: “Allah.” Tell them: “What do you think, then, of the deities whom you call upon instead of Allah? If Allah should will that an affliction befall me, will those deities remove the harm inflicted by Him? Or if Allah should will that I receive (His) Mercy, will they be able to withhold His Mercy from me?” Say: “Allah is sufficient for me; those who have to put their trust, let them put their trust in Him.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Tell them: “My people, continue to work in your position as you will, I too will continue with my work. Soon you shall know\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
whom the degrading chastisement will visit and upon whom the everlasting chastisement will alight.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
(O Prophet), We revealed to you the Book with the Truth for all mankind. So he who follows the Right Way does so to his own benefit, and he who goes astray, shall hurt only himself by straying. You are not accountable on their behalf.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmc{%
It is Allah Who takes away the souls of people at the hour of their death, and takes away at the time of sleep the souls of those that have not died. Then He retains the souls of those against whom He had decreed death and returns the souls of others till an appointed time. Surely there are Signs in this for a people who reflect.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Or have they taken others instead of Allah as intercessors? Say: “Will they intercede though they may have no power and though they may not even understand?”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say: “All intercession lies with Allah. His is the dominion of the heavens and the earth. And to Him will all of you be sent back.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
When Allah alone is mentioned, the hearts of those who do not believe in the Hereafter contract with bitterness, but when deities apart from Allah are mentioned, they are filled with joy.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say: “O Allah, the Originator of the heavens and the earth, the Knower of the unseen and the seen, You it is Who will judge among Your servants concerning what they differed.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
If the wrong-doers possessed the treasures of the earth in their entirety and as much besides, they would gladly offer it on the Day of Resurrection to redeem themselves from the harrowing chastisement. This because there will appear to them from Allah something (exceedingly dismal which) they had never even imagined.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
The evil consequences of their deeds will become fully apparent to them, and what they had scoffed at will encompass them.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
When an affliction befalls man, he cries out to Us; but when We grant him a favour from Us, he says: “I have been granted this on account of my knowledge.” Nay; this (favour) is a test; but most of them do not know.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Their predecessors also said the same, but their earnings proved of no avail to them,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
and the evil consequences of their deeds overtook them. The wrongdoers among these will also be overtaken by the evil consequences of their deeds. They will be utterly unable to frustrate (Us).\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Do they not know that Allah enlarges and straitens the provision of whomsoever He pleases? Therein are Signs for those that believe.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Tell them, (O Prophet): “My servants who have committed excesses against themselves, do not despair of Allah's Mercy. Surely Allah forgives all sins. He is Most Forgiving, Most Merciful.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
Turn to your Lord and surrender yourselves to Him before the chastisement over-takes you; for then you will receive no help.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
Follow the best of what has been revealed to you from your Lord before the chastisement suddenly comes upon you without you even being aware of it.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
Lest a person should say: “Alas for me for neglecting my duty towards Allah and for being among those that scoffed”;\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
and lest a person should say: “If only Allah had guided me, I should have been one of the God-fearing”;\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
or lest he should say, when he sees the chastisement: “O that I might return again, and be among those who do good.”\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
Yes indeed! But My Signs came to you and you rejected them as lies, and waxed arrogant and were among those who disbelieved.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
On the Day of Resurrection you shall see that the faces of those who had lied against Allah have turned dark. Is Hell not vast enough to provide a room to the vainglorious?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
But as for the God-fearing, Allah will deliver them on account of their achievements: no harm shall visit them nor shall they grieve.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is the Creator of everything; He is the Guardian over everything.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
To Him belong the keys of the heavens and the earth. It is those who disbelieve in Allah's Signs who will be the losers.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
(O Prophet), say: “Ignorant people! Do you bid me to serve any other beside Allah?”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
(Tell them clearly that) it was revealed to you and to all Prophets before you: “If you associate any others with Allah in His Divinity, your works will surely come to naught and you will certainly be among the losers.”\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Therefore, serve Allah alone and be among those who give thanks.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
They did not recognise the true worth of Allah. (Such is Allah's power that) on the Day of Resurrection the whole earth will be in His grasp, and the heavens shall be folded up in His Right Hand. Glory be to Him! Exalted be He from all that they associate with Him.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
And the Trumpet shall be blown and all who are in the heavens and the earth shall fall down dead save those whom Allah wills. Then the Trumpet shall be blown again, and lo! all of them will be standing and looking on.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
The earth shall shine with the light of its Lord, and the Scroll (of deeds) shall be set in place, and the Prophets and all witnesses shall be brought, and judgement shall be justly passed among them, and they shall not be wronged;\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
and everyone shall be paid in full for all that he did. Allah is best aware of all that they do.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
(After the judgement has been passed) the unbelievers shall be driven in companies to Hell so that when they arrive there, its gates shall be thrown open and its keepers shall say to them: “Did Messengers from among yourselves not come to you, rehearsing to you the Signs of your Lord and warning you against your meeting of this Day?” They will say: “Yes indeed; but the sentence of chastisement was bound to be executed against the unbelievers.”\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It will be said: “Enter the gates of Hell. Herein shall you abide.” How evil is the abode of the vainglorious!\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
And those who eschewed disobeying their Lord shall be driven in companies to Paradise so that when they arrive there its gates will have already been thrown open and its keepers shall say to them: “Peace be upon you; you have done well. So enter. Herein you shall abide.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
They will say: “All thanks and praise be to Allah Who has made His promise to us come true, and Who gave us the earth to inherit. We may now dwell in Paradise wherever we please.” How excellent is the reward of those who laboured!\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
You shall see the angels surrounding the Throne, glorifying their Lord with His praise, and judgement will have been made among them with fairness, and it will be proclaimed: “All praise and thanks be to Allah, the Lord of the whole Universe.”\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha'. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
This Book is a revelation from Allah, the All-Mighty, the All-Knowing;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
the Forgiver of sins, the Accepter of repentance, the Stern in retribution, the Bountiful. There is no god but He. To Him are all destined to return.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None but the unbelievers dispute regarding the Signs of Allah. So let not their strutting about in the land delude you.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
Before them the people of Noah also gave the lie (to Messengers), and so did many parties after them. Each nation sallied forth against its Messenger to seize him, and they disputed with false arguments seeking therewith to repudiate the Truth. Then I seized them; and behold, how woeful was My retribution!\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
Thus has the decree of your Lord become due against the unbelievers. They are destined for the Fire.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
The angels that bear the Throne and those that are around to extol your Lord's glory with His praise, they believe in Him, and ask forgiveness for the believers, saying: “Our Lord! You encompass everything with Your Mercy and Knowledge. So forgive those that repent and follow Your Path, and guard them against the chastisement of Hell.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
Our Lord, admit them to the everlasting Gardens You have promised them and those of their fathers and spouses and progeny that were righteous. Surely You alone are Most Mighty, Most Wise;\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
and guard them against all ills. He whom You guard against ills on that Day, to him You have surely been Most Merciful. That is the great triumph.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
It will be announced to the unbelievers (on the Day of Resurrection): “Surely Allah's abhorrence of you when you were called to believe but you disbelieved was greater than is your abhorrence of yourselves today.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They will say: “Our Lord, twice have You caused us to die and twice have You given us life. We have now confessed our sins. Is there, then, any way out?”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
(They will be told): “(The cause of your present state is that) when Allah alone was invoked, you disbelieved; and when others instead of Him were invoked, you believed. Today all judgement lies with Allah, the Most High, the All-Great.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
He it is Who shows you His Signs and sends down provision for you from the sky. Yet none takes heed except he who constantly turns to Allah.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
So call upon Allah, consecrating all your devotion to Him, howsoever much the unbelievers may dislike it.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
Exalted in Rank, Lord of the Throne: He causes the spirit to descend on whomsoever of His servants He pleases so as to warn them of the Day of Encounter;\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
the Day when they will emerge and nothing of them shall be hidden from Allah. (On that Day they will be asked): “Whose is the kingdom today?” (The whole world will cry out): “It is Allah's, the One, the Overpowering.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
(It will then be said): “Today shall everyone be fully recompensed for his deeds. None shall be wronged today. Surely Allah is Swift in Reckoning.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
(O Prophet), then warn them of the Day that has drawn near, the Day when hearts full of suppressed grief will leap up to the throats and the wrong-doers shall neither have any sincere friend nor intercessor whose word will be heeded.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
He knows even the most stealthy glance of the eyes and all the secrets that hearts conceal.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
Allah will judge with justice, whereas those whom they call upon beside Him cannot judge at all. Surely Allah -- and He alone -- is All- Hearing, All-Seeing.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Have they not journeyed in the land that they might observe the end of those who came before them? They were even greater in strength than they and left behind more splendid traces in the land. Then Allah seized them because of their sins and they had none who could protect them from Allah.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
They came to this end because their Messengers would come to them with Clear Signs and yet they would refuse to believe. So Allah seized them. He is indeed Strong, Terrible in Retribution.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
Verily We sent Moses with Our Signs and a clear authority\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
to Pharaoh and Haman and Korah. They said: “(He is) a sorcerer, an utter liar.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
When Moses brought them the Truth from Us they said: “Kill the sons of all the believers who have joined him, but spare the women.” The guile of the unbelievers always ends in vain.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
One day Pharaoh said: “Let me go and kill Moses; then let him invoke his Lord. I fear that he will change your religion or cause disruption in the land.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
Moses said: “I have taken refuge with my Lord and your Lord from everyone who waxes arrogant and does not believe in the Day of Reckoning.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
Then a man endowed with faith, from Pharaoh's folk, who had kept his faith hidden, said: “Do you kill a person simply because he says: 'My Lord is Allah' even though he brought to you clear Signs from your Lord? If he is a liar, his lying will recoil upon him; but if he is truthful, you will be smitten with some of the awesome consequences of which he warns you. Allah does not guide to the Right Way any who exceeds the limits and is an utter liar.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
My people, today the kingdom is yours, and you are supreme in the land. But if Allah's chastisement were to come upon you, who will come to our help?” Pharaoh said: “I only counsel what I consider right; I only direct you to the Path of Rectitude.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
He who had faith said: “My people, I fear that you will confront a day like that which overtook many parties before you,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
like the day that overtook the people of Noah and Ad and Thamud, and those who came after them. Allah does not wish to subject His servants to any injustice.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
My people, I fear that you will encounter a day when there will be much wailing and you will cry out to one another for help,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
the day when you will turn around to retreat, there will be none to protect you from Allah. He whom Allah lets go astray, none will be able to show him the Right Way.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
Verily Joseph came to you with Clear Signs before, yet you continued to doubt his Message. Thereafter when he died, you said: 'Allah shall send no Messenger after him.'” Thus Allah leads astray those who transgress the limits and are given to much doubting;\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
those who contend regarding Allah's Signs without any evidence that might have come to them. That is exceedingly loathsome to Allah and to those that believe. Thus does Allah seal the heart of everyone who is proud and high-handed.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
Pharaoh said: “Haman, build for me a lofty tower that I may scale the highways --\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
the highways to the heavens -- and have a look at the God of Moses, although I am certain that Moses is a liar.” Thus Pharaoh's evil deed was made to seem fair to him, and he was barred from the Right Path. Pharaoh's guile only led him to his own perdition.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
The person endowed with faith said: “My people, follow me; I shall direct you to the Path of Rectitude.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
My people, the life of this world is ephemeral, whereas the Hereafter, that is the permanent abode.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
Whosoever does an evil deed will be requited only with the like of it; and whosoever acts righteously and has attained to faith -- be he a male or a female -- they shall enter Paradise and be provided sustenance beyond all reckoning.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
My people, how is it that I call you to salvation while you call me to the Fire;\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
you call me to deny Allah and to associate with Him as His partners those regarding whom I have no knowledge (that they are Allah's partners in His Divinity), whereas I call you to the Most Mighty, the Most Forgiving?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
There is no doubt that those whom you call me to have no claim to be called upon in this world and in the Hereafter. Certainly to Allah shall be our return, and those who exceed the limits are destined to the Fire.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
Soon you shall remember what I say to you. I entrust my affairs to Allah. Surely Allah is watchful over His servants.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
Eventually Allah saved the person endowed with faith from all the evils of their guile, and a woeful chastisement encompassed the Pharaonites.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
They are exposed to the Fire every morning and evening; and when the Last Hour will come to pass, a command shall be given: “Admit the Pharaonites to an even more severe chastisement.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
Just imagine when they will remonstrate with one another in Hell. The weak ones will say to those who waxed proud: “We were your followers. Will you, then, lighten for us a part of our suffering of the Fire?”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who had waxed proud will reply: “All of us are in it. Allah has already passed His judgement among His servants.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
Those suffering in the Fire will say to the keepers of Hell: “Call upon your Lord to lighten the chastisement for us just for a day.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
The keepers of Hell will ask: “Did your Messengers not come to you with Clear Signs?” They will say: “Yes (they did).” The keepers of Hell will say: “Then you yourselves should call (upon the Lord). And the call of the unbelievers will end in vain.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Surely We shall help Our Messengers and the believers in the life of this world and on the Day when witnesses will rise to testify,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
the Day when the excuses offered by the wrong-doers shall not avail them. They shall be victims of the curse and a woeful abode.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
We surely guided Moses and made the Children of Israel the heirs of the Book\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
which was a guidance and good counsel to people endowed with understanding and wisdom.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
Be steadfast, then, (O Prophet), Allah's promise is true. Seek forgiveness for your shortcomings, and celebrate the praise of your Lord, evening and morning.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Verily those who dispute regarding the Signs of Allah without any evidence that might have come to them, nothing but vain pride fills their hearts. Yet they shall never be able to satisfy the pride with which they are puffed up. So seek refuge with Allah. Verily He is All-Hearing, All-Seeing.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
Surely the creation of the heavens and the earth is a greater act than the creation of human beings. But most people do not know.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
Never can the blind and the seeing be equal; nor those that believe and act righteously and those that do evil. Little do you understand.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
The Hour will indeed come; there is no doubt about that. Yet most people do not believe.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
Your Lord said: “Pray to Me, and I will accept your prayers. Surely those who wax too proud to worship Me shall enter Hell, utterly abased.”\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
Allah it is Who made the night so that you may seek repose in it, and made the day radiant. Surely Allah is Most Bounteous to people; but most people do not give thanks.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
Allah (Who bestowed all these favours upon you) is your Lord, the Creator of everything. There is no god but He. Whence are you, then, being led astray?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
Thus it is only those who had denied Allah's Signs that were led astray.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
Allah it is Who made the earth a dwelling place for you and made the sky a canopy, Who shaped you -- and shaped you exceedingly well -- and gave you good things as sustenance. That is Allah, your Lord; blessed be Allah, the Lord of the Universe.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Ever-Living: there is no god but He. So call upon Him, consecrating to Him all your devotion. All praise and thanks be to Allah, the Lord of the whole Universe.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say, (O Prophet): “I have been forbidden to worship those beside Allah whom you call upon. (How can I worship any beside Allah) when clear Signs have come to me from my Lord and I have been commanded to surrender to Allah, the Lord of the Universe?”\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
He it is Who created you from dust, then from a sperm-drop, then from a clot; then He brings you out as an infant, then causes you to grow into full maturity, and then causes you to grow further so that you may reach old age, while some of you He recalls earlier. All this is in order that you may reach an appointed term and that you may understand (the Truth).\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
He it is Who gives life and causes death. Whenever He decrees a thing, He only commands to it “Be”, and it is.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Did you not see those who dispute concerning Allah's Signs? Whence are they, then, being turned astray?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who gave the lie to this Book and all the Books which We had sent with Our Messengers shall soon come to know the Truth\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
when fetters and chains shall be on their necks, and they shall be dragged into\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
boiling water, and cast into the Fire.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
It will then be said to them: “Where are those whom you\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
associated with Allah in His Divinity?” They will say: “We have lost them; rather, we never used to call upon anyone before.” Thus will Allah cause them to stumble in error.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
(They will be told): “This is because while you were on earth you took delight in untruth and exulted in it.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter Hell now to abide in it. How woeful is the abode of those who wax proud!\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
So be patient, (O Prophet). Surely Allah's promise is true. Whether We show them a part of the woeful consequences against which We warn them (while you are still in their midst) or We recall you (from this world) before that, eventually it is to Us that they shall be brought back.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
Indeed We sent many Messengers before you: of them there are some whose account We have narrated to you and there are others whose account We have not narrated to you. It did not lie in any Messenger's power to bring any Sign except with Allah's leave. So when Allah's decree came, the matter was decided with justice, and those steeped in error courted utter loss, then and there.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
Allah it is Who has made cattle for you so that you ride some of them and from some of them you derive food.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
In them there are also other benefits for you, and through them you fulfil your heartfelt need (to reach places), and you are borne along upon them as upon the ships.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
Allah shows His Signs to you; then which of Allah's Signs will you deny?\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Did they not journey in the land that they may behold the end of those who had gone before them? They were more numerous and greater in strength and left behind more splendid traces in the land. Yet their attainments did not avail them.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
When their Messengers came to them with Clear Signs, they arrogantly exulted in whatever knowledge they had. They were then encompassed by what they had mocked.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
When they saw Our chastisement, they said: “We have come to believe in Allah, the Only One, and we reject all what we had associated (with Allah in His Divinity).”\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
But their believing after they had seen Our chastisement did not avail them. That has been Allah's Way concerning His servants. And the unbelievers courted utter loss, then and there.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha'. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
This is a revelation from the Most Merciful, the Most Compassionate,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
a Book whose verses have been well-expounded; an Arabic Qur'an for those who have knowledge,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
one bearing good news and warning. Yet most of them turned away and are not wont to give heed.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
They say: “Our hearts are securely wrapped up against what you call us to, and in our ears is a heaviness, and between you and us there is a veil. So act; we too are acting.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Tell them, (O Prophet): “I am only a human being like you. It is revealed to me that your God is One God; so direct yourselves straight to Him, and seek His forgiveness. Woe to those who associate others with Allah in His Divinity,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
who do not pay Zakah, and who deny the Hereafter.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
As to those who have faith and do good works, surely theirs shall be a never-ending reward.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Tell them, (O Prophet): “Do you indeed disbelieve in Him and assign compeers to Him Who created the earth in two days? He is the Lord of all beings of the Universe.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
(After creating the earth) He set up firm mountains on it, blessed it, and provided it with sustenance in proportion to the needs of all who seek (sustenance). All this was done in four days.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Then He turned to the heaven while it was all smoke. He said to the heaven and the earth: “Come (into being), willingly or unwillingly.” They said: “Here we come (into being) in willing obeisance.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
Then He made them seven heavens in two days and revealed to each heaven its law. And We adorned the lower heaven with lamps, and firmly secured it. All this is the firm plan of the All-Mighty, the All-Knowing.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
But if they turn away, tell them: “I warn you against a sudden scourge like that which struck Ad and Thamud.”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
When the Messengers (of Allah) came to them from the front and from the rear, saying: “Do not serve any but Allah”; they said: “Had our Lord so willed, He would have sent down angels. So we deny the Message you have brought.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for Ad, they waxed proud in the land without justification and said: “Who is greater than we in strength?” Did they not see that Allah, Who created them, is greater in strength than they? They continued to deny Our Signs,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
whereupon We sent upon them a fierce wind on inauspicious days that We might make them taste a degrading chastisement in the life of this world. And surely the chastisement of the Hereafter is even more degrading. There will be none to help them there.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
As for Thamud, We bestowed guidance upon them, but they preferred to remain blind rather than be guided. At last a humiliating scourge overtook them on account of their misdeeds.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
Yet We delivered those who believed and were God-fearing.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
Imagine the Day when Allah's enemies will be mustered to the Fire, and the people of the former times will be detained until the arrival of people of the later times,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
and when all have arrived, their ears, their eyes, and their skins shall bear witness against them, stating all that they had done in the life of the world.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
They will ask their skins: “Why did you bear witness against us?” The skins will reply: “Allah gave us speech, as He gave speech to all others. He it is Who created you for the first time and it is to Him that you will be sent back.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
When you used to conceal yourselves (while committing misdeeds) you never thought that your ears or your eyes or your skins would ever bear witness against you; you rather fancied that Allah does not know a great deal of what you do.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
This thought of yours about your Lord has led to your perdition and you have become among the losers.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
In this state, whether they bear with patience (or not), Fire alone shall be their abode. And if they seek to make amends, they will not be allowed to do so.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
We had assigned to them companions who embellished for them all that was before them and behind them. Thus the same decree (of chastisement) which had overtaken the previous generations of jinn and human beings (also) became due against them. Surely they became the losers.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
The deniers of the Truth say: “Do not give ear to the Qur'an and cause interruption when it is recited; thus perhaps you will gain the upper hand.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
We shall certainly make these unbelievers taste a terrible chastisement and shall fully requite them according to the worst deeds that they committed.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
That is the recompense of the enemies of Allah -- the Fire, their abiding home. That will be the re-compense for their denying Our Signs.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
There the unbelievers will say: “Our Lord, show us those that led us astray, both jinn and humans, and we will trample them under our feet so that they are utterly degraded.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Those who say “Allah is our Lord” and then remain steadfast, upon them descend angels (and say): “Do not fear nor grieve, and receive good tidings of Paradise which you were promised.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
We are your companions in this world and in the Hereafter. There you shall have all that you desire and all what you will ask for.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
This is by way of hospitality from Him Who is Most Forgiving, Most Merciful.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And who is fairer in speech than he who calls to Allah and acts righteously and says: “I am a Muslim”?\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
(O Prophet), good and evil are not equal. Repel (evil) with that which is good, and you will see that he, between whom and you there was enmity, shall become as if he were a bosom friend (of yours).\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
But none attains to this except those who are steadfast; none attains to this except those endowed with mighty good fortune.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
And if you are prompted by a provocation from Satan, seek refuge with Allah. He, and He alone, is All-Hearing, All- Knowing.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And of His Signs are the night and the day, and the sun and the moon. Do not prostrate yourselves before the sun, nor before the moon, but prostrate yourselves before Allah Who created them, if it is Him that you serve.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
But if they wax proud (and persist in their attitude, it does not matter, for) the angels near-stationed to your Lord glorify Him night and day, and never grow weary.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And of His Signs is that you see the earth withered, then We send down water upon it, and lo! it quivers and swells. Surely He Who gives life to the dead earth will also give life to the dead. Surely He has power over everything.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Those who pervert Our Signs are not hidden from Us. Is he who will be cast into the Fire better, or he who comes secure on the Day of Resurrection? Do as you wish; He sees all what you do.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
These are the ones who rejected the Good Counsel when it came to them, although it is certainly a Mighty Book.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
Falsehood may not enter it from the front or from the rear. It is a revelation that has been sent down from the Most Wise, the Immensely Praiseworthy.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
(O Prophet), nothing is said to you but what was already said to the Messengers before you. Surely your Lord is the Lord of forgiveness and the Lord of grievous chastisement.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
Had We revealed this as a non-Arabic Qur'an they would have said: “Why were its verses not clearly expounded? How strange, a non-Arabic scripture and an Arab audience!” Tell them: “It is a guidance and a healing to the believers. But to those who do not believe, it serves as a plug in their ears and a covering over their eyes. It is as if they are being called from a place far away.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
And in the past We gave Moses the Book and yet it became an object of dispute. If your Lord's decree had not gone forth before, a decisive judgement would have been made among them, once and for all. Surely they are in a disquieting doubt about it.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whoever does good, does so to his own benefit; and whoever does evil, will suffer its evil consequence. Your Lord does no wrong to His servants.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
The knowledge of the Hour rests solely with Him. Not a fruit comes forth from its sheath, nor does any female conceive nor give birth to a child but it is in His knowledge. On that Day He will call out to them: “Where are those associates of Mine?” They will answer: “We have declared to You that none of us can bear witness to that.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
Then all those deities whom they once used to call upon shall vanish and they will come to know for sure that there is no escape for them.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man wearies not of praying for good, but when evil visits him, he despairs and gives up all hope.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And if We bestow Our Mercy upon him after hardship, he will surely say: “This is what I truly deserve, and I do not believe that the Hour (of Resurrection) will ever come to pass; and if I am returned to my Lord, there too I shall enjoy the best.” Surely We shall fully apprise the unbelievers of what they have done, and We shall certainly make them taste a severe chastisement.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
When We bestow Our favour upon man, he turns away and waxes proud; but when a misfortune touches him, he is full of supplication.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Tell them, (O Prophet): “Did you ever consider: if this Qur'an is indeed from Allah and you still deny it, who can be in greater error than he who goes far in fiercely opposing it?”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
Soon shall We show them Our Signs on the horizons and in their own beings until it becomes clear to them that it is the Truth. Is it not enough that your Lord is a witness over everything?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Lo, they are in doubt concerning their meeting with their Lord. Surely He fully encompasses everything.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha'. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
Ayn. Sin. Qaf.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
Thus does Allah, the Most Mighty, the Most Wise reveal to you even as (He revealed) to those (Messengers) who preceded you.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
His is all that is in the heavens and all that is in the earth; He is the Most High, the All-Great.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
The heavens may well nigh rend asunder from above while the angels proclaim the praise of their Lord and ask forgiveness for those on earth. Lo, it is Allah, and He alone, Who is Most Forgiving, Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
Those who have taken others than Him as their protectors beside Him, it is Allah Who oversees them; you are no guardian over them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
And thus did We reveal this Arabic Qur'an to you that you may warn the people of the Mother of Cities (to wit, Makkah) and those who dwell around it; and warn them of the Day of Gathering concerning which there is no doubt: whereon some will be in Paradise, and some in the Blazing Fire.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
If Allah had so willed, He could have made them all a single community. But He admits whomsoever He pleases into His Mercy. As to those given to wrong-doing, they shall have none as protector or helper.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
(Are they so foolish that) they have chosen others rather than Allah as their protectors? Yet it is Allah Who is the Protector and Who resurrects the dead and Who has power over everything.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
The judgement on whatever you differ rests with Allah. Such is Allah, my Lord; in Him I have put all my trust and to Him I always turn in devotion.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
The Originator of the heavens and the earth, He has appointed for you pairs of your own kind, and pairs also of cattle. Thus does He multiply you. Naught in the universe is like Him. He is All-Hearing, All-Seeing.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
His are the keys of the heavens and the earth. He enlarges and straitens the sustenance of whomsoever He pleases. Surely He has knowledge of everything.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He has prescribed for you the religion which He enjoined upon Noah and which We revealed to you (O Muhammad), and which We enjoined upon Abraham and Moses and Jesus, commanding: “Establish this religion and do not split up regarding it.” What you are calling to is very hard upon those who associate others with Allah in His Divinity. Allah chooses for Himself whomsoever He pleases and guides to Himself whoever penitently turns to Him.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
They did not split up except after knowledge had come to them, and then only because they wished to commit excesses against each other. Had your Lord not already decreed that judgement would be made later at an appointed time, the matter between them would surely have been decided once and for all. Indeed those who were later made the heirs of the Book are in disquieting doubt about it.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
(This being so, O Muhammad), call people to the same religion and be steadfast about it as you were commanded, and do not follow their desires, and say (to them): “I believe in the Book Allah has sent down. I have been commanded to establish justice among you. Allah is our Lord and your Lord. We have our deeds and you have your deeds. There is no contention between us and you. Allah will bring us all together. To Him all are destined to return.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
Those who contend concerning Allah (after His call has been responded to), their contention is absolutely void in the sight of their Lord. Allah's wrath is upon them and a grievous chastisement awaits them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
Allah it is Who sent down this Book with the Truth and the Balance. And what would make you know that the Hour (of Judgement) has drawn near?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those who do not believe in it seek to hasten its coming. But those who believe (in it) hold it in dread and know that the Hour (of Judgement) is bound to come. Lo, those who dispute concerning the coming of the Hour are gone far in error.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Allah is Most Gentle to His servants and grants sustenance to whomsoever He pleases. He is All-Strong, Most Mighty.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whoever seeks the harvest of the Hereafter, We shall increase for him his harvest, and whoever seeks the harvest of this world, We shall give him thereof; but he will have no share in the Hereafter.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Do they have any associates (of Allah) who have laid down for them a way pertaining to faith which Allah did not sanction? But for the fact that a decree had already been made, the matter between them would have been decided once and for all. Surely a grievous chastisement awaits the wrong-doers.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
You will see the wrongdoers fearful of the consequence of their deeds which will certainly overtake them. But those who have faith and do good deeds will be in the meadows of the Gardens, wherein they shall have whatever they desire from their Lord; that is the great Bounty.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
That is the Bounty of which Allah gives tidings to His servants who have faith and do good deeds. Tell them, (O Prophet): “I do not ask you for any recompense for my work except love towards kinsfolk.” Whoever does a good deed, We shall increase its merit for him. Surely Allah is Most Forgiving, Most Appreciative.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Do they say: “He has forged a lie against Allah?” If Allah so wanted He could seal up your heart. Allah blots out falsehood and confirms the truth by His Words. He is well aware of all the secrets hidden in the breasts (of people).\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
He it is Who accepts repentance from His servants and forgives sins and knows all what you do,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
and answers the prayers of those who believe and do good deeds and bestows upon them even more out of His Bounty. As for those who deny (the Truth), a grievous chastisement awaits them.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
If Allah were to grant ample sustenance to His servants they would go about transgressing in the land. But He sends down in due measure whatever (sustenance) He wills. Surely He is Well-Aware and All-Seeing concerning matters that relate to His servants.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
He it is Who sends down the rain after they despair of it, spreading out His Mercy. He is the Protector, the Immensely Praiseworthy.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And of His Signs is the creation of the heavens and the earth and the living creatures that He has spread out in them. He has the power to bring them together when He so wills.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
Whatever misfortune befalls you is a consequence of your own deeds. But much of it He forgives.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
You cannot frustrate Him in the earth; you have no protector nor helper against Allah.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And of His Signs are the ships that sail in the sea like mountains.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If He so wills, He can cause the winds to become still so that they will remain motionless on its surface. Surely there are many Signs in this for those who are wont to be steadfast and give thanks.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
He may, while forgiving much of the sins of those that ride these ships, drown them on account of some of their misdeeds.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
Then those who wrangle about Our Signs will come to know that there is no escape for them.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
That which has been given to you is only the wherewithal of the transient life of this world. But that which is with Allah is better and more enduring for those who believe and put their trust in their Lord;\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
who eschew grave sins and shameful deeds, and whenever they are angry, forgive;\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
who obey their Lord and establish Prayer; who conduct their affairs by consultation, and spend out of what We have bestowed upon them;\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
who, when a wrong is done to them, seek its redress.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The recompense of evil is evil the like of it. But he who forgives and makes amends, his reward lies with Allah. Surely He does not love the wrong-doers.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
There is no blame against him who avenges himself after he has been wronged.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
Blame attaches only to those who subject people to wrong and commit excesses on earth. A painful chastisement awaits them.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
But he who patiently endures and forgives, that is a conduct of great resolve.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
He whom Allah lets go astray, none after Him can be his protector. You will see that when the wrong-doers observe the chastisement, they will exclaim: “Is there any way to go back?”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
You shall see them, as they are brought face to face with the chastisement, in a state of abject humiliation, looking with a furtive glance. But the believers will say: “Surely the true losers are they who lose themselves and their kindred on the Day of Resurrection.” Lo, the wrong-doers will be in an enduring torment.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
They shall have no protectors to help them against Allah. For he whom Allah causes to go astray will have no way to save himself.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Accept the command of your Lord before there comes a Day from Allah that cannot be averted. On that Day there shall be no shelter for you, and none may change your predicament.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
(O Prophet), if they turn away from the Truth, know that We did not send you to them as their overseer. Your task is only to convey (the Message). Indeed when We give man a taste of Our Mercy, he exults in it. But if any misfortune afflicts them on account of their deeds, man is utterly ungrateful.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
The dominion of the heavens and the earth belongs to Allah. He creates whatever He pleases. He grants females to whomever He pleases and males to whomever He pleases,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
or grants them a mix of males and females, and causes whomever He pleases to be barren. He is All- Knowing, All-Powerful.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
It is not given to any human being that Allah should speak to him except through revelation, or from behind a veil, or that a messenger (an angel) be sent to him who reveals to him by Allah's leave whatever He wishes. He is All-High, Most Wise.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
Even so We revealed to you, (O Prophet), a spirit by Our command. (Ere to that) you knew neither what the Book nor what the faith was. But We made that spirit a light whereby We guide those of Our servants whom We please to the Right Way. Surely you are directing people to the Right Way,\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
the Way of Allah, to Whom belongs the dominion of all that is in the heavens and the earth. Lo, it is to Allah that all things ultimately revert.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha'. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the Clear Book;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
verily We have made it an Arabic Qur'an that you may understand.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
Indeed it is transcribed in the Original Book with Us; sublime and full of wisdom.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Should We divert this Good Counsel from you because you are a people immersed in extravagance?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
How many a Prophet did We send to the earlier peoples!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
Yet never did a Prophet come to them but they mocked him.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
We utterly destroyed them although they were greater in might than these. The examples of ancient peoples have gone before.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
Yet if you were to ask them: “Who created the heavens and the earth?” they will certainly say: “The All-Mighty, the All-Knowing has created them.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
He it is Who made this earth for you a cradle and made in it pathways for you that you may find the way to your destination;\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
He Who sent down water from the sky in a determined measure, and thereby We revived a dead land: likewise will you be raised up (from the earth) --\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
He Who created these pairs, all of them, and provided you ships and cattle on which you ride,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
so that when you are mounted upon them you may remember the bounty of your Lord, and say: “Glory be to Him Who has subjected this to Us whereas we did not have the strength to subdue it.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
It is to our Lord that we shall eventually return.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
Yet they have made some of His servants a part of Him. Indeed man is most evidently thankless.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Has Allah taken for Himself daughters out of those whom He creates and has chosen you to have sons?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
(They believe so although when) any of them is given tidings of the birth of a female child the like of which he assigns to the Merciful One, his countenance darkens and he is choked with grief.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
Do they assign to Allah one who grows up amidst ornaments and is not well-versed in the art of disputation?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
They claim that angels, who are Allah's chosen servants, are females. Did they witness how their body is constituted? Their testimony shall be written and they shall be called to account.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
They say: “Had the Merciful One so willed, we would never have worshipped these deities.” But they have no knowledge of the matter and are simply conjecturing.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or did We bestow upon them a Book before on whose authority they are holding on (to angel-worship)?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Nay; they simply claim: “We found our forefathers on a way, and we continue to find guidance in their footsteps.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
And thus it is: whenever We sent any warner to a city its affluent ones said: “We found our forefathers on a way and we continue to follow in their footsteps.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
Each Prophet asked them: “Will you do so even if we were to show you a way better than the way of your forefathers?” They answered: “We disbelieve in the religion with which you have been sent.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
Then We exacted retribution from them. So do consider the end of those who gave the lie (to the Prophets).\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
Call to mind when Abraham said to his father and his people: “I totally disown all whom you serve\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
except the One Who created me; and, behold, it is He Who will direct me to the Right Way.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And Abraham left behind this word to endure among his posterity so that they may return to it.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
(Even when they began worshipping others than Allah We did not destroy them) but bestowed sustenance on them and on their forefathers until there came to them the Truth and a Messenger who clearly expounded things to them.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
And when the Truth came to them they said: “This is just sorcery and we reject it.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
They say: “Why was this Qur'an not sent down upon some great man from the two (main) cities?”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Is it they who distribute the Mercy of your Lord? It is We Who have distributed their livelihood among them in the life of this world, and have raised some above others in rank that some of them may harness others to their service. Your Lord's Mercy is better than all the treasures that they hoard.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
Were it not that all mankind would become a single community (and follow the same way), We would have provided for all those who disbelieve in the Merciful One silver roofs for their houses, and (silver) stairs on which to go up,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
and (silver) doors to their houses, and couches (of silver) upon which they would recline;\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
or that they be made of gold. Surely all this is only the enjoyment of the life of the world. But (true prosperity) in the Hereafter with Your Lord is only for the God-fearing.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
He who is negligent to remember the Merciful One, to him We assign a satan as his boon companion,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
and these satans hinder them from the Right Path, while he still reckons himself to be rightly-guided.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
But when he comes to Us, he will say (to his satan): “Would that there had been between me and you the distance as between the East and the West. How evil a companion you were!”\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
(He will then be told): “Today it will not benefit you the least that after your wrong-doing you and your satans now share the chastisement.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
Can you, (O Prophet), then make the deaf hear, or direct to the Right Way the blind or one lost in manifest error?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
We shall inflict retribution on them, whether We take you away from the world (before We do that),\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
or make you see the end that We had promised them, for We have full power over them.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
So hold fast to what has been revealed to you. Surely you are on the Straight Way.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
Verily it is a great source of eminence for you and your people, and soon you will be called to account concerning that.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
Ask all Our Messengers whom We sent before you whether We had appointed any deities beside the Merciful One to be worshipped.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
Indeed We sent Moses with Our Signs to Pharaoh and his nobles. He told them: “I am a Messenger of the Lord of the Universe.”\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
Yet when he brought forth Clear Signs from Us, then lo, they burst into laughter.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
Every Sign that We showed them was greater than its predecessor; and then We seized them with Our chastisement so that they may return (to the Right Way).\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
(Whenever they faced an affliction) they would say: “O magician, pray for us to your Lord according to your station with Him. We shall certainly be guided to the Right Way.”\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But lo, each time We removed Our affliction from them, they would go back on their word.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And Pharaoh proclaimed among his people: “My people, do I not have dominion over Egypt, and are these streams not flowing beneath me? Can't you see?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
Am I better or this contemptible man who is scarcely able to express himself?\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
Why were bracelets of gold not bestowed upon him? Why did a retinue of angels not accompany him as attendants?”\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
He incited his people to levity and they obeyed him. Surely they were an iniquitous people.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
So when they incurred Our wrath, We exacted retribution from them, and drowned them all,\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
and made them a thing of the past and an example for those who would come after them.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
No sooner the example of the son of Mary was mentioned than, lo and behold, your people raised a clamour\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
and said: “Who is better, our deities or he?” They said so only out of contentiousness. They are a disputatious people.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He was no more than a servant (of Ours), one upon whom We bestowed Our favours and whom We made an example (of Our infinite power) for the Children of Israel.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
If We had so willed We could have made some of you into angels to become your successors on earth.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
Verily he [i.e., Jesus) is a portent of the Hour. So be in no doubt concerning it and follow Me. This is the Straight Way.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
Let not Satan hinder you (from believing in the Hour), for surely he is your open enemy.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
When Jesus came with Clear Signs and said: “I have brought wisdom to you that I may make plain to you some of the things you differ about. So fear Allah and follow me.\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
Allah is my Lord and your Lord; therefore, serve Him. That is the Straight Way.”\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
Then the factions fell apart among themselves. So woe to the wrong-doers from the chastisement of a grievous Day.\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Are they awaiting anything other than the Last Hour that it should suddenly come upon them without their even perceiving it?\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
On that Day even bosom friends shall become enemies to one another, all except the God-fearing.\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
(It will be said to them): “My servants, today you have nothing to fear or regret,\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
you who believed in Our Signs and had surrendered yourselves (to Us)!\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
Enter Paradise joyfully, both you and your spouses.”\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
Platters and cups of gold shall be passed around them, and there shall be all that they might desire and all that their eyes might delight in. (They shall be told): “Herein shall you abide for ever.\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
Such is the Paradise that you shall inherit by virtue of your good deeds in the life of the world.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
Herein you will have abundant fruits of which you will eat.”\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
But the evil-doers shall abide in the torment of Hell.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
Never will their torment be lightened for them. They shall remain in utter despair.\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
It is not We Who wronged them; rather, it is they who wronged themselves.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
They shall call out: “O Malik, let your Lord put an end to us.” He will reply: “You must stay on in it.\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
We brought you the Truth; but to the truth most of you were averse.”\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Have they contrived some scheme? If so, We too will contrive a scheme.\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Or do they think that We do not hear their secret talks and their whispering counsels? Yes, indeed We do and Our messengers [i.e., angels) are with them, writing.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say: “If the Merciful One had a son, I would have been the first one to worship him.”\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Exalted be the Lord of the heavens and the earth, the Lord of the Throne, above what they attribute to Him.\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
So leave them alone to indulge in their vanities and to frolic about until they encounter that Day of theirs against which they have been warned.\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
He it is Who is God in the heavens and the earth. He is the Most Wise, the All-Knowing.\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
Blessed is He Who has dominion over the heavens and the earth and all that is between them. With Him is the knowledge of the Hour; and to Him you shall all be sent back.\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
Those whom they call upon, instead of Allah have no power of intercession, except such that testify to the truth based on knowledge.\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
If you were to ask them: “Who created them?” they will surely say: “Allah.” Whence are they, then, being led astray?\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
We call to witness the cry of the Messenger: “O Lord, these are a people not wont to believe!”\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
Indulge them, (O Prophet), and say to them: “Peace to you.” For soon they shall come to know.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha'. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the Clear Book.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
We revealed it on a Blessed Night, for We were intent on warning;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
(We revealed it on the Night) wherein every matter is wisely determined\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
by Our command. Verily, We were set to send a Messenger\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
as a Mercy from your Lord. Surely He is All-Hearing, All-Seeing,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
the Lord of the heavens and the earth and of all that is between them: if you would only have sure faith.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no god but He: He gives life and causes death. He is your Lord and the Lord of your forefathers of yore.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
(But the fact is, they lack certainty) and frolic about in doubt.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
So watch for the Day when the sky will come down with a pall of smoke,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
enveloping people. That will be a grievous scourge.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
(People will then say): “Our Lord, remove this scourge from us; we shall believe.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
But how will they take heed? Such are they that a Messenger came to them clearly expounding the Truth,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
yet they turned away from him and said: “This is a well-tutored madman.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
Yet We will hold the scourge back for a while, (but no sooner than We will do so) you will revert to your old ways.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
The Day when We shall seize them with a mighty seizing, that will be the Day on which We shall inflict upon you full retribution.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
Indeed before that We subjected the Pharaonites to the same test. A noble Messenger came to them\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
(and said): “Deliver to me Allah's servants. I am a trustworthy Messenger to you,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
and do not exalt yourselves in defiance of Allah. I have come to you with a clear authority (as a Messenger).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
I have taken refuge with my Lord and your Lord lest you should attack me with stones.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
But if you do not believe what I say, leave me alone (and desist from laying hands on me).”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
Then he called upon his Lord: “These are a criminal people.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
(He was told): “Set out with My servants by night for you will certainly be pursued.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
And leave the sea behind you as calm as ever. Surely they are an army that is doomed to be drowned.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How many gardens did they leave behind, and how many fountains\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
and sown fields and splendid mansions,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
and the life of ease in which they took delight!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
Thus it was; and We made another people inherit all that.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
Then neither the sky shed tears over them nor the earth. They were granted no respite.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
Thus did We deliver the Children of Israel from the humiliating chastisement,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
from Pharaoh who was most prominent among the prodigals.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
We knowingly exalted them (i.e., the Children of Israel) above other peoples of the world\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
and bestowed upon them the Signs wherein lay an evident test for them.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
Indeed these people say:\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
“This is our first and only death, and we shall never be raised again.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
Bring back to us our fathers if you are truthful.”\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are these better or the people of Tubba and those who went before them? We destroyed them for they were a criminal people.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
It was not in idle sport that We created the heavens and the earth and all that is between them.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We did not create them except in Truth. But most of them do not know.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
The Day of Final Decision is the appointed time for all;\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
the Day when a friend shall be of no avail to his friend nor shall they be helped,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
except those to whom Allah shows mercy. He is the Most Mighty, the Most Compassionate.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
The tree of al-Zaqqum\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
shall be the food of the sinful.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like dregs of oil, it will boil in their bellies\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
like boiling water.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
“Seize him and drag him to the middle of the Blazing Fire,\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
then pour boiling water over his head as chastisement.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
Taste this, you are a person mighty and noble!\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
This is what you used to doubt.”\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Verily the God-fearing shall be in a secure place\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
amidst gardens and springs.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
Attired in silk and brocade, they shall be arrayed face to face.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
Thus shall it be: and We shall espouse them to fair, wide-eyed maidens.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
While resting in security, they shall call for all kinds of fruit.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
They shall not taste death except the death in this world. And Allah will save them from the chastisement of Hell\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
as a favour from your Lord. That is the great triumph.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
(O Prophet), We have made this Book easy in your tongue so that they may take heed.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
Wait, then; they too are waiting.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha'. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
This Book is a revelation from the Most Mighty, the Most Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Behold, for those who believe there are (myriad) Signs in the heavens and the earth\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
and in your own creation; and in the animals which He spreads out over the earth too there are Signs for those endowed with sure faith;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
and in the succession of night and day, and in the provision that Allah sends down from the sky wherewith He gives life to the earth after it had been lifeless, and in the change of the winds: (in all these) there are Signs for people who use reason.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
These are Allah's Signs that We rehearse to you in Truth. In what kind of discourse after Allah and His Signs will they, then, believe?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe to every guilty impostor\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
who hears Allah's Signs being rehearsed to him, and yet persists in his pride, as though he had not heard it. Announce to him, then, the tidings of a grievous chastisement.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
Whenever he comes to know anything of Our Signs, he makes them an object of jest. For such there awaits a humiliating chastisement.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
Hell is behind them. Their worldly earnings shall not avail them, nor those whom they took as protectors instead of Allah. An awesome chastisement lies in store for them.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This (Qur'an) is the true guidance. Those who deny the Signs of their Lord shall suffer the torment of a woeful scourge.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
Allah it is Who has subjected the sea to you so that ships may sail upon it at His bidding and you may seek of His Bounty and give thanks to Him.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
He has subjected to you all that is in the heavens and the earth, all being from Him. Verily there are Signs in this for those who reflect.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
(O Prophet), tell the believers to indulge those who have no fear of any evil days coming upon them from Allah so that Allah may Himself requite them for their deeds.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whoever acts righteously, does so to his own good; and whoever commits an evil will suffer its consequence. All of you will then be sent back to your Lord.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
Indeed We endowed the Children of Israel with the Book and Wisdom and Prophethood, and provided them with good things as sustenance, and exalted them above the peoples of the whole world.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
We gave them clear directions in matters pertaining to religion. Yet they differed among themselves (not out of ignorance but) after knowledge had come to them; and they did so out of the desire to commit excesses against one another. On the Day of Resurrection Allah will judge among them regarding what they had differed.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
And then We set you, (O Prophet), on a clear high road in religious matters. So follow that and do not follow the desires of those who do not know.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Surely they will be of no avail to you against Allah. Indeed the wrong-doers are friends of each other, whereas Allah is the friend of the God-fearing.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
These are the lights of discernment for people and guidance and mercy for those endowed with sure faith.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Do the evil-doers imagine that We shall make them equal to those who believe and do good, making their lives and deaths alike? How vile is their judgement!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
Allah created the heavens and the earth in Truth that each person may be requited for his deeds. They shall not be wronged.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Did you ever consider the case of him who took his desire as his god, and then Allah caused him to go astray despite knowledge, and sealed his hearing and his heart, and cast a veil over his sight? Who, after Allah, can direct him to the Right Way? Will you not take heed?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
They say: “There is no life other than our present worldly life: herein we live and we die, and it is only (the passage of) time that destroys us. Yet the fact is that they know nothing about this and are only conjecturing.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our Clear Signs are rehearsed to them, their only contention is: “Bring back to us our fathers if you are truthful.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Tell them, (O Prophet): “It is Allah Who gives you life and then causes you to die, and He it is Who will then bring all of you together on the Day of Resurrection, a Day regarding which there can be no doubt. Yet most people do not know.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmd{%
Allah's is the kingdom of the heavens and the earth, and on the Day when the Hour (of Resurrection) shall come to pass, the followers of falsehood shall be in utter loss.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
On that Day you shall see every people fallen on their knees. Every people will be summoned to come forth and see its Record and will be told: “Today you shall be requited for your deeds.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This is Our Record which bears witness against you with truth; We used to record all what you did.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
As for those who believe and act righteously, their Lord shall admit them to His Mercy. That indeed is the manifest triumph.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
But those who denied the Truth, they shall be told: “Were My Signs not rehearsed to you? But you waxed proud and became a guilty people.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
And when it was said to them: “Surely Allah's promise is true, and there is no doubt regarding the Hour of Resurrection,” you were wont to say: “We do not know what the Hour (of Resurrection) is. We are simply making conjectures and are not at all certain.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
(On that Day) the evil of their deeds will become apparent to them and what they had mocked at will encompass them,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
and it will be said: “We will forget you today as you forgot the meeting of this Day of yours. The Fire shall now be your abode, and you shall have none to come to your aid.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
You reached this end because you made Allah's Signs an object of jest and the life of the world deluded you.” So they shall not be taken out of the Fire nor shall they be asked to make amends (and thus please their Lord).\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
So all praise be to Allah, the Lord of the heavens, the Lord of the earth, the Lord of the whole Universe.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
His is the glory in the heavens and the earth. He is the Most Mighty, the Most Wise.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha'. Mim.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The revelation of this Book is from Allah, the Most Mighty, the Most Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We have created the heavens and the earth and all that is between them in Truth and for an appointed term. But those who disbelieve have turned away from what they were warned against.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Tell them, (O Prophet): “Did you consider those whom you call upon beside Allah? Show me, which part of the earth they created? Or do they have any share in creating the heavens? Bring to me any Scripture earlier than this one, or any vestige of knowledge (in support of your belief) if you are truthful.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
Who is farther strayed from the Right Path than he who calls upon others than Allah that cannot answer his call till the Day of Resurrection, the while they are not even conscious that callers are calling upon them?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
When all human beings will be gathered together those who had been called upon will become the enemies to their votaries and will disown their worship.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
When Our Clear Messages are rehearsed to them, the unbelievers exclaim about the Truth when it came to them: “This is plain sorcery.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Do they claim that the Messenger himself has fabricated it? (If so), tell them: “If I have fabricated it, then you have no power to protect me from Allah's chastisement. He knows well the idle talk in which you indulge. He suffices as a witness between me and you. He is Most Forgiving, Most Merciful.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Tell them: “I am not the first of the Messengers; and I do not know what shall be done with me or with you. I follow only what is revealed to me, and I am nothing but a plain warner.”\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Tell them, (O Prophet): “Did you consider (what would be your end) if this Qur'an were indeed from Allah and yet you rejected it? And this even though a witness from the Children of Israel has testified to the like of it. But he believed, while you waxed arrogant. Verily Allah does not guide such wrong-doers to the Right Way.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
The unbelievers say to the believers: If there was any good in this Book, others would not have beaten us to its acceptance.” But since they have not been guided to it, they will certainly say: “This is an old fabrication.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
Yet before this the Book was revealed to Moses as a guide and a mercy. This Book, which confirms it, is in the Arabic tongue to warn the wrong-doers and to give good tidings to those who do good.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Surely those who said: “Our Lord is Allah” and then remained steadfast shall have nothing to fear nor to grieve.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
They are the people of Paradise. They shall remain in it forever as a reward for their deeds.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
We have enjoined man to be kind to his parents. In pain did his mother bear him and in pain did she give birth to him. The carrying of the child to his weaning is a period of thirty months. And when he is grown to full maturity and reaches the age of forty, he prays: “My Lord, dispose me that I may give thanks for the bounty that You have bestowed upon me and my parents, and dispose me that I may do righteous deeds that would please You, and also make my descendants righteous. I repent to You, and I am one of those who surrender themselves to You.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
Such are those from whom We accept their best deeds and whose evil deeds We overlook. They will be among the people of Paradise in consonance with the true promise made to them.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
But he who says to his parents: “Fie on you! Do you threaten me that I shall be resurrected, although myriad generations have passed away before me (and not one of them was resurrected)?” The parents beseech Allah (and say to their child): “Woe to you, have faith. Surely Allah's promise is true.” But he says: “All this is nothing but fables of olden times.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
It is against such that Allah's sentence (of punishment) has become due. They will join the communities of humans and jinn that have preceded them. Verily all of them will court utter loss.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
Of these all have ranks according to their deeds so that Allah may fully recompense them for their deeds. They shall not be wronged.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
And on the Day when the unbelievers will be exposed to the Fire, they will be told: “You have exhausted your share of the bounties in the life of the world, and you took your fill of enjoyments. So, degrading chastisement shall be yours on this Day for you waxed arrogant in the earth without justification and acted iniquitously.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
Recount to them the story of (Hud), the brother of (the tribe of) 'Ad. Hud warned his people beside the sand-dunes -- and there have been other warners before him and since his time -- saying: “Serve none but Allah. Verily I fear that the chastisement of an awesome day shall come upon you.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said: “Have you come to us to turn us away from our gods? Then, bring upon us the scourge that you threaten us with. Do so if you are truthful.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He replied: “Allah alone knows about this. I only convey to you the Message that I have been sent with. But I see that you are an ignorant people.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
When they saw the scourge advancing towards their valleys, they said: “This is a cloud that will bring much rain to us.” “By no means; it is what you had sought to hasten -- a wind-storm bearing a grievous chastisement\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
that will destroy everything by the command of its Lord.” Thereafter nothing was left to be seen except their dwellings. Thus do We requite the wrong-doers.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
We had established them firmly in a manner We have not established you. We had given them ears and eyes and hearts. But nothing availed them -- neither their ears, nor their eyes, nor their hearts, for they denied the Signs of Allah. Then what they had mocked at encompassed them.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
Surely We destroyed many a town around you. We sent Our Messages to them repeatedly and in diverse forms that they may eschew (their evil ways) and return (to Allah).\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
So why did those whom they had set up as gods apart from Allah, hoping that they would bring them nearer to Him, not come to their aid? Instead, they failed them. This was the end of the lie they had fabricated and the false beliefs they had invented.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
And call to mind when We sent to you a party of the jinn that they may listen to the Qur'an. When they reached the place (where you were reciting the Qur'an), they said to one another: “Be silent (and listen).” And when the recitation ended, they went back to their people as warners.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said: “Our people, We have heard a Scripture revealed after Moses, verifying the Scriptures revealed before it; it guides to the Truth and to the Straight Way.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
Our people, respond to the call of him who calls you to Allah and believe in him. Allah will forgive your sins and will protect you from a grievous chastisement.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
And he who does not respond to the one who calls to Allah will not be able to frustrate Him on earth, nor will they have anyone to protect them from Allah. Such people are in manifest error.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Do they not see that Allah, Who created the heavens and the earth -- and creating them did not wear Him out -- has the power to bring the dead back to life? Why not! He certainly has the power over everything.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
On the Day when the unbelievers will be brought within sight of the Fire, they will be asked: “Is this not the Truth?” and they will answer “Yes, by Our Lord (this is the Truth).” Allah will say: “Then suffer the chastisement as a requital for your disbelieving.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
So bear with patience, (O Prophet), even as the Messengers endowed with firmness of resolve (before you) bore with patience, and do not be hasty in their regard. The Day when they see what they had been warned against they will feel as though they had remained in the world no more than an hour of a day. (The Truth has been conveyed.) Will any, then, suffer perdition except those who disobey?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Allah has caused the works of those who disbelieve and hinder people from the way of Allah to go to waste.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
As for those who attained to faith and did righteous works and believed in what was revealed to Muhammad -- which indeed is the Truth from their Lord -- Allah has remitted their evil deeds and has set their condition right.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
That is because those who disbelieved followed falsehood whereas those who believed followed the Truth that came to them from their Lord. Thus does Allah set forth to people parables showing their true state.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
When you meet the unbelievers (in battle), smite their necks until you have crushed them, then bind your captives firmly; thereafter (you are entitled to) set them free, either by an act of grace, or against ransom, until the war ends. That is for you to do. If Allah had so willed, He would have Himself exacted retribution from them. (But He did not do so) that He may test some of you by means of others. As for those who are slain in the way of Allah, He shall never let their works go to waste.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will guide them and set their condition right\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
and will admit them to Paradise with which He has acquainted them.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
Believers, if you aid Allah, He will come to your aid and will plant your feet firmly.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
As to those who disbelieve, perdition lies in store for them and Allah has reduced their works to nought.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That was because they were averse to what Allah had revealed; so He let their works go to waste.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Have they not journeyed through the land to see the end of those who went before them? Allah utterly destroyed them. These unbelievers are doomed to the same end.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because Allah is the Protector of the believers whereas the unbelievers have none to protect them.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Allah shall admit those who believe and do righteous works to the Gardens beneath which rivers flow. As for the unbelievers, they enjoy the pleasures of this transient life and eat as cattle eat. The Fire shall be their resort.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
(O Prophet), how many are the cities that had greater power than your city that drove you out? We destroyed them and there was none to protect them.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
Then, can he, who is on a Clear Guidance from His Lord, be like him whose evil deeds have been embellished to him, and who pursued their lusts?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
Here is the parable of Paradise which the God-fearing have been promised: in it shall be rivers of incorruptible water, rivers of milk unchanging in taste, and rivers of wine, a delight to those that drink; and rivers of pure honey. In it they will have every kind of fruit as well as forgiveness from their Lord. Can such be like those who will abide in the Fire and will be given a boiling water to drink that will tear their bowels apart?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
Among them some give ear to you. But no sooner do they leave your presence than they ask those endowed with knowledge: “What is it that he said just now?” Such are those whose hearts Allah has sealed and who pursue their lusts.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
As for those who were led to the Guidance, Allah increases them in their guidance and causes them to grow in God-fearing.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Are they waiting, then, for anything else than the Last Hour to suddenly come upon them? Already some of its tokens have come. But when it does actually come upon them, where will any time be left for them to take heed?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
Know, therefore, (O Prophet), that there is no god but Allah, and ask forgiveness for your shortcomings and also for (the shortcomings of) believing men and believing women. Allah knows the places where you move about and where you dwell.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
The believers used to say: “Why is a surah (that would ordain fighting) not revealed?” But when a definitive surah was revealed wherein fighting was mentioned, you saw that those in whose hearts there was a sickness looked at you as though they were about to faint at the approach of death. Pity on them!\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
(They keep affirming their) obedience and saying good words. But when a course of action was clearly determined, it would have been better for them if they had proved true to Allah.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
Now, if you were to turn away, what else can be expected but that you will work corruption in the land and fly at each other's throats?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
It is these upon whom Allah has laid His curse: so He made them deaf and deprived them of their sight.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Do they, then, not reflect on the Qur'an? Or are there locks on their hearts?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Certainly those who have turned their backs on the True Guidance after it became manifest to them, Satan has embellished their ways for them and has buoyed them up with false hopes.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
This, because they said to those who are averse to the faith that Allah has revealed: “In some matters we shall obey you.” Allah has full knowledge of their secret parleys.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
But how will they fare when angels will take their souls at death and will carry them, striking their faces and backs?\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That is because they have followed a way that angered Allah, and have been averse to His good pleasure. So He reduced all their works to nought.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Or do they, in whose hearts there is a sickness, believe that Allah will not bring their failings to light?\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
If We were to so will, We could have shown them to you so that you would recognise them by their faces, and you would certainly know them by the manner of their speech. Allah knows all your deeds.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
We shall certainly test you until We know those of you who truly strive and remain steadfast, and will ascertain about you.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Those who disbelieved and barred others from Allah's Way and opposed the Messenger after the True Guidance had become manifest to them, they shall not be able to cause Allah the least harm; rather, Allah will reduce all their works to nought.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
Believers, obey Allah and obey the Messenger and do not cause your works to be nullified.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Verily Allah shall not forgive those who disbelieved and barred others from Allah's Way and clung to their unbelief until their death.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
So, be not faint-hearted and do not cry for peace. You shall prevail. Allah is with you and will not bring your works to nought.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The life of this world is but sport and amusement. If you believe and are God-fearing, He will grant you your reward, and will not ask you for your possessions.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He were to ask you for your possessions and press you (in that regard), you would have grown niggardly, and Allah would have brought your failings to light.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Behold, you are those who are called upon to spend in Allah's Way, but some of you are niggardly. Whoever is niggardly is in fact niggardly to himself. For Allah is All-Sufficient, whereas it is you who are in need of Him. If you turn away, He will replace you by a people other than you, and they will not be like you.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen (O Prophet), surely We have granted you a clear victory\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
so that Allah may forgive you your shortcomings, whether earlier or later, and may complete His favours upon you and guide you to the Straight Way,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
and that Allah may bestow upon you a mighty help.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
He it is Who bestowed inner peace on the hearts of the believers so that they may grow yet more firm in their faith. To Allah belong the legions of the heavens and the earth; Allah is All-Knowing, Most Wise.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
(He did this) to admit the believers, both men and women, to Gardens beneath which rivers flow, wherein they shall abide, and to efface their evil deeds from them. That, in Allah's sight, is the supreme triumph.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
(He also did this) to chastise the hypocrites, both men and women, and those who associate others in His Divinity, both men and women, and who harbour evil thoughts about Allah. They shall be afflicted with misfortune, Allah is wroth with them. He has laid His curse upon them and has prepared for them Hell. What an evil end!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
To Allah belong the legions of the heavens and the earth. Allah is Most Mighty, Most Wise.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
(O Prophet), We have sent you forth as a witness, as a bearer of good news, and as a warner\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
so that (all of) you may all believe in Allah and His Messenger, and support him, and revere him, and celebrate Allah's glory, morning and evening.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Those who swore fealty to you, (O Prophet), in fact swore fealty to Allah. The Hand of Allah is above their hands. So whoever breaks his covenant breaks it to his own hurt; and whoever fulfils the covenant that he made with Allah, He will bestow on him a great reward.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
(O Prophet), the bedouins who were left behind say to you: “We were occupied with our goods and families. So ask forgiveness for us.” They say with their tongues what is not in their hearts. Say to them: “Who can be of any avail to you against Allah if He should intend to cause you any harm or confer upon you any benefit?” Allah is well aware of all that you do.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
(But the truth is not what you say.) You had imagined that the Messenger and the believers would never return to their families, and this notion was embellished in your hearts. You harboured an evil thought, and you are an immensely evil people.”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
As for those who do not believe in Allah and His Messenger, for such unbelievers We have prepared a Blazing Fire.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
To Allah belongs the kingdom of the heavens and the earth. He forgives whom He pleases and chastises whom He pleases. He is Most Forgiving, Most Compassionate.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
When you press forth for the spoils, those who were left behind will say: “Let us accompany you.” They want to change the command of Allah. Say to them (in clear words): “You shall not accompany us. Thus has Allah already said.” Then they will say: “Nay; but you are jealous of us.” The truth is that they understand little.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say to the bedouins who were left behind: “You will be called against those who possess great might and be asked to fight against them unless they surrender. If you obey (the command to fight), Allah will bestow upon you a goodly reward. But if you turn away, as you turned away before, He shall inflict upon you a grievous chastisement.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
There is no blame on the blind, nor on the lame, nor on the sick (if they do not go forth to fight). Allah will admit those who obey Allah and His Messenger to the Gardens beneath which rivers flow and will inflict a grievous chastisement on those who turn away.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Allah was much pleased with the believers when they swore fealty to you under the tree. He knew what was in their hearts. So He bestowed inner peace upon them and rewarded them with a victory near at hand\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
and with abundant spoils which they shall acquire. Allah is Most Mighty, Most Wise.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah has promised you abundant spoils which you shall acquire. He has instantly granted you this (victory) and has restrained the hands of people from you that it may be a Sign for the believers and He may guide you to a Straight Way.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
He also promises you other spoils which you have not yet taken, but Allah has encompassed them. Allah has power over everything.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
Had the unbelievers fought against you at that time, they would have turned their backs (in flight), and would have found none to protect or help them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
Such is Allah's Way that has come down from the past. Never shall you find any change in the Way of Allah.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
He it is Who restrained their hands from you, and your hands from them in the valley of Makkah, even though He had made you victorious against them. Allah was watching all that you did.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
They are the ones who disbelieved and barred you from the Inviolable Mosque and prevented the animals you had designated for sacrifice from reaching the place of their offering. If it had not been for the believing men and believing women (who lived in Makkah and) whom you did not know, and had there not been the fear that you might trample on them and unwittingly incur blame on their account, (then fighting would not have been put to a stop. It was stopped so that) Allah may admit to His Mercy whomsoever He pleases. Had those believers been separated from the rest, We would certainly have inflicted a grievous chastise-ment on those of them [i.e. the Makkans) who disbelieved.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
(This is why) when the unbelievers set in their hearts a fierce bigotry -- the bigotry of ignorance -- Allah bestowed inner peace upon His Messenger and upon the believers and made the word of piety binding on them. They were more deserving and worthier thereof. Allah has knowledge of everything.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Allah indeed showed His Messenger the true vision, one fully in accord with reality. If Allah so wills you shall certainly enter the Inviolable Mosque, in full security, you will shave your heads and cut your hair short, and do so without any fear. He knew what you did not know, and He granted you a victory near at hand even before (the fulfilment of the vision).\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
He it is Who sent His Messenger with the True Guidance and the Religion of Truth that He may make it prevail over every religion. Sufficient is Allah as a witness (to this).\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is Allah's Messenger, and those who are with him are firm with the unbelievers but compassionate with one another. You see them occupied in bowing and prostrating and in seeking Allah's bounty and good pleasure. They are distinguished from others by the marks of prostration on their faces. Thus are they described in the Torah. And their parable in the Gospel is that of a tilth that puts forth its shoot, then strengthens it so that it becomes stout and stands firmly on its stem. This is a sight pleasing to the sowers and one by which the unbelievers will be enraged. As for those who believe and do righteous deeds, Allah has promised them forgiveness and a great reward.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen Believers, do not advance before Allah and His Messenger, and fear Allah. Verily Allah is All-Hearing, All-Knowing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
Believers, do not raise your voices above the voice of the Prophet and when speaking to him do not speak aloud as you speak aloud to one another, lest all your deeds are reduced to nothing without your even realising it.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
The ones who lower their voices in the presence of the Messenger of Allah are those whose hearts Allah has tested for God-fearing. Theirs shall be forgiveness and a great reward.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Surely most of those who call out to you, (O Prophet), from behind the apartments, are devoid of understanding.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
If they were patient until you went out to them, that would have been better for them. Allah is Most Forgiving, Most Merciful.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
Believers, when an ungodly person brings to you a piece of news, carefully ascertain its truth, lest you should hurt a people unwittingly and thereafter repent at what you did.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
Know that Allah's Messenger is among you. Were he to follow you in many an affair, you yourselves would suffer. But Allah has endeared faith to you and has embellished it in your hearts, and has made unbelief and evil-doing and disobedience abhorrent to you. Such are those who are rightly guided,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
by Allah's favour and bounty. Allah is All-Knowing, All-Wise.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
If two parties of the believers happen to fight, make peace between them. But then, if one of them transgresses against the other, fight the one that transgresses until it reverts to Allah's command. And if it does revert, make peace between them with justice, and be equitable for Allah loves the equitable.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
Surely the believers are none but brothers unto one another, so set things right between your brothers, and have fear of Allah that you may be shown mercy.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
Believers, let not a group (of men) scoff at another group, it may well be that the latter (at whom they scoff) are better than they; nor let a group of women scoff at another group, it may well be that the latter are better than they. And do not taunt one another, nor revile one another by nicknames. It is an evil thing to gain notoriety for ungodliness after belief. Those who do not repent are indeed the wrong-doers.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
Believers, avoid being excessively suspicious, for some suspicion is a sin. Do not spy, nor backbite one another. Would any of you like to eat the flesh of his dead brother? You would surely detest it. Have fear of Allah. Surely Allah is much prone to accept repentance, is Most Compassionate.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
Human beings, We created you all from a male and a female, and made you into nations and tribes so that you may know one another. Verily the noblest of you in the sight of Allah is the most God-fearing of you. Surely Allah is All-Knowing, All-Aware.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The Bedouins say: “We believe.” (O Prophet), say to them: “You do not believe; you should rather say: 'We have submitted'”; for belief has not yet entered your hearts. If you obey Allah and His Messenger, He will not diminish anything from the reward of any of your deeds. Surely Allah is Most Forgiving, Most Compassionate.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
Indeed the ones possessed of true faith are those who believed in Allah and His Messenger and then they did not entertain any doubt and strove hard in the Way of Allah with their lives and their possessions. These are the truthful ones.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say, (O Prophet), (to these pretenders to faith): “Are you apprising Allah of your faith? Allah knows all that is in the heavens and the earth. Allah has full knowledge of everything.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They count it as a favour to you that they accepted Islam. Say: “Do not regard your (accepting) Islam as a favour to me; rather, Allah has bestowed a favour on you by guiding you to faith, if you are truthful (in your claim to be believers).\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
Surely Allah knows every hidden thing of the heavens and the earth. Allah sees all that you do.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf. By the glorious Qur'an.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
Nay; they wondered that a warner should have come to them from among themselves. The unbelievers said: “This indeed is a strange thing.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
What! When we are dead and reduced to mere dust, (shall we be raised to life)? Such a return is far-fetched.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
(Thus do they imagine, although) We know well what the earth takes away from them. With Us is a Record that preserves everything.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
They gave the lie to the Truth when it came to them. So they are now in a state of great perplexity.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
Did they never observe the sky above them: how We built it and beautified it; and it has no cracks;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
and We have spread out the earth, and have set upon it firm mountains, and have caused it to bring out plants of all beauteous kinds?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
All these are to serve as eye openers and as a lesson to every being who is prone to turn (to the Truth).\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
We also sent down blessed water from the heaven, wherewith We caused gardens and harvest-grain to grow,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
and tall palm-trees with their thickly-clustered spathes;\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
all this as sustenance for Our servants. And thus We do bring the dead land back to life with water. Such shall be the coming forth (of human beings from the earth).\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
In the past Noah's people, and the people of Rass and Thamud gave the lie (to Messengers),\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
and so did 'Ad, and Pharaoh and Lot's brethren,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
and the people of Aykah, and the people of Tubba'. They all gave the lie to the Messengers. Thereafter My threat of chastisement against them was fulfilled.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
Did We, then, become worn out by the first creation? Not at all; but they are in doubt about a fresh creation.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
Surely We have created man, and We know the promptings of his heart, and We are nearer to him than even his jugular vein.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
Moreover, there are two scribes, one each sitting on the right and the left, recording everything.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
He utters not a word, but there is a vigilant watcher at hand.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
Lo, the agony of death has indeed come with the Truth. That is what you had sought to avoid.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And then the Trumpet was blown. This is the day of the promised chastisement.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
Everyone has come, each attended by one who will drive him on, and another who will bear witness.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
You were heedless of this. Now We have removed your veil and so your vision today is sharp.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
His companion said: “Here is he who was in my charge.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
The command was given: “Cast into Hell every hardened, stubborn unbeliever,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
who hinders good, exceeds the limits, is immersed in doubts,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
and has set up another deity with Allah. Hurl him into the grievous torment.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His companion said: “I did not incite him to rebel; he was far gone into error of his own accord.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
(It was said): “Do not remonstrate in My presence. I had warned you.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
My Word is not changed; and never do I inflict the least wrong upon My servants.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
On that Day We shall ask Hell: “Are you full?” And it will reply: “Are there any more?”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And when Paradise shall be brought close to the God-fearing, and will no longer be far away,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
it will be said: “This is what you were promised, a promise made to everyone who turned much (to Allah) and was watchful of his conduct,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
to everyone who feared the Merciful One though He is beyond the reach of perception, to everyone who has come with a heart ever wont to turn (to Him).\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
Enter this Paradise in peace.” That will be the Day of Eternity.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
Therein they shall get whatever they desire; and with Us there is even more.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
How many a nation did We destroy before them that were stronger in prowess than these. They searched about the lands of the world. But could they find a refuge?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Verily there is a lesson in this for everyone who has a (sound) heart and who listens with an attentive mind.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
We created the heavens and the earth and all that is between them in six days, and weariness did not even touch Us.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
Hence bear with patience whatever they say, and celebrate your Lord's glory before the rising of the sun and before its setting;\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
and in the night, too, celebrate His glory, in the wake of prostration.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
Hearken on the Day when the caller will call from a place nearby,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
the Day when they shall hear the Blast in truth. That will be the Day (for the dead) to come forth.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
Surely it is We Who give life and cause death, and to Us shall all return\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
on the Day when the earth will be rent asunder and people, rising from it, will hasten forth. To assemble them all will be easy for Us.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
(O Prophet), We are well aware of what they say; and you are not required to force things on them. So exhort with the Qur'an all those who fear My warning.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By the winds which scatter dust,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
which carry clouds laden with water,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
which then smoothly speed along,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
and execute the great task of apportioning (rainfall):\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
surely what you are being warned against is true,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
and the Judgement shall doubtlessly take place.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the heaven with its numerous forms:\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
surely you are at variance (about the Hereafter);\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
though only those who are averse to the Truth will turn away from (believing in it).\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Doomed are the conjecturers\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
who are steeped in ignorance and heedlessness.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask: “When will the Day of Judgement be?”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
It will be the Day when they shall be scourged by the Fire\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
(and be told): “Taste your ordeal! This is what you were seeking to hasten.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
As for the God-fearing, they shall be in the midst of gardens and fountains,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
joyously receiving what their Lord will have granted them. Verily they did good works before (the coming of this Day):\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
they used to sleep but little by night,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
and would ask for forgiveness at dawn,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
and in their wealth there was a rightful share for him who would ask and for the destitute.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
There are many Signs on earth for those of sure faith,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
and also in your own selves. Do you not see?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in heaven is your provision and also what you are being promised.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
So, by the Lord of the heaven and the earth, this is certainly true, as true as the fact of your speaking.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
(O Prophet), did the story of Abraham's honoured guests reach you?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they came to him, they said: “Peace”; he said: “Peace also be to you; (you seem to be) a group of strangers.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he went back to his family and brought a fat roasted calf\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
and laid it before them, saying: “Will you not eat?”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
Then he became afraid of them. They said: “Fear not,” and announced to him the good news of (the birth of) a boy endowed with knowledge.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
So hearing his wife went forth shouting. She struck her face and exclaimed: “A barren old woman am I.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said: “So has your Lord said (that you shall have a boy). Surely He is Most Wise, All-Knowing.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
Abraham said: “Envoys (of Allah), what is your errand?”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They replied: “Behold, we have been sent to a wicked people\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
that we may unleash a shower of clay-stones\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
marked by your Lord upon those who go beyond the limits.”\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
Then We evacuated there from all the believers\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
– and We did not find there any, apart from a single house of Muslims –\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
and We left therein a Sign for those who fear the grievous chastisement.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
There is also a Sign for you in the story of Moses when We sent him with a clear authority to Pharaoh.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
But Pharaoh turned away, showing arrogance on account of his power, and said (about Moses): “He is either a sorcerer or a madman.”\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We seized him and his hosts, and cast them into the sea. He became an object of much blame.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
There is also a Sign for you in (the story of) Ad, when We let loose upon them an ominous wind\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
that left nothing that it came upon without reducing it to rubble.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
There is also a Sign for you in (the story of) Thamud. They were told: “Enjoy yourselves for a while.”\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
But they brazenly disobeyed their Lord's command, and then a sudden chastisement overtook them while they looked on.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
They were unable even to stand up or protect themselves.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
Before all these We destroyed the people of Noah: they were a wicked people.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
And heaven – We made it with Our Own Power and We have the Power to do so.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And the earth – We spread it out, and how well have We smoothed it!\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And of everything We have created pairs; perhaps you will take heed.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
Flee, therefore, to Allah. Surely I am a clear warner to you from Him;\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
and do not set up any deity with Allah. Surely I am a clear warner to you from Him.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Thus has it been (in the past): never did a Messenger come to the nations that preceded them but they said: “(He is) a sorcerer, or a mad-man.”\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Have they arrived at a common understanding concerning this? No; but they are a people given to transgression.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So turn your attention away from them; you shall incur no blame.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
Do, however, keep exhorting them; for exhortation benefits those endowed with faith.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
I created the jinn and humans for nothing else but that they may serve Me;\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I desire from them no provision, nor do I want them to feed Me.\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Surely Allah is the Bestower of all provision, the Lord of all power, the Strong.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
The wrong-doers shall receive a portion of the chastisements as their fellows (of yore). So let them not rush Me.\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
Woe, then, betide those who disbelieved in that Day of theirs which they are being asked to hold in dread.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the Mount,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
and the Book inscribed\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
on fine parchment;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
by the much-frequented House,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
by the elevated canopy;\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
and by the swelling sea:\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
verily your Lord's chastisement shall come to pass,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
none can avert that.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
(It shall come to pass) on the Day when the heaven will convulse in a great convulsion,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
and the mountains shall violently fly about.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
Woe, then, on that Day to those who give the lie (to this Message)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
and amuse themselves with vain argumentation.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
On the Day when they shall be thrust into Hell with a violent thrust (and shall be told):\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
“This is the Hell which you used to give the lie to.”\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
Is this, then, any feat of magic or are you unable to see?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
Go now and burn in it. It is all the same whether you bear it patiently or do not bear it with patience. You are only being recompensed for your deeds.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
Surely the God-fearing shall be in Gardens and bliss,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
enjoying what Allah will have endowed them with; and their Lord will have saved them from the torment of the Blazing Fire.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
(They will be told): “Eat and drink to your hearts' content as a reward for your deeds.”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
The God-fearing shall be reclining on couches facing each other, and We shall wed them to maidens with large, beautiful eyes.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
We shall unite the believers with those descendants of theirs who followed them in their faith, and shall not deny them any part of the reward for their good deeds. Every person is pledged to what he did.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
We shall provide them in abundance with all kinds of fruit and meat, whatever they may desire.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
They shall pass on to one another a cup that will incite neither levity nor sin.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
Youths as fair as hidden pearls will be set apart to wait upon them; they will be running to and fro to serve them.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
They will turn to one another and ask (regarding the past events).\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
They will say: “When we were living before among our kinsfolk we lived in constant fear (of Allah's displeasure).\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
Then Allah graced us with His favour and saved us from the chastisement of the scorching wind.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
Formerly we had always prayed to Him. Surely He is Most Benign, Most Compassionate.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
So exhort (them, O Prophet), for by your Lord's Grace, you are neither a soothsayer nor a madman.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or do they say: “He is a poet for whom we await an adverse turn of fortune.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Tell them: “Wait; I too am waiting with you.”\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Do their minds prompt them to say such things, or are they a people immersed in transgression?”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Do they say: “He has himself fabricated the Qur'an?” No; the truth is that they are altogether averse to believing.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
(If they are truthful in this), then let them produce a discourse of similar splendour.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Did they come into being without any creator? Or were they their own creators?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or is it they who created the heavens and the earth? No; the truth is that they lack sure faith.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or do they have your Lord's treasures in their keeping? Or have absolute authority over them?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or do they have a ladder whereon they can climb and attempt to listen (to what is transpiring in the Higher Realm)? Then, let any of them who has listened to it produce a clear proof of it.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or does Allah have daughters whereas you have sons?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or is it that you ask of them any recompense so that they should fear to be weighed down under the burden of debt?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or is it that they have access to (the Truths in) the realm beyond sense-perception which they are writing down?\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or are they contriving a stratagem against you? If so, that stratagem will rebound against the unbelievers.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Do they have any god other than Allah? Exalted be Allah above whatever they associate (with Him in His Divinity).\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
(So obstinate are they that) even if they were to see some fragments of the sky falling down they would still say: “It is only a mass of cloud.”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
So leave them alone until they encounter that Day of theirs when they shall be struck down,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
when their stratagem shall be of no avail to them, nor shall they be succoured.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
Surely a chastisement awaits the wrong-doers even before the coming of that Day; but most of them do not know.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
Be patient, then, (O Prophet), until the judgement of your Lord comes. For surely you are before Our eyes. And celebrate the praise of your Lord when you rise,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
and also celebrate His praise at night, and at the retreat of the stars.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the star when it sets:\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
your companion has neither strayed nor is he deluded;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
nor does he speak out of his desire.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
This is nothing but a revelation that is conveyed to him,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
something that a very powerful one has imparted to him,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
one endowed with immense wisdom. He came forth and stood poised,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
being on the higher horizon.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Then he drew near and hung above suspended,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
until he was two bows' length away, or nearer.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
Then he revealed to Allah's servant whatever he had to reveal.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
His heart added no untruth to what he saw.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
Are you, then, going to contend with him regarding what he sees with his eyes?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
Indeed he saw him a second time,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
by the lote-tree at the farthest boundary,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
near which is the Garden of Abode.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
(This was) when the lote-tree was covered with that which covered it.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
His eye did not waver, nor did it stray,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
and he certainly saw some of the greatest Signs of His Lord.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
Have you ever thought about al-Lat and al-Uzza,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
and about the third deity, al-Manat?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
Shall you have the male issues, and He the female issues?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
That is indeed an unfair division!\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
These are nothing but names that you and your forefathers have invented, for which Allah has sent down no authority. They are merely following their conjectures and their carnal desires although guidance has come to them from their Lord.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Does man imagine that whatever he wishes for is right for him?\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
To Allah belong both the Next World and the present.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
Numerous are the angels in the heavens; yet their intercession shall be of no avail, except in regard to those whom He grants the leave of intercession and whose plea He is pleased to accept.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Those who do not believe in the Hereafter give angels the names of females,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
although they have no knowledge regarding that. They only follow their conjecture and conjecture can never take the place of the Truth.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
So leave alone those who turn away from the remembrance of Us and who seek nothing but the life of the world –\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
that being the utmost of their knowledge. Surely your Lord fully knows those who have strayed away from His Path and He also fully knows those who are rightly guided.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
To Allah alone belongs whatever is in the heavens and whatever is in the earth. He will requite the evil-doers for their deeds and bestow a goodly reward on those who have done good,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
on those who avoid grave sins and shameful deeds, even if they may sometimes stumble into lesser offences. Surely your Lord is abounding in His Forgiveness. Very well is He aware of you since He produced you from the earth, and while you were still in your mothers' wombs and not yet born. So do not boastfully claim yourselves to be purified. He fully knows those that are truly Godfearing.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
(O Prophet), did you see him who turned away (from the Path of Allah),\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
who gave a little, and then stopped?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Does he have any knowledge of the world beyond the ken of sense-perception, and therefore, clearly sees (the Truth)?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Has he not been informed of what is in the Scrolls of Moses,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
and of Abraham, who lived up to the trust?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
“That no bearer of a burden shall bear the burden of another,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
and that man shall have nothing but what he has striven for,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
and that (the result of) his striving shall soon be seen,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
and that he shall then be fully recompensed,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
and that the final end is with your Lord,\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
and that He it is Who causes people to laugh and to cry,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
and that He it is Who causes death and grants life,\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
and He it is Who created the two kinds, the male and the female,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
from a drop of sperm when it was emitted,\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
and that it is for Him to grant the second life,\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
that He it is Who bestowed wealth and riches,\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
that He is the Lord of Sirius,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
that He it is Who destroyed the ancient 'Ad,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
and Thamud, leaving no trace of them,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
and that He it is Who destroyed the people of Noah before for they were much given to iniquity and transgression.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And He brought perdition upon the subverted cities\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
and caused them to be covered with that which He covered them with.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
So, which of your Lord's bounties will you doubt?”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This is a warning among the warnings of yore.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The imminent Hour has drawn near,\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
and none but Allah can avert it.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Will you, then, wonder at this?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
Will you laugh at it rather than weep?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
Will you occupy yourselves simply in merriment?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
Prostrate yourselves before Allah, and serve Him.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour of Resurrection drew near and the moon split asunder.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
(Regardless of any Signs these people see), they turn away and say: “This is an ongoing sorcery.”\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
They also gave the lie to (the splitting asunder of the moon) and only followed their desires. Yet everything is destined to reach an end.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
Surely there came to them narratives (of the ancient nations) that should suffice to deter (them from transgression),\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
narratives that are full of consummate wisdom. But warnings do not avail them.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
So turn away from them, (O Prophet). On the Day when a caller shall call them to a thing most terrible,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
with down-cast eyes they shall go forth from their graves, as though they were scattered locusts.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
They shall be hurrying forth towards the caller, and the unbelievers (who had once denied this Day), will say: “This is a woeful Day.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
Before them Noah's people also gave the lie (to his Message). They rejected Our servant as a liar, saying: “He is a madman”; and he was rebuffed.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
Then he called upon His Lord: “Verily I am vanquished; so come You to my aid.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
Thereupon We opened the gates of the sky for water to pour down,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
and We made the earth burst forth with springs, and all this water converged to fulfil that which had been decreed.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We bore Noah on the vessel built of planks and nails,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
which sailed on under Our supervision: a reward for him who had been shown ingratitude.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And We left the Ark as a Sign. Is there, then, any who will take heed?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
So how awesome were My chastisement and My warnings!\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
We have made this Qur'an easy as a reminder. Is there, then, any who will take heed?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
'Ad also gave the lie (to Hud). So how awesome were My chastisement and My warnings!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
We sent a tumultuous wind against them on a day of unremitting misfortune,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
which tore people away and hurled them as though they were trunks of uprooted palm-trees.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
So how awesome were My chastisement and My warnings!\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
We have made the Qur'an easy to derive lessons from. Is there, then, any who will take heed?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
Thamud gave the lie to the warnings,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
saying: “Are we to follow a single mortal, one from among ourselves? If we do that, we shall surely be in error and folly.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
Was there none but he to whom the Reminder could be vouchsafed excluding all others? Nay; he is an insolent liar.”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
(We told Our Messenger): “Tomorrow they shall know who is the insolent liar.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
We shall send the she-camel as a trial for them; so watch their end with patience.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
Let them know that the water should be divided between them and the she-camel, each availing their turn.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
Eventually, they summoned their companion, and he undertook the (outrageous) task and hamstrung the she-camel.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
So how awesome were My chastisement and My warnings!\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
Behold, We sent a single Blast against them, and they became like the trampled twigs of a sheep pen-builder.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
Surely We have made this Qur'an easy as a reminder. Is there, then, any who will take heed?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
Lot's people also gave the lie to the warnings,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
and behold, We let loose upon them a tempest which rained stones upon them, except upon Lot's household whom We rescued in the last hours of the night\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
as a favour from Us. Thus do We reward those who give thanks.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
Surely Lot warned his people that We shall seize them (with Our chastisement), but they doubted the warnings.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
Then they even solicited his guests from him, whereupon We blotted out their eyes, (telling them): “Now have a taste of My chastisement and My warnings.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
Indeed an abiding chastisement came upon them in the morning.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
So have a taste of My chastisement and My warnings.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
Surely We have made this Qur'an easy as a reminder. Is there, then, any who will take heed?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
Warnings also came to the Pharaonites,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
but they gave the lie to Our Signs, to all of them. Thereupon We seized them with the seizing of the Most Mighty, the Most Powerful.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your unbelievers (of Makkah) any better than they? Or have you been granted any immunity in the Scriptures?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or do they say: “We are a strong legion, strong enough for victory?”\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
Soon shall this legion be routed and shall turn their backs and flee.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
Nay; the Hour of Doom is their appointed time, and the Hour shall be more calamitous and bitter.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
The evil-doers are victims of error and madness.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
There shall come a Day when they will be dragged on their faces into the Fire and will be told: “Now taste the flame of Hell.”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
We have created everything in a determined measure.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
Our command consists of only one Word which is carried out in the twinkling of an eye.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
We did indeed destroy many like you. Is there, then, any who will heed?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
All their deeds are recorded in the Scrolls;\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
everything large or small, is duly inscribed.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Surely those who shun disobedience will dwell amidst Gardens and running streams\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
where they will be honourably seated in the presence of a King, Mighty in Power.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen The Merciful One\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
has taught the Qur'an,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
has created man,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
and has taught him articulate speech.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon follow a reckoning,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
and the stars and the trees all prostrate themselves,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
and He has raised up the heaven and has set a balance\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
that you may not transgress in the balance,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
but weigh things equitably and skimp not in the balance.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And He has set up the earth for all beings.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
Therein are fruit and palm-trees with their dates in sheaths,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
and a variety of corn with both husk and grain.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
Which of the bounties of your Lord will you twain – you men and jinn – then deny?\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He has created man from dry, rotten clay like the potter's,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
and has created the jinn from the flame of fire.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
Which of the wonders of your Lord's power will you twain – you men and jinn – then deny?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
Lord of the two easts and of the two wests is He.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
Which of the powers of your Lord will you twain – you men and jinn – then deny?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He unleashed the two seas so that they merge together,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
and yet there is a barrier between them which they may not overstep.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
Which of the wonders of your Lord will you twain – you men and jinn – then deny?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
From these seas come forth pearls and coral.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
Which of the wonders of your Lord's power will you twain – you men and jinn – then deny?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
His are the ships, towering on the sea like mountains.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
All that is on earth will perish,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
only the Person of your Lord, full of majesty and splendour, will endure.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
So which of the wonders of your Lord will you twain – you men and jinn – then deny?\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
All in the heavens and the earth entreat Him for their needs; a new, mighty task engages Him each day.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
Which of your Lord's laudable attributes will you twain – you men and jinn – then deny?\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
O you twain, who are a burden (on the earth), We shall attend to you and call you to account.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
(We shall then see), which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O company of jinn and men, if you have the power to go beyond the bounds of the heavens and the earth, go beyond them! Yet you will be unable to go beyond them for that requires infinite power.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
Which of your Lord's powers will you twain – you men and jinn – then deny?\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
(If you so venture) a flame of fire and smoke shall be lashed at you, which you shall be unable to withstand.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
Which of your Lord's powers will you twain – you men and jinn – then deny?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
(What will happen) when the heaven will be split asunder and will become crimson like leather?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
Which of your Lord's powers will you twain – you men and jinn – then deny?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
On that Day there will be no need to ask either men or jinn about their sins.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
(We shall see) which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The culprits shall be known by their marks, and shall be seized by their forelocks and their feet.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
Which of the powers of your Lord, will you twain – you men and jinn – then deny?\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
(It will be said): “This is the Hell that the culprits had cried lies to.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
They will keep circling around between Hell and boiling water.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
Which of your Lord's powers will you twain – you men and jinn – then deny?\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
For any who fears to stand before his Lord are two Gardens.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
Which of your Lord's favours will you twain – you men and jinn – then deny?\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
These Gardens will abound in green, blooming branches.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
Which of your Lord's favours will you twain – you men and jinn – then deny?\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
In each of the two Gardens are two flowing springs.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
Which of your Lord's favours will you twain – you men and jinn – then deny?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
In both these is a pair of every fruit.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
Which of your Lord's favours will you twain – you men and jinn – then deny?\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
They shall recline on couches lined with brocade, and within reach shall hang the fruits of the two Gardens.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
Which of your Lord's favours will you twain – you men and jinn – then deny?\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
In the midst of these shall be maidens with modest, restrained glances; maidens whom no man or jinn has ever touched before.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
Which of your Lord's favours will you twain – you men and jinn – then deny?\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
Lovely as rubies and pearls.\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Can the reward of goodness be any other than goodness?\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
Which of the laudable attributes of your Lord will you twain – you men and jinn – then deny?\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And besides these two there shall be two other Gardens.\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Two Gardens, dark green and fresh.\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
In them will be two gushing springs.\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
Therein will be fruits and dates and pomegranates.\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
In the midst of these will be maidens, good and comely.\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
There shall be maidens sheltered in tents.\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
No man or jinn ever touched them before.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
They shall be reclining on green cushions and splendid carpets.\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
Which of the favours of your Lord will you twain – you men and jinn – then deny?\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed be the name of your Lord, the Lord of Majesty and Glory.\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the Event will come to pass\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
– and then there will be no one to deny its occurrence –\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
(a calamitous Event) that shall turn things upside down:\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
when the earth will suddenly shake with a terrible shaking,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
and the mountains will crumble\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
and will scatter abroad into fine dust.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
You shall then become three groups.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
The People on the Right: and how fortunate will be the People on the Right!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And the People on the Left: and how miserable will be the People on the Left!\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
As for the Foremost, they will be the foremost!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
They shall be near-stationed (to their Lord),\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
in the Gardens of Bliss.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A throng of the ancients,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
and a few from later times.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
They (will be seated) on gold-encrusted couches,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
reclining on them, arrayed face to face;\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
immortal youths shall go about them\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
with goblets and ewers and a cup filled with a drink drawn from a running spring,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
a drink by which their minds will not be clouded nor will it cause drunkenness;\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
they will also go about them with the fruits of which they may choose,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmm{%
and with the flesh of any fowl that they may desire to eat;\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
and there shall be wide-eyed maidens,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
beautiful as pearls hidden in their shells.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
All this shall be theirs as a reward for their deeds.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
There they shall hear no idle talk nor any sinful speech.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
All talk will be sound and upright.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
As for the People on the Right, how fortunate shall be the people on the Right!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
They shall be in the midst of thornless lote trees,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
and flower-clad acacias,\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
and extended shade,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
and gushing water,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
and abundant fruit,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
never-ending and unforbidden.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
They shall be on upraised couches,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
and their spouses We shall have brought them into being afresh,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
and shall have made them virgins,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
intensely loving and of matching age.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
All this will be for the People on the Right;\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
a large throng from the ancients,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
and also a large throng from those of later times.\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
As for the People on the Left: how miserable will be the People on the Left!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
They will be in the midst of scorching wind and boiling water,\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
and a shade of thick, pitch-black smoke,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
which will neither be cool nor soothing.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
Surely they had lived before in luxury,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
and had persisted in the Great Sin.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
They used to say: “What! Once we are dead and are reduced to dust and bones, shall we still be raised to a new life from the dead?\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
(We) and our fore-fathers of yore?”\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Tell them, (O Prophet): “The earlier ones and the later ones\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
shall all be brought together on an appointed Day.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
Then you, the erring ones and those that gave the lie to the Truth,\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
shall all eat from the Tree of al-Zaqqum,\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
filling your bellies with it;\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
and thereupon you shall drink boiling water,\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
drinking it as thirsty camels do.”\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
Thus shall they be entertained on the Day of Recompense.\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We have created you, then why would you not confirm it?\qt@no{(57)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Did you ever consider the sperm that you emit?\qt@no{(58)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Do you create a child out of it, or are We its creators?\qt@no{(59)}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
It is We Who ordained death upon you and We are not to be frustrated.\qt@no{(60)}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
Had We so wished, nothing could have hindered Us from replacing you by others like yourselves, or transforming you into beings you know nothing about.\qt@no{(61)}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
You are well aware of the first creation; then, do you learn no lesson from it?\qt@no{(62)}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
Have you considered the seeds you till?\qt@no{(63)}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Is it you or We Who make them grow?\qt@no{(64)}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
If We so wished, We could have reduced your harvest to rubble, and you would have been left wonder-struck to exclaim:\qt@no{(65)}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
“We have been penalised;\qt@no{(66)}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
nay; we have been undone!”\qt@no{(67)}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
Did you cast a good look at the water that you drink?\qt@no{(68)}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Is it you who brought it down from the clouds or is it We Who brought it down?\qt@no{(69)}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We had so pleased, We could have made it bitter. So why would you not give thanks?\qt@no{(70)}}%
\qt@newcmd\qurantrans@en@mmmmml{%
Did you consider the fire which you kindle?\qt@no{(71)}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Did you make its tree grow or was it We Who made it grow?\qt@no{(72)}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We made it a reminder and a provision for the needy.\qt@no{(73)}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Glorify, then, (O Prophet), the name of your Great Lord.\qt@no{(74)}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
No! I swear by the positions of the stars –\qt@no{(75)}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
and this is indeed a mighty oath, if only you knew –\qt@no{(76)}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
that this indeed is a noble Qur'an,\qt@no{(77)}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
inscribed in a well-guarded Book,\qt@no{(78)}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
which none but the pure may touch;\qt@no{(79)}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
a revelation from the Lord of the Universe.\qt@no{(80)}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
Do you, then, take this discourse in light esteem,\qt@no{(81)}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
and your portion in it is simply that you denounce it as false?\qt@no{(82)}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Why, then, when the soul leaps up to the throat,\qt@no{(83)}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
the while you are helplessly watching that he is on the verge of death,\qt@no{(84)}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
– at that moment when We are closer to him than you, although you do not see (Us)\qt@no{(85)}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
if you are not subject to anyone's authority,\qt@no{(86)}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
why are you then not able to bring them back to life if you are truthful?\qt@no{(87)}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
So if he is one of those who are near-stationed (to Allah),\qt@no{(88)}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
then happiness and delight and Gardens of Bliss are his.\qt@no{(89)}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he is one of the People on the Right,\qt@no{(90)}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
he will be welcomed by the words: “Peace to you” from the People on the Right.\qt@no{(91)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
And if he is one of those who give the lie (to this Message) and go astray,\qt@no{(92)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
then he will be served boiling water,\qt@no{(93)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
and will be scorched by the Fire.\qt@no{(94)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
That indeed is the absolute truth.\qt@no{(95)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
So glorify the name of your Great Lord.\qt@no{(96)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen All that is in the heavens and the earth extols the glory of Allah. He is the Most Mighty, the Most Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
His is the dominion of the heavens and the earth. He gives life and causes death, and He has power over everything.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First and the Last, and the Manifest and the Hidden, and He has knowledge of everything.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
He it is Who created the heavens and the earth in six days and then established Himself on the Throne. He knows all that enters the earth and all that comes forth from it, and all that comes down from the heaven and all that goes up to it. He is with you wherever you are. Allah sees all that you do.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
His is the dominion of the heavens and the earth, and to Him are all matters referred (for judgement).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He causes the night to pass into the day, and causes the day to pass into the night, and He fully knows all that is hidden in the breasts of people.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in Allah and in His Messenger and expend of what He has entrusted to you. A great reward awaits those of you who believe and spend their wealth.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
How is it that you do not believe in Allah when the Messenger calls you to believe in your Lord and although he has taken a covenant from you, if indeed you are believers?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
He it is Who sends down Clear Signs to His servant so as to bring you out from darkness into light. Surely Allah is Most Kind and Most Compassionate to you.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
How is it that you do not expend in the Way of Allah when to Allah belongs the inheritance of the heavens and the earth? Those who spent their wealth and took part in fighting before the Victory cannot be equated (with those who spent their wealth and took part in fighting afterwards). They are higher in rank than those who spent and fought afterwards. But to each Allah has promised a good reward. Allah is well aware of all that you do.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is it that will give Allah a beautiful loan? A loan that Allah will repay after increasing it many times and grant him a generous reward.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
On that Day you will see believing men and women that their light will be running before them and on their right hands. (They will be told): “A good tiding to you today.” There shall be Gardens beneath which rivers flow; therein they shall abide. That indeed is the great triumph.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
On that Day the hypocrites, both men and women, shall say to the believers: “Look at us that we may extract some light from your light.” They will be told: “Go back and seek light for yourselves elsewhere.” Then a wall shall be erected between them with a door in it. On the inside of it there will be mercy, and on the outside of it there will be chastisement.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
The hypocrites will call out to the believers: “Were we not with you?” The believers will reply: “Yes; but you allowed yourselves to succumb to temptations, and you wavered and you remained in doubt and false expectations deluded you until Allah's command came to pass, and the Deluder deluded you concerning Allah.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
So no ransom shall be accepted from you today, nor from those who disbelieved. You are destined for the Fire. That will be your guardian. And that indeed is a grievous destination.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Is the time not come that the hearts of the believers should be humbled to Allah's remembrance and to the Truth that He has revealed, and that they should not be like those who were vouchsafed the Book and then a long time elapsed so that their hearts were hardened? A great many of them are now evil-doers.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know well that Allah revives the earth after it becomes lifeless. We have clearly shown Our Signs to you, perchance you will use your reason.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Verily those who give alms -- be they men or women, -- and give Allah a beautiful loan shall be repaid after increasing it many times; and theirs shall be a generous reward.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
In Allah's sight only those who truly believe in Allah and His Messengers are utterly truthful and true bearers of witness (for the sake of Allah). For them is their reward and their light. As for those who gave the lie to Our Signs, they are the people of Hell.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know well that the life of this world is merely sport and diversion and adornment and an object of your boasting with one another, and a rivalry in the multiplication of riches and children. Its likeness is that of rain: when it produces vegetation it delights the tillers. But then it withers and you see it turn yellow, and then it crumbles away. In the Hereafter there is (either) grievous chastisement (or) forgiveness from Allah and (His) good pleasure. The life of this world is nothing but delusion.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
So vie with one another in seeking to attain your Lord's forgiveness and a Garden whose width is as the width of the heaven and the earth, one which has been prepared for those who believe in Allah and His Messengers. That is Allah's bounty which He bestows upon those whom He pleases. Allah is the Lord of abounding bounty.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
No misfortune ever befalls on earth, nor on yourselves but We have inscribed it in the Book before We make it manifest. Surely that is easy for Allah.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
(We do so) that you may not grieve over the loss you suffer, nor exult over what He gave you. Allah does not love the vainglorious, the boastful,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
those who are niggardly and bid others to be niggardly. And he who turns away, (should know that) Allah is Self-Sufficient, Immensely Praiseworthy.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
Indeed We sent Our Messengers with Clear Signs, and sent down with them the Book and the Balance that people may uphold justice. And We sent down iron, wherein there is awesome power and many benefits for people, so that Allah may know who, without even having seen Him, helps Him and His Messengers. Surely Allah is Most Strong, Most Mighty.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
Indeed We sent forth Noah and Abraham and established in their line Prophecy and the Book. Then some of them embraced the guidance and many of them are wicked.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
In their wake, We sent a succession of Our Messengers, and raised Jesus, son of Mary, after all of them, and bestowed upon him the Evangel, and We set tenderness and mercy in the hearts of those that followed him. As for monasticism, it is they who invented it; We did not prescribe it for them. They themselves invented it in pursuit of Allah's good pleasure, and then they did not observe it as it ought to have been observed. So We gave their reward to those of them that believed. But many of them are wicked.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
Believers, have fear of Allah and believe in His Messenger, and He will grant you a two-fold portion of His Mercy, and will appoint for you a light whereby you shall walk; and He will forgive you. Allah is Most Forgiving, Most Compassionate.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
(You should do this) so that the People of the Book know that they have no control over Allah's Bounty, and that all bounty is in Allah's Hand; He bestows it on whomsoever He pleases. Allah is the Lord of abounding bounty.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Allah has surely heard the words of her who contends with you concerning her husband and complains to Allah. Allah hears what both of you say. Verily Allah is All- Hearing, All-Seeing.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Those among you who divorce their wives by declaring them to be their mothers, such are not their mothers; none are their mothers except those who gave birth to them. Indeed what they say is highly contemptible and false. Verily Allah is Most Pardoning, Most Forgiving.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
Those who declare their wives to be their mothers and thereafter go back on what they have said shall free a slave before they may touch each other. That is what you are exhorted to do. Allah is fully aware of all your deeds.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
And he who does not find a slave (to free), shall fast for two months consecutively before they may touch each other; and he who is unable to do so shall feed sixty needy people. All this is in order that you may truly believe in Allah and His Messenger. These are the bounds set by Allah; and a grievous chastisement awaits the unbelievers.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Verily those who oppose Allah and His Messenger shall be brought low even as those before them were brought low. Surely We have sent down Clear Signs; and a humiliating chastisement awaits the unbelievers;\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
a chastisement that shall come upon them on the Day when Allah will raise them all to a new life and will inform them of their deeds. Allah has recorded it all while they have forgotten it. Allah is a witness over everything.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Are you not aware that Allah knows whatever is in the heavens and whatever is in the earth? Never is there any whispering among three but He is their fourth; nor among five but He is their sixth; nor fewer nor more but He is with them wherever they may be. And then He will tell them on the Day of Judgement all that they have done. Surely Allah knows everything.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Have you not seen those who were forbidden to whisper and yet they engaged in what they had been forbidden? They secretly converse among themselves concerning sin and transgression and disobedience to the Messenger. And when they come to you, they greet you in a manner that Allah does not greet you, and say to themselves: “Why does Allah not chastise us for these utterances of ours?” Hell it is that shall suffice them, and in it will they burn. How woeful is their destination!\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
Believers, when you converse in secrecy, let that not be concerning sin and transgression and disobedience to the Messenger; rather, converse concerning virtue and piety. And fear Allah to Whom all of you shall be mustered.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Whispering is an act of Satan, one that aims at causing grief to the believers; yet without Allah's leave no harm can be caused to them. So in Allah should the believers put all their trust.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
Believers, when you are told: “Make room for one another in your assemblies,” then make room; Allah will bestow amplitude on you. And when it is said: “Rise up,” then rise up; Allah will raise to high ranks those of you who believe and are endowed with knowledge. Allah is well aware of all that you do.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
Believers, when you come to the Messenger for private consultation, offer some charity before your consultation with him. That is better for you and more conducive to purity. But if you find nothing to offer in charity, then know that Allah is Most Merciful, Most Compassionate.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Are you afraid that you will have to offer charity when you hold private conversation with the Prophet? But if you are unable to do so and Allah pardons you, then establish Prayer and pay Zakah, and obey Allah and His Messenger. Allah is well aware of all that you do.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Do you not see those who took for friends a people whom Allah is wroth with? They neither belong to you nor you to them. They swear to a falsehood, and they do so knowingly.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah has prepared for them a grievous chastisement. Indeed, evil are the acts in which they are engaged.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They have taken their oaths as a shield by means of which they hinder people from the Way of Allah. Theirs shall be a humiliating chastisement.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Neither their possessions nor their offspring will be of any avail to them against Allah. They are the people of the Fire; therein they shall abide.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
On the Day when Allah will raise them all from the dead they will swear before Him as they swear before you today, thinking that this will avail them. Behold, they are utter liars.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
Satan has gained mastery over them and has made them neglect remembering Allah. They are the party of Satan. Behold, the party of Satan will be the losers.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Verily those who oppose Allah and His Messenger will be among the most abject beings.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah has written: “Surely I will prevail; I and My Messengers.” Verily Allah is Most Strong, Most Mighty.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
You shall not find a people who believe in Allah and the Last Day befriending those who oppose Allah and His Messenger even though they be their fathers or their sons or their brothers or their kindred. He has inscribed faith in their hearts and has strengthened them with a spirit from Him, and He shall make them enter Gardens beneath which rivers flow. Therein they shall abide. Allah is well-pleased with them, and they are well-pleased with Him. They belong to Allah's party. Verily Allah's party shall prosper.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen All that is in the heavens and all that is in the earth extols Allah's Glory: He is the Most Mighty, the Most Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
He it is Who in the first assault drove forth the People of the Book that disbelieved from their homes at the first gathering of forces. You did not believe that they would leave; while they too thought that their fortresses would defend them against Allah. Then Allah came upon them from whence they did not even imagine, casting such terror into their hearts that they destroyed their homes by their own hands and their destruction was also caused by the hands of the believers. So learn a lesson from this, O you who have perceptive eyes!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
If Allah had not decreed banishment for them, He would certainly have chastised them in this world. As for the Hereafter, the chastisement of the Fire awaits them.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they set themselves against Allah and His Messenger; and whoever sets himself against Allah should know that Allah is surely Most Stern in retribution.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
The palm-trees that you cut down or those that you left standing on their roots, it was by Allah's leave that you did so. (Allah granted you this leave) in order that He might humiliate the evil-doers.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
Whatever Allah has taken away from them and bestowed (as spoils) on His Messenger for which you spurred neither horses nor camels; but Allah grants authority to His Messengers over whomsoever He pleases. Allah has power over everything.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
Whatever (from the possessions of the towns people) Allah has bestowed on His Messenger belongs to Allah, and to the Messenger, and to his kinsfolk, and to the orphans, and to the needy, and to the wayfarer so that it may not merely circulate between the rich among you. So accept whatever the Messenger gives you, and refrain from whatever he forbids you. And fear Allah: verily Allah is Most Stern in retribution.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
It also belongs to the poor Emigrants who have been driven out of their homes and their possessions, those who seek Allah's favour and good pleasure and help Allah and His Messenger. Such are the truthful ones.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
It also belongs to those who were already settled in this abode (of Hijrah) having come to faith before the (arrival of the) Muhajirun (Emigrants). They love those who have migrated to them and do not covet what has been given them; they even prefer them above themselves though poverty be their own lot. And whosoever are preserved from their own greed, such are the ones that will prosper.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
(And it also belongs to) those who came after them, and who pray: “Lord, forgive us and our brethren who have preceded us in faith, and do not put in our hearts any rancour towards those who believe. Lord, You are the Most Tender, the Most Compassionate.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Did you not see the hypocrites say to their brethren, the unbelievers among the People of the Book: “If you are banished we too will go with you and will not listen to anyone concerning you; and if war is waged against you, we will come to your aid.” But Allah bears witness that they are liars.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
To be sure, if they are banished, they will not go with them and if war is waged against them, they will not aid them; and even if they provide any aid to them, they will still turn their backs, and thereafter no aid will be forthcoming to them.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Surely they have greater dread for you in their hearts than for Allah. That is because they are a people who are devoid of understanding.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They will never fight against you as a body (in an open battlefield); and if they fight against you they will fight only in fortified townships or from behind walls. Intense is their hostility to one another. You reckon them united while their hearts are divided. That is because they are a people devoid of reason.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
They are like those who tasted the evil consequences of their deeds a short while before. A grievous chastisement awaits them.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
Their parable is that of Satan when he says to man: “Disbelieve,” but when he disbelieves, he says: “I am quit of you. Verily I fear Allah, the Lord of the Universe.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
In the end both will be in the Fire, and will abide in it. That is the recompense of the wrong-doers.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
Believers, fear Allah and let every person look to what he sends forward for the morrow. Fear Allah; Allah is well aware of all that you do.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And be not like those who forgot Allah and so He made them oblivious of themselves. They are the wicked ones.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Those destined for the Fire and those destined for Paradise cannot be alike. Verily it is those destined for Paradise who shall triumph.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
Had We sent down this Qur'an upon a mountain you would indeed have seen it humbling itself and breaking asunder out of fear of Allah. We propound such parables to people that they may reflect.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is Allah: there is no god but He; the Knower of the unseen and the manifest, He is the Most Merciful, the Most Compassionate.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is Allah: there is no god but He: the King, the Holy, the All-Peace, the Giver of security, the Overseer, the Most Mighty, the Overpowering, the All-Great. Exalted be He from whatever they associate with Him.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is Allah, the Planner, Executer and Fashioner of creation. His are the names most beautiful. Whatever is in the heavens and the earth extols His Glory. He is the Most Mighty, the Most Wise.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen Believers, if you have left (your homes and) have come forth to struggle in My Way and to seek My good pleasure, do not make friends with My enemies and your enemies. You befriend them whereas they have spurned the Truth that has come to you; and (such is their enmity that) they expel the Messenger and yourselves for no other reason than that you believe in Allah, your Lord. You send to them messages of friendship in secrecy, although I know well whatever you do, be it secretly or publicly. And whosoever of you does so has indeed strayed far away from the Straight Path.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
If they could overcome you, they would act as your foes and would hurt you by their hands and tongues, and would love to see you become unbelievers.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
On the Day of Resurrection neither your blood-kindred nor your own offspring will avail you. (On that Day) He will separate you. Allah sees all that you do.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
You have a good example in Abraham and his companions: they said to their people: “We totally dissociate ourselves from you, and from the deities that you worship instead of Allah. We renounce you and there has come to be enmity and hatred between us and you until you believe in Allah, the One True God.” (But you may not emulate) Abraham's saying to his father: “Certainly I will ask pardon for you, although I have no power over Allah to obtain anything on your behalf.” (And Abraham and his companions prayed): “Our Lord, in You have we put our trust, and to You have we turned, and to You is our ultimate return.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
Our Lord, do not make us a test for the unbelievers, and forgive us, our Lord. Surely You are Most Mighty, Most Wise.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
Indeed there is a good example for you in them; a good example for anyone who looks forward to Allah and the Last Day. As for him who turns away, Allah is All-Sufficient, Immensely Praiseworthy.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
It may well be that Allah will implant love between you and those with whom you have had enmity. Allah is Most Powerful; and Allah is Most Forgiving, Most Compassionate.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah does not forbid that you be kind and just to those who did not fight against you on account of religion, nor drove you out of your homes. Surely Allah loves those who are equitable.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
Allah only forbids you to be friends with those who have fought against you on account of religion and who have driven you out of your homes and have abetted in your expulsion. And any who make friends with them, they are the wrong-doers.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
Believers, when believing women come to you as Emigrants (in the cause of faith), examine them. Allah fully knows (the truth) concerning their faith. And when you have ascertained them to be believing women, do not send them back to the unbelievers. Those women are no longer lawful to the unbelievers, nor are those unbelievers lawful to those (believing) women. Give their unbelieving husbands whatever they have spent (as bridal-dues); and there is no offence for you to marry those women if you give them their bridal-dues. Do not hold on to your marriages with unbelieving women: ask for the return of the bridal-due you gave to your unbelieving wives and the unbelievers may ask for the return of the bridal-due they had given to their believing wives. Such is Allah's command. He judges between you. Allah is All-Knowing, Most Wise.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if you fail to receive from the unbelievers a part of the bridal-due of your disbelieving wives, and then your turn comes, pay to those who have been left on the other side an amount the like of the bridal-due that they have paid. And have fear of Allah in Whom you believe.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet, when believing women come to you and pledge to you that they will not associate aught with Allah in His Divinity, that they will not steal, that they will not commit illicit sexual intercourse, that they will not kill their children, that they will not bring forth a calumny between their hands and feet, and that they will not disobey you in anything known to be good, then accept their allegiance and ask Allah to forgive them. Surely Allah is Most Forgiving, Most Compassionate.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
Believers, do not make friends with those against whom Allah is wrathful and who are despaired of the Hereafter, as despaired as are the unbelievers lying in their graves.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen All that is in the heavens and all that is on earth extols Allah's glory. He is the Most Mighty, the Most Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
Believers, why do you profess that which you do not practise?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
It is most loathsome in the sight of Allah that you should profess what you do not practise.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Allah indeed loves those who fight in His Way as though they are a solid wall cemented with molten lead.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And call to mind when Moses said to his people: “O my people, why do you torment me when you know well that I am Allah's Messenger to you?” So when they deviated, Allah made their hearts deviant. Allah does not direct the evil-doers to the Right Way.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And call to mind when Jesus, son of Mary, said: “O Children of Israel, I am Allah's Messenger to you, I verify the Torah which has come before me, and I give you the glad tiding of a Messenger who shall come after me, his name being Ahmad.” Yet when he came to them with Clear Signs they said: “This is sheer trickery.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
Who would be more unjust than he who invents a lie about Allah the while he is being called to Islam? Allah does not direct such evildoing folk to the Right Way.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
They seek to extinguish Allah's light (by blowing) with their mouths, but Allah shall spread His light in all its fullness, howsoever the unbelievers may abhor this.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
He it is Who has sent forth the Messenger with the Guidance and the True Religion that He may make it prevail over all religion, however those that associate aught with Allah in His Divinity might dislike this.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
Believers, shall I direct you to a commerce that will deliver you from a grievous chastisement?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
Have faith in Allah and His Messenger and strive in the Way of Allah with your possessions and your lives. That is better for you if you only knew.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive you your sins and will admit you to Gardens beneath which rivers flow. He will lodge you in excellent mansions in the Gardens of eternity. That is the supreme triumph.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
He will also grant you the other favour that you desire: help from Allah and a victory that will come soon. Give glad tidings of this to the believers.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
Believers, become Allah's helpers, as Jesus, son of Mary, said to the disciples: “Who is my helper in (calling people) to Allah?” The disciples had responded by saying: “We are Allah's helpers.” Then a section of the Children of Israel believed and a section rejected the call. Thereafter We aided the believers against their enemies, and they prevailed.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen All that is in the heavens and all that is in the earth extols the glory of Allah, the Sovereign, the Holy, the All- Mighty, the All-Wise.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
He it is Who has sent to the gentiles a Messenger from among themselves, one who rehearses to them His verses, purifies their lives, and imparts to them the Book and the Wisdom although before that they were in utter error;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
and (He has also) sent him to those others who have not yet joined them. He is the Most Mighty, the Most Wise.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
Such is Allah's favour: He bestows it on whomsoever He pleases. Allah is the Lord of abounding favour.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The parable of those who were charged with the Torah and then they failed to live up to it is that of a donkey laden with books. Even more evil is the parable of the people who gave the lie to the Signs of Allah. Allah does not direct such wrong-doers to the Right Way.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Tell them: “O you who have become Judaised, if you arrogantly fancy that you are Allah's favourites to the exclusion of all people, then wish for death, if you are truthful in your claim.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But they shall never wish for death because of the (evil) deeds they have committed. Allah is well aware of these evil-doers.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Tell them: “The death from which you flee will certainly overtake you. Then you will be returned to Him Who fully knows what is hidden and what is manifest. Thereupon He will let you know all that you used to do.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
Believers, when the call for Prayer is made on Friday, hasten to the remembrance of Allah and give up all trading. That is better for you, if you only knew.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
But when the Prayer is ended, disperse in the land and seek Allah's Bounty, and remember Allah much so that you may prosper.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
Yet no sooner than they saw some trading or amusement, they flocked to it and left you standing by yourself. Tell them: “That which is with Allah is far better than amusement and trading. Allah is the Best Provider of sustenance.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen (O Prophet), when the hypocrites come to you, they say: “We bear witness that you are certainly Allah's Messenger.” Allah certainly knows that you are His Messenger. But Allah also bears witness that the hypocrites are utter liars!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They shelter behind their oath, and thus hinder their own selves and others from the Path of Allah. Evil indeed is what they do.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
All that is because they first believed and then disbelieved, and therefore a seal was set on their hearts; as a result they understand nothing.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
When you look at them, their persons are pleasing, and when they speak, you pay heed to what they say. But in truth they are (merely) beams of timber propped-up (against a wall). They consider every shout they hear to be directed against them. They are your utter enemies; guard against them. May Allah do away with them! How are they being turned away (from the Truth)?\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
When it is said to them: “Come, Allah's Messenger will seek forgiveness for you,” they (contemptuously) shake their heads and you see them holding back in pride.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
It is all the same for them whether you ask forgiveness for them or not; for Allah shall never forgive them. Surely Allah does not direct the transgressing folk to the Right Way.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
It is they who say: “Give nothing to those who are with the Messenger of Allah so that they may disperse.” (They say so although) the treasures of the heavens and the earth belong to Allah. But the hypocrites do not understand.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say: “When we return to Madinah, the honourable ones will drive out from it those that are abject.” In truth, all honour belongs to Allah, and to His Messenger, and to the believers. But the hypocrites do not know.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
Believers, let your possessions and your offspring not make you negligent of Allah's remembrance. For whoso does that, they will be the losers.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
And spend of what Allah has granted you by way of sustenance before death should come to any of you and he should say: “Lord, why did You not defer my return for a while so that I might give alms and be among the righteous?”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
But when a person's term comes to an end, Allah never grants any respite. Allah is well aware of all that you do.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen All that is in the heavens and all that is in the earth extols Allah's glory. His is the sovereignty and to Him is all praise due; He has power over everything.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
He it is Who has created you: and among you are those that deny the Truth and among you are those that believe in it. Allah observes all that you do.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He created the heavens and the earth with Truth and shaped you, giving you excellent shapes. And to Him is your ultimate return.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows what is in the heavens and the earth, and knows what you conceal and what you disclose. Allah even knows what lies hidden in the breasts of people.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Has the news of the unbelievers of the past not reached you? (They disbelieved) and then tasted its evil consequence. A grievous chastisement awaits them.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
This was because their Messengers would come to them with Clear Signs, but they would say: “Shall mortals (like ourselves) guide us to the Right Way?” They rejected the Truth and turned away. Thereupon Allah became unconcerned with them, for Allah is Self-Sufficient, Innately Praiseworthy.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
The unbelievers have vehemently contended that they shall not be raised to life. Say to them: “Yes, by my Lord, you shall surely be raised to life, and you shall certainly be fully informed of all that you did. That is easy enough for Allah.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
So believe in Allah and in His Messenger and in the Light that We have sent down. Allah is fully aware of what you do.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
(You shall come to know that) when He will assemble you on the Day of Gathering. That shall be the Day (to determine) mutual gains and losses. Whoever believes in Allah and acts righteously, Allah will have his evil deeds expunged and will admit him to Gardens beneath which rivers flow. Therein they shall abide forever. That is the supreme triumph.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
As for those who disbelieved and gave the lie to Our Signs: they shall be the inmates of the Fire, and will abide in it. That is a woeful resort!\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No misfortune ever befalls unless it be by Allah's leave. And whosoever has faith in Allah, Allah directs his heart along the Right Path. Allah has knowledge of everything.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
Obey Allah and obey the Messenger. But if you turn away from obedience, (then know that) Our Messenger has no other duty than to clearly convey the Truth.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah there is no god but He; in Allah should the believers put all their trust.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
Believers, there are enemies to you from among your spouses and your off-spring, so beware of them. But if you forgive and overlook their offences and pardon them, then surely Allah is Most Forgiving, Most Compassionate.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your possessions and your offspring are nothing but a trial for you. And there awaits a great reward for you with Allah.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
So hold Allah in awe as much as you can, and listen and obey, and be charitable. This is for your own good. And whoever remains safe from his own greediness, it is such that will prosper.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If you give Allah a goodly loan, He will increase it for you several fold and will forgive you. Allah is Most Appreciative, Most Forbearing.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
He knows that which is beyond the ken of perception as well as that which can be perceived. He is the Most Mighty, the Most Wise.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet, when you divorce women, divorce them for their waiting-period, and compute the waiting period accurately, and hold Allah, your Lord, in awe. Do not turn them out of their homes (during the waiting period) – nor should they go away (from their homes) – unless they have committed a manifestly evil deed. Such are the bounds set by Allah; and he who transgresses the bounds set by Allah commits a wrong against himself. You do not know: maybe Allah will cause something to happen to pave the way (for reconciliation).\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
And when they reach the end of their term (of waiting), then either honourably retain them (in the bond of wedlock) or honourably part with them, and call two persons of known probity as witnesses from among yourselves, and (let these witnesses) give upright testimony for the sake of Allah. That is to what all those that believe in Allah and the Last Day are exhorted. Allah will find a way out for him who fears Allah,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
and will provide him sustenance from whence he never even imagined. Whoever puts his trust in Allah, He shall suffice him. Surely Allah brings about what He decrees; Allah has set a measure for everything.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
The waiting period of those of your women who have lost all expectation of menstruation shall be three months in case you entertain any doubt; and the same shall apply to those who have not yet menstruated. As for pregnant women, their waiting period shall be until the delivery of their burden. Allah will create ease for him who fears Allah.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
This is the commandment of Allah that He has revealed to you. Whoever fears Allah, He will expunge his evil deeds and will richly reward him.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
(During the waiting period) lodge them according to your means wherever you dwell, and do not harass them to make them miserable. And if they are pregnant, provide for them maintenance until they have delivered their burden. And if they suckle your offspring whom they bore you, then give them due recompense, and graciously settle the question of compensation between yourselves by mutual understanding. But if you experience difficulty (in determining the compensation for suckling) then let another woman suckle the child.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Whoever has abundant means, let him spend according to his means; and he whose means are straitened, let him spend out of what Allah has given him. Allah does not burden any human being beyond the means that He has bestowed upon him. Possibly Allah will grant ease after hardship.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
How many towns rebelled against the commandment of their Lord and His Messengers. Then We called them to a stern accounting, and subjected them to a harrowing chastisement.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
So they tasted the evil fruit of their deeds; and the fruit of their deeds was utter loss.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah has laid in store for them a grievous chastisement. So fear Allah, O people of understanding who have attained to faith. Allah has sent down to you an Exhortation,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
a Messenger who rehearses to you Allah's verses that clearly expound the Guidance so that He may bring out those that believe and act righteously, from every kind of darkness into light. He will admit whosoever believes in Allah and acts righteously to Gardens beneath which rivers flow. They shall abide in them forever. For such has Allah made an excellent provision.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
Allah it is He Who created seven heavens, and, like them, the earth. His commandment descends among them. (All this is being stated so that you know) that Allah has power over everything, and that Allah encompasses all things in His knowledge.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O Prophet, why do you forbid what Allah has made lawful for you? Is it to please your wives? Allah is Most Forgiving, Most Compassionate.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Allah has prescribed for you a way for the absolution of your oaths. Allah is your Guardian. He is All-Knowing, Most Wise.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
The Prophet confided something to one of his wives and then she disclosed it (to another); so after Allah revealed to the Prophet (that she had disclosed that secret), he made a part of it known to her and passed over a part of it. And when he told her about this (i.e., that she had disclosed the secret entrusted to her), she asked: “Who informed you of this?” He said: “I was told of it by He Who is All-Knowing, All-Aware.”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If the two of you turn in repentance to Allah (that is better for you), for the hearts of both of you have swerved from the Straight Path. But if you support one another against the Prophet, then surely Allah is his Protector; and after that Gabriel and all righteous believers and the angels are all his supporters.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
Maybe if he were to divorce you, your Lord might grant him in exchange wives better than you – those who truly submit to Allah, are full of faith, obedient, disposed to repentance, and given to worship and fasting – both previously wedded ones and virgins.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
Believers, guard yourselves and your kindred against a Fire whose fuel is human beings and stones, a Fire held in the charge of fierce and stern angels who never disobey what He has commanded them, and always do what they are bidden.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
(It will then be said): “Unbelievers, make no excuses today. You are being recompensed for nothing else but your deeds.”\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
Believers, turn to Allah in sincere repentance; maybe your Lord will expunge your evil deeds and admit you to the Gardens beneath which rivers flow. This will be on the Day when Allah will not disgrace the Prophet and those who have embraced faith and are with him; their light will be running before them and on their right hands, and they will say: “Our Lord, perfect for us our light and forgive us. Surely You have power over everything.”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet, strive against the unbelievers and the hypocrites, and be severe with them. Hell shall be their resort. What a grievous end!\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah has set forth for the unbelievers the parable of the wives of Noah and Lot. They were wedded to two of Our righteous servants, but each acted treacherously with her husband, and their husbands could be of no avail to them against Allah. The two of them were told: “Enter the Fire with all the others who enter it.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
Allah has set forth for the believers the parable of Pharaoh's wife. She prayed: “My Lord, build for me a house with You in Paradise and deliver me from Pharaoh and his misdeeds; and deliver me from the iniquitous people.”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
Allah has also set forth the parable of Mary, the daughter of Imran, who guarded her chastity, and into whom We breathed of Our Spirit, and who testified to the words of her Lord and His Books. She was among the obedient.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed is He in Whose Hand is the dominion of the Universe, and Who has power over everything;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
Who created death and life that He might try you as to which of you is better in deed. He is the Most Mighty, the Most Forgiving;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
Who created the seven heavens one upon another. You will see no incongruity in the Merciful One's creation. Turn your vision again, can you see any flaw?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then turn your vision again, and then again; in the end your vision will come back to you, worn out and frustrated.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
We have adorned the lower heaven with lamps, and have made them a means to drive away the satans. We have prepared for them the chastisement of the Blazing Fire.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
The chastisement of Hell awaits those who disbelieve in their Lord. What a wretched destination!\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they will be cast into it, they will hear it roar as it boils,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
as though it will burst with rage. Every time a multitude is cast into it, its keepers will ask them: “Did no warner come to you?”\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They will say: “Yes, a warner came to us, but we gave the lie to him and said: 'Allah has revealed nothing. You are surely in huge error.'\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
They will say: 'If we had only listened and understood, we would not be among the inmates of the Blazing Fire.'”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
Thus will they confess their sins. Damned are these inmates of the Blazing Fire.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
Surely forgiveness and a mighty reward await those who fear Allah without seeing Him.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
Whether you speak in secrecy or aloud, (it is all the same to Allah). He even knows the secrets that lie hidden in the breasts of people.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Would He not know, He Who has created, when He is All-Subtle, All-Aware?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
He it is Who made the earth subservient to you. So traverse in its tracks and partake of the sustenance He has provided. To Him will you be resurrected.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Do you feel secure that He Who is in the heaven will not cause the earth to cave in with you, and then suddenly it will begin to rock violently?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Do you feel secure that He Who is in the heaven will not let loose upon you a storm of stones? Then shall you know what My warning is like!\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
Those who came before them also gave the lie (to the Messengers): then how awesome was My chastisement!\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Have they not seen birds above them spreading and closing their wings, with none holding them except the Merciful One? He oversees everything.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Which is your army that will come to your aid against the Merciful Lord? But the unbelievers are in utter delusion.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Who shall provide for you if He withholds His sustenance? Nay; but they persist in rebellion and aversion.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
Who is better guided: he who walks grovelling on his face, or he who walks upright on a Straight Path?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say: “He it is Who has brought you into being, and has given you hearing and sight, and has given you hearts to think and understand. How seldom do you give thanks!”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say: “Allah it is Who multiplied you in the earth and to Him you will be mustered.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
They say: “If you are truthful, tell us when will this promise (of the Hereafter) be fulfilled?”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say: “Allah alone knows about that; and I am no more than a plain warner.”\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
When they will see it near at hand, the faces of all those who had denied it will be distraught, and then they will be told: “This is the doom which you used to ask for.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say to them: “Did you ever consider: whether Allah destroys me and those that are with me, or shows mercy to us, who can protect the unbelievers from a grievous chastisement?”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say to them: “He is Merciful, and it is in Him that we believe, and it is in Him that we put all our trust. Soon will you know who is in manifest error.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say to them: “Did you even consider: if all the water that you have (in the wells) were to sink down into the depths of the earth, who will produce for you clear, flowing water?”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nun. By the pen and what the scribes write.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
By your Lord's Grace, you are not afflicted with madness,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
and surely yours shall be a never-ending reward,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
and you are certainly on the most exalted standard of moral excellence.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
So you will soon see, and they too will see,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
which of you is afflicted with madness.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Surely your Lord knows well those who have strayed from His Way just as He knows well those who are on the Right Way.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
Do not, then, yield to those who reject the Truth, decrying it as false;\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
they would wish you to be pliant so that they too may be pliant.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
And do not yield to any contemptible swearer,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
the fault-finder who goes around slandering,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
the hinderer of good, the transgressor, the sinful;\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
the coarse-grained, and above all mean and ignoble;\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
(who so acts) simply because he has wealth and sons,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
and whenever Our verses are rehearsed to him, he says: “These are fairy- tales of times gone by.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
Soon shall We brand him on his snout.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
We have put them [i.e., the Makkans] to test even as We put to test the owners of the orchard when they vowed that they would gather the fruit of their orchard in the morning,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
without making any allowance (for the will of Allah).\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
Thereupon a calamity from your Lord passed over it while they were asleep,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
and so by morning the orchard lay as though it had been fully harvested.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
At daybreak they called out to one another:\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
“Hurry to your orchard if you would gather its fruit.”\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So off they went, whispering to one another:\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
“No destitute person shall enter it today.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
They went forth early, believing that they had the power (to gather the fruit).\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But as soon as they beheld the orchard, (they cried out): “We have certainly lost the way;\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
rather, we are utterly ruined.”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
The best among them said: “Did I not say to you: why do you not give glory to (your Lord)?”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They cried out: “Glory be to our Lord! Certainly we were sinners.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
Then they began to reproach one another.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said: “Woe to us! We had indeed transgressed.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
Maybe our Lord will give us a better orchard in its place; to our Lord do we penitently turn.”\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the chastisement; and the chastisement of the Hereafter is assuredly even greater, if only they knew.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Surely the God-fearing shall have Gardens of bliss with their Lord.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
What! Shall We treat those who have submitted (to Our command) like those who have acted as criminals?\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What is the matter with you? How ill do you judge!\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or do you have a Book wherein you read\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
that (in the Hereafter) you shall have all that you choose for yourselves?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or have We sworn a covenant with you which We are bound to keep till the Day of Resurrection, (a covenant requiring that whatever you ordain for yourselves shall be yours)?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them: “Which of them can guarantee that?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or has something been guaranteed by any of those whom they associate with Allah in His Divinity?” If so, let them bring forth their associates, if they are truthful.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
On the Day when the dreadful calamity will unfold, when people will be summoned to prostrate themselves, and yet they will not be able to prostrate.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
Their eyes shall be downcast and ignominy shall overwhelm them. For when they were safe and sound, they were summoned to prostrate themselves, (and they refused).\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
So leave Me, (O Prophet), to deal with him who gives the lie to this Discourse. We shall draw them little by little (to their undoing) in a way that they will not know.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
I am giving them a respite. Great is My scheme!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or are you asking them for some compensation so that they feel burdened with debt?\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or do they have any knowledge of the Unseen which they are now writing down?\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
So bear with patience until the Judgement of your Lord comes, and do not belike the man in the fish (i.e., Jonah) who called out, choking with grief:\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
had his Lord not bestowed His favour upon him, he would have been cast upon that barren shore (and would have remained there) in disgrace.\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
But his Lord exalted him, and included him among His righteous servants.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
When the unbelievers hear this Exhortation, they look at you as though they would knock you off your feet with their (hostile) glances. They say: “Surely he is afflicted with madness”;\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
although this is nothing but an Exhortation (to goodness) for everyone in the world.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The indubitable event!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
And what is that indubitable event?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
And what do you know what that indubitable event is?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
The Thamud and the Ad denied the (possibility of a) sudden calamity, calling it false.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
Then the Thamud were destroyed by an awesome upheaval;\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
and the Ad were destroyed by a furiously raging wind-storm\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
which He let loose upon them for seven nights and eight days in succession; so that (if you had been there) you might have seen people lying prostrate, as though they were uprooted trunks of hollowed palm trees.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Do you now see any trace of them?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
Pharaoh and those before him and the people of the overturned habitations all engaged in the same great sin.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
They did not follow the Messenger of their Lord, and so He seized them with a severe grip.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
Verily when the water rose to great heights, We bore you upon a floating vessel (i.e. the Ark)\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
so that We might make it an instructive event for you, and retentive ears might preserve its memory.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
So when the Trumpet is blown with a single blast\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
and the earth and the mountains are carried aloft and are crushed to bits at one stroke,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
on that Day shall that indubitable event come to pass;\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
when the sky will be rent asunder, the grip holding it together having loosened on that Day,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
and the angels will stand on the sides, with eight of them bearing aloft the Throne of your Lord on that Day.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
That will be the Day when you shall be brought forth (before Allah) and no secret of yours shall remain hidden.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
On that Day, he whose Record is given to him in his right hand will say: “Lo! Read my Record!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
Verily I was sure that I would be handed over my account.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
Then he shall find himself in a life of bliss;\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
in a lofty Garden\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
the clusters of whose fruit will be hanging low to be within reach (of the inmates of Paradise).\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
(They will be told): “Eat and drink with good cheer as a reward for the good deeds you did in the days that have passed by.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
As for him whose Record will be given to him in his left hand, he will exclaim: “Would that I had never been given my Record,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
and had not known my account.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
Oh! Would that the death that came to me in the world had made an end of me!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
My riches have not availed me,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
and my authority has vanished.”\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
(A command will be issued): “Seize him and shackle him,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
then cast him in the Fire,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
then fasten him with a chain, seventy cubits long.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
He would not believe in Allah, the Most Great;\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
nor would he urge the feeding of the poor.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
Today he has been left here friendless;\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
and has no food except the filth from the washing of wounds,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
which only the sinners will eat.”\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
But no; I swear by what you see,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
and by what you do not see,\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
that this is the speech of an honourable Messenger,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
not the speech of a poet. Little do you believe!\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor is this the speech of a soothsayer. Little do you reflect!\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
It has been revealed by the Lord of the Universe.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
And if he [i.e., the Prophets] had forged this Discourse and thereafter ascribed it to Us,\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We would surely have seized him by the right hand,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
and then severed his life vein;\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
and not one of you would have been able to withhold Us from doing so.\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
Surely it is a Good Counsel for the God-fearing.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
We certainly know that some among you will give the lie to it,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
and surely it will be a cause of regret for the unbelievers.\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
Certainly it is a Truth of absolute certainty.\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
So glorify the name of your Lord Most Great.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A beseecher besought the visitation of chastisement,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
(a chastisement meant) for the unbelievers, one which none can avert;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
a chastisement from Allah, the Lord of the ascending steps,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
by which the angels and the Spirit ascend to Him in one Day the duration of which is fifty thousand years.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
So, (O Prophet), persevere with gracious perseverance.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
Verily they think that the chastisement is far off,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
while We think that it is near at hand.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
It shall befall on a Day whereon the sky will become like molten brass,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
and the mountains will become like dyed tufts of wool,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
and no bosom friend will enquire about any of his bosom friends\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
although they shall be within sight of one another. The guilty one would fain ransom himself from the torment of that Day by offering his children,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
and his spouse and his brother,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
and his kinsfolk who had stood by him,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
and all persons of the earth, if only he could thus save himself.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
By no means! It will be the fierce flame\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
that will strip off the scalp.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
It shall insistently summon him who turned his back and retreated,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
and amassed wealth and covetously hoarded it.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Verily man is impatient by nature:\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
bewailing when evil befalls him,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
and tight-fisted when good fortune visits him,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
except those that pray,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
and are constant in their Prayer;\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
and those in whose wealth there is a known right\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
for those that ask and those that are dispossessed,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
those who firmly believe in the Day of Recompense,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
and fear the chastisement of their Lord –\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
surely the chastisement of their Lord is a thing none can feel secure from –\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
and those who guard their private parts,\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
except in regard to their spouses and those whom their right hands possess, for in regard to them they are not reproachable,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
but any who seeks to go beyond that, it is indeed they who are the transgressors,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
and those who fulfil their trusts and their covenants,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
and those who are upright in their testimonies;\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
and who take due care of their Prayer:\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
all these shall live honourably in the Gardens.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
But what is the matter with the unbelievers who are hurrying towards you\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
in crowds, both on the right and on the left?\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Does everyone of them wish to enter the Garden of Bliss?\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
By no means! They know that which We have created them from.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
I swear by the Lord of the easts and the wests that We have the power\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
to replace them by others who would be better than they; and We shall certainly not be overpowered.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
So leave them to engage in vain talk and to amuse themselves until they come face to face with the Day which they are promised,\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
the Day on which they will hastily come forth from their graves, as though they were hurrying on to the altars of their deities.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
Their eyes will be downcast and disgrace will overwhelm them. Such is the Day that they were promised.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen We sent Noah to his people (and directed him): “Warn your people before a grievous chastisement comes upon them.”\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
Noah said: “My people, I have certainly been sent as a clear warner to you,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
that you serve Allah and fear Him, and follow me;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
He will forgive your sins and will grant you respite until an appointed term. Indeed when Allah's appointed term comes, it cannot be deferred; if you only knew!”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said: “My Lord, I called my people by night and by day,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
but the more I called, the farther they fled.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
And every time I called them so that You might forgive them, they thrust their fingers into their ears and wrapped up their faces with their garments and obstinately clung to their attitude, and waxed very proud.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
Then I summoned them openly,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
and preached to them in public, and also addressed them in secret.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
I said to them: “Ask forgiveness from your Lord; surely He is Most Forgiving.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
He will shower upon you torrents from heaven,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
and will provide you with wealth and children, and will bestow upon you gardens and rivers.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What is amiss with you that you do not look forward to the majesty of Allah\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
when He has created you in stages?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
Do you not see how Allah has created seven heavens, one upon the other,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
and has placed the moon in them as a light, and the sun as a radiant lamp?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
And Allah has caused you to grow out of the earth so wondrously,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
and He will later cause you to return to it and will then again bring you out of it.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
Allah has made the earth a wide expanse for you\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
so that you may tread its spacious paths.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Noah said: “My Lord, they did not pay heed to what I said, and followed those (nobles) whose possession of wealth and children has led them to an even greater loss.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
They contrived a plot of great magnitude.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
They said: “Do not abandon your deities; do not abandon Wadd, nor Suwa, nor Yaghuth, nor Yauq, nor Nasr.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
They have misled many. So do not enable these evildoers to increase in anything except straying (from the Right Way).”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
And so they were drowned on account of their sins, and then cast into the Fire, and did not find any other than Allah, to come forth to their help.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
Noah said: “My Lord, do not leave out of these unbelievers even a single dweller on earth,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
for certainly if You should leave them (alive), they will mislead Your servants, and will beget none but sinners and utter unbelievers.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
My Lord, forgive me and my parents, and whoever enters my house as a believer, and forgive all believers, both men and women, and do not increase the wrong-doers in anything except perdition.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say, (O Prophet), it was revealed to me that a band of jinn attentively listened to (the recitation of the Qur'an) and then (went back to their people) and said:\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
“We have indeed heard a wonderful Qur'an which guides to the Right Way; so we have come to believe in it, and we will not associate aught with Our Lord in His Divinity”;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
and that “He – exalted be His Majesty – has not taken to Himself either a wife or a son”;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
and that “the foolish among us have been wont to say outrageous things about Allah”;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
and that “we had thought that men and jinn would never speak a lie about Allah”,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
and that “some from among the humans used to seek protection of some among the jinn, and thus they increased the arrogance of the jinn”;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
and that “they thought, even as you thought, that Allah would never raise anyone (as a Messenger)”;\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
and that “we tried to pry (the secrets of) the heaven, but we found it full of terrible guards and shooting meteors”;\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
and that “we would take up stations in the heaven to try to hear but anyone who now attempts to listen finds a shooting meteor in wait for him”;\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
and that “we do not know whether evil is intended for those on the earth, or whether their Lord intends to direct them to the Right Way”;\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
and that “some of us are upright and some of us are otherwise for we follow widely divergent paths”;\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
and that “we thought that we will neither be able to frustrate Allah on earth, nor frustrate Him by flight”;\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
and that “when we heard the teaching of the Right Way we came to believe in it; he who believes in His Lord shall have no fear of suffering loss or being subjected to any injustice”;\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
and that “among us some are Muslims (Those who have submitted to Allah), and some of us are deviant. So those who became Muslims found the Right Course;\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
but those who deviated from the Truth, will be the fuel for Hell.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
If people were to keep firmly to the Right Way, We would have vouchsafed them abundant rain\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
so that We might try them through this bounty. Whoso turns away from the remembrance of his Lord, He will cause him to suffer a grievous chastisement;\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
and that “mosques belong to Allah, so do not invoke anyone with Him”;\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
and when Allah's servant stood up to call on Him, they well-nigh swarmed him.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say, (O Prophet): “I call on my Lord alone, and I do not associate aught with Him in His Divinity.”\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say: “Surely neither it is in my power to hurt you nor to bring you to the Right Way.”\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say: “None can protect me from Allah, nor can I find a refuge apart from Him.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
(My task is no more than) to deliver Allah's proclamation and His messages. And whoever disobeys Allah and His Messenger, surely the Fire of Hell awaits him; therein he will abide in perpetuity.”\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
(They shall not change their ways) until they see that against which they had been warned, and then they will know whose helpers are weaker and whose supporters are fewer in number.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say: “I know not whether what you are promised is near or whether my Lord will prolong its term.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
He is the Knower of the Unseen, and He does not disclose His Unseen to anyone\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
other than to a Messenger whom He chooses (for the bestowal of any part of the knowledge of the Unseen), whereafter He appoints guards who go before him and behind him,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
so that He may know that they have delivered the messages of their Lord. He encompasses in His knowledge their surroundings and keeps a count of all things.”\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O you the (sleeping) enwrapped one!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Stand up in Prayer by night, all but a small part of it;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
half of it, or reduce it a little;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
or add to it a little; and recite the Qur'an slowly and distinctly.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
Behold, We shall cast upon you a Weighty Word.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Surely getting up at night is the best means of subduing the self and is more suitable for uprightness in speech.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
You are indeed much occupied during the day with the affairs of the world.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
So remember the name of your Lord and devote yourself to Him with exclusive devotion.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
He is the Lord of the East and the West; there is no god but He. So take Him alone for your Guardian,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And bear patiently the vain things they utter, and gracefully forsake them.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
Leave it to Me to deal with the affluent ones who give the lie (to the Truth), and bear with them for a while.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
We have heavy fetters and a blazing Fire in store for them;\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
and a food that chokes, and a grievous chastisement.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
(They will come across all this) on the Day when the earth and the mountains shall tremble violently and the mountains shall crumble into heaps of scattered sand.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
Surely We have sent to you a Messenger as a witness over you, just as We had sent a Messenger to Pharaoh.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
But Pharaoh disobeyed Our Messenger, so We seized him with a terrible seizing.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
If you persist in disbelieving, how will you guard yourself against the (woe of the) Day that will turn children grey-haired,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
the Day whose severity shall cause the heaven to split asunder? Allah's promise is ever bound to be fulfilled.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
Indeed this is nothing but a Good Counsel; so let him who will take a way leading to his Lord.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
(O Prophet), your Lord knows that you sometimes stand up in Prayer nearly two-thirds of the night, and sometimes half or one-third of it, and so does a party of those with you; Allah measures the night and the day. He knows that you cannot keep an accurate count of it, so He has shown mercy to you. So now recite as much of the Qur'an as you can. He knows that there are among you those who are sick and others who are journeying in the land in quest of Allah's bounty, and still others who are fighting in the cause of Allah. So recite as much of the Qur'an as you easily can, and establish Prayer, and pay Zakah, and give Allah a goodly loan. Whatever good you send forth for yourselves, you shall find it with Allah. That is better and its reward is greater. And ask for Allah's forgiveness; surely He is Most Forgiving, Most Compassionate.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O you enveloped in your cloak!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Arise, and warn,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
and magnify the glory of your Lord,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
and purify your robes,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
and shun uncleanness,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
and bestow not favour in order to seek from others a greater return,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
and persevere for your Lord's sake.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
When the Trumpet shall be sounded,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
that will surely be a hard day,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
not an easy day for the unbelievers.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me with him whom I alone have created,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
whom I have endowed with abundant riches,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
and sons ever present with him,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
and for whom I have smoothed the way (to power and riches),\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
and who still greedily desires that I should bestow upon him more.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
By no means; he is stubbornly opposed to Our Signs.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
I shall soon constrain him to a hard ascent.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
He reflected and then hatched a scheme.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
Ruin seize him, how did he hatch a scheme?\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
Again, ruin seize him, how did he hatch a scheme?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
He looked (at others);\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
then frowned and scowled;\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
then he retreated and waxed proud,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
and said: “This (Qur'an) is merely a sorcery of yore;\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
this is nothing but the word of a mere mortal!”\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
Him shall I soon roast in Hell.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
And what do you know what Hell is?\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It spares nothing; it leaves nothing intact;\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
it scorches (even) the skin.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Over it are nineteen keepers.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
We have appointed none but angels as the keepers of the Fire, and We have not made their number but as a trial for the unbelievers so that those who have been endowed with the Book will be convinced and the believers' faith will increase, and neither those who have been endowed with the Book nor the believers will fall into any doubt. As for those in whose hearts there is a sickness as well as the unbelievers, they will say: “What did Allah aim at by this strange parable?” Thus does Allah let whomsoever He pleases to go astray, and directs whomsoever He pleases to the Right Way. And none knows the hosts of your Lord but He. (And Hell has only been mentioned here) that people may take heed.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
Nay, by the moon,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
and by the night when it recedes,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
and by the day when it dawns (with its radiance),\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
surely (Hell) is one of the greatest Signs,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
a warning to humankind,\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
a warning to everyone of you whether he would like to come forward or lag behind.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Each one is a hostage to one's deeds,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
save the People of the Right Hand\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
who shall be in the Gardens, and shall ask\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
about the guilty ones:\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
“What drove you to Hell?”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will answer: “We were not among those who observed Prayer,\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
and we did not feed the poor,\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
and we indulged in vain talk with those who indulged in vain talk,\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
and we gave the lie to the Day of Judgement\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
until the inevitable event overtook us.”\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
The intercession of the intercessors shall then be of no avail to them.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
What is the matter with people that they are turning away from this Exhortation,\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
as though they were frightened wild asses,\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
fleeing from a lion?\qt@no{(51)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
No indeed; each one of them desires that open letters be sent to each of them.\qt@no{(52)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
No indeed; the truth is that they have no fear of the Hereafter.\qt@no{(53)}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
Nay; this is an Exhortation.\qt@no{(54)}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
So, whoever wills may benefit from it.\qt@no{(55)}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
But they will not benefit from it unless Allah Himself so wills. He is worthy to be feared; and He is worthy to forgive (those that fear Him).\qt@no{(56)}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen Nay, I swear by the Day of Resurrection;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
and nay, I swear by the self-reproaching soul!\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Does man imagine that We will not be able to bring his bones together again?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Yes indeed; We have the power to remould even his finger-tips.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
But man desires to persist in his evil ways.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He asks: “When will the Day of Resurrection be?”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
When the sight is dazed,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
and the moon is eclipsed,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
and the sun and the moon are joined together,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
on that Day will man say: “Whither the refuge?”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
No, there is no refuge.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
With your Lord alone will be the retreat that Day.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
On that Day will man be apprised of his deeds, both the earlier and the later.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
But lo, man is well aware of himself,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
even though he might make up excuses.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
(O Prophet), do not stir your tongue hastily (to commit the Revelation to memory).\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
Surely it is for Us to have you commit it to memory and to recite it.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
And so when We recite it, follow its recitation attentively;\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
then it will be for Us to explain it.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
Nay; the truth is that you love ardently (the good of this world) that can be obtained hastily,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
and are oblivious of the Hereafter.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
Some faces on that Day will be fresh and resplendent,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
and will be looking towards their Lord;\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
and some faces on that Day will be gloomy,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
believing that a crushing calamity is about to strike them.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
Nay; when a man's soul reaches up to the throat,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
and it is said: “Is there any enchanter who can step forward and help (by his chanting)?”\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
and he realises that the hour of parting is come,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
and calf is inter-twined with calf.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
On that Day you will be driven to your Lord.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
But he did not verify the Truth, nor did he observe Prayer;\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
on the contrary, he gave the lie to the Truth and turned his back upon it,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
then he went back to his kinsfolk, elated with pride.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
This (attitude) is worthy of you, altogether worthy;\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
again, it is worthy of you, altogether worthy.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Does man think that he will be left alone, unquestioned?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not a drop of ejaculated semen,\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
then he became a clot, and then Allah made it into a living body and proportioned its parts,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
and then He made of him a pair, male and female?\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
Does He, then, not have the power to bring back the dead to life?\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Was there a period of time when man was not even worthy of a mention?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
Verily We created man out of a drop of intermingled sperm so that We might try him, and We therefore endowed him with hearing and sight.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
Surely We showed him the Right Path, regardless of whether he chooses to be thankful or unthankful (to his Lord).\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
For the unbelievers, We have kept ready chains and fetters and a Blazing Fire.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
The virtuous shall drink from a cup tempered with camphor water.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
This will be a gushing spring wherefrom Allah's servants shall drink wine, a spring from which they will take out channels wherever they wish.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
These will be the ones who fulfil their vows and dread the Day whose woe shall be spread far and wide;\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
those who, for the love of Him, feed the needy, and the orphan, and the captive,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
(saying): “We feed you only for Allah's sake; we do not seek of you any recompense or thanks,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
we fear from our Lord a Day that shall be long and distressful.”\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
So Allah shall guard them against the woe of that Day, and will procure them freshness and joy,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
and will reward them for their steadfastness with Paradise and robes of silk.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
There they will recline on elevated couches and will be subjected neither to the burning heat of the sun nor to bitter cold.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
The shades of Paradise will bend over them, and its fruits will be brought within their easy reach;\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
and there shall be passed around them vessels of silver and goblets of crystal,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
goblets bright as crystal but made of silver, filled to exact measure.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
Therein they shall be served a cup flavoured with ginger,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
drawn from a spring (in Paradise) called Salsabil.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
There boys of everlasting youth shall go about attending them: when you see them, you would think that they are scattered pearls.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
Whitherto you look around, you will see an abundance of bliss and the glories of a great kingdom.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
They [i.e., the virtuous] shall be attired in garments of fine green silk and rich brocade and will be adorned with bracelets of silver. Their Lord will give them a pure wine to drink.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
Behold, this is your recompense and your endeavour has been appreciated.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
(O Prophet), indeed We have revealed the Qur'an to you in portions.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
So persevere with the command of your Lord and do not pay any heed to the wicked and the unbelieving,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
and remember the name of your Lord, morning and evening;\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
and prostrate yourself before Him at night, and extol His Glory during the long watches of the night.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Verily they love (the good of this world) that is hastily obtainable and are oblivious of the burdensome Day ahead of them.\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
We created them and strengthened their joints; and whenever We wish, We can change their faces entirely.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
Verily this is an Exhortation; so let him who so will take a way to his Lord.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
But your willing shall be of no avail until Allah Himself so wills. Surely Allah is All-Knowing, Most Wise.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He admits to His Mercy whomsoever He pleases. As for the wrong-doers, He has prepared for them a grievous chastisement.\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By the (winds) sent forth in quick succession,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
which then blow tempestuously\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
and raise (clouds) and scatter them around,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
then winnow them thoroughly,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
and then cast (Allah's) remembrance (in people's hearts),\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
to serve as an excuse or a warning.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Surely what you are promised shall come to pass.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
So when the stars are extinguished,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
and the sky is rent asunder,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
and the mountains are blown away,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
and the appointed time to bring the Messengers together arrives, (then shall the promised event come to pass).\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
To which Day has this task been deferred?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
To the Day of Judgement.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
What do you know what the Day of Judgement is?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy many a nation of the earlier times?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
And We shall cause those of later times to follow them.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
Thus do We deal with the guilty.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you of a mean fluid,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
which We then placed in a secure repository\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
until an appointed time?\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
See that We had the power to do so. Great indeed is Our power to do what We will.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Did We not make the earth a receptacle,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
for the living and the dead,\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
and did We not firmly fix towering mountains on it and give you sweet water to drink?\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
Proceed now towards that which you were wont to deny as false;\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
proceed towards the three-pronged shadow,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
which neither provides (cooling) shade nor protection against the flames;\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
it indeed throws up sparks like castles,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
which seem as though they are yellow-coloured camels.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
That will be the Day on which they will not (be able to) utter a word,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
nor will they be allowed to proffer excuses.\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
That is the Day of Judgement on which We have assembled you as well as all those who went before you.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
So if you have any ploy, try it against Me!\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Behold, today the God-fearing will be amidst shades and springs,\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
and the fruits that they desire (will be ready at hand).\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
Eat and drink and may every joy attend you as a reward for your deeds.\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
Thus do We reward those that do good.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
Eat and enjoy yourselves for a while. Surely you are evil-doers.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(47)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
When it is said to them: “Bow down (before Allah),” they do not bow down.\qt@no{(48)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe on that Day to those that give the lie to the Truth!\qt@no{(49)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
In what discourse after this (Qur'an) will they, then, believe?\qt@no{(50)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen About what are they asking one another?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
Is it about the awesome tiding\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
that they are in utter disagreement?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
No indeed; soon will they come to know;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
again, no indeed; soon will they come to know.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not spread the earth like a bed,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
and fixed the mountains like pegs,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
and created you in pairs (as men and women),\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
and made your sleep a means of repose,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
and made the night a covering,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
and made the day to seek livelihood,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
and built above you seven strong firmaments,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
and placed therein a hot, shining lamp,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
and sent down abundant water from the clouds\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
so that We may thereby bring forth grain and vegetation,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
and gardens dense with foliage?\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Surely the Day of Judgement has an appointed time;\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
the Day when the Trumpet shall be blown, and you will come forth in multitudes;\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
and when the sky shall be opened up and will become all doors;\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
and the mountains will be set in motion and become a mirage.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Surely the Hell is an ambush,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
a resort for the rebellious;\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
therein they shall abide for ages,\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
they shall taste in it no coolness, nor any pleasant drink\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
save boiling water and wash of the wounds;\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
a befitting recompense for their deeds.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
For indeed they did not look forward to any reckoning,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
and roundly denied Our Signs as false.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
And everything have We recorded in a Book.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
So taste (the fruit of your deeds). We shall only increase your torment.\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Surely the state of triumph awaits the God-fearing:\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
gardens and vineyards,\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
and youthful maidens of like age,\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
and an overflowing cup.\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
Therein they shall hear no idle talk, nor any falsehood;\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
a recompense from your Lord and an ample reward\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
from the Lord of the heavens and the earth and of that which is between them; the Most Merciful Lord before Whom none dare utter a word.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
The Day when the Spirit and the angels are ranged row on row. None shall speak save he whom the Merciful Lord will permit; and he too will speak what is right.\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That Day is sure to come. So let him who will seek a resort with his Lord.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Lo! We warn you of a chastisement near at hand; the Day when a man will look on what his own hands have sent forth, and the unbelievers shall say: “Oh would that I were utter dust.”\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By those (angels) that pluck out the soul from depths,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
and gently take it away;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
and by those that speedily glide along (the cosmos),\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
and vie with the others (in carrying out their Lord's behests);\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
and then manage the affairs of the Universe (according to their Lord's commands).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
The Day when the quaking will cause a violent convulsion,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
and will be followed by another quaking.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
On that Day some hearts shall tremble (with fright),\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
and their eyes shall be downcast with dread.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They say: “Shall we indeed be restored to life,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
even after we have been reduced to bones, hollow and rotten?”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They say: “That will then be a return with a great loss!”\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
Surely they will need no more than a single stern blast,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
and lo, they will all be in the open plain.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Has Moses' story reached you?\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
When his Lord called him in the sacred valley of Tuwa,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
and directed him: “Go to Pharaoh, he has rebelled,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
and say to him: 'Are you willing to be purified,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
that I may direct you to your Lord and then you hold Him in awe?'”\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
Then Moses (went to Pharaoh and) showed him the Great Sign;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
but he denied it as false and disobeyed,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
and then he turned back to have recourse to his craftiness,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
and gathered his people and declared:\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
“I am the supreme lord of you all.”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
Thereupon Allah seized him for the chastisement of the World to Come as well as of the present.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Surely there is a great lesson in it for whoever would fear (Allah).\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
Is it harder to create you or the heaven? But Allah built it,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
and raised its vault high and proportioned it;\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
and covered its night with darkness and brought forth from it its day;\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
and thereafter spread out the earth,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
and brought out of it its water and its pasture,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
and firmly fixed in it mountains;\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
all this as provision for you and your cattle.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
But when the great calamity will come about\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
on the Day when man will recall all his strivings,\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
and Hell will be brought in sight for anyone to see:\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
then he who transgressed\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
and preferred the life of this world,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
most surely his abode shall be Hell.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
But he who feared to stand before his Lord, and restrained himself from evil desires,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
most surely his abode shall be Paradise.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They ask you about the Hour: “When will it be?”\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
What concern do you have to speak about that?\qt@no{(43)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
Its knowledge rests with your Lord.\qt@no{(44)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
You are only a warner to him who has a fear of it.\qt@no{(45)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
On the Day they see it, they will feel as though they had stayed (in the grave) no more than one evening or one morning.\qt@no{(46)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen He frowned and turned away\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
that the blind man came to him.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
How could you know? Perhaps he would cleanse himself,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
or he might be mindful and good counsel might avail him.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
Now he who waxes indifferent,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
you attend to him,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
though you are not to blame if he would not cleanse himself.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
But he who comes to you running,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
and fears (Allah),\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
you pay no heed to him.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
No indeed; this is only a Reminder.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
So whoso wills may give heed to it.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
It is contained in scrolls highly honoured,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
most exalted and purified,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
borne by the hands of scribes,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
noble and purified.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Accursed be man! How stubbornly he denies the Truth.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
Out of what did Allah create him?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
Out of a sperm-drop did He create him and then determined a measure for him,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
and then made the course of life easy for him,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
then He caused him to die and brought him to the grave,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
and then, whenever He wishes, He will raise him back to life.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
Nay, but man did not fulfil what Allah had enjoined upon him.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
So let man just consider his food:\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
We poured water, pouring it in great abundance,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
and cleaved the earth, cleaving it asunder;\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
then caused the grain to grow out of it,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
together with grapes and vegetables,\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
and olives and palms,\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
and dense orchards,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
and fruits and pastures –\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
all this as a provision for you and your cattle.\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
But when the deafening cry shall be sounded\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
on the Day when each man shall flee from his brother,\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
and his mother and his father;\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
and his consort and his children;\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
on that Day each will be occupied with his own business, making him oblivious of all save himself.\qt@no{(37)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Some faces on that Day shall be beaming with happiness,\qt@no{(38)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
and be cheerful and joyous.\qt@no{(39)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
Some faces on that Day shall be dust-ridden,\qt@no{(40)}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
enveloped by darkness.\qt@no{(41)}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
These will be the unbelievers, the wicked.\qt@no{(42)}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun shall be folded up,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
when the stars shall scatter away,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
when the mountains shall be set in motion,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
when the ten-months pregnant camels shall be abandoned,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
when the savage beasts shall be brought together,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
when the seas shall be set boiling,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
when the souls shall be rejoined (with their bodies),\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
and when the girl-child buried alive shall be asked:\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
for what offence was she killed?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
and when the scrolls of (men's) deeds shall be unfolded,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
and when Heaven is laid bare;\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
and Hell is stoked,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
and Paradise brought nigh:\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
then shall each person know what he has brought along.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
No indeed; I swear by the alternating stars\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
that hide,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
and by the night as it recedes,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
and the morn as it breathes.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
Verily this is the word of a noble message-bearer;\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
one mighty and held in honour with the Lord of the Throne;\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
there he is obeyed and held trustworthy.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
(O people of Makkah), your companion is not mad;\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
he indeed saw the message-bearer on the clear horizon;\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
nor does he grudge (conveying this knowledge about) the Unseen;\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
nor is it a word of an accursed Satan.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
Where to are you then heading?\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
It is nothing but Good Counsel for everyone in the world,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
for everyone of you who wishes to follow the Straight Way;\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
but your wishing will not avail unless Allah, the Lord of the Universe, so wishes.\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the heaven is split asunder,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
when the stars are scattered,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
when the seas are made to burst forth,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
and when graves are laid open,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
everyone shall know all his deeds, both the earlier and the later.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O man! What has deceived you about your generous Lord\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
Who created you, shaped you, and made you well-proportioned,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
and set you in whatever form He pleased?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
No indeed; (the fact is that) you deny the Reckoning, declaring it a lie;\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
you do so the while there are watchers over you;\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
noble scribes,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
who know what you do.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Surely the virtuous shall be in Bliss,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
and the wicked shall be in the Blazing Fire.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
They shall enter it on the Day of Recompense\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
and then shall never come out of it.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
What do you know what the Day of Recompense is?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what do you know what the Day of Recompense is?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
It is the Day when no one shall have the power to do anything for another, and all command shall be Allah's.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe to the stinters;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
those who, when they take from others by measure, take their full share;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
but who, when they measure or weigh for others, give less than their due.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Do they not realise that they will be raised to life\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
on a Great Day,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
a Day when mankind will stand before the Lord of the Universe?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
No indeed! Verily the deeds of the wicked are in the Record locked up in the prison-house!\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
And how would you know what the Record of the prison-house is?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
It is a Book inscribed.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe, then, to those that give the lie,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
those that give the lie to the Day of Recompense.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
Yet none gives the lie to it except the transgressor immersed in sin;\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
who, when Our verses are recited to him, says: “Mere tales of olden times!”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
No indeed! The truth is that their hearts have become rusted on account of their evil deeds.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
No indeed! On that Day they will be screened off from seeing their Lord,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
and then they shall enter Hell,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
whereafter they will be told: “This is what you used to give the lie to.”\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
No indeed! Verily, the deeds of the virtuous shall be in the record of the exalted ones.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
And what do you know what the Record of the exalted ones is?\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
It is a Book inscribed,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
which the angels placed near Allah to safeguard.\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Verily the virtuous shall be in Bliss;\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
resting on couches, looking around.\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
You shall see upon their faces the glow of bliss.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They will be served a drink of the finest sealed wine,\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
whose seal is musk – so let all aspirants aspire after that –\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
a wine whose mixture is Tasnim,\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
a fountain at which the chosen ones shall drink.\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Behold, the wicked were wont to laugh at the believers:\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
when they passed by them they winked,\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
and when they went back to their families, they went back jesting,\qt@no{(31)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
and when they saw the believers, they said: “Lo! These are the erring ones”;\qt@no{(32)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
(they said so although) they had not been appointed watchers over them.\qt@no{(33)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
But today the believers are laughing at the unbelievers;\qt@no{(34)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
seated upon their couches, they are looking around.\qt@no{(35)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Have the unbelievers been duly rewarded for their deeds?\qt@no{(36)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the sky is rent asunder\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
and hearkens to the command of its Lord, doing what it should;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
and when the earth is stretched out\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
and casts out what is within it and is emptied,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
and hearkens to the command of its Lord, doing what it should.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O man, you are striving unto your Lord and you will meet Him.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Whoever is given the Record in his right hand\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
shall be called to an easy accounting,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
and shall return to his people joyfully.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But he who is given the Record behind his back,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
shall cry for “perdition,”\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
and will enter the Blazing Fire.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
He used to live joyfully among his people,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
thinking he would never revert (to Us).\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
But no; (how would he not revert)? His Lord was ever watching him.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
Nay; I swear by the twilight;\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
and by the night and what it enfolds,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
and by the moon, when it reaches its fullness:\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
you shall proceed onwards from stage to stage.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
So, what is the matter with them that they do not believe,\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
and when the Qur'an is recited to them, they do not prostrate themselves?\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
Instead, the unbelievers reject it, calling it a lie.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
Allah knows best what they are accumulating (in their Record).\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
So give them the good news of a painful chastisement,\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
except for those who believe and do good deeds. Theirs shall be an unending reward.\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the heaven with its impregnable castles;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
by the Promised Day,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
and by the witness and what is witnessed:\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
the people of the pit were destroyed\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
with fire abounding in fuel,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
while they sat around it,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
and were witnessing what they did to the believers.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
Against these they had no grudge except that they believed in Allah, the Most Mighty, the Most Praiseworthy,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
to Whom belongs the dominion of the heavens and the earth. Allah witnesses everything.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Surely those who tormented the believing men and the believing women and then did not repent, theirs shall be the chastisement of Hell, and theirs shall be the chastisement of burning.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
As for those who believed and acted righteously, theirs shall be Gardens beneath which rivers flow. That is the great triumph.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Stern indeed is your Lord's punishment.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
He it is Who creates for the first time and He it is Who will create again,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
and He is the Ever Forgiving, the Most Loving\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
– the Lord of the Glorious Throne,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
the Executor of what He wills.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Has the story of the armies reached you,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
the armies of Pharaoh and Thamud?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
The unbelievers are indeed engaged in denying it, calling it a lie,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
although Allah surrounds them.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
Nay; but this is a glorious Qur'an,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
inscribed on a well-guarded Tablet.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the heaven, and the night-visitor,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
what do you know what the night-visitor is?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
It is the piercing star.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
There is no living being but there is a protector over it.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
So let man consider of what he was created.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He was created of a gushing fluid,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
emanating from between the loins and the ribs.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Surely He (the Creator) has the power to bring him back (to life).\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
On the Day when man's deepest secrets shall be put to the test\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
he shall have no power, and no helper.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the heaven with its recurring cycle of rain,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
and by the earth ever bursting with verdure,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
this (Qur'an) is surely a decisive Word,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
not a flippant jest.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
They are devising a guile,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
and I too am devising a guile.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
So leave the unbelievers to themselves; respite them awhile.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Glorify the name of your Lord, the Most High,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
Who created all things and fashioned them in good proportion;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
Who determined and guided them,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
Who brought forth the pasture,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
and then made it into a blackish straw.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We shall make you recite and then you will not forget,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
except what Allah should wish. He knows all that is manifest and all that is hidden.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
We shall ease you to follow the way of Ease.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
So render good counsel if good counsel will avail.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
He who fears (Allah) shall heed it,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
but the wretched will turn away from it.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
He will be cast into the Great Fire.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
Then he will neither die in it, nor live.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
He who purified himself shall prosper,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
remembering his Lord's name and praying.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
No; but you prefer the present life,\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
whereas the Hereafter is better and more enduring.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
This, indeed, was in the ancient Scrolls,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
the Scrolls of Abraham and Moses.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Has the news of the overwhelming event reached you?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
Some faces that Day shall be downcast with fear,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
be toiling and worn-out;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
they shall burn in a Scorching Fire;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
their drink shall be from a boiling spring.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
They shall have no food except bitter dry thorns\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
that will neither nourish nor satisfy their hunger.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
On that very Day some faces shall be radiant with joy,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
well-pleased with their striving.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
They will be in a lofty Garden\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
wherein they shall hear no vain talk.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
In it there shall be a flowing spring,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
and couches raised high,\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
and goblets laid out,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
and cushions arrayed in rows,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
and rich carpets levelled out.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
Do (these unbelievers) not observe the camels: how they were created?\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And the sky: how it was raised high?\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And the mountains: how they were fixed?\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And the earth: how it was spread out?\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
So render good counsel, for you are simply required to counsel,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
and are not invested with the authority to compel them.\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
But whoever will turn away (from the Truth),\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
Allah will chastise him with the most terrible chastisement.\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Surely to Us is their return;\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
and then it is for Us to call them to account.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the dawn,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
and the ten nights,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
and the even and the odd,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
and by the night when it departs.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Is there in this an oath for one endowed with understanding?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Have you not seen how your Lord dealt with Ad\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
of Iram, known for their lofty columns,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
the like of whom no nation was ever created in the lands of the world?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And how did He deal with Thamud who hewed out rocks in the valley?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And with Pharaoh of the tent pegs\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
who transgressed in the countries of the world\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
spreading in them much corruption?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
Then their Lord unloosed upon them the lash of chastisement.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
Truly your Lord is ever watchful.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
As for man, when his Lord tests him by exalting him and bestowing His bounties upon him, he says: “My Lord has exalted me.”\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But when He tests him by straitening his sustenance, he says: “My Lord has humiliated me.”\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
But no; you do not treat the orphan honourably,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
and do not urge one another to feed the poor,\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
and greedily devour the entire inheritance,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
and love the riches, loving them ardently.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
But no; when the earth is ground to powder,\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
and when your Lord appears with rows upon rows of angels,\qt@no{(22)}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
and when Hell is brought near that Day. On that Day will man understand, but of what avail will that understanding be?\qt@no{(23)}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say: “Would that I had sent ahead what would be of avail for this life of mine!”\qt@no{(24)}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
Then on that Day Allah will chastise as none other can chastise;\qt@no{(25)}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
and Allah will bind as none other can bind.\qt@no{(26)}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
(On the other hand it will be said): “O serene soul!\qt@no{(27)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
Return to your Lord well-pleased (with your blissful destination), well-pleasing (to your Lord).\qt@no{(28)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
So enter among My (righteous) servants\qt@no{(29)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
and enter My Paradise.”\qt@no{(30)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen Nay! I swear by this city\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
– this city wherein you have been rendered violable–\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
and I swear by the parent and his offspring:\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
Verily We have created man into toil and hardship.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Does he think that no one can overpower him?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He says: “I have squandered enormous wealth.”\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Does he believe that none has seen him?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Did We not grant him two eyes,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
and a tongue and two lips?\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And did We not show him the two highroads (of good and evil)?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
But he did not venture to scale the difficult steep.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
And what do you know what that difficult steep is?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
It is freeing someone's neck from slavery;\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
or giving food on a day of hunger\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
to an orphan near of kin;\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
or to a destitute lying in dust;\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
and, then besides this, he be one of those who believed, and enjoined upon one another steadfastness and enjoined upon one another compassion.\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
These are the People of the Right Hand.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
As for those who rejected Our Signs, they are the People of the Left Hand.\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
Upon them shall be a Fire that will hem them in.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the sun and its heat and brightness,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
and by the moon as it follows it;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
and by the day as it displays the sun's glory,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
and by the night as it envelopes the sun;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
and by the sky and by Him Who made it;\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
and by the earth and by Him Who stretched it out;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
and by the soul and by Him Who perfectly proportioned it,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
and imbued it with (the consciousness of) its evil and its piety:\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
He who purifies it will prosper,\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
and he who suppresses it will be ruined.\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
In their presumptuous insolence the Thamud called the Truth a lie\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
when their arch-criminal rose up in rage.\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
Then Allah's Messenger warned them: “Hands off the she-camel and her drink!”\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
But they rejected his statement as a lie and hamstrung the she-camel. For that crime their Lord rumbled down upon them, utterly razing them to the ground.\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
He has no fear of its sequel.\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night when it enshrouds,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
and by the day when it breaks in its glory,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
and by Him Who created the male and the female:\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
surely your strivings are divergent.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
As for him who gave out his wealth (for Allah's sake) and abstained (from disobeying Him),\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
and affirmed the Truth of goodness:\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
We shall facilitate for him the Way to Bliss.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
As for him who was a miser and behaved with aversion (to Allah),\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
and denied the Truth of goodness:\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
We shall facilitate for him the way to Hardship,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
and his wealth shall be of no avail to him when he perishes.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Surely it is for Us to show the Right Way,\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
and to Us belong the Next Life and the present.\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
I have now warned you of a Blazing Fire,\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
where none shall burn except the most wicked,\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
who rejected the Truth, calling it falsehood and turned his back on it.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
But the God-fearing shall be kept away from it,\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
the Godfearing who spends his wealth to purify himself;\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
not as payment for any favours that he received,\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
but only to seek the good pleasure of his Lord Most High.\qt@no{(20)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
He will surely be well-pleased (with him).\qt@no{(21)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the bright forenoon,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
and by the night when it covers the world with peace:\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
(O Prophet), your Lord has neither forsaken you, nor is He displeased.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
Indeed what is to come will be better for you than what has gone by.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
Verily your Lord will soon give you so amply that you will be well-pleased.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find you an orphan and then gave you shelter?\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
Did He not find you unaware of the Right Way, and then directed you to it?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
And did He not find you in want, and then enriched you?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Therefore, be not harsh with the orphan;\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
and chide not him who asks,\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
and proclaim the bounty of your Lord.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen (O Prophet), Did We not lay open your breast\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
and relieve you of the burden\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
that had well-nigh broken your back?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And did We not exalt your fame?\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
Indeed, there is ease with hardship.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
Most certainly, there is ease with hardship.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
So, whenever you are free, strive in devotion,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
and turn to your Lord with longing.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the fig and the olive;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
and by the Mount Sinai,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
and by this city (of Makkah), a haven of peace:\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
surely We created man in the best mould;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
then We reverted him to the lowest of the low,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
except those who have faith and do righteous deeds. Theirs is a never ending reward.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
Who, then, can give the lie to you, (O Prophet), about the Reward and the Punishment?\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not Allah the Greatest of all sovereigns?\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Recite in the name of your Lord Who created,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
created man from a clot of congealed blood.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Recite: and your Lord is Most Generous,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
Who taught by the pen,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
taught man what he did not know.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
Nay, surely man transgresses;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
for he believes himself to be self-sufficient.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Surely to your Lord is your return.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
Did you see him who forbids\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
a servant (of Allah) when he prays?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Did you consider: what if he is on the Right Way,\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
and enjoins piety?\qt@no{(12)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
Did you consider: what if he gives the lie (to the Truth) and turns away (from it)?\qt@no{(13)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Does he not know that Allah sees everything?\qt@no{(14)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
No indeed; if he does not desist, We shall drag him by the forelock;\qt@no{(15)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
by the lying forelock steeped in sin.\qt@no{(16)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
So let him summon his helpmates;\qt@no{(17)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We too shall summon the guards of Hell.\qt@no{(18)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
No, not at all. Never obey him. But prostrate yourself and become nigh (to your Lord).\qt@no{(19)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen Behold, We revealed this (Qur'an) on the Night of Power.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
And what do you know what the Night of Power is?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Power is better than a thousand months.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
The angels along with the Spirit descend in it by the permission of their Lord with all kinds of decrees.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
All peace is that night until the rise of dawn.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen Those who disbelieved – be they from the People of the Book or from those who associated others with Allah in His Divinity – will not desist from unbelief until the Clear Proof should come to them;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
a Messenger from Allah, reciting from Purified Scrolls;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
in writings wherein are scriptures, absolutely true and unerring.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
Nor did those to whom the Book had been given split up until after the Proof (of the Right Way) had come to them.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
Yet all that they had been commanded was that they serve Allah, with utter sincerity, devoting themselves exclusively to Him, and that they establish Prayer and pay Zakah. That is the Right Faith.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Those who disbelieved – be they from among the People of the Book or among those who associated others with Allah in His Divinity– shall be in the Fire, and will abide in it. They are the worst of creatures.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
But those that believe and work righteous deeds, they are the best of creatures.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their recompense lies with their Lord: Gardens of eternity beneath which rivers flow; therein they shall dwell, forever and ever. Allah is well-pleased with them, and they are well-pleased with Him. All this is for him who fears his Lord.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth will be shaken with a mighty shaking,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
and the earth will throw up all her burdens,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
and man will cry out: “What is the matter with her?”\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
On that Day it will relate all her news,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
for your Lord will have commanded her (to do so).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
On that Day people will go forth in varying states so that they be shown their deeds.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
So, whoever does an atom's weight of good shall see it;\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
and whoever does an atom's weight of evil shall see it.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By (the horses) that charge snorting,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
then raise sparks of fire (by their hoofs),\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
then raid by the dawn,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
and blaze a trail of dust,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
and penetrate deep into a host.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Verily man is most ungrateful to his Lord;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
and he himself is a witness to that,\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
and surely he loves riches with a passionate loving.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Is he not aware that when whatever lies (buried) in the graves is overthrown;\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
and the secrets of the hearts are laid bare (and examined)?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
Surely on that Day will their Lord be fully informed about them.\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The Calamity!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the Calamity?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
And what do you know what the Calamity is?\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
On that Day human beings shall be like scattered moths,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
and the mountains shall be like fluffs of carded wool in varying colours.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then he whose scales weigh heavier\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
shall have a blissful life;\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
but he whose scales weigh lighter,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
his shall be the deep pit for a dwelling.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
And what do you know what that is?\qt@no{(10)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
A Blazing Fire!\qt@no{(11)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen The craving for ever-greater worldly gains and to excel others in that regard keeps you occupied\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
until you reach your graves.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
Nay, you will soon come to know;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
nay, again, you shall soon come to know.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
Nay, would that you knew with certainty of knowledge (what your attitude will lead to, you would never have acted the way you do).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
You will surely end up seeing Hell;\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
again, you shall most certainly end up seeing it with absolute certainty.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then, on that Day, you will be called to account for all the bounties you enjoyed.\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By the time!\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Lo! Man is in a state of loss;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
save those who have faith and do righteous deeds, and counsel each other to hold on to truth and counsel each other to be steadfast.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe to every fault-finding backbiter;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
who amasses wealth and counts it over and again.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
He thinks that his wealth will immortalise him forever.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
Nay, he shall be thrown into the Crusher.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
And what do you know what the Crusher is?\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
It is the Fire kindled by Allah,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
the Fire that shall rise to the hearts (of criminals).\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
Verily it will close in upon them,\qt@no{(8)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
in outstretched columns.\qt@no{(9)}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Have you not seen how your Lord dealt with the people of the elephants?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not bring their plan to naught?\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And He sent against them swarms of birds\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
which smote them with stones of baked clay,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
and made them like straw eaten up (by cattle).\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen Since the Quraysh became accustomed,\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
accustomed to the journey of winter and summer,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
therefore, let them worship the Lord of this House;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
Who fed them against hunger, and secured them against fear.\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Did you see him who gives the lie to the Reward and Punishment of the Hereafter?\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
Such is the one who repulses the orphans away,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
and urges not the feeding of the needy.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
Woe, then, to those who pray,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
but are heedless in their Prayers,\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
those who do good (in order) to be seen,\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
and deny people the articles of common necessity.\qt@no{(7)}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen (O Prophet), We have surely bestowed upon you good in abundance.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
So offer Prayer and sacrifice to your Lord alone.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
Verily your enemy alone has been cut off from the roots.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say: “O unbelievers!”\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
I do not worship those that you worship\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
neither do you worship Him Whom I worship;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
nor will I worship those whom you have worshipped;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
nor are you going to worship Him Whom I worship.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
To you is your religion, and to me, my religion.\qt@no{(6)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When the help comes from Allah, and victory (is granted),\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
and you see people entering Allah's religion in multitudes,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
then extol the praise of your Lord and pray to Him for forgiveness. For He indeed is ever disposed to accept repentance.\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen Destroyed were the hands of Abu Lahab, and he lay utterly doomed.\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth did not avail him, nor his acquisitions.\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
Surely, he will be cast into a Flaming Fire\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
along with his wife, that carrier of slanderous tales;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
upon her neck shall be a rope of palm-fibre.\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say: “He is Allah, the One and Unique;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
Allah, Who is in need of none and of Whom all are in need;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
He neither begot any nor was He begotten,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
and none is comparable to Him.”\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say: “I seek refuge with the Lord of the rising day;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
from the evil of all that He created;\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
from the evil of night's darkness when it spreads around;\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
from the evil of the women who blow on knots;\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
and from the evil of the envier when he envies.”\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say: “I seek refuge with the Lord of mankind;\qt@no{(1)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
the King of mankind,\qt@no{(2)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
the True God of mankind,\qt@no{(3)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
from the mischief of the whispering, elusive prompter who returns again and again,\qt@no{(4)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
who whispers in the hearts of people;\qt@no{(5)}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
whether he be from the jinn or humans.”\qt@no{(6)}}%
%% End of file `qurantext-envii.translation.def'
